@@ -23,6 +23,7 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <dirent.h>
+#include <errno.h>
 
 #include <tsys.h>
 #include "base.h"
@@ -100,12 +101,14 @@ void ModMArch::put( vector<TMess::SRec> &mess )
 		if( i_arh == 0 && 
 		    ((m_max_size && arh_s[i_arh]->size() > m_max_size*1024) ||
 		     (mess[i_m].time >= arh_s[i_arh]->begin()+m_time_size*24*60*60)) ) break;
-	      	arh_s[i_arh]->put(mess[i_m]);
+	      	try{ arh_s[i_arh]->put(mess[i_m]); }
+		catch(TError err)
+		{ mess_err(err.cat.c_str(),err.mess.c_str()); continue; }
 		i_arh = -1;
 		break;
 	    }
 	//- If going a new data then create new file -
-	if( i_arh == 0 )
+	if( i_arh >= 0 )
 	{
 	    res.release();
 	    
@@ -288,33 +291,33 @@ void ModMArch::cntrCmdProc( XMLNode *opt )
     else if( a_path == "/prm/st/tarch" && ctrChkNode(opt) ) 	opt->setText(TSYS::real2str(tm_calc,6));
     else if( a_path == "/bs/xml" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(m_use_xml?"1":"0");
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_use_xml = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText( useXML() ? "1" : "0" );
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setUseXML( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/sz" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_max_size));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_max_size = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( maxSize() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setMaxSize( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/fl" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_numb_files));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_numb_files = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( numbFiles() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setNumbFiles( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/len" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_time_size));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_time_size = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( timeSize() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setTimeSize( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/pcktm" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_pack_tm));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_pack_tm = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( packTm() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setPackTm( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/tm" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_chk_tm));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_chk_tm = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( checkTm() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setCheckTm( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/chk_nw" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	checkArchivator(true);
     else TMArchivator::cntrCmdProc(opt);
@@ -351,7 +354,8 @@ MFileArch::MFileArch( const string &iname, time_t ibeg, ModMArch *iowner, const
 	m_node->setAttr("Begin",TSYS::int2str(m_beg,TSYS::Hex));
 	m_node->setAttr("End",TSYS::int2str(m_end,TSYS::Hex));
 	string x_cf = "<?xml version=\"1.0\" encoding=\"UTF-8\" ?>" + m_node->save(XMLNode::BrOpenPrev);
-	write(hd,x_cf.c_str(),x_cf.size());
+	if( write(hd,x_cf.c_str(),x_cf.size()) < 0 )
+	    throw TError(owner().nodePath().c_str(),_("Write to file error: %s"),strerror(errno));
     }
     else
     {
@@ -359,7 +363,8 @@ MFileArch::MFileArch( const string &iname, time_t ibeg, ModMArch *iowner, const
 	char s_buf[STR_BUF_LEN];
 	snprintf(s_buf,sizeof(s_buf),"%s %s %8s %8x %8x\n",
 	    mod->modId().c_str(),mod->modInfo("Version").c_str(),m_chars.c_str(),m_beg,m_end);
-	write(hd,s_buf,strlen(s_buf));
+	if( write(hd,s_buf,strlen(s_buf)) < 0 )
+	    throw TError(owner().nodePath().c_str(),_("Write to file error: %s"),strerror(errno));
     }
     close(hd);    
     m_load = true;
@@ -450,7 +455,7 @@ void MFileArch::attach( const string &iname, bool full )
 		//-- Read full file to buffer --
 		while( r_cnt = fread(buf,1,sizeof(buf),f) )
 		    s_buf.append(buf,r_cnt);
-		fclose(f);
+		fclose(f); f = NULL;		
 	
 		//-- Parse full file --
     		m_node->load(s_buf);
@@ -522,11 +527,11 @@ void MFileArch::attach( const string &iname, bool full )
     }
     catch( TError err )
     { 
-	mess_err(err.cat.c_str(),"%s",err.mess.c_str()); 
+	mess_err(err.cat.c_str(),"%s",err.mess.c_str());
 	if( m_node ) delete m_node;
 	m_node = NULL;
 	m_err = true;
-	fclose(f);
+	if( f )	fclose(f);
     }
 }
 
@@ -537,7 +542,11 @@ void MFileArch::put( TMess::SRec mess )
     if( !m_load )
     {
 	attach( m_name ); 
-	if( m_err || !m_load )	throw TError(owner().nodePath().c_str(),_("Archive file isn't attaching!"));
+	if( m_err || !m_load )
+	{
+	    m_err = true;
+	    throw TError(owner().nodePath().c_str(),_("Archive file '%s' isn't attaching!"),m_name.c_str());
+	}
     }
     
     ResAlloc res(m_res,true);
@@ -586,7 +595,7 @@ void MFileArch::put( TMess::SRec mess )
 	    	Mess->codeConvOut(m_chars,TSYS::strEncode(mess.categ,TSYS::Custom," \n\t%")).c_str(),
 		Mess->codeConvOut(m_chars,TSYS::strEncode(mess.mess,TSYS::Custom," \n\t%")).c_str());
 	    fseek(f,0,SEEK_END);
-	    fwrite(buf,strlen(buf),1,f);	    
+	    fwrite(buf,strlen(buf),1,f);
 	}
 	else
 	{
