@@ -247,7 +247,7 @@ void ModVArch::expArch(const string &arch_nm, time_t beg, time_t end, const stri
 	    SYS->archive().at().valAt(arch_nm).at().getVal(buf,c_tm,end_tm,workId());
 	
 	    //-- Check scale --
-	    for(;c_tm <= buf.end();c_tm++)
+	    for( ; c_tm <= buf.end(); c_tm+=buf_per )
 	    {
 		c_val = buf.getR(&c_tm,true);
 		if(c_val == EVAL_REAL)	continue;
@@ -267,7 +267,7 @@ void ModVArch::expArch(const string &arch_nm, time_t beg, time_t end, const stri
 	    end_tm = vmin(end_tm,(long long)end*1000000);
 	    SYS->archive().at().valAt(arch_nm).at().getVal(buf,c_tm,end_tm,workId());	
 	
-	    for(;c_tm <= buf.end();c_tm++, val_cnt++)
+	    for( ; c_tm <= buf.end(); c_tm+=buf_per, val_cnt++ )
 	    {
 		c_val = buf.getR(&c_tm,true);
 		if(c_val == EVAL_REAL)	c_val = v_over;
@@ -295,9 +295,8 @@ void ModVArch::expArch(const string &arch_nm, time_t beg, time_t end, const stri
 	{
 	    long long end_tm = c_tm+buf_sz*buf_per;
 	    end_tm = vmin(end_tm,(long long)end*1000000);
-	    SYS->archive().at().valAt(arch_nm).at().getVal(buf,c_tm,end_tm,workId());	
-	
-    	    for(; c_tm <= buf.end(); c_tm++ )
+	    SYS->archive().at().valAt(arch_nm).at().getVal(buf,c_tm,end_tm,workId());
+    	    for(; c_tm <= buf.end(); c_tm+=buf_per )
 	    {
 		sprintf(c_val,"%g\n",buf.getR(&c_tm,true));
 		write(hd,c_val,strlen(c_val));
@@ -345,28 +344,28 @@ void ModVArch::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/bs/tm" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::real2str(time_size,6));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	time_size = atof(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::real2str( fileTimeSize(), 6 ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setFileTimeSize( atof(opt->text().c_str()) );
     }	
     else if( a_path == "/bs/fn" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(numb_files));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	numb_files = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( fileNumber() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setFileNumber( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/round" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::real2str(round_proc,6));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	round_proc = atof(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::real2str( roundProc(), 6 ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setRoundProc( atof(opt->text().c_str()) );
     }
     else if( a_path == "/bs/pcktm" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_pack_tm));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_pack_tm = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( packTm() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setPackTm( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/tmout" )	
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str(m_chk_tm));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_chk_tm = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(TSYS::int2str( checkTm() ));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setCheckTm( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/arch/arch" && ctrChkNode(opt) )
     {
