@@ -33,7 +33,7 @@
 #define MOD_NAME    "DB FireBird"
 #define MOD_TYPE    "BD"
 #define VER_TYPE    VER_BD
-#define VERSION     "0.6.0"
+#define VERSION     "0.7.0"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "DB modul. Allow support of the DB FireBird."
 #define LICENSE     "GPL"
@@ -99,7 +99,7 @@ string BDMod::optDescr( )
     return buf;
 }			
 
-void BDMod::modLoad( )
+void BDMod::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -136,7 +136,7 @@ string BDMod::sqlReqCode( const string &req, char symb )
 //************************************************
 //* FireBird::MBD                                *
 //************************************************
-MBD::MBD( const string &iid, TElem *cf_el ) : TBD(iid,cf_el), hdb(NULL)//, commCnt(0)
+MBD::MBD( const string &iid, TElem *cf_el ) : TBD(iid,cf_el), hdb(0)
 {
 
 }
@@ -160,7 +160,7 @@ void MBD::postDisable(int flag)
 	isc_modify_dpb(&dpb, &dpb_length, isc_dpb_password, pass.c_str(),pass.size());    
 	
 	ISC_STATUS_ARRAY status;
-	isc_tr_handle	trans = NULL;	
+	isc_tr_handle	trans = 0;	
 	if( isc_attach_database( status, 0, fdb.c_str(), &hdb, dpb_length, dpb) ) return;
 	if( isc_drop_database(status, &hdb) ) 
 	    throw TError(TSYS::DBOpen,nodePath().c_str(),_("Drop DB '%s' error: %s"),fdb.c_str(),getErr(status).c_str());
@@ -187,10 +187,8 @@ void MBD::enable( )
     ISC_STATUS_ARRAY status;
     if( isc_attach_database( status, 0, fdb.c_str(), &hdb, dpb_length, dpb) )
     {
-	if( !create() ) 
-	    throw TError(TSYS::DBOpen,nodePath().c_str(),_("Open DB '%s' error: %s"),fdb.c_str(),getErr(status).c_str());
 	//--- Make try for create DB ---
-	isc_tr_handle	trans = NULL;
+	isc_tr_handle	trans = 0;
 	if( isc_dsql_execute_immediate(status, &hdb, &trans, 0, 
 		    ("CREATE DATABASE '"+fdb+"' USER '"+user+"' PASSWORD '"+pass+"'").c_str(), 3, NULL) )
 	    throw TError(TSYS::DBOpen,nodePath().c_str(),_("Create DB '%s' error: %s"),fdb.c_str(),getErr(status).c_str());
@@ -208,6 +206,7 @@ void MBD::disable( )
     ResAlloc res(conn_res,true);
     ISC_STATUS_ARRAY status;
     isc_detach_database( status, &hdb );
+    hdb = 0;
 }	
 
 void MBD::allowList( vector<string> &list )
@@ -242,7 +241,33 @@ string MBD::getErr( ISC_STATUS_ARRAY status )
     return err;
 }
 
+void MBD::transOpen( isc_tr_handle *trans )
+{
+    ISC_STATUS_ARRAY status;
+    
+    ResAlloc res(conn_res,true);
+    if( !trans || *trans )	return;
+    if( isc_start_transaction(status, trans, 1, &hdb, 0, NULL) )
+        throw TError(TSYS::DBRequest,nodePath().c_str(),_("Start trasaction error: %s"),getErr(status).c_str());
+}
+
+void MBD::transCommit( isc_tr_handle *trans )
+{
+    ISC_STATUS_ARRAY status;
+    
+    ResAlloc res(conn_res,true);
+    if( !trans || !(*trans) )	return;
+    if( isc_commit_transaction(status, trans) )
+	throw TError(TSYS::DBRequest,nodePath().c_str(),_("DSQL close transaction error: %s"),getErr(status).c_str());
+    *trans = 0;
+}
+
 void MBD::sqlReq( const string &ireq, vector< vector<string> > *tbl )
+{
+    sqlReq(NULL,ireq,tbl);
+}
+
+void MBD::sqlReq( isc_tr_handle *itrans, const string &ireq, vector< vector<string> > *tbl )
 {    
     if( tbl ) tbl->clear();
     if(!enableStat())	return; 
@@ -256,16 +281,16 @@ void MBD::sqlReq( const string &ireq, vector< vector<string> > *tbl )
     out_sqlda->sqln = 10;
     char    *dtBuf = NULL;
     int      dtBufLen = 0;
+    isc_stmt_handle stmt = 0;
+    isc_tr_handle trans = (itrans && *itrans) ? (*itrans) : 0;
+    ISC_STATUS_ARRAY status;       
 
     try
     {
     	//- Prepare statement -
-    	ISC_STATUS_ARRAY status;
-    	isc_stmt_handle stmt = NULL;
-    	isc_tr_handle trans = NULL;
     	if( isc_dsql_allocate_statement(status, &hdb, &stmt) )
     	    throw TError(TSYS::DBRequest,nodePath().c_str(),_("Allocate statement error: %s"),getErr(status).c_str());
-    	if( isc_start_transaction(status, &trans, 1, &hdb, 0, NULL) )
+    	if( !trans && isc_start_transaction(status, &trans, 1, &hdb, 0, NULL) )
     	    throw TError(TSYS::DBRequest,nodePath().c_str(),_("Start trasaction error: %s"),getErr(status).c_str());
     	//- Prepare output data structure -
     	if( isc_dsql_prepare(status, &trans, &stmt, 0, Mess->codeConvOut(cd_pg.c_str(),ireq).c_str(), 3, NULL) )
@@ -305,10 +330,7 @@ void MBD::sqlReq( const string &ireq, vector< vector<string> > *tbl )
 	
     	//-- Get data --
     	if( isc_dsql_execute(status, &trans, &stmt, 1, NULL) )
-	{
-	    mess_debug(_("Execution of message <%s> is error."),ireq.c_str());
     	    throw TError(TSYS::DBRequest,nodePath().c_str(),_("DSQL execute error: %s"),getErr(status).c_str());
-	}
 	if( tbl && out_sqlda->sqld )
 	{
 	    //if( isc_dsql_set_cursor_name(status, &stmt,"dyn_cursor", 0) )
@@ -360,7 +382,7 @@ void MBD::sqlReq( const string &ireq, vector< vector<string> > *tbl )
 			    //- Read blob data -
 			    ISC_QUAD blob_id = *((ISC_QUAD*)var.sqldata);
 			    ISC_STATUS blob_stat;
-			    isc_blob_handle blob_handle = NULL;
+			    isc_blob_handle blob_handle = 0;
 			    char blob_segment[STR_BUF_LEN];
 			    unsigned short actual_seg_len;			    
 			    string bval;
@@ -383,11 +405,19 @@ void MBD::sqlReq( const string &ireq, vector< vector<string> > *tbl )
 	    }	    
 	}
     	if( isc_dsql_free_statement(status, &stmt, DSQL_drop) )
+	{
+	    stmt = 0;
     	    throw TError(TSYS::DBRequest,nodePath().c_str(),_("DSQL free statement error: %s"),getErr(status).c_str());
-    	if( isc_commit_transaction(status, &trans) )
+	}
+    	if( (!itrans || !(*itrans)) && isc_commit_transaction(status, &trans) )
+	{
+	    stmt = trans = 0;
     	    throw TError(TSYS::DBRequest,nodePath().c_str(),_("DSQL close transaction error: %s"),getErr(status).c_str());
+	}
     }catch(...)
     {
+	if( stmt ) isc_dsql_free_statement(status, &stmt, DSQL_drop);
+	if( trans && (!itrans || !(*itrans)) )	isc_commit_transaction(status, &trans);
 	free(out_sqlda);
 	if(dtBuf) free(dtBuf);
 	throw;
@@ -407,7 +437,7 @@ string MBD::clrEndSpace( const string &vl )
 //************************************************
 //* FireBird::Table                              *
 //************************************************
-MTable::MTable(string inm, MBD *iown, bool create ) : TTable(inm)
+MTable::MTable(string inm, MBD *iown, bool create ) : TTable(inm), trans(0)
 {
     setNodePrev(iown);    
     
@@ -431,10 +461,12 @@ MTable::~MTable(  )
 }
 
 void MTable::postDisable(int flag)
-{
+{    
+    owner().transCommit(&trans);
     if( flag )
     {	
-	try{ owner().sqlReq("DROP TABLE \""+mod->sqlReqCode(name(),'"')+"\""); }
+	try
+	{ owner().sqlReq("DROP TABLE \""+mod->sqlReqCode(name(),'"')+"\""); }
 	catch(TError err) { mess_err(err.cat.c_str(),"%s",err.mess.c_str()); }
     }
 }
@@ -442,6 +474,7 @@ void MTable::postDisable(int flag)
 void MTable::getStructDB( vector< vector<string> > &tblStrct )
 {
     //- Get generic data structure -
+    owner().transCommit(&trans);
     owner().sqlReq("SELECT R.RDB$FIELD_NAME, F.RDB$FIELD_TYPE, F.RDB$FIELD_LENGTH "
 	"FROM RDB$FIELDS F, RDB$RELATION_FIELDS R where F.RDB$FIELD_NAME = R.RDB$FIELD_SOURCE and "
 	"R.RDB$SYSTEM_FLAG = 0 and R.RDB$RELATION_NAME = '"+mod->sqlReqCode(name())+"'",&tblStrct);
@@ -449,7 +482,7 @@ void MTable::getStructDB( vector< vector<string> > &tblStrct )
     {
 	//- Get keys -
 	vector< vector<string> > keyLst;
-	owner().sqlReq("SELECT I.RDB$FIELD_NAME, C.RDB$CONSTRAINT_TYPE "
+	owner().sqlReq(&trans,"SELECT I.RDB$FIELD_NAME, C.RDB$CONSTRAINT_TYPE "
 	    "FROM RDB$RELATION_CONSTRAINTS C, RDB$INDEX_SEGMENTS I "
 	    "WHERE C.RDB$INDEX_NAME = I.RDB$INDEX_NAME AND C.RDB$RELATION_NAME = '"+
 	    mod->sqlReqCode(name())+"'",&keyLst);
@@ -492,7 +525,8 @@ bool MTable::fieldSeek( int row, TConfig &cfg )
     vector< vector<string> > tbl;
     
     if( tblStrct.empty() ) throw TError(TSYS::DBTableEmpty,nodePath().c_str(),_("Table is empty."));
-    
+
+    owner().transCommit(&trans);
     //- Make WHERE -
     string req = "SELECT FIRST 1 SKIP "+TSYS::int2str(row)+" ";
     string req_where = "WHERE ";
@@ -546,6 +580,7 @@ void MTable::fieldGet( TConfig &cfg )
     
     if( tblStrct.empty() ) throw TError(TSYS::DBTableEmpty,nodePath().c_str(),_("Table is empty."));
 
+    owner().transCommit(&trans);
     //- Prepare request -
     string req = "SELECT ";
     string req_where;
@@ -596,7 +631,8 @@ void MTable::fieldSet( TConfig &cfg )
     vector< vector<string> > tbl;
         
     if( tblStrct.empty() ) fieldFix(cfg);
-    
+
+    owner().transOpen(&trans);
     //- Get config fields list -
     vector<string> cf_el;
     cfg.cfgList(cf_el);    
@@ -615,50 +651,45 @@ void MTable::fieldSet( TConfig &cfg )
     }    
     
     //- Prepare query -
-    string req = "SELECT 1 FROM \""+mod->sqlReqCode(name(),'"')+"\" "+req_where;
-    try{ owner().sqlReq( req, &tbl ); }
-    catch(TError err)	{ fieldFix(cfg); owner().sqlReq( req ); }
-    if( tbl.size() < 2 )
+    //-- Add new record --
+    string reqi = "INSERT INTO \""+mod->sqlReqCode(name(),'"')+"\" ";
+    string ins_name, ins_value;
+    next = false;
+    for( int i_el = 0; i_el < cf_el.size(); i_el++ )
     {
-	//-- Add new record --
-	req = "INSERT INTO \""+mod->sqlReqCode(name(),'"')+"\" ";
-	string ins_name, ins_value;
-	next = false;
-        for( int i_el = 0; i_el < cf_el.size(); i_el++ )
-        {
-            TCfg &u_cfg = cfg.cfg(cf_el[i_el]);
-	    if(	!(u_cfg.fld().flg()&TCfg::Key) && !u_cfg.view() ) continue;
+	TCfg &u_cfg = cfg.cfg(cf_el[i_el]);
+	if( !(u_cfg.fld().flg()&TCfg::Key) && !u_cfg.view() ) continue;
 
-	    if( !next ) next = true; 
-	    else 
-	    {
-		ins_name=ins_name+",";
-		ins_value=ins_value+",";
-	    }
-	    ins_name=ins_name+"\""+mod->sqlReqCode(cf_el[i_el],'"')+"\" ";		    
-	    string val;
-	    switch(u_cfg.fld().type())
-	    {
-		case TFld::String:	val = u_cfg.getS();			break;
-		case TFld::Integer:	val = SYS->int2str(u_cfg.getI());	break;
-		case TFld::Real:	val = SYS->real2str(u_cfg.getR());	break;
-		case TFld::Boolean:	val = SYS->int2str(u_cfg.getB());	break;
-	    }
-	    ins_value=ins_value+"'"+mod->sqlReqCode(val)+"' ";
+	if( !next ) next = true; 
+	else 
+	{
+	    ins_name=ins_name+",";
+	    ins_value=ins_value+",";
 	}
-      	req = req + "("+ins_name+") VALUES ("+ins_value+")";
+	ins_name=ins_name+"\""+mod->sqlReqCode(cf_el[i_el],'"')+"\" ";		    
+	string val;
+	switch(u_cfg.fld().type())
+	{
+	    case TFld::String:	val = u_cfg.getS();			break;
+	    case TFld::Integer:	val = SYS->int2str(u_cfg.getI());	break;
+	    case TFld::Real:	val = SYS->real2str(u_cfg.getR());	break;
+	    case TFld::Boolean:	val = SYS->int2str(u_cfg.getB());	break;
+	}
+	ins_value=ins_value+"'"+mod->sqlReqCode(val)+"' ";
     }
-    else
+    reqi = reqi + "("+ins_name+") VALUES ("+ins_value+")";
+    try{ owner().sqlReq( &trans, reqi ); }
+    catch(TError err)
     {
 	//-- Update present record --
-	req = "UPDATE \""+mod->sqlReqCode(name(),'"')+"\" SET ";
+	string requ = "UPDATE \""+mod->sqlReqCode(name(),'"')+"\" SET ";
 	next = false;
 	for( int i_el = 0; i_el < cf_el.size(); i_el++ )
         {
             TCfg &u_cfg = cfg.cfg(cf_el[i_el]);
 	    if( u_cfg.fld().flg()&TCfg::Key || !u_cfg.view() ) continue;
 			     
-	    if( !next ) next = true; else req=req+",";
+	    if( !next ) next = true; else requ=requ+",";
 	    string val;
 	    switch(u_cfg.fld().type())
 	    {
@@ -667,22 +698,24 @@ void MTable::fieldSet( TConfig &cfg )
 		case TFld::Real:	val = SYS->real2str(u_cfg.getR());	break;
 		case TFld::Boolean:	val = SYS->int2str(u_cfg.getB());	break;
 	    }
-	    req=req+"\""+mod->sqlReqCode(cf_el[i_el],'"')+"\"='"+mod->sqlReqCode(val)+"' ";
+	    requ=requ+"\""+mod->sqlReqCode(cf_el[i_el],'"')+"\"='"+mod->sqlReqCode(val)+"' ";
+	}
+    	requ = requ + req_where;
+    	try{ owner().sqlReq( &trans, requ ); }
+    	catch( TError err )	
+	{ 
+	    fieldFix(cfg);
+	    try{ owner().sqlReq( &trans, reqi ); }
+	    catch(TError err)	{ owner().sqlReq( &trans, requ ); }
 	}
-    	req = req + req_where;
     }
-    
-    //- Query -
-    //printf("TEST 02: query: <%s>\n",req.c_str());
-    try{ owner().sqlReq( req ); }
-    catch(TError err)	{ fieldFix(cfg); owner().sqlReq( req ); }
-    //printf("TEST 01b: End from set\n");
 }
 
 void MTable::fieldDel( TConfig &cfg )
 {
     if( tblStrct.empty() ) throw TError(TSYS::DBTableEmpty,nodePath().c_str(),_("Table is empty."));
 
+    owner().transOpen(&trans);
     //- Get config fields list -
     vector<string> cf_el;
     cfg.cfgList(cf_el);    
@@ -701,12 +734,14 @@ void MTable::fieldDel( TConfig &cfg )
 		         mod->sqlReqCode(u_cfg.getS())+"' ";
 	}
     }
-    owner().sqlReq( req );
+    owner().sqlReq( &trans, req );
 }
 
 void MTable::fieldFix( TConfig &cfg )
 {
     bool next = false, next_key = false;
+
+    owner().transCommit(&trans);	
     
     //- Get config fields list -
     vector<string> cf_el;
@@ -784,4 +819,6 @@ void MTable::fieldFix( TConfig &cfg )
         owner().sqlReq( req );
 	getStructDB( tblStrct );
     }
+
+    owner().transOpen(&trans);
 }    
