@@ -35,7 +35,7 @@
 #define MOD_NAME    "DB MySQL"
 #define MOD_TYPE    "BD"
 #define VER_TYPE    VER_BD
-#define VERSION     "1.3.0"
+#define VERSION     "1.3.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "BD modul. Allow support of the BD MySQL."
 #define MOD_LICENSE "GPL"
@@ -100,7 +100,7 @@ string BDMod::optDescr( )
     return buf;
 }			
 
-void BDMod::modLoad( )
+void BDMod::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -177,13 +177,8 @@ void MBD::enable( )
 
     TBD::enable( );
 
-    if( create() )
-    {
-        string req = "CREATE DATABASE IF NOT EXISTS `"+TSYS::strEncode(bd,TSYS::SQL)+"`";
-	sqlReq(req);	
-    }
-    
-    //sqlReq("USE `"+TSYS::strEncode(bd,TSYS::SQL)+"`");
+    string req = "CREATE DATABASE IF NOT EXISTS `"+TSYS::strEncode(bd,TSYS::SQL)+"`";
+    sqlReq(req);	
 }
 
 void MBD::disable( )
@@ -596,18 +591,17 @@ void MTable::fieldFix( TConfig &cfg )
 	    string f_tp;
 	    switch(u_cfg.fld().type())
 	    {
-    		case TFld::String:
-		    if( u_cfg.fld().len() < 256 )
-			f_tp = "varchar("+TSYS::int2str(u_cfg.fld().len())+")";
+		    if( u_cfg.fld().len() < 256 || u_cfg.fld().flg()&TCfg::Key )
+			f_tp = "varchar("+TSYS::int2str(vmax(1,vmin((u_cfg.fld().flg()&TCfg::Key)?150:255,u_cfg.fld().len())))+")";
 		    else if( u_cfg.fld().len() < 65536 )
 			f_tp = "text";
 		    else f_tp = "mediumtext";
 		    break;
 		case TFld::Integer:
-		    f_tp = "int("+TSYS::int2str(u_cfg.fld().len())+")";     
+		    f_tp = "int("+TSYS::int2str(vmax(1,u_cfg.fld().len()))+")";     
 		    break;
 		case TFld::Real:
-		    f_tp = "double("+TSYS::int2str(u_cfg.fld().len())+","+TSYS::int2str(u_cfg.fld().dec())+")";
+		    f_tp = "double("+TSYS::int2str(vmax(3,u_cfg.fld().len()))+","+TSYS::int2str(vmax(2,u_cfg.fld().dec()))+")";
 		    break;
 		case TFld::Boolean:
  		    f_tp = "tinyint(1)";
@@ -651,20 +645,20 @@ void MTable::fieldPrmSet( TCfg &cfg, const string &last, string &req )
     switch(cfg.fld().type())
     {
 	case TFld::String:
-	    if( cfg.fld().len() < 256 )
-		req=req+"varchar("+SYS->int2str(cfg.fld().len())+") NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
+	    if( cfg.fld().len() < 256 || cfg.fld().flg()&TCfg::Key )
+		req=req+"varchar("+SYS->int2str(vmax(1,vmin((cfg.fld().flg()&TCfg::Key)?150:255,cfg.fld().len())))+") NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
 	    else if( cfg.fld().len() < 65536 ) 
-		req=req+"text NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
-	    else req=req+"mediumtext NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
+		req=req+"text NOT NULL ";// DEFAULT '"+cfg.fld().def()+"' ";
+	    else req=req+"mediumtext NOT NULL ";// DEFAULT '"+cfg.fld().def()+"' ";
 	    break;
 	case TFld::Integer:
-	    req=req+"int("+SYS->int2str(cfg.fld().len())+") NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
+	    req=req+"int("+SYS->int2str(vmax(1,cfg.fld().len()))+") NOT NULL DEFAULT '"+TSYS::int2str(atoi(cfg.fld().def().c_str()))+"' ";
 	    break;
 	case TFld::Real:
-	    req=req+"double("+SYS->int2str(cfg.fld().len())+","+SYS->int2str(cfg.fld().dec())+") NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
+	    req=req+"double("+SYS->int2str(vmax(3,cfg.fld().len()))+","+SYS->int2str(vmax(2,cfg.fld().dec()))+") NOT NULL DEFAULT '"+TSYS::real2str(atof(cfg.fld().def().c_str()))+"' ";
 	    break;
 	case TFld::Boolean:
-	    req=req+"tinyint(1) NOT NULL DEFAULT '"+cfg.fld().def()+"' ";
+	    req=req+"tinyint(1) NOT NULL DEFAULT '"+TSYS::int2str(atoi(cfg.fld().def().c_str()))+"' ";
 	    break;
     }
     //- Position param -
