@@ -30,8 +30,6 @@
 #undef _
 #define _(mess) mod->I18N(mess)
 
-#define COM_MAX_CNT 100
-
 using std::string;
 using std::vector;
 
@@ -46,7 +44,7 @@ class MTable : public TTable
 {
     public:
 	//Public methods
-	MTable(string name, MBD *bd, bool create);
+	MTable( string name, MBD *bd, bool create );
 	~MTable(  );
 
 	//- Field's operations -
@@ -94,10 +92,11 @@ class MBD : public TBD
 	TTable *openTable( const string &name, bool create );
 	
 	//Private attributes
-	string      cd_pg;
-	sqlite3     *m_db;	    
-	int        	commCnt;
-	Res		conn_res;
+	string	cd_pg;
+	sqlite3	*m_db;	    
+	int	commCnt;
+	Res	conn_res;
+	int 	trans_reqs;
 };
 
 
@@ -110,11 +109,13 @@ class BDMod: public TTipBD
 	//Public methods
 	BDMod( string name );
 	~BDMod();
-	
-	void modLoad( );
 	    
 	static string sqlReqCode( const string &req, char symb = '\'' );
-	    
+
+    protected:
+	//Methods
+	void load_( );	
+
     private:
 	//Private methods
 	TBD *openBD( const string &iid );
