@@ -44,7 +44,7 @@
 #define MOD_NAME    "Block based calculator"
 #define MOD_TYPE    "DAQ"
 #define VER_TYPE    VER_CNTR
-#define VERSION     "1.0.0"
+#define VERSION     "1.0.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Allow block based calculator."
 #define LICENSE     "GPL"
@@ -103,7 +103,7 @@ string TipContr::optDescr( )
     return(buf);
 }
 
-void TipContr::modLoad()
+void TipContr::load_()
 {
     //========== Load parameters from command line ============
     int next_opt;
@@ -137,13 +137,11 @@ void TipContr::postEnable( int flag )
     fldAdd( new TFld("BLOCK_SH",_("Block's table"),TFld::String,TFld::NoFlag,"30","block") );	
     fldAdd( new TFld("PERIOD",_("Calc period (ms)"),TFld::Integer,TFld::NoFlag,"5","1000","0;10000") );
     fldAdd( new TFld("PRIOR",_("Calc task priority"),TFld::Integer,TFld::NoFlag,"2","0","0;100") );
-    fldAdd( new TFld("PER_DB",_("Sync db period (s)"),TFld::Integer,TCfg::Prevent,"5","0","0;3600") );
     fldAdd( new TFld("ITER",_("Iteration number into calc period"),TFld::Integer,TFld::NoFlag,"2","1","0;99") );
     
     //Add parameter types
     int t_prm = tpParmAdd("std","PRM_BD",_("Standard"));
-    tpPrmAt(t_prm).fldAdd( new TFld("BLK",_("Block"),TFld::String,TCfg::NoVal,"10") );
-    tpPrmAt(t_prm).fldAdd( new TFld("IO",_("IOs(Sep - ';')"),TFld::String,TCfg::NoVal,"50") );
+    tpPrmAt(t_prm).fldAdd( new TFld("IO",_("Blocks' IOs"),TFld::String,TFld::FullText|TCfg::NoVal,"200") );
     
     //Blok's db structure
     blk_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"10") );
@@ -178,96 +176,18 @@ TController *TipContr::ContrAttach( const string &name, const string &daq_db )
     return new Contr(name,daq_db,this);
 }
 
-void TipContr::loadBD()
-{
-    
-}
-
-void TipContr::saveBD()
-{
-
-}
-
-void TipContr::copy( const string &src, const string &dst )
-{
-    string s_el = TSYS::strSepParse(src,1,'.');
-    string d_el = TSYS::strSepParse(dst,1,'.');
-    string t_el;
-    vector<string>  el_ls, tmp_ls;
-    //- Check parameters -
-    //if( !s_el.empty() && d_el.empty() ) d_el = s_el;
-    if( !s_el.empty() && !d_el.empty() && ( s_el.size() <= 4 || d_el.size() <= 4 ||
-	    (s_el.substr(0,4) != "prm_" && s_el.substr(0,4) != "blk_") || 
-	    s_el.substr(0,4) != d_el.substr(0,4) ) )
-        throw TError(nodePath().c_str(),_("Parameters record error."));	
-
-    //- Connect to source and destination DB -
-    AutoHD<Contr> s_cntr = at(TSYS::strSepParse(src,0,'.'));
-    AutoHD<Contr> d_cntr = at(TSYS::strSepParse(dst,0,'.'));
-    //- Controllers list prepare -
-    if( s_el.empty() || s_el == "blk_*" )
-    {
-	s_cntr.at().blkList(tmp_ls);
-	for( int i_el = 0; i_el < tmp_ls.size(); i_el++ )
-	    el_ls.push_back("blk_"+tmp_ls[i_el]);
-    }
-    if( s_el.empty() || s_el == "prm_*" )
-    {
-	s_cntr.at().list(tmp_ls);
-	for( int i_el = 0; i_el < tmp_ls.size(); i_el++ )
-	    el_ls.push_back("prm_"+tmp_ls[i_el]);
-    }
-    if( el_ls.empty() ) el_ls.push_back(s_el);
-    if( el_ls.size() > 1 && !d_el.empty() )
-        throw TError(nodePath().c_str(),_("Copy several elements to one element not allow."));
-    //- Controllers list process -
-    for( int i_l = 0; i_l < el_ls.size(); i_l++ )
-    {
-	s_el = el_ls[i_l].substr(4);
-	t_el = d_el.empty()?s_el:d_el.substr(4);
-	if( el_ls[i_l].substr(0,4) == "blk_" )
-	{
-	    if( !d_cntr.at().blkPresent(t_el) )	d_cntr.at().blkAdd(t_el);
-	    d_cntr.at().blkAt(t_el).at() = s_cntr.at().blkAt(s_el).at();
-	}
-	else if( el_ls[i_l].substr(0,4) == "prm_" )
-	{
-	    if( !d_cntr.at().present(t_el) )	d_cntr.at().add(t_el,tpPrmToId("std"));
-	    d_cntr.at().at(t_el).at() = s_cntr.at().at(s_el).at();
-	}
-    }
-} 
-
 void TipContr::cntrCmdProc( XMLNode *opt )
 {
     //Get page info
     if( opt->name() == "info" )
     {
         TTipDAQ::cntrCmdProc(opt);
-	if( ctrMkNode("area",opt,1,"/copy",_("Copy")) && 
-		ctrMkNode("comm",opt,-1,"/copy/copy",_("Copy controller/block/parameter"),0660) )
-	{
-	    ctrMkNode("fld",opt,-1,"/copy/copy/src",_("Source"),0660,"root","root",3,"tp","str","dest","sel_ed","select","/copy/cntrls");
-    	    ctrMkNode("fld",opt,-1,"/copy/copy/dst",_("Destination"),0660,"root","root",3,"tp","str","dest","sel_ed","select","/copy/cntrls");
-	}		
 	ctrMkNode("fld",opt,-1,"/help/g_help",_("Options help"),0440,"root","root",3,"tp","str","cols","90","rows","5");
     }
+    
     //Process command to page
     string a_path = opt->attr("path");
-    if( a_path == "/copy/copy" && ctrChkNode(opt,"set",0440) )
-	copy(ctrId(opt,"src")->text(),ctrId(opt,"dst")->text());
-    else if( a_path == "/copy/cntrls" && ctrChkNode(opt) )
-    {
-	vector<string> lst;
-        list(lst);
-    	for( unsigned i_a=0; i_a < lst.size(); i_a++ )
-	{
-            opt->childAdd("el")->setText(lst[i_a]);
-            opt->childAdd("el")->setText(lst[i_a]+".prm_*");
-            opt->childAdd("el")->setText(lst[i_a]+".blk_*");
-	}
-    }    
-    else if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440) ) opt->setText(optDescr());
+    if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440) ) opt->setText(optDescr());
     else TTipDAQ::cntrCmdProc(opt);
 }
 
@@ -276,24 +196,41 @@ void TipContr::cntrCmdProc( XMLNode *opt )
 //************************************************ 
 Contr::Contr( string name_c, const string &daq_db, ::TElem *cfgelem) :
     ::TController(name_c, daq_db, cfgelem), prc_st(false), endrun_req(false), sync_st(false), tm_calc(0.0),
-    m_per(cfg("PERIOD").getId()), m_prior(cfg("PRIOR").getId()), m_iter(cfg("ITER").getId()), m_dbper(cfg("PER_DB").getId())
+    m_per(cfg("PERIOD").getId()), m_prior(cfg("PRIOR").getId()), m_iter(cfg("ITER").getId())
 {
     cfg("PRM_BD").setS("BlckCalcPrm_"+name_c);
     cfg("BLOCK_SH").setS("BlckCalcBlcks_"+name_c);
     m_bl = grpAdd("blk_");
-    
-    //Create sync DB timer
-    struct sigevent sigev;
-    sigev.sigev_notify = SIGEV_THREAD;
-    sigev.sigev_value.sival_ptr = this;
-    sigev.sigev_notify_function = TaskDBSync;
-    sigev.sigev_notify_attributes = NULL;
-    timer_create(CLOCK_REALTIME,&sigev,&sncDBTm);			    
 }
 
 Contr::~Contr()
 {
-    timer_delete(sncDBTm);
+
+}
+
+TCntrNode &Contr::operator=( TCntrNode &node )
+{
+    TController::operator=(node);
+
+    Contr *src_n = dynamic_cast<Contr*>(&node);
+    if( !src_n ) return *this;
+
+    //- Blocks copy -
+    if( src_n->enableStat( ) )
+    {
+        if( !enableStat( ) )    enable();
+    
+	//-- Blocks copy --
+	vector<string> ls;
+	src_n->blkList(ls);    
+	for( int i_l = 0; i_l < ls.size(); i_l++ )
+	{
+	    if( !blkPresent(ls[i_l]) ) blkAdd(ls[i_l]);
+    	    (TCntrNode&)blkAt(ls[i_l]).at() = (TCntrNode&)src_n->blkAt(ls[i_l]).at();
+	}        
+    }
+    
+    return *this;
 }
 
 void Contr::postDisable(int flag)
@@ -318,18 +255,27 @@ void Contr::postDisable(int flag)
     TController::postDisable(flag);
 }
 
-void Contr::load( )
+void Contr::load_( )
 {
-    TController::load( );
+    TController::load_( );
+
+    //- Load block's configuration -
+    TConfig c_el(&mod->blockE());
+    c_el.cfgViewAll(false);	    
+    string bd = DB()+"."+cfg("BLOCK_SH").getS();
     
-    loadV();
-}
-
-void Contr::save( )
-{
-    TController::save();
-
-    saveV();
+    int fld_cnt = 0;
+    while( SYS->db().at().dataSeek(bd,mod->nodePath()+cfg("BLOCK_SH").getS(),fld_cnt++,c_el) )
+    {
+        string id = c_el.cfg("ID").getS();
+        if( !chldPresent(m_bl,id) )
+        {
+            blkAdd(id);
+            ((TConfig &)blkAt(id).at()) = c_el;
+        }
+	blkAt(id).at().load();
+	c_el.cfg("ID").setS("");
+    }
 }
 
 void Contr::enable_( )
@@ -364,7 +310,7 @@ void Contr::disable_( )
 
 void Contr::start_( )
 {   
-    //Make process all bloks
+    //- Make process all bloks -
     vector<string> lst;
     blkList(lst);
     for( int i_l = 0; i_l < lst.size(); i_l++ )
@@ -376,7 +322,7 @@ void Contr::start_( )
 	    mess_warning(nodePath().c_str(),_("Process block <%s> error."),lst[i_l].c_str());
 	}
     
-    //Start the request and calc data task
+    //- Start the request and calc data task -
     if( !prc_st )
     {
 	pthread_attr_t pthr_attr;
@@ -393,17 +339,11 @@ void Contr::start_( )
         if( TSYS::eventWait(prc_st, true, nodePath()+"start",5) )
             throw TError(nodePath().c_str(),_("Acquisition task no started!"));
     }	    
-
-    //Start interval timer for periodic thread creating of DB syncing
-    struct itimerspec itval;
-    itval.it_interval.tv_sec = itval.it_value.tv_sec = m_dbper;
-    itval.it_interval.tv_nsec = itval.it_value.tv_nsec = 0;
-    timer_settime(sncDBTm, 0, &itval, NULL);
 }
 
 void Contr::stop_( )
 {  
-    //Stop the request and calc data task
+    //- Stop the request and calc data task -
     if( prc_st )
     {
 	endrun_req = true;
@@ -413,15 +353,7 @@ void Contr::stop_( )
         pthread_join( calcPthr, NULL );
     }
 
-    //Stop interval timer for periodic thread creating
-    struct itimerspec itval;
-    itval.it_interval.tv_sec = itval.it_interval.tv_nsec =
-	itval.it_value.tv_sec = itval.it_value.tv_nsec = 0;
-    timer_settime(sncDBTm, 0, &itval, NULL);
-    if( TSYS::eventWait( sync_st, false, nodePath()+"sync_stop",5) )
-        throw TError(nodePath().c_str(),_("Controller sync DB no stoped!"));
-	
-    //Make deprocess all blocks
+    //- Make deprocess all blocks -
     vector<string> lst;
     blkList(lst);
     for( int i_l = 0; i_l < lst.size(); i_l++ )
@@ -429,50 +361,6 @@ void Contr::stop_( )
     	    blkAt(lst[i_l]).at().setProcess(false);
 } 
 
-void Contr::loadV( )
-{
-    TConfig c_el(&mod->blockE());
-    c_el.cfgViewAll(false);	    
-    string bd = DB()+"."+cfg("BLOCK_SH").getS();
-    
-    int fld_cnt = 0;
-    while( SYS->db().at().dataSeek(bd,mod->nodePath()+cfg("BLOCK_SH").getS(),fld_cnt++,c_el) )
-    {
-        string id = c_el.cfg("ID").getS();
-        if( !chldPresent(m_bl,id) )
-        {
-            blkAdd(id);
-            ((TConfig &)blkAt(id).at()) = c_el;
-            //if( blkAt(id).at().toEnable() ) blkAt(id).at().enable(true);
-        }
-	blkAt(id).at().load();
-	c_el.cfg("ID").setS("");
-    }
-}
-
-void Contr::saveV( )
-{
-    vector<string> lst;
-	
-    // Save messages bd
-    blkList(lst);
-    for( int i_l = 0; i_l < lst.size(); i_l++ )
-        blkAt(lst[i_l]).at().save();
-}
-
-void Contr::freeV( )
-{
-    vector<string> lst;
-	
-    // Save messages bd
-    blkList(lst);
-    for( int i_l = 0; i_l < lst.size(); i_l++ )    
-    {
-	try{ blkDel(lst[i_l]); }
-	catch(TError){ throw TError(nodePath().c_str(),_("Can't delete block <%s>."),lst[i_l].c_str()); }
-    }
-}
-
 void *Contr::Task( void *icontr )
 {
     long long work_tm, last_tm = 0;
@@ -530,22 +418,6 @@ void *Contr::Task( void *icontr )
     return NULL;
 }
 
-void Contr::TaskDBSync(union sigval obj)
-{
-    Contr *cntr = (Contr *)obj.sival_ptr;
-    if( cntr->sync_st )  return;
-    cntr->sync_st = true;
-    
-    try{ cntr->saveV( ); }
-    catch(TError err) 
-    { 
-	mess_err(err.cat.c_str(),"%s",err.mess.c_str() ); 
-	mess_err(cntr->nodePath().c_str(),_("Block save error."));
-    }
-    
-    cntr->sync_st = false;
-}
-
 TParamContr *Contr::ParamAttach( const string &name, int type )
 {
     return new Prm(name,&owner().tpPrmAt(type));
@@ -571,28 +443,13 @@ void Contr::blkProc( const string & id, bool val )
 	clc_blks.erase(clc_blks.begin()+i_blk);
 }	
 
-bool Contr::cfgChange( TCfg &cfg )
-{
-    if( startStat() )
-    {
-	struct itimerspec itval;
-	if( cfg.fld().name() == "PER_DB" )
-	{
-	    itval.it_interval.tv_sec = itval.it_value.tv_sec = m_dbper;
-    	    itval.it_interval.tv_nsec = itval.it_value.tv_nsec = 0;
-	    timer_settime(sncDBTm, 0, &itval, NULL);
-	}
-    }
-    return true;
-}
-
 void Contr::cntrCmdProc( XMLNode *opt )
 {
     //Get page info
     if( opt->name() == "info" )
     {
         TController::cntrCmdProc(opt);
-	ctrMkNode("grp",opt,-1,"/br/blk_",_("Block"),0440,"root","root",1,"list","/scheme/sch");
+	ctrMkNode("grp",opt,-1,"/br/blk_",_("Block"),0664,"root","root",1,"idm","1");
 	if(ctrMkNode("area",opt,-1,"/scheme",_("Blocks scheme")))
 	{
 	    ctrMkNode("fld",opt,-1,"/scheme/ctm",_("Calk time (usek)"),0444,"root","root",1,"tp","real");
@@ -603,7 +460,7 @@ void Contr::cntrCmdProc( XMLNode *opt )
     //Process command to page
     string a_path = opt->attr("path");
     if( a_path == "/scheme/ctm" && ctrChkNode(opt) )	opt->setText(TSYS::real2str(tm_calc,6));
-    else if( a_path == "/scheme/sch" )
+    else if( a_path == "/br/blk_" || a_path == "/scheme/sch" )
     {
 	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )
 	{
@@ -646,52 +503,51 @@ void Prm::postEnable( int flag )
 void Prm::enable()
 {
     if( enableStat() )  return;
-    
-    m_blck = cfg("BLK").getS();
-    
-    if( !((Contr &)owner()).blkPresent(m_blck) )
-        throw TError(nodePath().c_str(),_("Block not connected."));
-    
-    //Init elements
-    string mio;
-    for( int io_off = 0; (mio=TSYS::strSepParse(cfg("IO").getS(),0,';',&io_off)).size(); )
-    {
-        unsigned flg = TVal::DirWrite|TVal::DirRead;
-        TFld::Type    tp  = TFld::String;
-        int           io_id = ((Contr &)owner()).blkAt(m_blck).at().ioId(mio);
-        if(io_id >= 0)
-	{
-	    //if( ((Contr &)owner()).blkAt(m_blck).at().ioMode(io_id) != IO::Input )
-	    //	flg |= Fld::NoWrite;
-	    switch( ((Contr &)owner()).blkAt(m_blck).at().ioType(io_id) )
-	    {
-		case IO::String: 	tp = TFld::String; 	break;
-		case IO::Integer:	tp = TFld::Integer;	break;
-		case IO::Real:		tp = TFld::Real;	break;
-		case IO::Boolean:	tp = TFld::Boolean;	break;
-	    }
-	    if( !v_el.fldPresent(mio) || 
-		v_el.fldAt(v_el.fldId(mio)).type() != tp || 
-		v_el.fldAt(v_el.fldId(mio)).flg() != flg )
-	    {
-		if(v_el.fldPresent(mio)) v_el.fldDel(v_el.fldId(mio));
-		v_el.fldAdd( new TFld(mio.c_str(),((Contr &)owner()).blkAt(m_blck).at().func()->io(io_id)->name().c_str(),tp,flg) );
-    	    }
-	}
-    }
-    
-    //Check and delete no used fields
+
+    //- Check and delete no used fields -
     for(int i_fld = 0; i_fld < v_el.fldSize(); i_fld++)
     {
         string fel;
-        for( int io_off = 0; (fel=TSYS::strSepParse(cfg("IO").getS(),0,';',&io_off)).size(); )
-    	    if( fel == v_el.fldAt(i_fld).name() ) break;
-        if( fel.empty() )
-        {
+        for( int io_off = 0; (fel=TSYS::strSepParse(cfg("IO").getS(),0,'\n',&io_off)).size(); )
+    	    if( TSYS::strSepParse(fel,0,':') == v_el.fldAt(i_fld).reserve() ) break;
+        if( fel.empty() )	
+	{
             v_el.fldDel(i_fld);
             i_fld--;
 	}
     }	
+
+    //- Init elements -
+    AutoHD<Block> blk;
+    int io;
+    string mio, ioaddr, ioblk, ioid, aid, anm;
+    for( int io_off = 0; (mio=TSYS::strSepParse(cfg("IO").getS(),0,'\n',&io_off)).size(); )
+    {
+	ioaddr = TSYS::strSepParse(mio,0,':');
+	ioblk  = TSYS::strSepParse(ioaddr,0,'.');
+	ioid   = TSYS::strSepParse(ioaddr,1,'.');
+	aid    = TSYS::strSepParse(mio,1,':');
+	anm    = TSYS::strSepParse(mio,2,':');
+	if( aid.empty() ) aid = ioblk+"_"+ioid;
+	if( !((Contr&)owner()).blkPresent(ioblk) ) continue;
+	blk = ((Contr&)owner()).blkAt(ioblk);
+	if( (io=blk.at().ioId(ioid)) < 0 )	continue;
+	
+        unsigned 	flg    = TVal::DirWrite|TVal::DirRead;
+        TFld::Type	tp     = TFld::String;
+	switch( blk.at().ioType(io) )
+	{
+	    case IO::String: 	tp = TFld::String; 	break;
+	    case IO::Integer:	tp = TFld::Integer;	break;
+	    case IO::Real:	tp = TFld::Real;	break;
+	    case IO::Boolean:	tp = TFld::Boolean;	break;
+	}
+	if( !v_el.fldPresent(aid) || v_el.fldAt(v_el.fldId(aid)).type() != tp || v_el.fldAt(v_el.fldId(aid)).flg() != flg )
+	{
+	    if(v_el.fldPresent(aid)) v_el.fldDel(v_el.fldId(aid));
+	    v_el.fldAdd( new TFld(aid.c_str(),anm.empty() ? blk.at().func()->io(io)->name().c_str() : anm.c_str(),tp,flg,"","","","",ioaddr.c_str()) );
+    	}
+    }
     
     TParamContr::enable();
 }
@@ -707,27 +563,18 @@ void Prm::vlSet( TVal &val )
 {
     if( !enableStat() )	return;
     try
-    {
-        int io_id = ((Contr &)owner()).blkAt(m_blck).at().ioId(val.name());
+    {	
+    	AutoHD<Block> blk = ((Contr &)owner()).blkAt(TSYS::strSepParse(val.fld().reserve(),0,'.'));
+        int io_id = blk.at().ioId(TSYS::strSepParse(val.fld().reserve(),1,'.'));
 	if( io_id < 0 ) disable();
 	else
-	{
 	    switch(val.fld().type())
 	    {
-		case TFld::String: 		    
-		    ((Contr &)owner()).blkAt(m_blck).at().setS(io_id,val.getS(0,true));
-		    break;
-		case TFld::Integer:
-		    ((Contr &)owner()).blkAt(m_blck).at().setI(io_id,val.getI(0,true));
-		    break;
-		case TFld::Real:
-		    ((Contr &)owner()).blkAt(m_blck).at().setR(io_id,val.getR(0,true));
-		    break;
-		case TFld::Boolean:
-		    ((Contr &)owner()).blkAt(m_blck).at().setB(io_id,val.getB(0,true));
-		    break;
+		case TFld::String:	blk.at().setS(io_id,val.getS(0,true));	break;
+		case TFld::Integer:	blk.at().setI(io_id,val.getI(0,true));	break;
+		case TFld::Real:	blk.at().setR(io_id,val.getR(0,true));	break;
+		case TFld::Boolean:	blk.at().setB(io_id,val.getB(0,true));	break;
 	    }
-	}
     }catch(TError err) { disable(); }
 }
 
@@ -739,32 +586,23 @@ void Prm::vlGet( TVal &val )
 	    val.setS(_("2:Controller stoped"),0,true);
 	else if( !enableStat() )   		   
 	    val.setS(_("1:Parameter disabled"),0,true);
-	else if( !owner().blkPresent(m_blck) ) 
-	    val.setS(_("3:Block no present"),0,true);
-	else if( !owner().blkAt(m_blck).at().enable() )
-    	    val.setS(_("4:Block disabled"),0,true);
-	else if( !owner().blkAt(m_blck).at().process() )
-    	    val.setS(_("5:Block no process"),0,true);
 	else val.setS("0",0,true);	
 	return;
     }
 
     try
     {
-	if( !enableStat() ) return;
-	int io_id = owner().blkAt(m_blck).at().ioId(val.name());
+	if( !enableStat() ) return;	
+     	AutoHD<Block> blk = ((Contr &)owner()).blkAt(TSYS::strSepParse(val.fld().reserve(),0,'.'));
+        int io_id = blk.at().ioId(TSYS::strSepParse(val.fld().reserve(),1,'.'));        
 	if( io_id < 0 )	disable();
 	else
 	    switch(val.fld().type())
 	    {
-		case TFld::String: 
-		    val.setS(enableStat()?owner().blkAt(m_blck).at().getS(io_id):EVAL_STR,0,true); break;
-		case TFld::Integer:
-		    val.setI(enableStat()?owner().blkAt(m_blck).at().getI(io_id):EVAL_INT,0,true); break;
-		case TFld::Real:
-		    val.setR(enableStat()?owner().blkAt(m_blck).at().getR(io_id):EVAL_REAL,0,true);break;
-		case TFld::Boolean:
-		    val.setB(enableStat()?owner().blkAt(m_blck).at().getB(io_id):EVAL_BOOL,0,true);break;
+		case TFld::String: 	val.setS( enableStat() ? blk.at().getS(io_id) : EVAL_STR, 0, true );	break;
+		case TFld::Integer:	val.setI( enableStat() ? blk.at().getI(io_id) : EVAL_INT, 0, true ); 	break;
+		case TFld::Real:	val.setR( enableStat() ? blk.at().getR(io_id) : EVAL_REAL, 0, true );	break;
+		case TFld::Boolean:	val.setB( enableStat() ? blk.at().getB(io_id) : EVAL_BOOL, 0, true );	break;
 	    }
     }catch(TError err) { disable(); }
 }
@@ -777,27 +615,3 @@ void Prm::vlArchMake( TVal &val )
     val.arch().at().setHardGrid( true );
     val.arch().at().setHighResTm( false );
 }
-
-void Prm::cntrCmdProc( XMLNode *opt )
-{
-    //- Service commands process -
-    string a_path = opt->attr("path");
-    if( a_path.substr(0,6) == "/serv/" )  { TParamContr::cntrCmdProc(opt); return; }
-
-    //- Get page info -
-    if( opt->name() == "info" )
-    {
-	TParamContr::cntrCmdProc(opt);
-	ctrMkNode("fld",opt,-1,"/prm/cfg/BLK",cfg("BLK").fld().descr(),0660,"root","root",3,"tp","str","dest","select","select","/prm/cfg/BLK_list");
-	return;
-    }
-    //- Process command to page -
-    if( a_path == "/prm/cfg/BLK_list" && ctrChkNode(opt) )
-    {
-        vector<string> list;
-        ((Contr &)owner()).blkList(list);
-        for( unsigned i_f=0; i_f < list.size(); i_f++ )
-    	    opt->childAdd("el")->setAttr("id",list[i_f])->setText(owner().blkAt(list[i_f]).at().name());
-    }
-    else TParamContr::cntrCmdProc(opt);
-}
