@@ -38,7 +38,7 @@
 #define MOD_NAME    "Diamond DA boards"
 #define MOD_TYPE    "DAQ"
 #define VER_TYPE    VER_CNTR
-#define VERSION     "1.0.0"
+#define VERSION     "1.0.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Allow access to Diamond systems DA boards. Include support of Athena board."
 #define LICENSE     "GPL"
@@ -103,11 +103,11 @@ void TTpContr::postEnable( int flag )
 	"DMM16;ATHENA;DMM32XAT") );
     fldAdd( new TFld("PRM_BD_A",_("Analog parameters' table"),TFld::String,0,"30","diamond_prm_a") );
     fldAdd( new TFld("PRM_BD_D",_("Digital parameters' table"),TFld::String,0,"30","diamond_prm_d") );
-    fldAdd( new TFld("DATA_EMUL",_("Data emulation"),TFld::Boolean,TCfg::Prevent,"1","0") );
+    fldAdd( new TFld("DATA_EMUL",_("Data emulation"),TFld::Boolean,TFld::NoFlag,"1","0") );
     fldAdd( new TFld("ADDR",_("Base board address"),TFld::Integer,TFld::HexDec,"3","640") );
-    fldAdd( new TFld("INT",_("Interrupt vector"),TFld::Integer,0,"2","5") );    
+    fldAdd( new TFld("INT",_("Interrupt vector"),TFld::Integer,0,"2","5") );
     fldAdd( new TFld("DIO_CFG",_("Digit IO config byte"),TFld::Integer,TFld::HexDec,"2","0") );
-    fldAdd( new TFld("ADMODE",_("A/D interrupt mode"),TFld::Boolean,TCfg::Prevent,"1","0") );
+    fldAdd( new TFld("ADMODE",_("A/D interrupt mode"),TFld::Boolean,TFld::NoFlag,"1","0") );
     fldAdd( new TFld("ADRANGE",_("A/D voltage range"),TFld::Integer,TFld::Selected,"1",TSYS::int2str(RANGE_10).c_str(),
         (TSYS::int2str(RANGE_5)+";"+TSYS::int2str(RANGE_10)).c_str(),_("5v;10v")) );
     fldAdd( new TFld("ADPOLAR",_("A/D polarity"),TFld::Integer,TFld::Selected,"1",TSYS::int2str(BIPOLAR).c_str(),
@@ -119,28 +119,28 @@ void TTpContr::postEnable( int flag )
     //- Parameter type bd structure -
     //-- Analog --
     int t_prm = tpParmAdd("a_prm","PRM_BD_A",_("Analog parameter"));
-    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",_("Analog parameter type"),TFld::Integer,TFld::Selected|TCfg::NoVal|TCfg::Prevent,"1","0","0;1",_("Input;Output")) );
+    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",_("Analog parameter type"),TFld::Integer,TFld::Selected|TCfg::NoVal,"1","0","0;1",_("Input;Output")) );
     tpPrmAt(t_prm).fldAdd( new TFld("CNL",_("Channel"),TFld::Integer,TCfg::NoVal,"2","0") );
-    tpPrmAt(t_prm).fldAdd( new TFld("GAIN",_("A/D converter gain"),TFld::Integer,TFld::Selected|TCfg::NoVal|TCfg::Prevent,"1",TSYS::int2str(GAIN_1).c_str(),
+    tpPrmAt(t_prm).fldAdd( new TFld("GAIN",_("A/D converter gain"),TFld::Integer,TFld::Selected|TCfg::NoVal,"1",TSYS::int2str(GAIN_1).c_str(),
 	(TSYS::int2str(GAIN_1)+";"+TSYS::int2str(GAIN_2)+";"+TSYS::int2str(GAIN_4)+";"+TSYS::int2str(GAIN_8)).c_str(),"x1;x2;x4;x8") );
     //-- Digit --
     t_prm = tpParmAdd("d_prm","PRM_BD_D",_("Digital parameter"));
-    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",_("Digital parameter type"),TFld::Integer,TFld::Selected|TCfg::NoVal|TCfg::Prevent,"1","0","0;1",_("Input;Output")) );
-    tpPrmAt(t_prm).fldAdd( new TFld("PORT",_("Port"),TFld::Integer,TFld::Selected|TCfg::NoVal|TCfg::Prevent,"2","0","0;1;2","A;B;C") );
-    tpPrmAt(t_prm).fldAdd( new TFld("CNL",_("Channel"),TFld::Integer,TCfg::NoVal|TCfg::Prevent,"1") );
+    tpPrmAt(t_prm).fldAdd( new TFld("TYPE",_("Digital parameter type"),TFld::Integer,TFld::Selected|TCfg::NoVal,"1","0","0;1",_("Input;Output")) );
+    tpPrmAt(t_prm).fldAdd( new TFld("PORT",_("Port"),TFld::Integer,TFld::Selected|TCfg::NoVal,"2","0","0;1;2","A;B;C") );
+    tpPrmAt(t_prm).fldAdd( new TFld("CNL",_("Channel"),TFld::Integer,TCfg::NoVal,"1") );
 
     //- Init value elements -
     //-- Analog input --
-    elem_ai.fldAdd( new TFld("value",_("Value %"),TFld::Real,TFld::NoWrite|TVal::DirRead,"",TSYS::real2str(EVAL_REAL).c_str(),"0;100","",1) );
-    elem_ai.fldAdd( new TFld("voltage",_("Voltage V"),TFld::Real,TFld::NoWrite|TVal::DirRead,"",TSYS::real2str(EVAL_REAL).c_str(),"-10;10","",2) );
-    elem_ai.fldAdd( new TFld("code",_("A/D code"),TFld::Integer,TFld::NoWrite|TVal::DirRead,"",TSYS::int2str(EVAL_INT).c_str(),"","",3) );
+    elem_ai.fldAdd( new TFld("value",_("Value %"),TFld::Real,TFld::NoWrite|TVal::DirRead,"",TSYS::real2str(EVAL_REAL).c_str(),"0;100","","1") );
+    elem_ai.fldAdd( new TFld("voltage",_("Voltage V"),TFld::Real,TFld::NoWrite|TVal::DirRead,"",TSYS::real2str(EVAL_REAL).c_str(),"-10;10","","2") );
+    elem_ai.fldAdd( new TFld("code",_("A/D code"),TFld::Integer,TFld::NoWrite|TVal::DirRead,"",TSYS::int2str(EVAL_INT).c_str(),"","","3") );
     //-- Analog output --
-    elem_ao.fldAdd( new TFld("value",_("Value %"),TFld::Real,TVal::DirWrite,"",TSYS::real2str(EVAL_REAL).c_str(),"0;100","",1) );
-    elem_ao.fldAdd( new TFld("voltage",_("Voltage V"),TFld::Real,TVal::DirWrite,"",TSYS::real2str(EVAL_REAL).c_str(),"-10;10","",2) );
+    elem_ao.fldAdd( new TFld("value",_("Value %"),TFld::Real,TVal::DirWrite,"",TSYS::real2str(EVAL_REAL).c_str(),"0;100","","1") );
+    elem_ao.fldAdd( new TFld("voltage",_("Voltage V"),TFld::Real,TVal::DirWrite,"",TSYS::real2str(EVAL_REAL).c_str(),"-10;10","","2") );
     //-- Digit input --
-    elem_di.fldAdd( new TFld("value",_("Value"),TFld::Boolean,TFld::NoWrite|TVal::DirRead,"",TSYS::int2str(EVAL_BOOL).c_str(),"","",1) );
+    elem_di.fldAdd( new TFld("value",_("Value"),TFld::Boolean,TFld::NoWrite|TVal::DirRead,"",TSYS::int2str(EVAL_BOOL).c_str(),"","","1") );
     //-- Digit output --
-    elem_do.fldAdd( new TFld("value",_("Value"),TFld::Boolean,TVal::DirWrite,"",TSYS::int2str(EVAL_BOOL).c_str(),"","",1) );
+    elem_do.fldAdd( new TFld("value",_("Value"),TFld::Boolean,TVal::DirWrite,"",TSYS::int2str(EVAL_BOOL).c_str(),"","","1") );
 }
 
 TController *TTpContr::ContrAttach( const string &name, const string &daq_db )
@@ -177,18 +177,13 @@ TParamContr *TMdContr::ParamAttach( const string &name, int type )
     return new TMdPrm(name,&owner().tpPrmAt(type));
 }
 
-void TMdContr::load( )
+void TMdContr::load_( )
 {
     cfgViewAll(true);
-    TController::load( );
+    TController::load_( );
     cfg("ADMODE").setB(cfg("ADMODE").getB());	//For hiden attributes visible status update
 }
 
-void TMdContr::save( )
-{
-    TController::save();
-}
-
 void TMdContr::start_( )
 {
     //- Check inited of Diamond API -
@@ -258,6 +253,8 @@ void TMdContr::stop_( )
 
 bool TMdContr::cfgChange( TCfg &icfg )
 {
+    TController::cfgChange(icfg);
+
     if(icfg.fld().name() == "ADMODE")
     {
 	if(icfg.getB()) 
@@ -529,10 +526,10 @@ void TMdPrm::postEnable( int flag )
     else if( TParamContr::type().name == "d_prm" )	setType(DI);
 }
 
-void TMdPrm::load( )
+void TMdPrm::load_( )
 {
     cfgViewAll(true);
-    TParamContr::load();
+    TParamContr::load_();
     setType(type());		//For hiden attributes visible status update    
 }
 
@@ -573,6 +570,8 @@ void TMdPrm::setType( TMdPrm::Type vtp )
 
 bool TMdPrm::cfgChange( TCfg &i_cfg )
 {
+    TParamContr::cfgChange(i_cfg);
+
     //- Change TYPE parameter -
     if( i_cfg.name() == "TYPE" )
     {
@@ -588,10 +587,12 @@ bool TMdPrm::cfgChange( TCfg &i_cfg )
 	case AI:
 	    if( i_cfg.name() == "GAIN" ) m_gain = i_cfg.getI();
 	    else return false;
+	    break;
 	case DI: case DO:
 	    if( i_cfg.name() == "PORT" ) 	m_dio_port = (i_cfg.getI()<<4)+cfg("CNL").getI();
 	    else if( i_cfg.name() == "CNL" )	m_dio_port = (cfg("PORT").getI()<<4)+i_cfg.getI();
-	    else return false;	        
+	    else return false;
+	    break;
     }
     
     return true;
@@ -599,14 +600,18 @@ bool TMdPrm::cfgChange( TCfg &i_cfg )
 
 void TMdPrm::vlSet( TVal &val )
 {    
-    if( !enableStat() )	return;
+    if( !owner().startStat() || !enableStat() )	return;
+    
     switch(type())
     {
 	case AO:
 	{
 	    int code;
-	    if(val.fld().reserve()==1)		code = (int)(4095.*val.getR(0,true)/100.);
-	    else if(val.fld().reserve()==2)	code = (int)(4095.*val.getR(0,true)/10.);
+	    switch( atoi(val.fld().reserve().c_str()) )
+	    {
+	    	case 1:	code = (int)(4095.*val.getR(0,true)/100.);	break;
+		case 2:	code = (int)(4095.*val.getR(0,true)/10.);	break;
+	    }
 
 	    //- Direct writing -
 	    if( owner().dataEmul() )	break;
@@ -638,7 +643,8 @@ void TMdPrm::vlSet( TVal &val )
 
 void TMdPrm::vlGet( TVal &val )
 {
-    if( val.fld().reserve() == 0 )
+    int aid = atoi(val.fld().reserve().c_str());
+    if( aid == 0 )
     {
         if( !owner().startStat() )
             val.setS(_("2:Controller stoped"),0,true);
@@ -646,7 +652,8 @@ void TMdPrm::vlGet( TVal &val )
             val.setS(_("1:Parameter disabled"),0,true);
 	else val.setS("0",0,true);
 	return;
-    }						
+    }
+    if( !owner().startStat() || !enableStat() )	{ val.setS(EVAL_STR,0,true); return; }
 
     switch(type())
     {
@@ -680,7 +687,7 @@ void TMdPrm::vlGet( TVal &val )
 		    owner().ai_res.resReleaseW( );
 		}
 	    }
-	    switch(val.fld().reserve())
+	    switch( aid )
 	    {
 		case 1: val.setR(enableStat()?(100.*((double)gval/32768.)):EVAL_REAL,0,true); break;
 		case 2: val.setR(enableStat()?(10.*((double)gval/32768.)):EVAL_REAL,0,true);  break;
