@@ -49,6 +49,11 @@ Func::~Func( )
 
 }
 
+void Func::postEnable( int flag )
+{
+    if( owner().DB().empty() )	modifClr();
+}
+
 void Func::preDisable( int flag )
 {
     if( m_tval ) { delete m_tval; m_tval = NULL; }
@@ -57,7 +62,7 @@ void Func::preDisable( int flag )
 void Func::postDisable( int flag )
 {
     setStart(false);
-    if( flag && owner().DB().size() )
+    if( flag && !owner().DB().empty() )
     {
 	try{ del( ); }
 	catch(TError err)
@@ -75,6 +80,20 @@ string Func::name( )
     return m_name.size()?m_name:id();
 }
 
+TCntrNode &Func::operator=( TCntrNode &node )
+{
+    Func *src_n = dynamic_cast<Func*>(&node);
+    if( !src_n ) return *this;
+    
+    *(TConfig *)this = *(TConfig*)src_n;
+    *(TFunction *)this = *(TFunction*)src_n;
+    
+    //- Set to DB -
+    cfg("ID").setS(m_id);
+    
+    if( src_n->startStat( ) && !startStat( ) )	setStart( true );
+}
+
 Func &Func::operator=(Func &func)
 {
     *(TConfig *)this = (TConfig&)func;
@@ -84,9 +103,33 @@ Func &Func::operator=(Func &func)
     cfg("ID").setS(m_id);
 }
 
-void Func::load( )
+void Func::setName( const string &nm )          
+{ 
+    m_name = nm; 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::setDescr( const string &dscr )       
+{ 
+    m_descr = dscr; 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::setMaxCalcTm( int vl )             
+{ 
+    max_calc_tm = vl; 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::setProg( const string &prg )         
+{ 
+    prg_src = prg; 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::load_( )
 {
-    if( !owner().DB().size() )	return;
+    if( owner().DB().empty() )	return;
     
     SYS->db().at().dataGet(owner().fullDB(),mod->nodePath()+owner().tbl(),*this);
     
@@ -132,9 +175,9 @@ void Func::loadIO( )
     }
 }
 
-void Func::save( )
+void Func::save_( )
 {
-    if( !owner().DB().size() )  return;
+    if( owner().DB().empty() )  return;
 
     SYS->db().at().dataSet(owner().fullDB(),mod->nodePath()+owner().tbl(),*this);
 
@@ -233,6 +276,30 @@ void Func::setStart( bool val )
     }
 }
 
+void Func::ioAdd( IO *io )            
+{ 
+    TFunction::ioAdd(io); 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::ioIns( IO *io, int pos )   
+{ 
+    TFunction::ioIns(io,pos); 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::ioDel( int pos )           
+{ 
+    TFunction::ioDel(pos); 
+    if(!owner().DB().empty()) modif(); 
+}
+
+void Func::ioMove( int pos, int to )  
+{ 
+    TFunction::ioMove(pos,to); 
+    if(!owner().DB().empty()) modif(); 
+}
+
 void Func::progCompile()
 {
     ResAlloc res(parse_res,true);
@@ -570,8 +637,8 @@ Reg *Func::cdBinaryOp( Reg::Code cod, Reg *op1, Reg *op2 )
 		switch(cod)
 		{
 		    case Reg::AddI: *op1->val().s_el += *op2->val().s_el;	break;
-                    case Reg::EQI:  *op1 = *op1->val().s_el == *op2->val().s_el;	break;		    
-                    case Reg::NEI:  *op1 = *op1->val().s_el != *op2->val().s_el;	break;		    
+                    case Reg::EQI:  *op1 = (char)(*op1->val().s_el == *op2->val().s_el);	break;		    
+                    case Reg::NEI:  *op1 = (char)(*op1->val().s_el != *op2->val().s_el);	break;
 		}
 		break;    
 	}    
@@ -606,14 +673,14 @@ Reg *Func::cdBinaryOp( Reg::Code cod, Reg *op1, Reg *op2 )
 		case Reg::BitOr: prg+=(BYTE)Reg::BitOr;	break;
 		case Reg::BitAnd: prg+=(BYTE)Reg::BitAnd; break;
 		case Reg::BitXor: prg+=(BYTE)Reg::BitXor; break;
-                case Reg::LOr:  prg+=(BYTE)Reg::LOr;    break;
-		case Reg::LAnd: prg+=(BYTE)Reg::LAnd;   break;
-                case Reg::LTI: 	prg+=(BYTE)Reg::LTI;	break;
-                case Reg::GTI: 	prg+=(BYTE)Reg::GTI;	break;
-                case Reg::LEI: 	prg+=(BYTE)Reg::LEI;	break;
-                case Reg::GEI: 	prg+=(BYTE)Reg::GEI;	break;
-                case Reg::EQI: 	prg+=(BYTE)Reg::EQI;	break;
-                case Reg::NEI: 	prg+=(BYTE)Reg::NEI;	break;
+                case Reg::LOr:  prg+=(BYTE)Reg::LOr;    rez->setType(Reg::Bool); break;
+		case Reg::LAnd: prg+=(BYTE)Reg::LAnd;   rez->setType(Reg::Bool); break;
+                case Reg::LTI: 	prg+=(BYTE)Reg::LTI;	rez->setType(Reg::Bool); break;
+                case Reg::GTI: 	prg+=(BYTE)Reg::GTI;	rez->setType(Reg::Bool); break;
+                case Reg::LEI: 	prg+=(BYTE)Reg::LEI;	rez->setType(Reg::Bool); break;
+                case Reg::GEI: 	prg+=(BYTE)Reg::GEI;	rez->setType(Reg::Bool); break;
+                case Reg::EQI: 	prg+=(BYTE)Reg::EQI;	rez->setType(Reg::Bool); break;
+                case Reg::NEI: 	prg+=(BYTE)Reg::NEI;	rez->setType(Reg::Bool); break;
 	    }
             break;
 	case Reg::Real:
@@ -626,22 +693,22 @@ Reg *Func::cdBinaryOp( Reg::Code cod, Reg *op1, Reg *op2 )
 		case Reg::BitOr: prg+=(BYTE)Reg::BitOr; break;
                 case Reg::BitAnd: prg+=(BYTE)Reg::BitAnd;       break;
 		case Reg::BitXor: prg+=(BYTE)Reg::BitXor; break;
-                case Reg::LOr:  prg+=(BYTE)Reg::LOr;    break;
-		case Reg::LAnd: prg+=(BYTE)Reg::LAnd;   break;
-                case Reg::LTI: 	prg+=(BYTE)Reg::LTR;	break;
-                case Reg::GTI: 	prg+=(BYTE)Reg::GTR;	break;
-                case Reg::LEI: 	prg+=(BYTE)Reg::LER;	break;
-                case Reg::GEI: 	prg+=(BYTE)Reg::GER;	break;
-                case Reg::EQI: 	prg+=(BYTE)Reg::EQR;	break;
-                case Reg::NEI: 	prg+=(BYTE)Reg::NER;	break;
+                case Reg::LOr:  prg+=(BYTE)Reg::LOr;    rez->setType(Reg::Bool); break;
+		case Reg::LAnd: prg+=(BYTE)Reg::LAnd;   rez->setType(Reg::Bool); break;
+                case Reg::LTI: 	prg+=(BYTE)Reg::LTR;	rez->setType(Reg::Bool); break;
+                case Reg::GTI: 	prg+=(BYTE)Reg::GTR;	rez->setType(Reg::Bool); break;
+                case Reg::LEI: 	prg+=(BYTE)Reg::LER;	rez->setType(Reg::Bool); break;
+                case Reg::GEI: 	prg+=(BYTE)Reg::GER;	rez->setType(Reg::Bool); break;
+                case Reg::EQI: 	prg+=(BYTE)Reg::EQR;	rez->setType(Reg::Bool); break;
+                case Reg::NEI: 	prg+=(BYTE)Reg::NER;	rez->setType(Reg::Bool); break;
 	    }
             break;
 	case Reg::String:
 	    switch(cod)
 	    {
-		case Reg::AddI:	prg+=(BYTE)Reg::AddS;   break;
-                case Reg::EQI: 	prg+=(BYTE)Reg::EQS;	break;
-                case Reg::NEI: 	prg+=(BYTE)Reg::NES;	break;
+		case Reg::AddI:	prg+=(BYTE)Reg::AddS;	break;
+                case Reg::EQI: 	prg+=(BYTE)Reg::EQS;	rez->setType(Reg::Bool); break;
+                case Reg::NEI: 	prg+=(BYTE)Reg::NES;	rez->setType(Reg::Bool); break;
 	    }
             break;
     }     
@@ -889,113 +956,114 @@ Reg *Func::cdExtFnc( int f_id, int p_cnt, bool proc )
     return rez;
 }
 
-bool Func::getValB( TValFunc *io, RegW &rg )
-{
-    switch(rg.type())
-    {
-	case Reg::Bool:         return rg.val().b_el;
-	case Reg::Int:          return (bool)rg.val().i_el;
-	case Reg::Real:         return (bool)rg.val().r_el;
-	case Reg::String:       return (bool)atoi(rg.val().s_el->c_str());
-	case Reg::Var:          return io->getB(rg.val().io);
-	case Reg::PrmAttr:	return rg.val().p_attr->at().getB();
-    }	
-}
-
-int Func::getValI( TValFunc *io, RegW &rg )
-{
-    switch(rg.type())
-    {
-	case Reg::Bool:         return rg.val().b_el;
-	case Reg::Int:          return rg.val().i_el;
-	case Reg::Real:         return (int)rg.val().r_el;
-	case Reg::String:       return atoi(rg.val().s_el->c_str());
-	case Reg::Var:          return io->getI(rg.val().io);
-	case Reg::PrmAttr:      return rg.val().p_attr->at().getI();
-    }	
-}
-	
-double Func::getValR( TValFunc *io, RegW &rg )
-{
-    switch(rg.type())
-    {
-	case Reg::Bool:         return (double)rg.val().b_el;
-	case Reg::Int:          return (double)rg.val().i_el;
-	case Reg::Real:         return rg.val().r_el;
-	case Reg::String:       return atof(rg.val().s_el->c_str());
-	case Reg::Var:          return io->getR(rg.val().io);
-	case Reg::PrmAttr:      return rg.val().p_attr->at().getR();
-    }	
-}
-	
 string Func::getValS( TValFunc *io, RegW &rg )
 {
     switch(rg.type())
     {
-	case Reg::Bool:         return TSYS::int2str(rg.val().b_el);
-	case Reg::Int:          return TSYS::int2str(rg.val().i_el);
-	case Reg::Real:         return TSYS::real2str(rg.val().r_el);
+	case Reg::Bool:         return (rg.val().b_el!=EVAL_BOOL) ? TSYS::int2str((bool)rg.val().b_el) : EVAL_STR;    
+	case Reg::Int:          return (rg.val().i_el!=EVAL_INT) ? TSYS::int2str(rg.val().i_el) : EVAL_STR;
+	case Reg::Real:         return (rg.val().r_el!=EVAL_REAL) ? TSYS::real2str(rg.val().r_el) : EVAL_STR;
 	case Reg::String:       return *rg.val().s_el;
 	case Reg::Var:          return io->getS(rg.val().io);
 	case Reg::PrmAttr:      return rg.val().p_attr->at().getS();
     }	
 }
-	
-void Func::setValB( TValFunc *io, RegW &rg, bool val )
+
+int Func::getValI( TValFunc *io, RegW &rg )
+{    
+    switch(rg.type())
+    {
+	case Reg::Bool:         return (rg.val().b_el!=EVAL_BOOL) ? (bool)rg.val().b_el : EVAL_INT;
+	case Reg::Int:          return rg.val().i_el;
+	case Reg::Real:         return (rg.val().r_el!=EVAL_REAL) ? (int)rg.val().r_el : EVAL_INT;
+	case Reg::String:       return ((*rg.val().s_el)!=EVAL_STR) ? atoi(rg.val().s_el->c_str()) : EVAL_INT;
+	case Reg::Var:		return io->getI(rg.val().io);
+	case Reg::PrmAttr:      return rg.val().p_attr->at().getI();
+    }	
+}
+
+double Func::getValR( TValFunc *io, RegW &rg )
 {
     switch(rg.type())
     {
-	case Reg::Bool:         rg.val().b_el = val;    break;
-	case Reg::Int:          rg.val().i_el = val;    break;
-	case Reg::Real:         rg.val().r_el = val;    break;
-	case Reg::String:       *rg.val().s_el = TSYS::int2str(val);    break;
-	case Reg::Var:          io->setB(rg.val().io,val);      break;
-	case Reg::PrmAttr:      rg.val().p_attr->at().setB(val);	break;
+	case Reg::Bool:         return (rg.val().b_el!=EVAL_BOOL) ? (bool)rg.val().b_el : EVAL_REAL;
+	case Reg::Int:          return (rg.val().i_el!=EVAL_INT) ? rg.val().i_el : EVAL_REAL;
+	case Reg::Real:         return rg.val().r_el;
+	case Reg::String:       return ((*rg.val().s_el)!=EVAL_STR) ? atof(rg.val().s_el->c_str()) : EVAL_REAL;
+	case Reg::Var:          return io->getR(rg.val().io);
+	case Reg::PrmAttr:      return rg.val().p_attr->at().getR();
     }	
 }
-	
-void Func::setValI( TValFunc *io, RegW &rg, int val )
+
+char Func::getValB( TValFunc *io, RegW &rg )
 {
     switch(rg.type())
     {
-	case Reg::Bool:         rg.val().b_el = val;    break;
-	case Reg::Int:          rg.val().i_el = val;    break;
-	case Reg::Real:         rg.val().r_el = val;    break;
-	case Reg::String:       *rg.val().s_el = TSYS::int2str(val);    break;
-	case Reg::Var:          io->setI(rg.val().io,val);      break;
-	case Reg::PrmAttr:	rg.val().p_attr->at().setI(val);	break;
+	case Reg::Bool:         return rg.val().b_el;
+	case Reg::Int:          return (rg.val().i_el!=EVAL_INT) ? (bool)rg.val().i_el : EVAL_BOOL;
+	case Reg::Real:         return (rg.val().r_el!=EVAL_REAL) ? (bool)rg.val().r_el : EVAL_BOOL;
+	case Reg::String:       return ((*rg.val().s_el)!=EVAL_STR) ? (bool)atoi(rg.val().s_el->c_str()) : EVAL_BOOL;
+	case Reg::Var:          return io->getB(rg.val().io);
+	case Reg::PrmAttr:	return rg.val().p_attr->at().getB();
     }	
 }
-	
-void Func::setValR( TValFunc *io, RegW &rg, double val )
-{
-    switch(rg.type())
-    {
-	case Reg::Bool:         rg.val().b_el = val;    break;
-	case Reg::Int:          rg.val().i_el = (int)val;	break;
-	case Reg::Real:         rg.val().r_el = val;	break;
-	case Reg::String:       *rg.val().s_el = TSYS::real2str(val);	break;
-	case Reg::Var:          io->setR(rg.val().io,val);	break;
-	case Reg::PrmAttr:      rg.val().p_attr->at().setR(val);	break;
-    }	
-}
-	
+
 void Func::setValS( TValFunc *io, RegW &rg, const string &val )
 {
     switch(rg.type())
     {
-	case Reg::Bool:         rg.val().b_el = atoi(val.c_str());      break;
-	case Reg::Int:          rg.val().i_el = atoi(val.c_str());      break;
-	case Reg::Real:         rg.val().r_el = atof(val.c_str());      break;
-	case Reg::String:       *rg.val().s_el = val;   break;
-	case Reg::Var:          io->setS(rg.val().io,val);      break;
+	case Reg::Bool:         rg.val().b_el = (val!=EVAL_STR) ? (bool)atoi(val.c_str()) : EVAL_BOOL;	break;
+	case Reg::Int:          rg.val().i_el = (val!=EVAL_STR) ? atoi(val.c_str()) : EVAL_INT;      	break;
+	case Reg::Real:         rg.val().r_el = (val!=EVAL_STR) ? atof(val.c_str()) : EVAL_REAL;      	break;
+	case Reg::String:       *rg.val().s_el = val;   		break;
+	case Reg::Var:          io->setS(rg.val().io,val);      	break;
 	case Reg::PrmAttr:      rg.val().p_attr->at().setS(val);	break;
     }	
 }
 
+void Func::setValI( TValFunc *io, RegW &rg, int val )
+{
+    switch(rg.type())
+    {
+	case Reg::Bool:         rg.val().b_el = (val!=EVAL_INT) ? (bool)val : EVAL_BOOL;    		break;
+	case Reg::Int:          rg.val().i_el = val;    		break;
+	case Reg::Real:         rg.val().r_el = (val!=EVAL_INT) ? val : EVAL_REAL;    			break;
+	case Reg::String:       *rg.val().s_el = (val!=EVAL_INT) ? TSYS::int2str(val) : EVAL_STR;	break;
+	case Reg::Var:          io->setI(rg.val().io,val);		break;
+	case Reg::PrmAttr:	rg.val().p_attr->at().setI(val);	break;
+    }	
+}
+
+void Func::setValR( TValFunc *io, RegW &rg, double val )
+{
+    switch(rg.type())
+    {
+	case Reg::Bool:         rg.val().b_el = (val!=EVAL_REAL) ? (bool)val : EVAL_BOOL;    	break;
+	case Reg::Int:          rg.val().i_el = (val!=EVAL_REAL) ? (int)val : EVAL_INT;		break;
+	case Reg::Real:         rg.val().r_el = val;			break;
+	case Reg::String:       *rg.val().s_el = (val!=EVAL_REAL) ? TSYS::real2str(val) : EVAL_STR;	break;
+	case Reg::Var:          io->setR(rg.val().io,val);		break;
+	case Reg::PrmAttr:      rg.val().p_attr->at().setR(val);	break;
+    }	
+}
+
+void Func::setValB( TValFunc *io, RegW &rg, char val )
+{
+    switch(rg.type())
+    {
+	case Reg::Bool:         rg.val().b_el = val;    		break;
+	case Reg::Int:          rg.val().i_el = (val!=EVAL_BOOL) ? (bool)val : EVAL_INT;    	break;
+	case Reg::Real:         rg.val().r_el = (val!=EVAL_BOOL) ? (bool)val : EVAL_REAL;    	break;
+	case Reg::String:       *rg.val().s_el = (val!=EVAL_BOOL) ? TSYS::int2str((bool)val) : EVAL_STR;    break;
+	case Reg::Var:          io->setB(rg.val().io,val);      	break;
+	case Reg::PrmAttr:      rg.val().p_attr->at().setB(val);	break;
+    }	
+}
+	
 void Func::calc( TValFunc *val )
 { 
     calc_res.resRequestR( );
+    if( !startStat( ) )	return;
     
     //- Init list of registers -
     RegW reg[m_regs.size()];
@@ -1040,7 +1108,7 @@ void Func::exec( TValFunc *val, RegW *reg, const BYTE *cprg, ExecData &dt )
 #if DEBUG_VM
                 printf("CODE: Load bool %d to reg %d.\n",*(BYTE *)(cprg+2),*(BYTE *)(cprg+1));
 #endif		
-                reg[*(BYTE *)(cprg+1)] = (bool)*(BYTE*)(cprg+2);
+                reg[*(BYTE *)(cprg+1)] = *(char*)(cprg+2);
                 cprg+=3; break;
 	    case Reg::MviI: 	    
 #if DEBUG_VM	    
@@ -1253,7 +1321,7 @@ void Func::exec( TValFunc *val, RegW *reg, const BYTE *cprg, ExecData &dt )
 #if DEBUG_VM	    
                 printf("CODE: Integer %d = %d == %d.\n",*(BYTE *)(cprg+1),*(BYTE *)(cprg+2),*(BYTE *)(cprg+3));
 #endif		
-                reg[*(BYTE *)(cprg+1)] = getValI(val,reg[*(BYTE *)(cprg+2)]) == getValI(val,reg[*(BYTE *)(cprg+3)]);
+		reg[*(BYTE *)(cprg+1)] = getValI(val,reg[*(BYTE *)(cprg+2)]) == getValI(val,reg[*(BYTE *)(cprg+3)]);
                 cprg+=4; break;	
             case Reg::EQR:
 #if DEBUG_VM	    
@@ -1425,7 +1493,19 @@ void Func::exec( TValFunc *val, RegW *reg, const BYTE *cprg, ExecData &dt )
                 printf("CODE: Function %d=pow(%d,%d).\n",*(BYTE *)(cprg+1),*(BYTE *)(cprg+2),*(BYTE *)(cprg+3));
 #endif		
 	     	reg[*(BYTE *)(cprg+1)] = pow(getValR(val,reg[*(BYTE *)(cprg+2)]),getValR(val,reg[*(BYTE *)(cprg+3)]));
-                cprg+=4; break;	    
+                cprg+=4; break;
+	    case Reg::FMin:
+#if DEBUG_VM	    
+                printf("CODE: Function %d=min(%d,%d).\n",*(BYTE *)(cprg+1),*(BYTE *)(cprg+2),*(BYTE *)(cprg+3));
+#endif		
+	     	reg[*(BYTE *)(cprg+1)] = vmin(getValR(val,reg[*(BYTE *)(cprg+2)]),getValR(val,reg[*(BYTE *)(cprg+3)]));
+                cprg+=4; break;
+	    case Reg::FMax:
+#if DEBUG_VM	    
+                printf("CODE: Function %d=max(%d,%d).\n",*(BYTE *)(cprg+1),*(BYTE *)(cprg+2),*(BYTE *)(cprg+3));
+#endif		
+	     	reg[*(BYTE *)(cprg+1)] = vmax(getValR(val,reg[*(BYTE *)(cprg+2)]),getValR(val,reg[*(BYTE *)(cprg+3)]));
+                cprg+=4; break;
 	    case Reg::FSqrt:
 #if DEBUG_VM	    
                 printf("CODE: Function %d=sqrt(%d).\n",*(BYTE *)(cprg+1),*(BYTE *)(cprg+2));
@@ -1459,7 +1539,7 @@ void Func::exec( TValFunc *val, RegW *reg, const BYTE *cprg, ExecData &dt )
 	    case Reg::CProc:
 	    case Reg::CFunc:
 		{
-		    TValFunc vfnc("",&funcAt(*(BYTE *)(cprg+1))->func().at());
+		    TValFunc vfnc("JavaLikeFuncCalc",&funcAt(*(BYTE *)(cprg+1))->func().at());
 #if DEBUG_VM		    
 		    printf("CODE: Call function/procedure %d = %s(%d).\n",*(BYTE *)(cprg+3),vfnc.func()->id().c_str(),*(BYTE *)(cprg+2));
 #endif		    
@@ -1520,11 +1600,9 @@ void Func::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
         TFunction::cntrCmdProc(opt);
-        ctrMkNode("fld",opt,-1,"/func/cfg/name",_("Name"),0664,"root","root",1,"tp","str");
-        ctrMkNode("fld",opt,-1,"/func/cfg/descr",_("Description"),0664,"root","root",3,"tp","str","cols","90","rows","3");
+        ctrMkNode("fld",opt,-1,"/func/cfg/name",_("Name"),owner().DB().empty()?0444:0664,"root","root",1,"tp","str");
+        ctrMkNode("fld",opt,-1,"/func/cfg/descr",_("Description"),owner().DB().empty()?0444:0664,"root","root",3,"tp","str","cols","90","rows","3");
 	ctrMkNode("fld",opt,-1,"/func/cfg/m_calc_tm",_("Maximum calc time (sec)"),0664,"root","root",1,"tp","dec");
-	ctrMkNode("comm",opt,-1,"/func/cfg/load",_("Load"),0660);
-        ctrMkNode("comm",opt,-1,"/func/cfg/save",_("Save"),0660);
 	if(ctrMkNode("area",opt,-1,"/io",_("Programm")))
 	{
 	    if(ctrMkNode("table",opt,-1,"/io/io",_("IO"),0664,"root","root",1,"s_com","add,del,ins,move"))
@@ -1543,12 +1621,12 @@ void Func::cntrCmdProc( XMLNode *opt )
     
     //- Process command to page -
     string a_path = opt->attr("path");
-    if( a_path == "/func/cfg/name" && ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )		m_name 	= opt->text();
-    else if( a_path == "/func/cfg/descr" && ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	m_descr = opt->text();
+    if( a_path == "/func/cfg/name" && ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )		setName( opt->text() );
+    else if( a_path == "/func/cfg/descr" && ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setDescr( opt->text() );
     else if( a_path == "/func/cfg/m_calc_tm" )
     {
-	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )	opt->setText(TSYS::int2str(max_calc_tm));
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	max_calc_tm = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )	opt->setText( TSYS::int2str(maxCalcTm()) );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setMaxCalcTm( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/io/io" )
     {
@@ -1586,6 +1664,7 @@ void Func::cntrCmdProc( XMLNode *opt )
 	    else if( col == 3 )	io(row)->setFlg(io(row)->flg()^((io(row)->flg()^atoi(opt->text().c_str()))&(IO::Output|IO::Return)));
 	    else if( col == 4 )	io(row)->setHide(atoi(opt->text().c_str()));
 	    else if( col == 5 )	io(row)->setDef(opt->text());
+	    if(!owner().DB().empty()) modif();
 	}
     }
     else if( a_path == "/io/tp" && ctrChkNode(opt) )
@@ -1603,11 +1682,9 @@ void Func::cntrCmdProc( XMLNode *opt )
     }
     else if( a_path == "/io/prog" )
     {
-	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )	opt->setText(prg_src);
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	{ prg_src = opt->text(); progCompile();	}
+	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )	opt->setText( prog() );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	{ setProg( opt->text() ); progCompile();	}
     }
-    else if( a_path == "/func/cfg/load" &&  ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	load();
-    else if( a_path == "/func/cfg/save" &&  ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	save();
     else TFunction::cntrCmdProc(opt);
 }
 
