@@ -151,6 +151,8 @@ class Reg
 	    FLn,	//[CRR]: Function natural logarithm.
 	    FExp,	//[CRR]: Function exponent.
 	    FPow,	//[CRRR]: Function power.
+	    FMin,	//[CRRR]: Function minimum.
+	    FMax,	//[CRRR]: Function maximum.
 	    FSqrt,	//[CRR]: Function sqrt.
 	    FAbs,	//[CRR]: Function absolute.
 	    FSign,	//[CRR]: Function sign.
@@ -162,7 +164,7 @@ class Reg
 	
 	union El
         {
-	    bool	b_el;	//Boolean for constant and local variable
+	    char	b_el;	//Boolean for constant and local variable
             int         i_el;   //Integer for constant and local variable
 	    double      r_el;   //Real for constant and local variable
 	    string	*s_el;  //String for constant and local variable
@@ -180,7 +182,7 @@ class Reg
 	}
 
 	Reg &operator=( Reg &irg );
-	void operator=( bool ivar )		{ setType(Bool);	el.b_el = ivar; }
+	void operator=( char ivar )		{ setType(Bool);	el.b_el = ivar; }
 	void operator=( int ivar )		{ setType(Int); 	el.i_el = ivar; }
 	void operator=( double ivar )		{ setType(Real); 	el.r_el = ivar; }
 	void operator=( const string &ivar )	{ setType(String);	*el.s_el = ivar;}
@@ -229,7 +231,7 @@ class RegW
 	RegW( ) : m_tp(Reg::Free) {  }
 	~RegW( ) { setType(Reg::Free); }
 
-	void operator=( bool ivar )		{ setType(Reg::Bool);	el.b_el = ivar; }
+	void operator=( char ivar )		{ setType(Reg::Bool);	el.b_el = ivar; }
 	void operator=( int ivar )		{ setType(Reg::Int); 	el.i_el = ivar; }
 	void operator=( double ivar )		{ setType(Reg::Real); 	el.r_el = ivar; }
 	void operator=( const string &ivar )	{ setType(Reg::String);	*el.s_el = ivar;}
@@ -268,20 +270,22 @@ class Func : public TConfig, public TFunction
 	//Attributes
         Func( const char *, const char *name = "" );
         ~Func( );	
+
+	TCntrNode &operator=( TCntrNode &node );
 	
 	Func &operator=( Func &func );
 	    
         string name( );
-        string descr( )			{ return m_descr; }	
+        string descr( )			{ return m_descr; }
+	int maxCalcTm( )		{ return max_calc_tm; }
 	const string &prog( )		{ return prg_src; }
 	
-	void setName( const char *nm )	{ m_name = nm; }
-	void setDescr( const char *dscr )	{ m_descr = dscr; }
-	void setProg( const char *prg )	{ prg_src = prg; }	
+	void setName( const string &nm );
+	void setDescr( const string &dscr );
+	void setMaxCalcTm( int vl );
+	void setProg( const string &prg );
 	void setStart( bool val );
-	
-	void load( );
-        void save( );
+
 	void del( );
 	
         void calc( TValFunc *val );
@@ -320,20 +324,21 @@ class Func : public TConfig, public TFunction
 	Reg *cdExtFnc( int f_id, int p_cnt, bool proc = false );
 
 	//- Variable access -
-	bool getValB( TValFunc *io, RegW &rg );
-	int getValI( TValFunc *io, RegW &rg );
-	double getValR( TValFunc *io, RegW &rg );
-	string getValS( TValFunc *io, RegW &rg );
-	void setValB( TValFunc *io, RegW &rg, bool val );
+	string 	getValS( TValFunc *io, RegW &rg );
+	int 	getValI( TValFunc *io, RegW &rg );
+	char 	getValB( TValFunc *io, RegW &rg );
+	double 	getValR( TValFunc *io, RegW &rg );
+
+	void setValS( TValFunc *io, RegW &rg, const string &val );
 	void setValI( TValFunc *io, RegW &rg, int val );
 	void setValR( TValFunc *io, RegW &rg, double val );
-	void setValS( TValFunc *io, RegW &rg, const string &val );
+	void setValB( TValFunc *io, RegW &rg, char val );
 	
 	//- IO operations -
-	void ioAdd( IO *io )		{ TFunction::ioAdd(io); }
-        void ioIns( IO *io, int pos )	{ TFunction::ioIns(io,pos); }
-        void ioDel( int pos )		{ TFunction::ioDel(pos); }
-        void ioMove( int pos, int to )	{ TFunction::ioMove(pos,to); }
+	void ioAdd( IO *io );
+        void ioIns( IO *io, int pos );
+        void ioDel( int pos );
+        void ioMove( int pos, int to );
 
 	Lib &owner( );
 	
@@ -349,9 +354,13 @@ class Func : public TConfig, public TFunction
 	};
 	
 	//Methods
-	void preDisable(int flag);
-	void postDisable(int flag);
+	void postEnable( int flag );
+	void preDisable( int flag );
+	void postDisable( int flag );
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
+
+	void load_( );
+        void save_( );
 	
 	void loadIO( );
 	void saveIO( );
