@@ -2305,8 +2305,25 @@ int yylex( )
     if( c == '"' && (pos+1) < prog.size() )
     {
 	st_pos = ++pos;
+	string rez_str;
 	while( pos < prog.size() && prog[pos] != '"' && prog[pos] != '\n' )
-        { pos++; yylloc.last_column++; }
+        {
+	    if( prog[pos] == '\\' && (pos+1) < prog.size() )
+	    {
+		switch( prog[pos+1] )
+		{
+		    case 'n':	rez_str += '\n';	break;
+		    case 't':	rez_str += '\t';	break;
+		    case 'b':	rez_str += '\b';        break;
+		    case 'f':	rez_str += '\f';        break;
+		    case 'r':	rez_str += '\r';        break;
+		    default:	rez_str += prog[pos+1];
+		}
+		pos++;
+	    }
+	    else rez_str += prog[pos];
+	    pos++; yylloc.last_column++;
+	}
 	if( pos >= prog.size() )
 	{
 	    yyerror(_("Unexpected end programm, expect end string symbol '\"', "));
@@ -2319,7 +2336,8 @@ int yylex( )
 	}
 	
 	yylval.reg = p_fnc->regTmpNew();
-	*yylval.reg = prog.substr(st_pos,pos-st_pos);
+	*yylval.reg = rez_str;
+	//*yylval.reg = prog.substr(st_pos,pos-st_pos);
 	pos++;
 	return CONST;
     }
@@ -2358,12 +2376,14 @@ int yylex( )
 	    {
 		case TFld::Real: 	*yylval.reg = *(double*)(cnst_v->val.c_str()); 	break;
 		case TFld::Integer:	*yylval.reg = *(int*)(cnst_v->val.c_str()); 	break;
+		case TFld::Boolean:	*yylval.reg = *(char*)(cnst_v->val.c_str()); 	break;
 		case TFld::String: 	*yylval.reg = cnst_v->val; 			break;
 	    }
     	    return CONST;
 	}
+
 	//Find buildin function
-	if( mod->bFuncGet( smb_nm.c_str() ) != NULL )
+	if( c == '(' && mod->bFuncGet( smb_nm.c_str() ) != NULL )
 	{
 	    yylval.id = mod->bFuncGet(smb_nm.c_str())->code;
 	    switch( mod->bFuncGet(smb_nm.c_str())->prm )
@@ -2378,18 +2398,18 @@ int yylex( )
 	}
 	
 	//Find external functions
-        if( p_fnc->funcGet( smb_nm ) >= 0 )
+        if( c == '(' && p_fnc->funcGet( smb_nm ) >= 0 )
 	{
     	    yylval.id = p_fnc->funcGet( smb_nm );
 	    return FUNC;
     	}
-	
+
 	//Check allow registers
 	if( p_fnc->regGet(smb_nm.c_str()) >= 0 )
 	{
 	    yylval.reg = p_fnc->regAt(p_fnc->regGet(smb_nm.c_str()));
 	    return VAR;
-	}
+	}	
 			
 	//Only function and global atributes can have dots.
 	if( is_dot )
