@@ -38,7 +38,7 @@
 #define MOD_TYPE    "DAQ"
 #define VER_TYPE    VER_SPC
 #define SUB_TYPE    "LIB"
-#define VERSION     "1.0.0"
+#define VERSION     "1.0.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Allow java-like based calculator and function's libraries engine. User can create and modify function and libraries."
 #define LICENSE     "GPL"
@@ -97,7 +97,6 @@ void TipContr::postEnable( int flag )
     fldAdd( new TFld("FUNC",_("Controller's function"),TFld::String,TFld::NoFlag,"20") );
     fldAdd( new TFld("PERIOD",_("Calc period (ms)"),TFld::Integer,TFld::NoFlag,"7","1000","0;1000000") );
     fldAdd( new TFld("PRIOR",_("Calc task priority"),TFld::Integer,TFld::NoFlag,"2","0","0;100") );
-    fldAdd( new TFld("PER_DB",_("Sync db period (s)"),TFld::Integer,TCfg::Prevent,"5","0","0;3600") );
     fldAdd( new TFld("ITER",_("Iteration number into calc period"),TFld::Integer,TFld::NoFlag,"2","1","0;99") );
         
     //- Controller value db structure -
@@ -138,7 +137,7 @@ void TipContr::postEnable( int flag )
     rvl = EVAL_REAL; m_const.push_back(NConst(TFld::Real,"EVAL_REAL",string((char*)&rvl,sizeof(rvl))));
     int ivl;
     ivl = EVAL_INT; m_const.push_back(NConst(TFld::Integer,"EVAL_INT",string((char*)&ivl,sizeof(ivl))));
-    ivl = EVAL_BOOL; m_const.push_back(NConst(TFld::Integer,"EVAL_BOOL",string((char*)&ivl,sizeof(ivl))));
+    ivl = EVAL_BOOL; m_const.push_back(NConst(TFld::Boolean,"EVAL_BOOL",string((char*)&ivl,1)));
     
     m_const.push_back(NConst(TFld::String,"EVAL_STR",EVAL_STR));
     
@@ -157,6 +156,8 @@ void TipContr::postEnable( int flag )
     m_bfunc.push_back(BFunc("ln",Reg::FLn,1));
     m_bfunc.push_back(BFunc("exp",Reg::FExp,1));
     m_bfunc.push_back(BFunc("pow",Reg::FPow,2));
+    m_bfunc.push_back(BFunc("min",Reg::FMin,2));
+    m_bfunc.push_back(BFunc("max",Reg::FMax,2));
     m_bfunc.push_back(BFunc("sqrt",Reg::FSqrt,1));
     m_bfunc.push_back(BFunc("abs",Reg::FAbs,1));
     m_bfunc.push_back(BFunc("sign",Reg::FSign,1));
@@ -177,7 +178,7 @@ void TipContr::compileFuncLangs( vector<string> &ls )
 
 string TipContr::compileFunc( const string &lang, TFunction &fnc_cfg, const string &prog_text )
 {
-    if( lang != "JavaScript" )	throw TError(nodePath().c_str(),_("Compile the program language %s is no support."));
+    if( lang != "JavaScript" )	throw TError(nodePath().c_str(),_("Compile the program language %s is no support."),lang.c_str());
     if(!lbPresent("sys_compile"))	lbReg( new Lib("sys_compile","","") );
     if(!lbAt("sys_compile").at().present(fnc_cfg.id()))
 	lbAt("sys_compile").at().add(fnc_cfg.id().c_str(),"");
@@ -210,7 +211,7 @@ string TipContr::optDescr( )
     return buf;
 }
 
-void TipContr::modLoad( )
+void TipContr::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -268,11 +269,6 @@ void TipContr::modLoad( )
 	    if(!lbPresent(l_id)) lbReg(new Lib(l_id.c_str(),"","*.*"));		
 	    c_el.cfg("ID").setS("");		
 	}	
-	
-	//-- Load present libraries --
-	lbList(tdb_ls);
-        for( int l_id = 0; l_id < tdb_ls.size(); l_id++ )
-    	    lbAt(tdb_ls[l_id]).at().load();
     }catch( TError err )
     { 
 	mess_err(err.cat.c_str(),"%s",err.mess.c_str());
@@ -280,17 +276,6 @@ void TipContr::modLoad( )
     }
 }
 
-void TipContr::modSave()
-{   
-    //- Save parameters -
-
-    //- Save function's libraries -
-    vector<string> ls;
-    lbList(ls);
-    for( int l_id = 0; l_id < ls.size(); l_id++ )
-	lbAt(ls[l_id]).at().save();
-}  
-
 void TipContr::modStart( )
 {
     vector<string> lst;
@@ -323,19 +308,15 @@ void TipContr::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
 	TTipDAQ::cntrCmdProc(opt);
-	ctrMkNode("grp",opt,-1,"/br/lib_",_("Library"),0440,"root","root",1,"list","/libs/lb");
+	ctrMkNode("grp",opt,-1,"/br/lib_",_("Library"),0664,"root","root",1,"idm","1");
 	if(ctrMkNode("area",opt,1,"/libs",_("Functions' Libraries")))
-	{
 	    ctrMkNode("list",opt,-1,"/libs/lb",_("Libraries"),0664,"root","root",4,"tp","br","idm","1","s_com","add,del","br_pref","lib_");
-	    ctrMkNode("comm",opt,-1,"/libs/load",_("Load"),0660);
-    	    ctrMkNode("comm",opt,-1,"/libs/save",_("Save"),0660);
-	}
         return;
     }
     
     //- Process command to page -
     string a_path = opt->attr("path");
-    if( a_path == "/libs/lb" )
+    if( a_path == "/br/lib_" || a_path == "/libs/lb" )
     {
 	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )
 	{
@@ -347,8 +328,6 @@ void TipContr::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )	lbReg(new Lib(opt->attr("id").c_str(),opt->text().c_str(),"*.*"));
 	if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )	lbUnreg(opt->attr("id"),1);
     }
-    else if( a_path == "/libs/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	modLoad();
-    else if( a_path == "/libs/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	modSave();
     else TTipDAQ::cntrCmdProc(opt);
 }
 
@@ -371,25 +350,17 @@ BFunc *TipContr::bFuncGet( const char *nm )
 //*************************************************
 Contr::Contr( string name_c, const string &daq_db, ::TElem *cfgelem) :
     ::TController(name_c, daq_db, cfgelem), TValFunc(name_c.c_str(),NULL,false), prc_st(false), 
-    endrun_req(false), sync_st(false),
-    m_per(cfg("PERIOD").getId()), m_prior(cfg("PRIOR").getId()), m_dbper(cfg("PER_DB").getId()), 
+    endrun_req(false),
+    m_per(cfg("PERIOD").getId()), m_prior(cfg("PRIOR").getId()),  
     m_iter(cfg("ITER").getId()), m_fnc(cfg("FUNC").getSd())
 {
     cfg("PRM_BD").setS("JavaLikePrm_"+name_c);
     setDimens(true);
-
-    //- Create sync DB timer -
-    struct sigevent sigev;
-    sigev.sigev_notify = SIGEV_THREAD;
-    sigev.sigev_value.sival_ptr = this;
-    sigev.sigev_notify_function = TaskDBSync;
-    sigev.sigev_notify_attributes = NULL;
-    timer_create(CLOCK_REALTIME,&sigev,&sncDBTm);
 }
 		
 Contr::~Contr()
 {
-    timer_delete(sncDBTm);
+
 }
 
 void Contr::postDisable(int flag)
@@ -432,9 +403,9 @@ void Contr::disable_( )
     setFunc(NULL);
 }
 
-void Contr::load( )
+void Contr::load_( )
 {
-    TController::load( );
+    TController::load_( );
     
     loadFunc( );
 }
@@ -460,9 +431,9 @@ void Contr::loadFunc( )
     }
 }
 
-void Contr::save( )
+void Contr::save_( )
 {
-    TController::save();
+    TController::save_();
     
     if( func() != NULL )
     {
@@ -516,12 +487,6 @@ void Contr::start_( )
 	if( TSYS::eventWait(prc_st, true, nodePath()+"start",5) )
             throw TError(nodePath().c_str(),_("Acquisition task no started!"));
     }
-    
-    //- Start interval timer for periodic thread creating -
-    struct itimerspec itval;
-    itval.it_interval.tv_sec = itval.it_value.tv_sec = m_dbper;
-    itval.it_interval.tv_nsec = itval.it_value.tv_nsec = 0;
-    timer_settime(sncDBTm, 0, &itval, NULL);
 }
 
 void Contr::stop_( )
@@ -535,14 +500,6 @@ void Contr::stop_( )
             throw TError(nodePath().c_str(),_("Acquisition task no stoped!"));
         pthread_join( procPthr, NULL );
     }
-    
-    //- Stop interval timer for periodic thread creating -
-    struct itimerspec itval;
-    itval.it_interval.tv_sec = itval.it_interval.tv_nsec =
-        itval.it_value.tv_sec = itval.it_value.tv_nsec = 0;
-    timer_settime(sncDBTm, 0, &itval, NULL);
-    if( TSYS::eventWait( sync_st, false, nodePath()+"sync_stop",5) )
-        throw TError(nodePath().c_str(),_("Controller sync DB no stoped!"));
 }
 
 void *Contr::Task( void *icntr )
@@ -557,7 +514,11 @@ void *Contr::Task( void *icntr )
     while(!cntr.endrun_req)
     {	
 	for( int i_it = 0; i_it < cntr.m_iter; i_it++ )
-	    try{ cntr.calc(); } 
+	    try
+	    { 
+		cntr.calc();
+		cntr.modif();
+	    } 
 	    catch(TError err) 
 	    { 
 		mess_err(err.cat.c_str(),"%s",err.mess.c_str() ); 
@@ -578,42 +539,11 @@ void *Contr::Task( void *icntr )
     return NULL;    
 }
 
-void Contr::TaskDBSync(union sigval obj)
-{
-    Contr *cntr = (Contr *)obj.sival_ptr;
-    if( cntr->sync_st )  return;
-    cntr->sync_st = true;
-	    
-    try{ cntr->save( ); }
-    catch(TError err) 
-    { 
-	mess_err(err.cat.c_str(),"%s",err.mess.c_str() );
-	mess_err(cntr->nodePath().c_str(),_("Save controller error."));
-    }
-    
-    cntr->sync_st = false;
-}
-
 TParamContr *Contr::ParamAttach( const string &name, int type )
 {
     return new Prm(name,&owner().tpPrmAt(type));
 }
 
-bool Contr::cfgChange( TCfg &cfg )
-{
-    if( startStat() )
-    {
-        struct itimerspec itval;
-        if( cfg.fld().name() == "PER_DB" )
-        {
-            itval.it_interval.tv_sec = itval.it_value.tv_sec = m_dbper;
-            itval.it_interval.tv_nsec = itval.it_value.tv_nsec = 0;
-            timer_settime(sncDBTm, 0, &itval, NULL);
-	}
-    }
-    return true;
-}
-
 void Contr::cntrCmdProc( XMLNode *opt )
 {
     //- Get page info -
@@ -682,10 +612,14 @@ void Contr::cntrCmdProc( XMLNode *opt )
 		if(n_val)	n_val->childAdd("el")->setText(getS(id));
 	    }	    	    	
 	}
-        if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )	((Func *)func())->ioAdd( new IO("new","New IO",IO::Real,IO::Default) );
-        if( ctrChkNode(opt,"ins",0664,"root","root",SEQ_WR) )	((Func *)func())->ioIns( new IO("new","New IO",IO::Real,IO::Default), atoi(opt->attr("row").c_str()) );
-        if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )	((Func *)func())->ioDel( atoi(opt->attr("row").c_str()) );
-        if( ctrChkNode(opt,"move",0664,"root","root",SEQ_WR) )	((Func *)func())->ioMove( atoi(opt->attr("row").c_str()), atoi(opt->attr("to").c_str()) );
+        if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )	
+	{ ((Func *)func())->ioAdd( new IO("new","New IO",IO::Real,IO::Default) ); modif(); }
+        if( ctrChkNode(opt,"ins",0664,"root","root",SEQ_WR) )	
+	{ ((Func *)func())->ioIns( new IO("new","New IO",IO::Real,IO::Default), atoi(opt->attr("row").c_str()) ); modif(); }
+        if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )	
+	{ ((Func *)func())->ioDel( atoi(opt->attr("row").c_str()) ); modif(); }
+        if( ctrChkNode(opt,"move",0664,"root","root",SEQ_WR) )	
+	{ ((Func *)func())->ioMove( atoi(opt->attr("row").c_str()), atoi(opt->attr("to").c_str()) ); modif(); }
         if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )
 	{
             int row = atoi(opt->attr("row").c_str());
@@ -700,6 +634,8 @@ void Contr::cntrCmdProc( XMLNode *opt )
 		case 3:	func()->io(row)->setFlg( func()->io(row)->flg()^((atoi(opt->text().c_str())^func()->io(row)->flg())&(IO::Output|IO::Return)) );	break;
 		case 4:	setS(row,opt->text());	break;
 	    }
+	    modif();
+	    if( !((Func *)func())->owner().DB().empty() ) ((Func *)func())->modif();
 	}
     }	
     else if( a_path == "/fnc/tp" && ctrChkNode(opt) )
@@ -722,6 +658,7 @@ void Contr::cntrCmdProc( XMLNode *opt )
 	{
 	    ((Func *)func())->setProg(opt->text().c_str());
 	    ((Func *)func())->progCompile();
+	    modif();
 	}
     }
     else TController::cntrCmdProc(opt);
