@@ -100,7 +100,7 @@ string TTpContr::optDescr( )
     return buf;
 }
 
-void TTpContr::modLoad( )
+void TTpContr::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -185,16 +185,6 @@ TParamContr *TMdContr::ParamAttach( const string &name, int type )
     return new TMdPrm(name,&owner().tpPrmAt(type));
 }
 
-void TMdContr::load( )
-{
-    TController::load( );
-}
-
-void TMdContr::save( )
-{
-    TController::save();
-}
-
 void TMdContr::start_( )
 {      
     //- Former process parameters list -
@@ -219,7 +209,7 @@ void TMdContr::start_( )
         pthread_create(&procPthr,&pthr_attr,TMdContr::Task,this);
         pthread_attr_destroy(&pthr_attr);
         if( TSYS::eventWait(prc_st, true, nodePath()+"start",5) )
-            throw TError(nodePath().c_str(),_("Acquisition task no started!"));    
+            throw TError(nodePath().c_str(),_("Acquisition task no started!"));
     }
 }
 
@@ -386,9 +376,9 @@ void TMdPrm::disable()
     TParamContr::disable();
 }
 
-void TMdPrm::load( )
+void TMdPrm::load_( )
 {
-    TParamContr::load();
+    TParamContr::load_();
     try
     {
 	mode(mode(),m_prm);
@@ -418,9 +408,9 @@ void TMdPrm::loadIO()
     }
 }
 
-void TMdPrm::save( )
+void TMdPrm::save_( )
 {
-    TParamContr::save();
+    TParamContr::save_();
     saveIO();
 }
 
@@ -750,25 +740,26 @@ void TMdPrm::calc( bool first, bool last )
 	
         //- Get input links -
         for( int i_l = 0; i_l < lnkSize(); i_l++ )
-            if( !lnk(i_l).aprm.freeStat() )
-		switch(tmpl->val.ioType(lnk(i_l).io_id))
-		{
-		    case IO::String:
-			tmpl->val.setS(lnk(i_l).io_id,lnk(i_l).aprm.at().getS());
-			break;
-		    case IO::Integer:
-			tmpl->val.setI(lnk(i_l).io_id,lnk(i_l).aprm.at().getI());
-			break;
-		    case IO::Real:
-			tmpl->val.setR(lnk(i_l).io_id,lnk(i_l).aprm.at().getR());
-			break;
-		    case IO::Boolean:
-			tmpl->val.setB(lnk(i_l).io_id,lnk(i_l).aprm.at().getB());
-			break;
-		}
+            if( lnk(i_l).aprm.freeStat() )	tmpl->val.setS(lnk(i_l).io_id,EVAL_STR);
+	    else switch(tmpl->val.ioType(lnk(i_l).io_id))
+	    {
+	        case IO::String:
+	    	    tmpl->val.setS(lnk(i_l).io_id,lnk(i_l).aprm.at().getS());
+		    break;
+		case IO::Integer:
+		    tmpl->val.setI(lnk(i_l).io_id,lnk(i_l).aprm.at().getI());
+		    break;
+		case IO::Real:
+		    tmpl->val.setR(lnk(i_l).io_id,lnk(i_l).aprm.at().getR());
+		    break;
+		case IO::Boolean:
+		    tmpl->val.setB(lnk(i_l).io_id,lnk(i_l).aprm.at().getB());
+		    break;
+	    }
 	
 	//- Calc template -
         tmpl->val.calc();
+	modif();
 	
         //- Put output links -
         for( int i_l = 0; i_l < lnkSize(); i_l++ )
@@ -808,8 +799,8 @@ void TMdPrm::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
         TParamContr::cntrCmdProc(opt);
-	ctrMkNode("fld",opt,-1,"/prm/cfg/MODE",cfg("MODE").fld().descr(),0660,"root","root",3,"tp","str","dest","select","select","/cfg/mode_lst");
-	ctrMkNode("fld",opt,-1,"/prm/cfg/PRM",cfg("PRM").fld().descr(),0660,"root","root",3,"tp","str","dest","sel_ed","select","/cfg/prmp_lst");
+	ctrMkNode("fld",opt,-1,"/prm/cfg/MODE",cfg("MODE").fld().descr(),0660,"root","root",3,"tp","str","dest","select","select","/prm/cfg/mode_lst");
+	ctrMkNode("fld",opt,-1,"/prm/cfg/PRM",cfg("PRM").fld().descr(),0660,"root","root",3,"tp","str","dest","sel_ed","select","/prm/cfg/prmp_lst");
         if( mode() == TMdPrm::Template && ctrMkNode("area",opt,-1,"/cfg",_("Template config")) )
 	{
             ctrMkNode("fld",opt,-1,"/cfg/attr_only",_("Only atributes show"),0664,"root","root",1,"tp","bool");
@@ -867,12 +858,12 @@ void TMdPrm::cntrCmdProc( XMLNode *opt )
 		m_prm = owner().owner().modId()+"."+owner().id();
 	    mode( (TMdPrm::Mode)m_mode, m_prm ); 
 	} catch(...){ disable(); throw; }    
-    else if( a_path == "/cfg/mode_lst" && ctrChkNode(opt) )
+    else if( a_path == "/prm/cfg/mode_lst" && ctrChkNode(opt) )
     {
 	opt->childAdd("el")->setAttr("id",TSYS::int2str(TMdPrm::DirRefl))->setText(_("Direct reflection"));
 	opt->childAdd("el")->setAttr("id",TSYS::int2str(TMdPrm::Template))->setText(_("Template"));
     }
-    else if( a_path == "/cfg/prmp_lst" && ctrChkNode(opt) )
+    else if( a_path == "/prm/cfg/prmp_lst" && ctrChkNode(opt) )
     {
 	int c_lv = 0;
 	string c_path = "", c_el;
@@ -931,10 +922,16 @@ void TMdPrm::cntrCmdProc( XMLNode *opt )
 	    int c_lvl = 0;
             for( int c_off = 0; TSYS::strSepParse(p_vl,0,'.',&c_off).size(); c_lvl++ );
 	    AutoHD<TValue> prm;
-	    if(c_lvl==3) 
+	    if(c_lvl==3)
+	    {
+		if( TSYS::strSepParse(p_vl,0,'.') == owner().owner().modId() && 
+			TSYS::strSepParse(p_vl,1,'.') == owner().id() && 
+			TSYS::strSepParse(p_vl,2,'.') == id() )
+		    throw TError(nodePath().c_str(),_("Self to self linking is error."));
 		prm = SYS->daq().at().at(TSYS::strSepParse(p_vl,0,'.')).at().
 				      at(TSYS::strSepParse(p_vl,1,'.')).at().
 				      at(TSYS::strSepParse(p_vl,2,'.'));
+	    }
             for( int i_l = 0; i_l < lnkSize(); i_l++ )
                 if( p_nm == TSYS::strSepParse(tmpl->val.func()->io(lnk(i_l).io_id)->def(),0,'|') )
         	{
@@ -945,6 +942,7 @@ void TMdPrm::cntrCmdProc( XMLNode *opt )
 			if( prm.at().vlPresent(p_attr) )
 			{ 
 			    lnk(i_l).prm_attr= p_vl+"."+p_attr; 
+			    modif( );
 			    noonly_no_set = false; 
 			}
 			else no_set+=p_attr+",";
@@ -1012,11 +1010,16 @@ void TMdPrm::cntrCmdProc( XMLNode *opt )
     	    int i_io = atoi(a_path.substr(12).c_str());
     	    if( tmpl->val.func()->io(i_io)->flg()&TPrmTempl::CfgLink )
             {
+		if( TSYS::strSepParse(opt->text(),0,'.') == owner().owner().modId() && 
+			TSYS::strSepParse(opt->text(),1,'.') == owner().id() && 
+			TSYS::strSepParse(opt->text(),2,'.') == id() )
+		    throw TError(nodePath().c_str(),_("Self to self linking is error."));
                 lnk(lnkId(i_io)).prm_attr = opt->text();
                 mode( (TMdPrm::Mode)m_mode, m_prm );
             }
             else if( tmpl->val.func()->io(i_io)->flg()&TPrmTempl::CfgPublConst )
 		tmpl->val.setS(i_io,opt->text());
+	    modif();
         }
     }
     else TParamContr::cntrCmdProc(opt);
