@@ -33,7 +33,7 @@
 #define MOD_NAME    "Data sources transporter"
 #define MOD_TYPE    "DAQ"
 #define VER_TYPE    VER_CNTR
-#define VERSION     "0.3.0"
+#define VERSION     "0.3.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Allow to make transport data sources of remote OpenSCADA station to local OpenSCADA station."
 #define LICENSE     "GPL"
@@ -93,7 +93,7 @@ string TTpContr::optDescr( )
     return buf;
 }
 
-void TTpContr::modLoad( )
+void TTpContr::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -175,22 +175,14 @@ TParamContr *TMdContr::ParamAttach( const string &name, int type )
     return new TMdPrm(name,&owner().tpPrmAt(type));
 }
 
-void TMdContr::load( )
-{
-    TController::load( );
-}
-
-void TMdContr::save( )
-{
-    TController::save();
-}
-
 void TMdContr::enable_( )
 {
     string statv, cp_el, daqtp, cntrnm, prmnm, cntrpath;
     vector<string> prm_ls;
     XMLNode req("list");
     
+    bool en_err = false;
+    
     //- Remote station scaning -
     for( int st_off = 0; (statv=TSYS::strSepParse(m_stations,0,'\n',&st_off)).size(); )
 	//- Controllers and parameters scaning -
@@ -209,9 +201,9 @@ void TMdContr::enable_( )
 		{
 		    //-- Get attributes list --
     		    req.clear()->setName("get")->setAttr("path",cntrpath+"%2fprm%2fprm");
-		    if( !mod->cntrIfCmd(req) )
-			for( int i_ch = 0; i_ch < req.childSize(); i_ch++ )
-			    prm_ls.push_back(req.childGet(i_ch)->attr("id"));
+		    if( mod->cntrIfCmd(req) || req.childSize() == 0 )	en_err = true;
+		    else for( int i_ch = 0; i_ch < req.childSize(); i_ch++ )
+			prm_ls.push_back(req.childGet(i_ch)->attr("id"));
 		}
 		else prm_ls.push_back(prmnm);
 		
@@ -222,7 +214,7 @@ void TMdContr::enable_( )
 		    {		    
 			//--- Parameter name request and make new parameter object ---
 			req.clear()->setName("get")->setAttr("path",cntrpath+prm_ls[i_p]+"/%2fprm%2fcfg%2fNAME");
-			if( mod->cntrIfCmd(req) )	continue;
+			if( mod->cntrIfCmd(req) ) { en_err = true; continue; }
 			add(prm_ls[i_p],owner().tpPrmToId("std"));
 			at(prm_ls[i_p]).at().setName(req.text());
 		    }
@@ -232,6 +224,8 @@ void TMdContr::enable_( )
 		    at(prm_ls[i_p]).at().load();
 		}
 	    }catch(TError err){ }
+
+    if( en_err ) throw TError(nodePath().c_str(),_("Some enable errors is present"));
 }
 
 void TMdContr::start_( )
@@ -302,9 +296,10 @@ void *TMdContr::Task( void *icntr )
 		//-- Update parameter's values --
 		cntr.p_hd[i_p].at().update();
 		//-- Check sync moment and sync parameter's structure --
-		unsigned int div = (unsigned int)(cntr.m_sync/cntr.m_per);
+		unsigned int div = (unsigned int)(cntr.m_sync/cntr.period());
 		if( div && (it_cnt+i_p)%div == 0 )
 		{ 
+		    cntr.p_hd[i_p].at().modifG();
 		    cntr.p_hd[i_p].at().load();
 		    //-- Check for delete parameter --
 		    if( cntr.p_hd[i_p].at().isDel() )
@@ -325,8 +320,8 @@ void *TMdContr::Task( void *icntr )
     
     	    //- Calc next work time and sleep -
     	    clock_gettime(CLOCK_REALTIME,&get_tm);
-	    work_tm = (((long long)get_tm.tv_sec*1000000000+get_tm.tv_nsec)/(long long)(cntr.m_per*1000000000) + 1)*(long long)(cntr.m_per*1000000000);
-	    if(last_tm == work_tm)	work_tm+=(long long)(cntr.m_per*1000000000);	//Fix early call
+	    work_tm = (((long long)get_tm.tv_sec*1000000000+get_tm.tv_nsec)/(long long)(cntr.period()*1000000000) + 1)*(long long)(cntr.period()*1000000000);
+	    if(last_tm == work_tm)	work_tm+=(long long)(cntr.period()*1000000000);	//Fix early call
     	    last_tm = work_tm;
 	    get_tm.tv_sec = work_tm/1000000000; get_tm.tv_nsec = work_tm%1000000000;
     	    clock_nanosleep(CLOCK_REALTIME,TIMER_ABSTIME,&get_tm,NULL);
@@ -413,7 +408,7 @@ void TMdPrm::setCntrAdr( const string &vl )
     m_cntr_adr+=vl+";";
 }
 
-void TMdPrm::load( )
+void TMdPrm::load_( )
 {
     string scntr;
     XMLNode req("get");
