@@ -34,7 +34,7 @@
 #define MOD_NAME    "HTTP-realisation"
 #define MOD_TYPE    "Protocol"
 #define VER_TYPE    VER_PROT
-#define M_VERSION   "1.3.0"
+#define M_VERSION   "1.3.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Allow support HTTP for WWW based UIs."
 #define LICENSE     "GPL"
@@ -93,7 +93,7 @@ string TProt::optDescr( )
     return(buf);
 }
 
-void TProt::modLoad( )
+void TProt::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
