@@ -83,7 +83,7 @@ TProt::~TProt( )
     res.release();
 }
 
-int TProt::ses_open( const char *user,const char *pass )
+int TProt::sesOpen( const char *user,const char *pass )
 {
     if( !SYS->security().at().usrPresent(user) || !SYS->security().at().usrAt(user).at().auth(pass) )
 	return -1;
@@ -103,9 +103,9 @@ int TProt::ses_open( const char *user,const char *pass )
     return id_ses;
 }
 
-void TProt::ses_close(int id_ses)
+void TProt::sesClose( int id_ses )
 {
-    ResAlloc res(ses_res,true);
+    ResAlloc res( ses_res, true );
     int i_s = 0;
     while( i_s < auth_lst.size() )
 	if( time(NULL) > (auth_lst[i_s].t_auth+10*authTime()) || auth_lst[i_s].id_ses == id_ses )
@@ -113,7 +113,7 @@ void TProt::ses_close(int id_ses)
     	else i_s++;
 }
 
-TProt::SAuth TProt::ses_get(int id_ses)
+TProt::SAuth TProt::sesGet(int id_ses)
 {
     ResAlloc res(ses_res,true);
     time_t cur_tm = time(NULL);
@@ -143,7 +143,7 @@ string TProt::optDescr( )
     return(buf);
 }			
 
-void TProt::modLoad( )
+void TProt::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -169,7 +169,7 @@ void TProt::modLoad( )
     m_t_auth = atoi( TBDS::genDBGet(nodePath()+"SessTimeLife",TSYS::int2str(m_t_auth)).c_str() );
 }
 
-void TProt::modSave( )
+void TProt::save_( )
 {
     TBDS::genDBSet(nodePath()+"SessTimeLife",TSYS::int2str(m_t_auth));
 }
@@ -185,6 +185,8 @@ string TProt::outMess( const string &in, TTransportOut &tro )
     string req, resp;
     int rez, resp_len;
 
+    ResAlloc res( ores, true );
+
     int in_off = 0;
     string user = TSYS::strSepParse(in,0,'\n',&in_off);
     string pass = TSYS::strSepParse(in,0,'\n',&in_off);
@@ -215,14 +217,14 @@ string TProt::outMess( const string &in, TTransportOut &tro )
             buf1[0] = 0;
             if(sscanf(resp.c_str(),"REZ %d %255s\n",&rez,buf1)<=0)
         	throw TError(nodePath().c_str(),_("Station respond <%s> error!"),tro.id().c_str());
-            if(rez == 1)        { tro.setPrm1(-1); continue; }
-            if(rez > 0) throw TError(nodePath().c_str(),_("Station <%s> error: %d:%s!"),tro.id().c_str(),rez,buf1);
+            if( rez == 1 )	{ tro.setPrm1(-1); continue; }
+            if( rez > 0 )	throw TError(nodePath().c_str(),_("Station <%s> error: %d:%s!"),tro.id().c_str(),rez,buf1);
             int head_end = resp.find("\n",0);
-            if(head_end == string::npos)
+            if( head_end == string::npos )
         	throw TError(nodePath().c_str(),_("Station <%s> error: Respond broken!"),tro.id().c_str());
             int resp_size = atoi(buf1);
             //-- Wait tail --
-            while(resp.size() < resp_size+head_end+sizeof('\n'))
+            while( resp.size() < resp_size+head_end+sizeof('\n') )
             {
         	resp_len = tro.messIO(NULL,0,buf,sizeof(buf),20);
         	resp.append(buf,resp_len);
@@ -243,11 +245,7 @@ void TProt::cntrCmdProc( XMLNode *opt )
         TProtocol::cntrCmdProc(opt);
 	if(ctrMkNode("area",opt,1,"/prm",_("Parameters")))
     	    if(ctrMkNode("area",opt,1,"/prm/cfg",_("Module options")))
-	    {
     		ctrMkNode("fld",opt,-1,"/prm/cfg/lf_tm",_("Life time of auth sesion(min)"),0660,"root","root",1,"tp","dec");
-    		ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660);
-    		ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660);
-	    }
         ctrMkNode("fld",opt,-1,"/help/g_help",_("Options help"),0440,"root","root",3,"tp","str","cols","90","rows","5");
         return;
     }
@@ -256,12 +254,10 @@ void TProt::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/prm/cfg/lf_tm" )
     {
-        if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )   opt->setText(TSYS::int2str(m_t_auth));
-        if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )   m_t_auth = atoi(opt->text().c_str());
+        if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )   opt->setText( TSYS::int2str(authTime()) );
+        if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )   setAuthTime( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440) )   opt->setText(optDescr());
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )  modLoad();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )  modSave();
     else TProtocol::cntrCmdProc(opt);
 }
 
@@ -298,20 +294,20 @@ bool TProtIn::mess( const string &request, string &answer, const string &sender
 	char user[256] = "", 
 	     pass[256] = "";
 	sscanf(req.c_str(),"SES_OPEN %255s %255s",user,pass);
-	ses_id = mod->ses_open(user,pass);
+	ses_id = mod->sesOpen( user, pass );
 	if(ses_id < 0)	answer = "REZ 1 Auth error. User or password error.\n";
 	else answer = "REZ 0 "+TSYS::int2str(ses_id)+"\n";
     }
     else if( req.substr(0,9) == "SES_CLOSE" )
     {
 	sscanf(req.c_str(),"SES_CLOSE %d",&ses_id);
-	mod->ses_close(ses_id);
+	mod->sesClose(ses_id);
 	answer = "REZ 0\n";
     }
     else if( req.substr(0,3) == "REQ" )
     {
 	sscanf(req.c_str(),"REQ %d %d",&ses_id,&req_sz);
-	TProt::SAuth auth = mod->ses_get(ses_id);
+	TProt::SAuth auth = mod->sesGet(ses_id);
 	if( !auth.t_auth ) answer = "REZ 1 Auth error. Session no valid.\n";
 	else
 	{
