@@ -32,7 +32,7 @@
 #define MOD_TYPE    "Special"
 #define VER_TYPE    VER_SPC
 #define SUB_TYPE    "LIB"
-#define VERSION     "1.0.0"
+#define VERSION     "1.0.1"
 //*************************************************
 
 FLibComplex1::Lib *FLibComplex1::mod;
@@ -131,13 +131,13 @@ void Lib::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
         TSpecial::cntrCmdProc(opt);
-	ctrMkNode("grp",opt,-1,"/br/fnc_",_("Function"),0444,"root","root",1,"list","/prm/func");
+	ctrMkNode("grp",opt,-1,"/br/fnc_",_("Function"),0444,"root","root",1,"idm","1");
         ctrMkNode("list",opt,-1,"/prm/func",_("Functions"),0444,"root","root",3,"tp","br","idm","1","br_pref","fnc_");	
 	return;
     }
     //- Process command to page -
     string a_path = opt->attr("path");
-    if( a_path == "/prm/func" && ctrChkNode(opt) )
+    if( (a_path == "/br/fnc_" || a_path == "/prm/func") && ctrChkNode(opt) )
     {
         vector<string> lst;
         list(lst);
