@@ -308,7 +308,7 @@ class varhGetB : public TFunction
     public:
 	varhGetB( ) : TFunction("varhGetB")
 	{
-	    ioAdd( new IO("val",_("Return value"),IO::Integer,IO::Return) );
+	    ioAdd( new IO("val",_("Return value"),IO::Boolean,IO::Return) );
 	    ioAdd( new IO("id",_("Buffer id"),IO::Integer,IO::Default) );
 	    ioAdd( new IO("sec",_("Seconds"),IO::Integer,IO::Output) );
 	    ioAdd( new IO("usec",_("Microseconds"),IO::Integer,IO::Output) );
@@ -516,6 +516,165 @@ class messPut : public TFunction
 	}
 };
 
+//*************************************************
+//* String manipulation functions                 *
+
+//*************************************************
+//* String size                                   *
+//*************************************************
+class strSize : public TFunction
+{
+    public:
+	strSize( ) : TFunction("strSize")
+	{
+	    ioAdd( new IO("rez",_("Rezult"),IO::Integer,IO::Return) );
+	    ioAdd( new IO("str",_("String"),IO::String,IO::Default) );
+	}
+	
+	string name( )	{ return _("String: Get size"); }
+	string descr( )	{ return _("Use for string size getting."); }
+
+	void calc( TValFunc *val )
+	{
+	    val->setI(0,val->getS(1).size());
+	}
+};
+
+//*************************************************
+//* String substring                              *
+//*************************************************
+class strSubstr : public TFunction
+{
+    public:
+	strSubstr( ) : TFunction("strSubstr")
+	{
+	    ioAdd( new IO("rez",_("Rezult"),IO::String,IO::Return) );
+	    ioAdd( new IO("str",_("String"),IO::String,IO::Default) );
+	    ioAdd( new IO("pos",_("Position"),IO::Integer,IO::Default,"0") );
+	    ioAdd( new IO("n"  ,_("Number"),IO::Integer,IO::Default,"-1") );
+	}
+	
+	string name( )	{ return _("String: Get substring"); }
+	string descr( )	{ return _("Use for substring getting."); }
+
+	void calc( TValFunc *val )
+	{
+	    string vl  = val->getS(1);
+	    int    pos = val->getI(2);
+	    if( pos<0 || pos>=vl.size() ) return;
+	    int	   n   = val->getI(3);
+	    if( n < 0 )	n = vl.size();
+	    n = vmin(vl.size()-pos,n);
+	    val->setS(0,vl.substr(pos,n));
+	}
+};
+
+//*************************************************
+//* String insertion                              *
+//*************************************************
+class strInsert : public TFunction
+{
+    public:
+	strInsert( ) : TFunction("strInsert")
+	{
+	    ioAdd( new IO("str",_("String"),IO::String,IO::Output) );
+	    ioAdd( new IO("pos",_("Position"),IO::Integer,IO::Default,"0") );
+	    ioAdd( new IO("ins",_("Insert string"),IO::String,IO::Default) );
+	}
+	
+	string name( )	{ return _("String: Insert string to other string"); }
+	string descr( )	{ return _("Use for insertion string to other string."); }
+
+	void calc( TValFunc *val )
+	{
+	    string vl = val->getS(0);
+	    int   pos = val->getI(1);
+	    pos = vmax(0,vmin(vl.size(),pos));
+	    val->setS(0,vl.insert(pos,val->getS(2)));
+	}
+};
+
+//*************************************************
+//* String replace                                *
+//*************************************************
+class strReplace : public TFunction
+{
+    public:
+	strReplace( ) : TFunction("strReplace")
+	{
+	    ioAdd( new IO("str",_("String"),IO::String,IO::Output) );
+	    ioAdd( new IO("pos",_("Position"),IO::Integer,IO::Default,"0") );
+	    ioAdd( new IO("n"  ,_("Number"),IO::Integer,IO::Default,"-1") );	    
+	    ioAdd( new IO("repl",_("Replace string"),IO::String,IO::Default) );
+	}
+	
+	string name( )	{ return _("String: Replace part string on other string"); }
+	string descr( )	{ return _("Use for replacing part string on other string."); }
+
+	void calc( TValFunc *val )
+	{
+	    string vl  = val->getS(0);
+	    int    pos = val->getI(1);
+	    if( pos<0 || pos>=vl.size() ) return;
+	    int	   n   = val->getI(2);
+	    if( n < 0 )	n = vl.size();
+	    n = vmin(vl.size()-pos,n);
+	    val->setS(0,vl.replace(pos,n,val->getS(3)));
+	}
+};
+
+//*************************************************
+//* String parsing on separator                   *
+//*************************************************
+class strParse : public TFunction
+{
+    public:
+	strParse( ) : TFunction("strParse")
+	{
+	    ioAdd( new IO("rez",_("Rezult"),IO::String,IO::Return) );
+	    ioAdd( new IO("str",_("String"),IO::String,IO::Default) );
+	    ioAdd( new IO("lev",_("Level"),IO::Integer,IO::Default) );
+	    ioAdd( new IO("sep",_("Separator"),IO::String,IO::Default,".") );
+	    ioAdd( new IO("off",_("Offset"),IO::Integer,IO::Output) );
+	}
+	
+	string name( )	{ return _("String: Parse on separator"); }
+	string descr( )	{ return _("Use for parse string on separator."); }
+
+	void calc( TValFunc *val )
+	{
+	    string sep = val->getS(3);
+	    int off = val->getI(4);
+	    val->setS(0,TSYS::strSepParse(val->getS(1),val->getI(2),sep.size()?sep[0]:' ',&off));
+	    val->setI(4,off);
+	}
+};
+
+//*************************************************
+//* Path parsing                                  *
+//*************************************************
+class strParsePath : public TFunction
+{
+    public:
+	strParsePath( ) : TFunction("strParsePath")
+	{
+	    ioAdd( new IO("rez",_("Rezult"),IO::String,IO::Return) );
+	    ioAdd( new IO("path",_("Path"),IO::String,IO::Default) );
+	    ioAdd( new IO("lev",_("Level"),IO::Integer,IO::Default) );
+	    ioAdd( new IO("off",_("Offset"),IO::Integer,IO::Output) );
+	}
+	
+	string name( )	{ return _("String: Path parse"); }
+	string descr( )	{ return _("Use for parse path on elements."); }
+
+	void calc( TValFunc *val )
+	{
+	    int off = val->getI(3);
+	    val->setS(0,TSYS::pathLev(val->getS(1),val->getI(2),true,&off));
+	    val->setI(3,off);
+	}
+};
+
 }
 
 #endif //SYSFNC_H
