@@ -147,7 +147,7 @@ string TTest::optDescr( )
     return(buf);
 }			
 
-void TTest::modLoad( )
+void TTest::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -408,7 +408,6 @@ void TTest::Test( const string &id, XMLNode *t_n )
 	
 	bd.at().open(n_bd);
 	bd.at().at(n_bd).at().setAddr(bd_addr);
-	bd.at().at(n_bd).at().setCreate(true);
 	bd.at().at(n_bd).at().enable();
 			    
 	mess_info(test_cat,"Open Table: <%s>",n_tbl.c_str());
@@ -422,7 +421,7 @@ void TTest::Test( const string &id, XMLNode *t_n )
 	bd_cfg.elem().fldAdd( new TFld("descr","Description fields",TFld::String,0,"50") );
 	bd_cfg.elem().fldAdd( new TFld("val","Field value",TFld::Real,0,"10.2","5") );
 	bd_cfg.elem().fldAdd( new TFld("id","Field id",TFld::Integer,0,"7","34") );
-	bd_cfg.elem().fldAdd( new TFld("stat","Field stat",TFld::Boolean,0,"","1") );
+	bd_cfg.elem().fldAdd( new TFld("stat","Field stat",TFld::Boolean,0,"1","1") );
 	
 	//Test of The create fields
 	mess_info(test_cat,"Create fields!");
