@@ -45,7 +45,7 @@
 #define MOD_NAME    "Sockets"
 #define MOD_TYPE    "Transport"
 #define VER_TYPE    VER_TR
-#define VERSION     "1.3.0"
+#define VERSION     "1.3.1"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Allow sockets based transport. Support inet and unix sockets. Inet socket use TCP and UDP protocols."
 #define LICENSE     "GPL"
@@ -117,7 +117,7 @@ string TTransSock::optDescr( )
     return(buf);
 }
 
-void TTransSock::modLoad( )
+void TTransSock::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -526,18 +526,18 @@ void TSocketIn::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/bs/q_ln" )
     {
-	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText(TSYS::int2str(max_queue));
-	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	max_queue = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText( TSYS::int2str(maxQueue()) );
+	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	setMaxQueue( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/cl_n" )
     {
-	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText(TSYS::int2str(max_fork));
-	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	max_fork = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText( TSYS::int2str(maxFork()) );
+	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	setMaxFork( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/bs/bf_ln" )
     {
-	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) ) 	opt->setText(TSYS::int2str(buf_len));
-	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	buf_len = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) ) 	opt->setText( TSYS::int2str(bufLen()) );
+	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	setBufLen( atoi(opt->text().c_str()) );
     }
     else TTransportIn::cntrCmdProc(opt);
 }
@@ -558,6 +558,8 @@ TSocketOut::~TSocketOut()
 
 void TSocketOut::start()
 {
+    ResAlloc res( wres, true ); 
+    
     if( run_st ) return;
 
     string s_type = TSYS::strSepParse(addr(),0,':');
@@ -593,6 +595,8 @@ void TSocketOut::start()
 	{
 	    if( (sock_fd = socket(PF_INET,SOCK_STREAM,0) )== -1 )
         	throw TError(nodePath().c_str(),_("Error create TCP socket: %s!"),strerror(errno));
+	    int vl = 1;
+	    setsockopt(sock_fd,SOL_SOCKET,SO_REUSEADDR,&vl,sizeof(int));
 	}	
 	else if( type == SOCK_UDP )
 	{
@@ -630,6 +634,8 @@ void TSocketOut::start()
 
 void TSocketOut::stop()
 {
+    ResAlloc res( wres, true ); 
+
     if( !run_st ) return;
     
     if( sock_fd >= 0 )
@@ -643,6 +649,9 @@ void TSocketOut::stop()
 int TSocketOut::messIO( const char *obuf, int len_ob, char *ibuf, int len_ib, int time )
 {
     int kz;
+    
+    ResAlloc res( wres, true ); 
+    
     if( !run_st ) throw TError(nodePath().c_str(),_("Transport no started!"));    
     
     //- Write request -
