@@ -79,10 +79,18 @@ class TSocketIn: public TTransportIn
 	 *   UNIX - UNIX socket with "UNIX:<path>"
 	 */
 	TSocketIn(string name,const string &idb,TElem *el);
-	~TSocketIn();
-	    
-	void start();
-	void stop();
+	~TSocketIn( );
+	
+	int maxQueue( )		{ return max_queue; }
+	int maxFork( )		{ return max_fork; }
+	int bufLen( )		{ return buf_len; }
+	
+	void setMaxQueue( int vl )	{ max_queue = vl; modif(); }
+	void setMaxFork( int vl )	{ max_fork = vl; modif(); }
+	void setBufLen( int vl )	{ buf_len = vl; modif(); }
+	
+	void start( );
+	void stop( );
 	    
     private:
 	//Methods
@@ -132,11 +140,11 @@ class TSocketOut: public TTransportOut
 	 *   UDP  - UDP socket with  "TCP:<host>:<port>"
 	 *   UNIX - UNIX socket with "UNIX:<path>"
 	 */
-	TSocketOut(string name,const string &idb,TElem *el);
-	~TSocketOut();
+	TSocketOut( string name, const string &idb, TElem *el );
+	~TSocketOut( );
 
-	void start();
-	void stop();
+	void start( );
+	void stop( );
 
 	int messIO( const char *obuf, int len_ob, char *ibuf = NULL, int len_ib = 0, int time = 0 );
 
@@ -146,6 +154,7 @@ class TSocketOut: public TTransportOut
 	int	type;        // socket's types 
 	struct sockaddr_in  name_in;
 	struct sockaddr_un  name_un;
+	Res  	wres;
 };
 
 //************************************************
@@ -155,13 +164,14 @@ class TTransSock: public TTipTransport
 {
     public:
 	TTransSock( string name );
-	~TTransSock();
-	    
-	void modLoad( );
+	~TTransSock( );
 	    
 	TTransportIn  *In( const string &name, const string &idb );
-	TTransportOut *Out( const string &name, const string &idb );	    
-	    
+	TTransportOut *Out( const string &name, const string &idb );
+	
+    protected:
+	void load_( );
+
     private:	
 	//Methods
 	string optDescr( );
