@@ -74,7 +74,7 @@ using namespace QTCFG;
 //* ConfApp                                       *
 //*************************************************
 ConfApp::ConfApp( string open_user ) : 
-    que_sz(20), block_tabs(false), pg_info("info"), root(&pg_info), tbl_init(false)
+    que_sz(20), block_tabs(false), pg_info("info"), root(&pg_info), tbl_init(false), copy_buf("0")
 {   
     //- Main window settings -
     setAttribute(Qt::WA_DeleteOnClose,true);
@@ -185,7 +185,7 @@ ConfApp::ConfApp( string open_user ) :
     actPrev->setStatusTip(_("Press for going to previos page"));
     actPrev->setEnabled(false);
     connect(actPrev, SIGNAL(activated()), this, SLOT(pagePrev()));    
-    //-- Previos page --
+    //-- Next page --
     if(!ico_t.load(TUIS::icoPath("next").c_str())) ico_t.load(":/images/next.png");
     actNext = new QAction(QPixmap::fromImage(ico_t),_("&Next"),this);
     actNext->setShortcut(Qt::ALT+Qt::Key_Right);
@@ -194,6 +194,67 @@ ConfApp::ConfApp( string open_user ) :
     actNext->setStatusTip(_("Press for going to next page"));
     actNext->setEnabled(false);
     connect(actNext, SIGNAL(activated()), this, SLOT(pageNext()));    
+    //--- Load item from db ---
+    if(!ico_t.load(TUIS::icoPath("load").c_str())) ico_t.load(":/images/load.png");
+    actDBLoad = new QAction(QPixmap::fromImage(ico_t),_("Load from DB"),this);
+    actDBLoad->setToolTip(_("Load item data from DB"));
+    actDBLoad->setWhatsThis(_("The button for loading item data from DB"));
+    actDBLoad->setStatusTip(_("Press for loading item data from DB."));
+    actDBLoad->setEnabled(false);
+    connect(actDBLoad, SIGNAL(activated()), this, SLOT(itDBLoad()));
+    //--- Save item to db ---
+    if(!ico_t.load(TUIS::icoPath("save").c_str())) ico_t.load(":/images/save.png");
+    actDBSave = new QAction(QPixmap::fromImage(ico_t),_("Save to DB"),this);
+    actDBSave->setToolTip(_("Save item data to DB"));
+    actDBSave->setWhatsThis(_("The button for saving item data to DB"));
+    actDBSave->setStatusTip(_("Press for saving item data to DB."));
+    actDBSave->setShortcut(QKeySequence("Ctrl+S"));
+    actDBSave->setEnabled(false);
+    connect(actDBSave, SIGNAL(activated()), this, SLOT(itDBSave()));    
+    //-- Item add --
+    if(!ico_t.load(TUIS::icoPath("it_add").c_str())) ico_t.load(":/images/it_add.png");
+    actItAdd = new QAction(QPixmap::fromImage(ico_t),_("&Add"),this);
+    actItAdd->setToolTip(_("Add item"));
+    actItAdd->setWhatsThis(_("The button for adding new item"));
+    actItAdd->setStatusTip(_("Press for adding new item."));
+    actItAdd->setEnabled(false);
+    connect(actItAdd, SIGNAL(activated()), this, SLOT(itAdd()));
+    //-- Item delete --
+    if(!ico_t.load(TUIS::icoPath("it_del").c_str())) ico_t.load(":/images/it_del.png");
+    actItDel = new QAction(QPixmap::fromImage(ico_t),_("&Delete"),this);
+    actItDel->setToolTip(_("Delete item"));
+    actItDel->setWhatsThis(_("The button for deleting item"));
+    actItDel->setStatusTip(_("Press for deleting item."));
+    actItDel->setShortcut(QKeySequence("Ctrl+D"));
+    actItDel->setEnabled(false);
+    connect(actItDel, SIGNAL(activated()), this, SLOT(itDel()));
+    //--- Cut item ---
+    if(!ico_t.load(TUIS::icoPath("editcut").c_str())) ico_t.load(":/images/editcut.png");
+    actItCut = new QAction(QPixmap::fromImage(ico_t),_("Item cut"),this);
+    actItCut->setToolTip(_("Goes item cut"));
+    actItCut->setWhatsThis(_("The button for goes to item cut"));
+    actItCut->setStatusTip(_("Press for goes to item cut."));
+    actItCut->setShortcut(QKeySequence("Ctrl+X"));
+    actItCut->setEnabled(false);
+    connect(actItCut, SIGNAL(activated()), this, SLOT(itCut()));
+    //--- Copy item ---
+    if(!ico_t.load(TUIS::icoPath("editcopy").c_str())) ico_t.load(":/images/editcopy.png");
+    actItCopy = new QAction(QPixmap::fromImage(ico_t),_("Item copy"),this);
+    actItCopy->setToolTip(_("Goes item copy"));
+    actItCopy->setWhatsThis(_("The button for goes to item copy"));
+    actItCopy->setStatusTip(_("Press for goes to item copy."));
+    actItCopy->setShortcut(QKeySequence("Ctrl+C"));
+    actItCopy->setEnabled(false);
+    connect(actItCopy, SIGNAL(activated()), this, SLOT(itCopy()));
+    //--- Paste item ---
+    if(!ico_t.load(TUIS::icoPath("editpaste").c_str())) ico_t.load(":/images/editpaste.png");
+    actItPaste = new QAction(QPixmap::fromImage(ico_t),_("Item paste"),this);
+    actItPaste->setToolTip(_("Goes item paste"));
+    actItPaste->setWhatsThis(_("The button for goes to item paste"));
+    actItPaste->setStatusTip(_("Press for goes to item paste."));
+    actItPaste->setShortcut(QKeySequence("Ctrl+V"));
+    actItPaste->setEnabled(false);
+    connect(actItPaste, SIGNAL(activated()), this, SLOT(itPaste()));
     //-- Update --
     if(!ico_t.load(TUIS::icoPath("reload").c_str())) ico_t.load(":/images/reload.png");
     QAction *actUpdate = new QAction(QPixmap::fromImage(ico_t),_("&Refresh"),this);
@@ -244,8 +305,19 @@ ConfApp::ConfApp( string open_user ) :
     //- Create menu -
     //-- Create menu "file" --
     QMenu *mn_file = menuBar()->addMenu(_("&File"));
+    mn_file->addAction(actDBLoad);
+    mn_file->addAction(actDBSave);
+    mn_file->addSeparator( );
     mn_file->addAction(actClose);
     mn_file->addAction(actQuit);
+    //-- Create menu "edit" --
+    QMenu *mn_edit = menuBar()->addMenu(_("&Edit"));    
+    mn_edit->addAction(actItAdd);
+    mn_edit->addAction(actItDel);
+    mn_edit->addSeparator( );
+    mn_edit->addAction(actItCopy);
+    mn_edit->addAction(actItCut);
+    mn_edit->addAction(actItPaste);
     //-- Create menu "view" --
     QMenu *mn_view = menuBar()->addMenu(_("&View"));    
     mn_view->addAction(actUpdate);
@@ -260,17 +332,27 @@ ConfApp::ConfApp( string open_user ) :
     QMenu *help = menuBar()->addMenu(_("&Help"));
     help->addAction(actAbout);
     help->addAction(actQtAbout);
-    help->addSeparator();
+    help->addSeparator( );
     help->addAction(actWhatIs);
 
     //- Create tool bars -    
     //-- Main tool bar --
     QToolBar *toolBar = new QToolBar(_("OpenSCADA toolbar"),this);
     addToolBar(toolBar);
+    toolBar->addAction(actDBLoad);
+    toolBar->addAction(actDBSave);
+    toolBar->addSeparator();    
     toolBar->addAction(actUp);
     toolBar->addAction(actPrev);
     toolBar->addAction(actNext);
     toolBar->addSeparator();
+    toolBar->addAction(actItAdd);
+    toolBar->addAction(actItDel);
+    toolBar->addSeparator();
+    toolBar->addAction(actItCopy);
+    toolBar->addAction(actItCut);
+    toolBar->addAction(actItPaste);
+    toolBar->addSeparator();
     toolBar->addAction(actUpdate);
     toolBar->addAction(actStartUpd);
     toolBar->addAction(actStopUpd);
@@ -283,6 +365,11 @@ ConfApp::ConfApp( string open_user ) :
     statusBar()->insertPermanentWidget(0,w_user);
     connect(w_user, SIGNAL(userChanged()), this, SLOT(userSel()));
 
+    mStModify = new QLabel(" ",this);
+    mStModify->setWhatsThis(_("This label display the local station modifying."));
+    mStModify->setToolTip(_("Field for display of the local station modifying."));
+    statusBar()->insertPermanentWidget(0,mStModify);
+
     statusBar()->showMessage(_("Ready"), 2000 );
     
     //- Other resources init -
@@ -311,9 +398,37 @@ ConfApp::~ConfApp()
 
 void ConfApp::quitSt()
 {
+    exitModifChk( );
+
     SYS->stop();
 }
 
+void ConfApp::exitModifChk( )
+{
+    //- Check for no saved local station -
+    XMLNode req("modify");
+    req.setAttr("path","/"+SYS->id()+"/%2fobj");
+    if( !cntrIfCmd(req) && atoi(req.text().c_str()) )
+    {
+	bool saveExit = false;
+	req.clear()->setName("get")->setAttr("path","/"+SYS->id()+"/%2fgen%2fsaveExit");
+	if( !cntrIfCmd(req) )	saveExit |= atoi(req.text().c_str());
+	req.setAttr("path","/"+SYS->id()+"/%2fgen%2fsavePeriod");
+	if( !cntrIfCmd(req) )	saveExit |= atoi(req.text().c_str());
+	if( !saveExit )
+	{
+	    InputDlg dlg(this,actDBSave->icon(),
+		    _("Some nodes of local station is changed. Save changing to DB on exit?"),
+		    _("Station save"),false,false);
+	    if( dlg.exec() == QDialog::Accepted )
+	    {
+		req.clear()->setName("save")->setAttr("path","/"+SYS->id()+"/%2fobj");
+		cntrIfCmd(req);
+	    }
+	}
+    }     
+}
+
 void ConfApp::endRunChk( )
 {
     if( mod->endRun() ) close();
@@ -358,6 +473,234 @@ void ConfApp::pageNext()
     try{ pageDisplay( path ); } catch(TError err) { mod->postMess(err.cat,err.mess,TUIMod::Error,this); } 
 }
 
+void ConfApp::itDBLoad( )
+{
+    //- Create request -
+    XMLNode req("load");
+    req.setAttr("path",sel_path+"/%2fobj");
+    if( cntrIfCmd(req) )	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TUIMod::Info,this);
+    else pageRefresh(); 
+}
+
+void ConfApp::itDBSave( )
+{
+    //- Create request -
+    XMLNode req("save");
+    req.setAttr("path",sel_path+"/%2fobj");
+    if( cntrIfCmd(req) )	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TUIMod::Info,this);
+    else pageRefresh(); 
+}		
+
+void ConfApp::itAdd( )
+{
+    if( sel_path.empty() || !root->childGet("id","br",true) )	return;
+    XMLNode *branch = root->childGet("id","br");
+
+    QComboBox *nCont = new QComboBox(NULL);
+
+    //- Load branches list -
+    bool idm = false;
+    for( int i_b = 0; i_b < branch->childSize(); i_b++ )
+	if( atoi(branch->childGet(i_b)->attr("acs").c_str())&SEQ_WR )
+	{
+	    idm |= (bool)atoi(branch->childGet(i_b)->attr("idm").c_str());
+	    nCont->addItem( branch->childGet(i_b)->attr("dscr").c_str(), 
+			    (string(atoi(branch->childGet(i_b)->attr("idm").c_str())?"1":"0")+branch->childGet(i_b)->attr("id")).c_str() );
+	}
+    if( !nCont->count() )
+    { mod->postMess(mod->nodePath().c_str(),_("No one editable container present."),TUIMod::Info,this); return; }
+
+    InputDlg dlg(this,actItAdd->icon(),
+            QString(_("Add item to node: '%1'.")).arg(sel_path.c_str()),
+	    _("Add node"),true,idm);
+    dlg.ed_lay->addWidget( new QLabel(_("Item type:"),&dlg), 0, 0 );
+    nCont->setParent(&dlg);
+    dlg.ed_lay->addWidget( nCont, 0, 1 ); 
+
+    if( dlg.exec() != QDialog::Accepted )   return;
+
+    //- Check for already present node -
+    XMLNode req("get");
+    req.setAttr("path",sel_path+"/%2fbr%2f"+string(nCont->itemData(nCont->currentIndex()).toString().toAscii().data()+1));
+    if( !cntrIfCmd(req) )
+        for( int i_lel = 0; i_lel < req.childSize(); i_lel++ )
+    	    if( (req.childGet(i_lel)->attr("id").size() && req.childGet(i_lel)->attr("id") == dlg.id().toAscii().data()) ||
+	        (!req.childGet(i_lel)->attr("id").size() && req.childGet(i_lel)->text() == dlg.id().toAscii().data()) )
+	    {
+		mod->postMess(mod->nodePath().c_str(),QString(_("Node '%1' already present.")).arg(dlg.id()).toAscii().data(),TUIMod::Info,this);
+		return;
+	    }
+    
+    //- Send create request -
+    req.clear()->
+	setName("add")->
+	setAttr("path",sel_path+"/%2fbr%2f"+string(nCont->itemData(nCont->currentIndex()).toString().toAscii().data()+1));
+    if( nCont->itemData(nCont->currentIndex()).toString()[0] == '1' )
+	req.setAttr("id",dlg.id().toAscii().data())->setText(dlg.name().toAscii().data());
+    else req.setText(dlg.id().toAscii().data());
+    if( cntrIfCmd(req) )	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TUIMod::Info,this);
+    else { treeUpdate(); pageRefresh(); }
+}
+
+void ConfApp::itDel( const string &iit )
+{
+    string rmit = iit.empty() ? sel_path : iit;
+    if( rmit.empty() )	return;
+
+    if( iit.empty() )
+    {
+	InputDlg dlg(this,actItDel->icon(),
+        	QString(_("You sure for delete node: '%1'?")).arg(rmit.c_str()),
+		_("Delete node"),false,false);
+	if( dlg.exec() != QDialog::Accepted )   return;
+    }    
+    
+    string t_el, sel_own, sel_el;
+    int n_obj = 0;
+    for( int off = 0; !(t_el=TSYS::pathLev(rmit,0,true,&off)).empty(); n_obj++ )
+    { if( n_obj ) sel_own += ("/"+sel_el); sel_el = t_el; }
+    if( n_obj > 2 )
+    {
+        XMLNode req("info");
+        req.setAttr("path",sel_own+"/%2fbr");
+        if( !cntrIfCmd(req) && req.childGet(0,true) )
+        {
+            XMLNode *branch = req.childGet(0);
+            for( int i_b = 0; i_b < branch->childSize(); i_b++ )
+                if( branch->childGet(i_b)->attr("id") == sel_el.substr(0,branch->childGet(i_b)->attr("id").size()) &&
+                    atoi(branch->childGet(i_b)->attr("acs").c_str())&SEQ_WR )
+            	{
+		    string b_id = branch->childGet(i_b)->attr("id");
+		    bool idm = atoi(branch->childGet(i_b)->attr("idm").c_str());
+		    req.clear()->setName("del")->setAttr("path",sel_own+"/%2fbr%2f"+b_id);
+		    if( idm )	req.setAttr("id",sel_el.substr(b_id.size()));
+		    else 	req.setText(sel_el.substr(b_id.size()));
+		    if( cntrIfCmd(req) )
+		        mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TUIMod::Info,this);
+		    else treeUpdate();
+		    break; 
+		}
+        }
+    }
+}
+
+void ConfApp::itCut( )
+{
+    copy_buf = "1"+sel_path;
+    editToolUpdate();
+}
+
+void ConfApp::itCopy( )
+{
+    copy_buf = "0"+sel_path;
+    editToolUpdate();
+}
+
+void ConfApp::itPaste( )
+{
+    int off;
+    string s_el, s_elp, t_el, b_grp;
+
+    //- Src elements calc -
+    int n_sel = 0;
+    for( off = 0; !(t_el=TSYS::pathLev(copy_buf.substr(1),0,true,&off)).empty(); n_sel++ )
+    { if( n_sel ) s_elp += ("/"+s_el); s_el = t_el; }
+
+    if( TSYS::pathLev(copy_buf.substr(1),0) != TSYS::pathLev(sel_path,0) ) 
+    { mod->postMess( mod->nodePath().c_str(), _("Copy is imposible."), TUIMod::Error, this ); return; }
+
+    QComboBox *nCont = new QComboBox(NULL);
+    if( atoi(root->attr("acs").c_str())&SEQ_WR ) nCont->addItem( _("Selected") );
+    
+    XMLNode *branch = root->childGet("id","br",true);
+    if( branch )
+	for( int i_b = 0; i_b < branch->childSize(); i_b++ )
+    	    if( atoi(branch->childGet(i_b)->attr("acs").c_str())&SEQ_WR )
+    	    {
+		nCont->addItem( branch->childGet(i_b)->attr("dscr").c_str(), branch->childGet(i_b)->attr("id").c_str() );	    	    
+		if( s_el.substr(0,branch->childGet(i_b)->attr("id").size()) == branch->childGet(i_b)->attr("id") )
+		{
+		    nCont->setCurrentIndex(nCont->count()-1);
+		    b_grp = branch->childGet(i_b)->attr("id");
+		}
+	    }
+
+    //-- Make request dialog --
+    InputDlg dlg(this,actItPaste->icon(),"",_("Move or copy node"),true,false);
+
+    dlg.ed_lay->addWidget( new QLabel(_("Target:"),&dlg), 0, 0 );
+    nCont->setParent(&dlg);
+    dlg.ed_lay->addWidget( nCont, 0, 1 );
+    dlg.setMess( (QString((copy_buf[0] == '1') ? _("Move node '%1' to '%2'.\n") : _("Copy node '%1' to '%2'.\n"))+
+            _("Enter new node identifier.")).arg(copy_buf.substr(1).c_str()).arg(sel_path.c_str()) );
+    dlg.setId( s_el.substr(b_grp.size()).c_str() );
+    if( dlg.exec() != QDialog::Accepted ) return;    
+    
+    off = 0; 
+    string stat_nm = TSYS::pathLev(copy_buf.substr(1),0,true,&off);
+    string src_nm  = copy_buf.substr(off+1);
+    off = 0;
+    stat_nm = TSYS::pathLev(sel_path,0,true,&off);
+    string dst_nm  = sel_path.substr(off);
+    if( !nCont->itemData(nCont->currentIndex()).toString().isEmpty() )
+    {
+	dst_nm = dst_nm + "/" + nCont->itemData(nCont->currentIndex()).toString().toAscii().data() + dlg.id().toAscii().data();
+	//- Check for already present node -
+	XMLNode req("get");
+	req.setAttr("path",sel_path+"/%2fbr%2f"+nCont->itemData(nCont->currentIndex()).toString().toAscii().data());
+	if( !cntrIfCmd(req) )
+	    for( int i_lel = 0; i_lel < req.childSize(); i_lel++)
+		if( (req.childGet(i_lel)->attr("id").size() && req.childGet(i_lel)->attr("id") == dlg.id().toAscii().data()) ||
+		    (!req.childGet(i_lel)->attr("id").size() && req.childGet(i_lel)->text() == dlg.id().toAscii().data()) )
+		{
+		    InputDlg dlg1(this,actItPaste->icon(),QString(_("Node '%1' already present. Continue?")).arg(dst_nm.c_str()).toAscii().data(),_("Move or copy node"),false,false);
+		    if( dlg1.exec() != QDialog::Accepted ) return;
+		}
+    }
+
+    //- Copy visual item -
+    XMLNode req("copy");
+    req.setAttr("path","/"+stat_nm+"/%2fobj")->setAttr("src",src_nm)->setAttr("dst",dst_nm);
+    if( cntrIfCmd(req) ) 
+    { mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TUIMod::Error,this); return; }
+    
+    //- Remove source widget -
+    if( copy_buf[0] == '1' )
+    { itDel(copy_buf.substr(1)); copy_buf = "0"; }
+    
+    treeUpdate( );
+    pageRefresh( );
+}
+
+void ConfApp::editToolUpdate( )
+{
+    actItCut->setEnabled( (!sel_path.empty()&&root&&atoi(root->attr("acs").c_str())&SEQ_WR) ? true : false );
+    actItCopy->setEnabled( !sel_path.empty() );
+    actItPaste->setEnabled( false );
+        
+    //- Src and destination elements calc -
+    if( copy_buf.size() <= 1 || copy_buf.substr(1) == sel_path ||
+	    TSYS::pathLev(copy_buf.substr(1),0) != TSYS::pathLev(sel_path,0) )
+	return;
+    string s_elp, s_el, t_el;
+    for( int off = 0; !(t_el=TSYS::pathLev(copy_buf.substr(1),0,true,&off)).empty(); )
+    { s_elp += ("/"+s_el); s_el = t_el; }
+    
+    XMLNode *branch = root->childGet("id","br",true);
+    if( branch )
+	for( int i_b = 0; i_b < branch->childSize(); i_b++ )
+    	    if( atoi(branch->childGet(i_b)->attr("acs").c_str())&SEQ_WR )
+    	    { actItPaste->setEnabled(true); break; }
+    if( atoi(root->attr("acs").c_str())&SEQ_WR ) actItPaste->setEnabled(true);
+}
+
+void ConfApp::treeUpdate( )
+{
+    for( int i_t = 0; i_t < CtrTree->topLevelItemCount(); i_t++ )
+        if( CtrTree->topLevelItem(i_t)->isExpanded() )
+            viewChildRecArea(CtrTree->topLevelItem(i_t),-1);
+}
+
 void ConfApp::userSel()
 {
     pg_info.setAttr("path","");
@@ -365,13 +708,13 @@ void ConfApp::userSel()
     initHosts();
 }
 
-void ConfApp::pageRefresh()
+void ConfApp::pageRefresh( )
 {
     try{ pageDisplay(sel_path); }
     catch(TError err) { mod->postMess(err.cat,err.mess,TUIMod::Error,this); }
 }
 
-void ConfApp::pageCyclRefrStart()
+void ConfApp::pageCyclRefrStart( )
 {
     actStartUpd->setEnabled(false);
     actStopUpd->setEnabled(true);
@@ -380,7 +723,7 @@ void ConfApp::pageCyclRefrStart()
     autoUpdTimer->start(1000);
 }
 
-void ConfApp::pageCyclRefrStop()
+void ConfApp::pageCyclRefrStop( )
 {
     actStopUpd->setEnabled(false);
     actStartUpd->setEnabled(true);
@@ -388,7 +731,7 @@ void ConfApp::pageCyclRefrStop()
     autoUpdTimer->stop();
 }
 
-void ConfApp::about()
+void ConfApp::about( )
 {
     char buf[STR_BUF_LEN];
     
@@ -413,6 +756,8 @@ void ConfApp::enterWhatsThis()
 
 void ConfApp::closeEvent( QCloseEvent* ce )
 {
+    if( !SYS->stopSignal() )    exitModifChk( );
+
     ce->accept();
 }
 
@@ -733,7 +1078,7 @@ void ConfApp::selectChildRecArea( const XMLNode &node, const string &a_path, QWi
 				    }
 				if( sel_n < 0 )
 				{
-				    elms.insert(elms.begin(),"");
+				    elms.insert(elms.begin(),t_linf->childGet(i_el)->text().c_str());
 				    sel_n = 0;
 				}
 			    
@@ -918,6 +1263,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
 	    else
 	    {
 		lab_r = new QLabel( widget );
+		lab_r->setTextInteractionFlags(Qt::TextSelectableByMouse);
                 lab_r->setStatusTip((sel_path+"/"+br_path).c_str());
 	    }
 	    
@@ -987,7 +1333,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
     		{
 		    if(comb)
 		    {
-        		comb->insertItem(c_el,"");
+        		comb->insertItem(c_el,data_req.text().c_str());
     			comb->setCurrentIndex(c_el);
 		    }
 		    if(lab_r)	lab_r->setText("");
@@ -1017,6 +1363,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
 		else
         	{
 		    lab_r = new QLabel( widget );
+		    lab_r->setTextInteractionFlags(Qt::TextSelectableByMouse);
 		    lab_r->setStatusTip((sel_path+"/"+br_path).c_str());
 		}
 
@@ -1107,7 +1454,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
 	    }
 	    //-- Fill Edit --
 	    if( lab )	lab->setText((t_s.attr("dscr")+":").c_str());
-	    if( edit ) 	edit->setText(data_req.text().c_str());
+	    if( edit && !edit->isChanged() ) 	edit->setText(data_req.text().c_str());
 	}
         //- View Data-Time fields -
 	else if( t_s.attr("tp") == "time" )
@@ -1127,6 +1474,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
 		if( !wr )
 		{
 		    val_r = new QLabel( widget );
+		    val_r->setTextInteractionFlags(Qt::TextSelectableByMouse);
 		    val_r->setStatusTip((sel_path+"/"+br_path).c_str());
 		    QSizePolicy sp(QSizePolicy::Expanding, QSizePolicy::Preferred);
 		    sp.setHorizontalStretch(1);
@@ -1180,7 +1528,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
             //-- Fill data --
  	    if( lab ) 	lab->setText((t_s.attr("dscr")+":").c_str());
 	    if( val_r )	val_r->setText( "<b>"+dtm.toString("dd.MM.yyyy hh:mm:ss")+"</b>" );
-	    if( val_w )	val_w->setDateTime( dtm );
+	    if( val_w && !val_w->isChanged() )	val_w->setDateTime( dtm );
 	}
 	//- View other string and numberic fields -
 	else
@@ -1194,8 +1542,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
 		if( !wr )
 		{
 		    val_r = new QLabel( widget );
-		    //if( val_r > (void*)0x9000000 )
-		    //	printf("TEST 00: %xh (%s)\n",val_r,(sel_path+"/"+br_path).c_str());
+		    val_r->setTextInteractionFlags(Qt::TextSelectableByMouse);
 		    val_r->setStatusTip((sel_path+"/"+br_path).c_str());
 		    QSizePolicy sp(QSizePolicy::Expanding, QSizePolicy::Preferred);
 		    sp.setHorizontalStretch(1);
@@ -1276,7 +1623,7 @@ void ConfApp::basicFields( XMLNode &t_s, const string &a_path, QWidget *widget,
             //-- Fill line --
  	    if( lab ) 	lab->setText((t_s.attr("dscr")+":").c_str());
 	    if( val_r )	val_r->setText((string("<b>")+TSYS::strEncode(data_req.text(),TSYS::Html)+"</b>").c_str());
-	    if( val_w )	val_w->setText(data_req.text().c_str());
+	    if( val_w && !val_w->isChanged() )	val_w->setText(data_req.text().c_str());
 	}
     }
 }
@@ -1310,7 +1657,7 @@ void ConfApp::pageDisplay( const string &path )
     else		actNext->setEnabled(false);
     
     //- Delete all tabs for new node -
-    if( path != pg_info.attr("path") ) //sel_path )
+    if( path != pg_info.attr("path") )
     {
 	//-- Stop refresh --
 	pageCyclRefrStop();
@@ -1338,7 +1685,7 @@ void ConfApp::pageDisplay( const string &path )
 	//-- Check the new node structure and the old node --
 	XMLNode n_node("info");
 	n_node.setAttr("path",sel_path);
-	if(cntrIfCmd(n_node)) 
+	if( cntrIfCmd(n_node) )
 	{ 
 	    mod->postMess(n_node.attr("mcat"),n_node.text(),TUIMod::Error,this); 
 	    return; 
@@ -1346,6 +1693,35 @@ void ConfApp::pageDisplay( const string &path )
 	upStruct(*root,*n_node.childGet(0));
     }	
     selectChildRecArea(*root,"/");
+    
+    //- Add and delete access allow check -
+    //-- Add process --
+    actItAdd->setEnabled(false);
+    if( root->childGet("id","br",true) )
+    {
+	XMLNode *branch = root->childGet("id","br");
+	for( int i_b = 0; i_b < branch->childSize(); i_b++ )
+	    if( atoi(branch->childGet(i_b)->attr("acs").c_str())&SEQ_WR )
+	    { actItAdd->setEnabled(true); break; }
+    }
+    //-- Delete process --    
+    actItDel->setEnabled( (root&&atoi(root->attr("acs").c_str())&SEQ_WR) ? true : false );
+    
+    //- Load and Save allow check -
+    actDBLoad->setEnabled(false); actDBSave->setEnabled(false);
+    XMLNode req("modify");
+    req.setAttr("path",sel_path+"/%2fobj");
+    if( cntrIfCmd(req) ) mod->postMess(req.attr("mcat"),req.text(),TUIMod::Error,this); 
+    else if( atoi(req.text().c_str()) )
+    { actDBLoad->setEnabled(true); actDBSave->setEnabled(true); }
+    
+    //- Local station modifying check -
+    mStModify->setText(" ");
+    req.setAttr("path","/"+SYS->id()+"/%2fobj");
+    if( !cntrIfCmd(req) && atoi(req.text().c_str()) )	mStModify->setText("*"); 
+    
+    //- Edit tools update -
+    editToolUpdate( );
 }
 
 bool ConfApp::upStruct(XMLNode &w_nd, const XMLNode &n_nd)
@@ -1435,6 +1811,22 @@ void ConfApp::ctrTreePopup( )
 
     try
     {
+	if( lview && lview->currentItem() && lview->currentItem()->text(2)[0] != '*' )
+	{
+	    //- Load and Save actions -
+	    popup.addAction(actDBLoad);
+	    popup.addAction(actDBSave);
+	    popup.addSeparator();
+	    //- Add and delete item action add -
+	    popup.addAction(actItAdd);
+	    popup.addAction(actItDel);
+	    popup.addSeparator();
+	    popup.addAction(actItCut);
+	    popup.addAction(actItCopy);
+	    popup.addAction(actItPaste);
+	    popup.addSeparator();
+	}
+	//- Main action add -
 	QAction *actRemHostUp = new QAction(_("Update remote hosts list"),this);
 	popup.addAction(actRemHostUp);
         QAction *rez = popup.exec(QCursor::pos());
@@ -1466,7 +1858,7 @@ void ConfApp::viewChildRecArea( QTreeWidgetItem *i, int level )
 	    string simg = TSYS::strDecode(dt_req.text(),TSYS::base64);
 	    QImage img;
 	    if( img.loadFromData((const uchar*)simg.c_str(),simg.size()) )
-    		i->setIcon(0,QPixmap::fromImage(img));//.smoothScale(16,16)));
+    		i->setIcon(0,QPixmap::fromImage(img).scaled(16,16,Qt::KeepAspectRatio,Qt::SmoothTransformation));
 	}
     }
     
@@ -1488,7 +1880,13 @@ void ConfApp::viewChildRecArea( QTreeWidgetItem *i, int level )
 	}
 	else if( brs->childSize() > 1 )
 	{
-	    it = new QTreeWidgetItem(i);
+	    it = NULL;
+	    //- Search no present item -
+	    if( level < 0 )
+		for( int i_it = 0; i_it < i->childCount(); i_it++ )
+		    if( i->child(i_it)->text(2) == (string("*")+br->attr("id")).c_str() )
+		    { it = i->child(i_it); break; }
+	    if( !it )	it = new QTreeWidgetItem(i);
 	    it->setText(0,(br->attr("dscr")+":").c_str());
 	    it->setText(1,br->attr("dscr").c_str());
 	    it->setText(2,(string("*")+br->attr("id")).c_str());
@@ -1496,11 +1894,16 @@ void ConfApp::viewChildRecArea( QTreeWidgetItem *i, int level )
 	    QFont fnt = it->font(0);
 	    fnt.setItalic(true);
 	    it->setFont(0,fnt);
+	    //--- Next node for next level ---
+            if( level-1 > 0 )		viewChildRecArea(it,level-1);
+	    else if( level == -1 )	viewChildRecArea(it,it->isExpanded()?-1:-2);
+	    continue;
     	}
 	
 	//-- Get branches --
 	XMLNode req("get");
-	req.setAttr("path",path+"/"+TSYS::strEncode(br->attr("list"),TSYS::PathEl));
+	if( br->attr("list").empty() )	req.setAttr("path",path+"/%2fbr%2f"+br->attr("id"));
+	else req.setAttr("path",path+"/"+TSYS::strEncode(br->attr("list"),TSYS::PathEl));
 	if( cntrIfCmd(req) ) 
 	{ 
 	    mod->postMess(req.attr("mcat"),req.text(),TUIMod::Error,this); 
@@ -1515,16 +1918,71 @@ void ConfApp::viewChildRecArea( QTreeWidgetItem *i, int level )
 	    if( br_el->attr("id").size() )	br_path.append(br_el->attr("id"));
 	    else				br_path.append(br_el->text());
 	    br_path = TSYS::strEncode(br_path,TSYS::PathEl);
-		    
-	    QTreeWidgetItem *ch_it = new QTreeWidgetItem(it);
+	
+	    QTreeWidgetItem *ch_it = NULL;
+	    if( level < 0 )
+		for( int i_it = 0; i_it < it->childCount(); i_it++ )
+		    if( it->child(i_it)->text(2) == (path+"/"+br_path).c_str() )
+		    { ch_it = it->child(i_it); break; }
+	    if( !ch_it ) ch_it = new QTreeWidgetItem(it);
 	    ch_it->setText(0,br_el->text().c_str());
 	    ch_it->setText(1,br->attr("dscr").c_str());
 	    ch_it->setText(2,(path+"/"+br_path).c_str());
 			    			    
 	    //--- Next node for next level ---
-	    if( level-1 > 0 )	viewChildRecArea(ch_it,level-1);
+	    if( level-1 > 0 )		viewChildRecArea(ch_it,level-1);
+	    else if( level == -1 ) 	viewChildRecArea(ch_it,ch_it->isExpanded()?-1:-2);
 	}
-    }    
+    }
+    
+    //- Remove no present node's items -
+    if( level < 0 && brs->childSize() )
+    {
+	if( i->text(2)[0] == '*' || brs->childSize() == 1 )
+	{
+	    for( int ibr = 0; ibr < brs->childSize(); ibr++ )
+		if( brs->childSize() == 1 || i->text(2) == (string("*")+brs->childGet(ibr)->attr("id")).c_str() )
+		{
+		    XMLNode *br = brs->childGet(ibr);
+		    XMLNode req("get");
+		    if( br->attr("list").empty() )  req.setAttr("path",path+"/%2fbr%2f"+br->attr("id"));
+		    else req.setAttr("path",path+"/"+TSYS::strEncode(br->attr("list"),TSYS::PathEl));
+		    if( !cntrIfCmd(req) )
+			for( int i_it = 0; i_it < i->childCount(); i_it++ )
+			{
+			    int i_lel;
+			    for( i_lel = 0; i_lel < req.childSize(); i_lel++ )
+			    {
+				XMLNode *br_el = req.childGet(i_lel);
+				string br_path = br->attr("id");
+				if( br_el->attr("id").size() )      br_path.append(br_el->attr("id"));
+				else                                br_path.append(br_el->text());
+				br_path = TSYS::strEncode(br_path,TSYS::PathEl);
+				if( i->child(i_it)->text(2) == (path+"/"+br_path).c_str() ) break;
+			    }
+			    if( i_lel >= req.childSize() ) 
+			    { 
+				delete i->takeChild(i_it); 
+				i_it--; 
+			    }
+			}		    
+		    break;
+		}
+	}
+	else
+	    for( int i_it = 0; i_it < i->childCount(); i_it++ )
+	    {
+		int ibr;
+		for( ibr = 0; ibr < brs->childSize(); ibr++ )
+		    if( i->child(i_it)->text(2) == (string("*")+brs->childGet(ibr)->attr("id")).c_str() )
+			break;
+		if( ibr >= brs->childSize() )
+		{
+		    delete i->takeChild(i_it);
+		    i_it--;
+		}
+	    }
+    }
 }
 
 int ConfApp::cntrIfCmd( XMLNode &node )
@@ -1535,21 +1993,25 @@ int ConfApp::cntrIfCmd( XMLNode &node )
     if( station.empty() ) station = sel_path = SYS->id();
     else node.setAttr("path",path.substr(path_off));
     
-    //- Check local station request -    
-    if( station == SYS->id() )
+    try
     {
-	node.setAttr("user",w_user->user().toAscii().data());
-        SYS->cntrCmd(&node);
-	node.setAttr("path",path);
-	return atoi(node.attr("rez").c_str());
-    }
+	//- Check local station request -    
+	if( station == SYS->id() )
+	{
+	    node.setAttr("user",w_user->user().toAscii().data());
+    	    SYS->cntrCmd(&node);
+	    node.setAttr("path",path);
+	    return atoi(node.attr("rez").c_str());
+	}
     
-    //- Request to remote host -
-    TTransportS::ExtHost host = SYS->transport().at().extHostGet(w_user->user().toAscii().data(),station);
-    AutoHD<TTransportOut> tr = SYS->transport().at().extHost(host,"TrCntr");    
-    if(!tr.at().startStat())	tr.at().start();
-    node.load(tr.at().messProtIO(host.user+"\n"+host.pass+"\n"+node.save(),"SelfSystem"));
-    node.setAttr("path",path);
+	//- Request to remote host -
+	TTransportS::ExtHost host = SYS->transport().at().extHostGet(w_user->user().toAscii().data(),station);
+	AutoHD<TTransportOut> tr = SYS->transport().at().extHost(host,"TrCntr");    
+	if(!tr.at().startStat())	tr.at().start();
+	node.load(tr.at().messProtIO(host.user+"\n"+host.pass+"\n"+node.save(),"SelfSystem"));
+	node.setAttr("path",path);
+    }catch( TError err )
+    { node.setAttr("mcat",err.cat)->setAttr("rez","3")->setText(err.mess); }
     return atoi(node.attr("rez").c_str());
 }                          
 
@@ -1868,9 +2330,12 @@ void ConfApp::listBoxPopup( )
 	    if(!rez)	{ popup.clear(); return; }
 	    if( rez == actAdd || rez == actIns || rez == actEd )
 	    {
-		InputDlg dlg(ind_m);
+		InputDlg dlg(this,this->windowIcon(),"",_("Item name set"),ind_m,true);
+		if( rez == actAdd )	dlg.setMess(_("Add new element."));
+		else if( rez == actIns )dlg.setMess(_("Insert new element."));
 		if( rez == actEd )
 		{
+		    dlg.setMess(_("Rename element."));
 		    dlg.setId(p_id.c_str());
 		    dlg.setName(p_text.c_str());
 		}
@@ -1944,6 +2409,9 @@ void ConfApp::listBoxPopup( )
 	    autoUpdTimer->setSingleShot(true);
 	    autoUpdTimer->start(CH_REFR_TM);      //Redraw
 	    
+	    if( n_el->attr("tp") == "br" && (rez == actAdd || rez == actIns || rez == actEd || rez == actDel) )
+		treeUpdate();
+	    
 	    popup.clear();
 	}
     }catch(TError err) 
