@@ -69,45 +69,55 @@ class ConfApp: public QMainWindow
 	void closeEvent( QCloseEvent* );
 
     private slots:
-	//Slots
+	//Slots	
 	void quitSt( );
-	    
+	void exitModifChk( );
+
 	void pageUp( );
 	void pagePrev( );
 	void pageNext( );
+	void itDBLoad( );
+	void itDBSave( );
+	void itAdd( );
+	void itDel( const string &it = "" );
+	void itCut( );
+	void itCopy( );
+	void itPaste( );
 	void pageRefresh( );
 	void pageCyclRefrStart( );
 	void pageCyclRefrStop( );
 
 	void userSel( );
-	    
+
 	void about( );
 	void aboutQt( );
 	void enterWhatsThis( );
-	    
+
+	void editToolUpdate( );				//Edit tools visible update
 	void endRunChk( );      			//End run flag check
 
 	//- QListView -
 	void selectItem( );				//Processing of select item signal
-	void viewChild( QTreeWidgetItem * i );	//Processing of view item signal 
+	void viewChild( QTreeWidgetItem * i );		//Processing of view item signal 
 	void onItem( QTreeWidgetItem * i );		//View item path
 	void ctrTreePopup( );
-	    
+	void treeUpdate( );				//Update expanded content of tree
+
 	//- QTabWidget -
-	void tabSelect( QWidget *wdg );		//Change curent widget
+	void tabSelect( QWidget *wdg );			//Change curent widget
 
 	//- Self widget's slots -
 	void checkBoxStChange( int stat ); 		//QCheckBox	    
-	void buttonClicked( );			//Button
-	void combBoxActivate( const QString& );	//QComboBox
+	void buttonClicked( );				//Button
+	void combBoxActivate( const QString& );		//QComboBox
 	void listBoxGo( QListWidgetItem* );		//QListBox go for banch	    
-	void listBoxPopup();			//QListBox popup menu
-	void tablePopup( const QPoint &pos );	//QTable popup menu
+	void listBoxPopup();				//QListBox popup menu
+	void tablePopup( const QPoint &pos );		//QTable popup menu
 	void tableSet( int row, int col );		//QTable set
 	void dataTimeChange( const QDateTime & );	//Change data-time
 	void editChange( const QString& );		//Change Edit (LineEdit and TextEdit)
-	void applyButton( );			//Apply button
-	void cancelButton( );			//Cancel button
+	void applyButton( );				//Apply button
+	void cancelButton( );				//Cancel button
 	void imgPopup( const QPoint &pos );		//Image popup
 	    
     private:
@@ -135,19 +145,21 @@ class ConfApp: public QMainWindow
 	QTreeWidget	*CtrTree;
 	QLabel		*titleIco;
 	QLabel		*titleLab;
+	QLabel		*mStModify;
 	QTabWidget  	*tabs;
 	UserStBar	*w_user;
 	    
-	QAction 	*actUp;
-	QAction 	*actPrev;
-	QAction 	*actNext;	    
-	QAction 	*actUser;	    
-	QAction 	*actStartUpd;
-	QAction 	*actStopUpd;
+	QAction 	*actUp,	*actPrev, *actNext,
+			*actUser,
+			*actStartUpd, *actStopUpd,
+			*actDBLoad, *actDBSave,
+			*actItAdd, *actItDel,
+			*actItCut, *actItCopy, *actItPaste;
 
 	XMLNode		pg_info;
 	XMLNode 	*root;    
-	string		sel_path;
+	string		sel_path,
+			copy_buf;       //Copy buffer
 
 	int		que_sz;
 	vector<string>	prev;
