@@ -121,6 +121,12 @@ LineEdit::LineEdit( QWidget *parent, bool prev_dis ) :
     }
 }
 
+bool LineEdit::isChanged( )
+{
+    if( bt_fld && bt_fld->isEnabled() )	return true;
+    return false;
+}
+
 bool LineEdit::hasFocus( ) const
 {
     return ed_fld->hasFocus( );
@@ -144,7 +150,7 @@ void LineEdit::setText(const QString &txt)
     {
 	bt_fld->setEnabled(false);
 	bt_fld->setVisible(false);
-    }	 
+    }
 }
 
 QString LineEdit::text() const
@@ -154,6 +160,8 @@ QString LineEdit::text() const
 
 void LineEdit::applySlot( )
 {
+    emit textChanged(text());
+    
     bt_fld->setEnabled(false);
     bt_fld->setVisible(false);
     
@@ -172,6 +180,8 @@ bool LineEdit::event( QEvent * e )
 	}
 	else if(keyEvent->key() == Qt::Key_Escape )
 	{
+	    bt_fld->setEnabled(false);
+	    bt_fld->setVisible(false);
 	    emit cancel();
 	    return true;	
 	}
@@ -202,17 +212,23 @@ TextEdit::TextEdit( QWidget *parent, const char *name, bool prev_dis ) :
         but_box->button(QDialogButtonBox::Apply)->setText(_("Apply"));
         if(!ico_t.load(TUIS::icoPath("button_ok").c_str())) ico_t.load(":/images/button_ok.png");
         but_box->button(QDialogButtonBox::Apply)->setIcon(QPixmap::fromImage(ico_t));
-        connect(but_box->button(QDialogButtonBox::Apply), SIGNAL(clicked()), this, SIGNAL(apply()));
+        connect(but_box->button(QDialogButtonBox::Apply), SIGNAL(clicked()), this, SLOT(btApply()));
         but_box->button(QDialogButtonBox::Cancel)->setText(_("Cancel"));
         if(!ico_t.load(TUIS::icoPath("button_cancel").c_str())) ico_t.load(":/images/button_cancel.png");
         but_box->button(QDialogButtonBox::Cancel)->setIcon(QPixmap::fromImage(ico_t));
-        connect(but_box, SIGNAL(rejected()), this, SIGNAL(cancel()));
+        connect(but_box, SIGNAL(rejected()), this, SLOT(btCancel()));	
 	but_box->setVisible(false);
 	box->addWidget(but_box);
     }
     
 }
 
+bool TextEdit::isChanged( )
+{
+    if( but_box && but_box->isVisible() ) return true;
+    return false;
+}
+
 QString TextEdit::text()
 {
     return ed_fld->toPlainText();
@@ -239,6 +255,20 @@ void TextEdit::changed()
     emit textChanged(text());
 }
 
+void TextEdit::btApply( )
+{
+    emit textChanged(text());    
+    but_box->setVisible(false);
+    emit apply();
+}
+
+void TextEdit::btCancel( )
+{
+    but_box->setVisible(false);
+    emit cancel();
+}
+	
+
 //*************************************************
 //* DateTimeEdit: Data and time edit widget.      *
 //*************************************************
@@ -266,6 +296,12 @@ DateTimeEdit::DateTimeEdit( QWidget *parent, bool prev_dis ) :
     }
 }
 
+bool DateTimeEdit::isChanged( )
+{
+    if( bt_fld && bt_fld->isEnabled() ) return true;
+    return false;
+}
+
 bool DateTimeEdit::hasFocus( ) const
 {
     return ed_fld->hasFocus( );
@@ -298,6 +334,7 @@ QDateTime DateTimeEdit::dateTime() const
 
 void DateTimeEdit::applySlot( )
 {
+    emit valueChanged(dateTime());
     bt_fld->setEnabled(false);
     bt_fld->setVisible(false);
     emit apply();    
@@ -315,6 +352,8 @@ bool DateTimeEdit::event( QEvent * e )
 	}
 	else if(keyEvent->key() == Qt::Key_Escape )
 	{
+	    bt_fld->setEnabled(false);
+	    bt_fld->setVisible(false);	
 	    emit cancel();
 	    return true;	
 	}
@@ -325,37 +364,65 @@ bool DateTimeEdit::event( QEvent * e )
 //*************************************************
 //* InputDlg: Id and name input dialog.           *
 //*************************************************
-InputDlg::InputDlg( bool with_id ) : m_id(NULL), m_name(NULL)
+InputDlg::InputDlg( QWidget *parent, const QIcon &icon, const QString &mess,
+        const QString &ndlg, bool with_id, bool with_nm ) :
+    		QDialog(parent), m_id(NULL), m_name(NULL)
 {
-    setWindowTitle(_("Enter name"));
-    
+    setWindowTitle(ndlg);
+    setMinimumSize( QSize( 120, 150 ) );
+    setWindowIcon(icon);
+    setSizeGripEnabled(true);
+		
     QVBoxLayout *dlg_lay = new QVBoxLayout(this);
     dlg_lay->setMargin(10);
     dlg_lay->setSpacing(6);
-
-    QGridLayout *ed_lay = new QGridLayout;
-    ed_lay->setSpacing(6);
-    if( with_id )
+			    
+    //- Icon label and text message -
+    QHBoxLayout *intr_lay = new QHBoxLayout;
+    intr_lay->setSpacing(6);
+					
+    QLabel *icon_lab = new QLabel(this);
+    icon_lab->setSizePolicy( QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum) );
+    icon_lab->setPixmap(icon.pixmap(48));
+    intr_lay->addWidget(icon_lab);
+		
+    inp_lab = new QLabel(mess,this);
+    //inp_lab->setAlignment(Qt::AlignHCenter);
+    inp_lab->setWordWrap(true);
+    intr_lay->addWidget(inp_lab);
+    dlg_lay->addItem(intr_lay);
+				    
+    //- Id and name fields -
+    ed_lay = new QGridLayout;
+    if( with_nm || with_id )
     {
-        ed_lay->addWidget( new QLabel(_("ID:"),this), 0, 0 );
-        m_id = new QLineEdit(this);
-        ed_lay->addWidget( m_id, 0, 1 );
+        ed_lay->setSpacing(6);
+        if( with_id )
+        {
+            ed_lay->addWidget( new QLabel(_("ID:"),this), 3, 0 );
+            m_id = new QLineEdit(this);
+            ed_lay->addWidget( m_id, 3, 1 );
+        }
+        if( with_nm )
+        {
+            ed_lay->addWidget( new QLabel(_("Name:"),this), 4, 0 );
+            m_name = new QLineEdit(this);
+            ed_lay->addWidget( m_name, 4, 1 );
+        }
+
     }
-    ed_lay->addWidget( new QLabel(_("Name:"),this), 1, 0 );
-    m_name = new QLineEdit(this);
-    ed_lay->addWidget( m_name, 1, 1 );
     dlg_lay->addItem(ed_lay);
 
-    dlg_lay->addItem( new QSpacerItem( 20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
+    //- Qk and Cancel buttons -
+    dlg_lay->addItem( new QSpacerItem( 10, 0, QSizePolicy::Minimum, QSizePolicy::Expanding ) );
 
     QFrame *sep = new QFrame(this);
     sep->setFrameShape( QFrame::HLine );
     sep->setFrameShadow( QFrame::Raised );
-
     dlg_lay->addWidget( sep );
-
+			
     QDialogButtonBox *but_box = new QDialogButtonBox(QDialogButtonBox::Ok|
-	                                             QDialogButtonBox::Cancel,Qt::Horizontal,this);
+                                		     QDialogButtonBox::Cancel,Qt::Horizontal,this);
     QImage ico_t;
     but_box->button(QDialogButtonBox::Ok)->setText(_("Ok"));
     if(!ico_t.load(TUIS::icoPath("button_ok").c_str())) ico_t.load(":/images/button_ok.png");
@@ -366,30 +433,42 @@ InputDlg::InputDlg( bool with_id ) : m_id(NULL), m_name(NULL)
     but_box->button(QDialogButtonBox::Cancel)->setIcon(QPixmap::fromImage(ico_t));
     connect(but_box, SIGNAL(rejected()), this, SLOT(reject()));
     dlg_lay->addWidget( but_box );
+
+    resize(400,120+(40*with_nm)+(40*with_id));
 }
 
 QString InputDlg::id()
 {
-    if( m_id )	return m_id->text();
+    if( m_id )  return m_id->text();
     return "";
 }
-	    
+	
 QString InputDlg::name()
 {
     if( m_name )return m_name->text();
     return "";
 }
-	    
-void InputDlg::setId(const QString &val)
+		
+QString InputDlg::mess( )
 {
-    if( m_id )	m_id->setText(val);
+    return inp_lab->text();
 }
 
+void InputDlg::setId(const QString &val)
+{
+    if( m_id )  m_id->setText(val);
+}
+    
 void InputDlg::setName(const QString &val)
 {
     if( m_name )m_name->setText(val);
 }
-
+	
+void InputDlg::setMess( const QString &val )
+{
+    inp_lab->setText( val );
+}
+		    
 //*************************************************
 //* DlgUser: User select dialog                   *
 //*************************************************
