@@ -52,13 +52,12 @@ class TUIMod: public TUI
 	
 	string startPath( )	{ return start_path; }
 	string startUser( )	{ return start_user; }
+	
+	void setStartPath( const string &vl )	{ start_path = vl; modif(); }
+	void setStartUser( const string &vl )	{ start_user = vl; modif(); }
 
 	void modStart( );
 	void modStop( );
-
-	void postEnable( int flag );
-	void modLoad( );
-	void modSave( );
 	
 	//- Module info attributes -    
         string modInfo( const string &name );
@@ -73,6 +72,12 @@ class TUIMod: public TUI
 	//- Put message -
         void postMess( const string &cat, const string &mess, MessLev type = Info, QWidget *parent = 0 );
     
+    protected:
+	//Methods
+	void postEnable( int flag );
+	void load_( );
+	void save_( );
+    
     private:
 	//Methods
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
