@@ -50,6 +50,42 @@ WidgetLib::~WidgetLib( )
 
 }
 
+TCntrNode &WidgetLib::operator=( TCntrNode &node )
+{
+    WidgetLib *src_n = dynamic_cast<WidgetLib*>(&node);
+    if( !src_n ) return *this;
+
+    //- Copy generic configuration -
+    string tid = m_id;
+    *(TConfig*)this = *(TConfig*)src_n;
+    m_id  = tid;
+    m_dbt = string("wlb_")+tid;
+    work_lib_db = src_n->work_lib_db;
+
+    if( !src_n->enable() ) return *this;
+    if( !enable() ) setEnable(true);
+
+    vector<string> pls;
+    //- Mime data copy -
+    src_n->mimeDataList(pls);
+    string mimeType, mimeData;
+    for( int i_m = 0; i_m < pls.size(); i_m++ )
+    {
+	src_n->mimeDataGet( pls[i_m], mimeType, &mimeData );
+        mimeDataSet( pls[i_m], mimeType, mimeData );
+    }
+
+    //- Copy include pages -
+    src_n->list(pls);
+    for( int i_p = 0; i_p < pls.size(); i_p++ )
+    {
+	if( !present(pls[i_p]) ) add(pls[i_p],"");
+	(TCntrNode&)at(pls[i_p]).at() = (TCntrNode&)src_n->at(pls[i_p]).at();
+    }
+    
+    return *this;
+}
+
 void WidgetLib::postEnable( int flag )
 {
     if( flag&TCntrNode::NodeRestore )	setEnable(true);
@@ -113,15 +149,17 @@ void WidgetLib::setUser( const string &it )
 	SYS->security().at().usrGrpList(user(),gls);
 	setGrp(gls.size()?gls[0]:"UI");
     }
+    modif();
 }
 
 void WidgetLib::setFullDB( const string &it )
 {
     work_lib_db = TSYS::strSepParse(it,0,'.')+"."+TSYS::strSepParse(it,1,'.');
     m_dbt = TSYS::strSepParse(it,2,'.');
+    modifG();
 }
 
-void WidgetLib::load( )
+void WidgetLib::load_( )
 {
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),_("Load widget library."));
@@ -140,30 +178,37 @@ void WidgetLib::load( )
         if( !present(f_id) )	add(f_id,"","");
     }
     
-    //- Load present widgets -
-    vector<string> f_lst;
-    list(f_lst);
-    for( int i_ls = 0; i_ls < f_lst.size(); i_ls++ )
-        at(f_lst[i_ls]).at().load();    
+    mOldDB = TBDS::realDBName(DB());
 }
 
-void WidgetLib::save( )
+void WidgetLib::save_( )
 {
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),_("Save widget library."));
 #endif
 
     SYS->db().at().dataSet(DB()+"."+mod->wlbTable(),mod->nodePath()+"LIB/",*this);
-
-    //- Save widgets -
-    vector<string> f_lst;
-    list(f_lst);
-    for( int i_ls = 0; i_ls < f_lst.size(); i_ls++ )
-        at(f_lst[i_ls]).at().save();
+    
+    //- Check for need copy mime data to other DB and same copy -
+    if( !mOldDB.empty() && mOldDB != TBDS::realDBName(DB()) )
+    {
+	vector<string> pls;
+	mimeDataList(pls,mOldDB);
+	string mimeType, mimeData;
+	for( int i_m = 0; i_m < pls.size(); i_m++ )
+	{
+	    mimeDataGet( pls[i_m], mimeType, &mimeData, mOldDB );
+    	    mimeDataSet( pls[i_m], mimeType, mimeData, DB() );
+	}	
+    }
+    
+    mOldDB = TBDS::realDBName(DB());
 }
 
 void WidgetLib::setEnable( bool val )
 {
+    if( val == enable() )       return;
+
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),val ? _("Enable widget library.") : _("Disable widget library."));
 #endif
@@ -171,40 +216,56 @@ void WidgetLib::setEnable( bool val )
     vector<string> f_lst;
     list(f_lst);
     for( int i_ls = 0; i_ls < f_lst.size(); i_ls++ )
-    {
-	try{ at(f_lst[i_ls]).at().setEnable(val); }	
+	try { at(f_lst[i_ls]).at().setEnable(val); }
 	catch( TError err )
-	{ 
-	    mess_err(nodePath().c_str(),_("Enable/disable widget '%s' error %s."),f_lst[i_ls].c_str(),err.mess.c_str()); 
-	}
-    }
+	{ mess_err(nodePath().c_str(),_("Enable/disable widget '%s' error %s."),f_lst[i_ls].c_str(),err.mess.c_str()); }
 
     m_enable = val;
 }
 
-void WidgetLib::mimeDataList( vector<string> &list )
+void WidgetLib::mimeDataList( vector<string> &list, const string &idb )
 {
     string wtbl = tbl()+"_mime";
-    TConfig c_el(&mod->elWdgData());
-    c_el.cfgViewAll(false);
+    string wdb  = idb.empty() ? DB() : idb;
+    TConfig c_el( &mod->elWdgData() );
+    c_el.cfgViewAll( false );
     
-    list.clear();    
-    for( int fld_cnt = 0; SYS->db().at().dataSeek(DB()+"."+wtbl,mod->nodePath()+wtbl,fld_cnt,c_el); fld_cnt++ )
+    list.clear( );
+    for( int fld_cnt = 0; SYS->db().at().dataSeek(wdb+"."+wtbl,mod->nodePath()+wtbl,fld_cnt,c_el); fld_cnt++ )
     {
-        list.push_back(c_el.cfg("ID").getS());
+        list.push_back( c_el.cfg("ID").getS() );
 	c_el.cfg("ID").setS("");
     }
 }
 
-bool WidgetLib::mimeDataGet( const string &iid, string &mimeType, string *mimeData )
+bool WidgetLib::mimeDataGet( const string &iid, string &mimeType, string *mimeData, const string &idb )
 {
-    if( iid.substr(0,6) == "file:/" )
+    bool is_file = (iid.size()>5 && iid.substr(0,5) == "file:");
+    bool is_res  = (iid.size()>4 && iid.substr(0,4) == "res:");
+    
+    if( !is_file )
+    {
+	//- Get resource file from DB -
+	string dbid = is_res ? iid.substr(4) : iid;
+	string wtbl = tbl()+"_mime";
+	string wdb  = idb.empty() ? DB() : idb;	
+	TConfig c_el( &mod->elWdgData() );
+	if( !mimeData ) c_el.cfg("DATA").setView(false);
+	c_el.cfg("ID").setS( dbid );
+	if( SYS->db().at().dataGet( wdb+"."+wtbl, mod->nodePath()+wtbl, c_el ) )
+	{
+	    mimeType = c_el.cfg("MIME").getS();
+	    if( mimeData )	*mimeData = c_el.cfg("DATA").getS();
+	    return true;
+	}
+    }
+    if( !is_res )
     {
 	//- Get resource file from file system -
-	string filepath = iid.substr(6);
+	string filepath = is_file ? iid.substr(5) : iid;
 	int len;
 	char buf[STR_BUF_LEN];
-	string rez;		    
+	string rez;
         int hd = open(filepath.c_str(),O_RDONLY);
 	if( hd == -1 )	return false;
     	
@@ -213,44 +274,31 @@ bool WidgetLib::mimeDataGet( const string &iid, string &mimeType, string *mimeDa
 	
 	mimeType = ((filepath.rfind(".") != string::npos) ? filepath.substr(filepath.rfind(".")+1)+";" : "file/unknown;")+TSYS::int2str(rez.size());
 	if( mimeData )	*mimeData = TSYS::strEncode(rez,TSYS::base64);
+	return true;
     }
-    else
-    {
-	//- Get resource file from DB -
-	string dbid = iid;
-	if( dbid.substr(0,5) == "res:/" ) dbid = dbid.substr(5);
-	
-	string wtbl = tbl()+"_mime";
-	TConfig c_el(&mod->elWdgData());
-	if(!mimeData) c_el.cfg("DATA").setView(false);
-	c_el.cfg("ID").setS(dbid);
-	if(SYS->db().at().dataGet(DB()+"."+wtbl,mod->nodePath()+wtbl,c_el))
-	{
-	    mimeType = c_el.cfg("MIME").getS();
-	    if( mimeData )	*mimeData = c_el.cfg("DATA").getS();
-	    return true;
-	}
-    }
-    return false;    
+    
+    return false;
 }
 
-void WidgetLib::mimeDataSet( const string &iid, const string &mimeType, const string &mimeData )
+void WidgetLib::mimeDataSet( const string &iid, const string &mimeType, const string &mimeData, const string &idb )
 {
     string wtbl = tbl()+"_mime";
-    TConfig c_el(&mod->elWdgData());
-    c_el.cfg("ID").setS(iid);
-    c_el.cfg("MIME").setS(mimeType);    
-    if(!mimeData.size()) c_el.cfg("DATA").setView(false);
+    string wdb  = idb.empty() ? DB() : idb;
+    TConfig c_el( &mod->elWdgData() );
+    c_el.cfg("ID").setS( iid );
+    c_el.cfg("MIME").setS( mimeType );    
+    if( !mimeData.size() ) c_el.cfg("DATA").setView(false);
     else c_el.cfg("DATA").setS(mimeData);
-    SYS->db().at().dataSet(DB()+"."+wtbl,mod->nodePath()+wtbl,c_el);
+    SYS->db().at().dataSet( wdb+"."+wtbl, mod->nodePath()+wtbl, c_el );
 }			
 
-void WidgetLib::mimeDataDel( const string &iid )
+void WidgetLib::mimeDataDel( const string &iid, const string &idb )
 {
     string wtbl = tbl()+"_mime";
-    TConfig c_el(&mod->elWdgData());
+    string wdb  = idb.empty() ? DB() : idb;    
+    TConfig c_el( &mod->elWdgData() );
     c_el.cfg("ID").setS(iid);
-    SYS->db().at().dataDel(DB()+"."+wtbl,mod->nodePath()+wtbl,c_el);
+    SYS->db().at().dataDel( wdb+"."+wtbl, mod->nodePath()+wtbl, c_el );
 }
 
 void WidgetLib::add( const string &id, const string &name, const string &orig )
@@ -276,10 +324,10 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
     //- Get page info -
     if( opt->name() == "info" )
     {
-        ctrMkNode("oscada_cntr",opt,-1,"/",_("Widget's library: ")+id());
+        ctrMkNode("oscada_cntr",opt,-1,"/",_("Widget's library: ")+id(),permit(),user().c_str(),grp().c_str());
 	if(ico().size()) ctrMkNode("img",opt,-1,"/ico","",R_R_R_);
         if(ctrMkNode("branches",opt,-1,"/br","",R_R_R_))
-	    ctrMkNode("grp",opt,-1,"/br/wdg_",_("Widget"),R_R_R_,"root","UI",1,"list","/wdg/wdg");
+	    ctrMkNode("grp",opt,-1,"/br/wdg_",_("Widget"),permit(),user().c_str(),grp().c_str(),1,"idm","1");
         if(ctrMkNode("area",opt,-1,"/obj",_("Library")))
 	{
     	    if(ctrMkNode("area",opt,-1,"/obj/st",_("State")))
@@ -298,8 +346,6 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
 		ctrMkNode("fld",opt,-1,"/obj/cfg/u_a",_("Access: user-grp-other"),RWR_R_,user().c_str(),grp().c_str(),3,"tp","dec","dest","select","select","/obj/a_lst");
 		ctrMkNode("fld",opt,-1,"/obj/cfg/g_a","",RWR_R_,user().c_str(),grp().c_str(),3,"tp","dec","dest","select","select","/obj/a_lst");
 		ctrMkNode("fld",opt,-1,"/obj/cfg/o_a","",RWR_R_,user().c_str(),grp().c_str(),3,"tp","dec","dest","select","select","/obj/a_lst");
-    		ctrMkNode("comm",opt,-1,"/obj/cfg/load",_("Load"),permit(),user().c_str(),grp().c_str());
-    		ctrMkNode("comm",opt,-1,"/obj/cfg/save",_("Save"),permit(),user().c_str(),grp().c_str());
 	    }
 	}
 	if(ctrMkNode("area",opt,-1,"/wdg",_("Widgets")))
@@ -318,58 +364,56 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/obj/st/en" )
     {
-        if( ctrChkNode(opt,"get",RWRWR_,user().c_str(),grp().c_str(),SEQ_RD) ) opt->setText(TSYS::int2str(enable()));
-        if( ctrChkNode(opt,"set",RWRWR_,user().c_str(),grp().c_str(),SEQ_WR) ) setEnable(atoi(opt->text().c_str()));
+        if( ctrChkNode(opt,"get",RWRWR_,user().c_str(),grp().c_str(),SEQ_RD) ) opt->setText( TSYS::int2str(enable()) );
+        if( ctrChkNode(opt,"set",RWRWR_,user().c_str(),grp().c_str(),SEQ_WR) ) setEnable( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/obj/st/db" )
     {
-	if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText(fullDB());
-        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setFullDB(opt->text());
+	if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText( fullDB() );
+        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setFullDB( opt->text() );
     }
     else if( a_path == "/obj/st/user" )
     {
-        if( ctrChkNode(opt,"get",RWRWR_,"root","root",SEQ_RD) )	opt->setText(user());
-        if( ctrChkNode(opt,"set",RWRWR_,"root","root",SEQ_WR) )	setUser(opt->text());
+        if( ctrChkNode(opt,"get",RWRWR_,"root","root",SEQ_RD) )	opt->setText( user() );
+        if( ctrChkNode(opt,"set",RWRWR_,"root","root",SEQ_WR) )	setUser( opt->text() );
     }
     else if( a_path == "/obj/st/grp" )
     {
-        if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText(grp());
-        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setGrp(opt->text());
+        if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText( grp() );
+        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setGrp( opt->text() );
     }
     else if( a_path == "/obj/cfg/u_a" || a_path == "/obj/cfg/g_a" || a_path == "/obj/cfg/o_a" )
     {
 	if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )
 	{
-	    if( a_path == "/obj/cfg/u_a" )	opt->setText(TSYS::int2str((m_permit>>6)&0x7));
-	    if( a_path == "/obj/cfg/g_a" )	opt->setText(TSYS::int2str((m_permit>>3)&0x7));
-	    if( a_path == "/obj/cfg/o_a" )	opt->setText(TSYS::int2str(m_permit&0x7));
+	    if( a_path == "/obj/cfg/u_a" )	opt->setText( TSYS::int2str((permit()>>6)&0x7) );
+	    if( a_path == "/obj/cfg/g_a" )	opt->setText( TSYS::int2str((permit()>>3)&0x7) );
+	    if( a_path == "/obj/cfg/o_a" )	opt->setText( TSYS::int2str(permit()&0x7) );
 	}
 	if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )
 	{
-	    if( a_path == "/obj/cfg/u_a" )	m_permit=(m_permit&(~(0x07<<6)))|(atoi(opt->text().c_str())<<6);
-	    if( a_path == "/obj/cfg/g_a" )	m_permit=(m_permit&(~(0x07<<3)))|(atoi(opt->text().c_str())<<3);
-	    if( a_path == "/obj/cfg/o_a" )	m_permit=(m_permit&(~0x07))|atoi(opt->text().c_str());
+	    if( a_path == "/obj/cfg/u_a" )	setPermit( (permit()&(~(0x07<<6)))|(atoi(opt->text().c_str())<<6) );
+	    if( a_path == "/obj/cfg/g_a" )	setPermit( (permit()&(~(0x07<<3)))|(atoi(opt->text().c_str())<<3) );
+	    if( a_path == "/obj/cfg/o_a" )	setPermit( (permit()&(~0x07))|atoi(opt->text().c_str()) );
 	}
     }
     else if( a_path == "/obj/cfg/ico" || a_path == "/ico" )
     {
-	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText(ico());
-	if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setIco(opt->text());
+	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText( ico() );
+	if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setIco( opt->text() );
     }
     else if( a_path == "/obj/cfg/id" && ctrChkNode(opt,"get",R_R_R_,user().c_str(),grp().c_str()) ) opt->setText(id());
     else if( a_path == "/obj/cfg/name" )
     {
-	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText(name());
-        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setName(opt->text());
+	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText( name() );
+        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setName( opt->text() );
     }
     else if( a_path == "/obj/cfg/descr" )
     {
-        if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText(descr());
-        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setDescr(opt->text());
+        if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText( descr() );
+        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setDescr( opt->text() );
     }
-    else if( a_path == "/obj/cfg/load" && ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )  load();
-    else if( a_path == "/obj/cfg/save" && ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )  save();
-    else if( a_path == "/wdg/wdg" )
+    else if( a_path == "/br/wdg_" || a_path == "/wdg/wdg" )
     {
         if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )
         {
@@ -417,7 +461,7 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
 	    if( !idmime.empty() && idcol == "dt" && atoi(opt->attr("data").c_str()) )
 	    {
 		string mimeType, mimeData;
-		if( mimeDataGet( "res:/"+idmime, mimeType, &mimeData ) ) opt->setText( mimeData );
+		if( mimeDataGet( "res:"+idmime, mimeType, &mimeData ) ) opt->setText( mimeData );
 	    }	    
 	    else
 	    {
@@ -429,7 +473,7 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
 		string mimeType;
 		mimeDataList(lst);
         	for(int i_el = 0; i_el < lst.size(); i_el++)
-		    if( mimeDataGet("res:/"+lst[i_el],mimeType) )
+		    if( mimeDataGet("res:"+lst[i_el],mimeType) )
 		    {
 			if( n_id )	n_id->childAdd("el")->setText(lst[i_el]);
             		if( n_tp )	n_tp->childAdd("el")->setText(TSYS::strSepParse(mimeType,0,';'));
@@ -448,7 +492,7 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
 	    {
 		string mimeType, mimeData;
 		//--- Copy mime data to new record ---
-		if( mimeDataGet( "res:/"+idmime, mimeType, &mimeData ) )
+		if( mimeDataGet( "res:"+idmime, mimeType, &mimeData ) )
 		{
 		    mimeDataSet( opt->text(), mimeType, mimeData );
 		    mimeDataDel( idmime );
@@ -458,28 +502,31 @@ void WidgetLib::cntrCmdProc( XMLNode *opt )
 	    {
 		string mimeType;
 		//--- Copy mime data to new record ---
-		if( mimeDataGet( "res:/"+idmime, mimeType ) )
+		if( mimeDataGet( "res:"+idmime, mimeType ) )
 		    mimeDataSet( idmime, opt->text()+";"+TSYS::strSepParse(mimeType,1,';'), "");
 	    }
 	    else if( idcol == "dt" )
 	    {
 		string mimeType;
-		if( mimeDataGet( "res:/"+idmime, mimeType ) )
+		if( mimeDataGet( "res:"+idmime, mimeType ) )
 		    mimeDataSet( idmime, TSYS::strSepParse(mimeType,0,';')+";"+TSYS::real2str((float)opt->text().size()/1024.,6),opt->text() );
 	    }
 	}
     }
+    else TCntrNode::cntrCmdProc(opt);
 }
 
 //************************************************
 //* LWidget: Library stored widget               *
 //************************************************
-LWidget::LWidget( const string &id, const string &isrcwdg ) :
-        Widget(id,isrcwdg), TConfig(&mod->elWdg()),
+LWidget::LWidget( const string &iid, const string &isrcwdg ) :
+        Widget(iid), TConfig(&mod->elWdg()),
         m_ico(cfg("ICO").getSd()), m_proc(cfg("PROC").getSd()), m_proc_per(cfg("PROC_PER").getId()),
-	m_user(cfg("USER").getSd()), m_grp(cfg("GRP").getSd()), m_permit(cfg("PERMIT").getId())
+	m_user(cfg("USER").getSd()), m_grp(cfg("GRP").getSd()), m_permit(cfg("PERMIT").getId()), 
+	m_parent(cfg("PARENT").getSd()), m_attrs(cfg("ATTRS").getSd())
 {
-    cfg("ID").setS(id);
+    cfg("ID").setS(id());
+    
     setParentNm(isrcwdg);
 }
 
@@ -552,6 +599,7 @@ void LWidget::setUser( const string &iuser )
         SYS->security().at().usrGrpList(user(),gls);
         setGrp(gls.size()?gls[0]:Widget::grp());
     }
+    modif();
 }
 
 string LWidget::grp( )
@@ -559,12 +607,6 @@ string LWidget::grp( )
     return SYS->security().at().grpPresent(m_grp)?m_grp:Widget::grp( );
 }
 
-void LWidget::setParentNm( const string &isw )
-{
-    cfg("PARENT").setS(isw);
-    Widget::setParentNm(isw);
-}
-
 string LWidget::calcId( )
 {
     if( m_proc.empty() )
@@ -611,6 +653,7 @@ int LWidget::calcPer( )
 void LWidget::setCalcLang( const string &ilng )
 {
     m_proc = m_proc.replace(0,m_proc.find("\n"),ilng);
+    modif();
 }
 
 void LWidget::setCalcProg( const string &iprg )
@@ -623,26 +666,28 @@ void LWidget::setCalcProg( const string &iprg )
         lng_end=tmp_prg.find("\n");
     }
     m_proc = tmp_prg.replace(lng_end+1,string::npos,iprg);
+    modif();
 }
 
 void LWidget::setCalcPer( int vl )
 {
     m_proc_per = vl;
+    modif();
 }
 
-void LWidget::load( )
+void LWidget::load_( )
 {    
     //- Load generic widget's data -
     string db  = owner().DB();
     string tbl = owner().tbl();
     SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,*this);
-    setParentNm(cfg("PARENT").getS());
     
     loadIO();
 }
 
 void LWidget::loadIO( )
 {
+    string tstr;
     vector<string> als;
     
     if( !enable() ) return;
@@ -650,18 +695,35 @@ void LWidget::loadIO( )
     //- Load widget's work attributes -
     string db  = owner().DB();
     string tbl = owner().tbl()+"_io";
+
+    //- Inherit modify attributes -
+    /*attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+        AutoHD<Attr> attr = attrAt(als[i_a]);
+        if( attr.at().flgGlob()&Attr::IsInher && attr.at().modif() && m_attrs.find(als[i_a]) == string::npos )
+        {
+	    
+            attr.at().setModif(0);
+            inheritAttr(als[i_a]);
+        }
+    }    
+    als.clear();*/
+    if( m_attrs != "*" )
+	for( int off = 0; !(tstr = TSYS::strSepParse(m_attrs,0,';',&off)).empty(); )
+	    als.push_back(tstr);
     
-    attrList( als );
+    //-- Same attributes load --
     TConfig c_el(&mod->elWdgIO());
     c_el.cfg("IDW").setS(id());    
     for( int i_a = 0; i_a < als.size(); i_a++ )
     {
+	if( !attrPresent(als[i_a]) )    continue;
 	AutoHD<Attr> attr = attrAt(als[i_a]);
 	if( !(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser ) continue;
 	c_el.cfg("ID").setS(als[i_a]);
 	if( !SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,c_el) ) continue;
 	attr.at().setS(c_el.cfg("IO_VAL").getS());
-	if( attr.at().flgGlob()&Attr::Active )	attrList( als );
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
@@ -703,32 +765,36 @@ void LWidget::loadIO( )
     {
         string sid  = c_el.cfg("ID").getS();
 	c_el.cfg("ID").setS("");
-	if( wdgPresent(sid) && c_el.cfg("PARENT").getS() == "<deleted>" )
-	{ wdgDel(sid); continue; }
+	if( c_el.cfg("PARENT").getS() == "<deleted>" )
+	{ 
+	    if( wdgPresent(sid) )	wdgDel(sid);
+	    continue;
+	}
         if( !wdgPresent(sid) ) wdgAdd(sid,"","");
 
         wdgAt(sid).at().load();
     }    
 }
 
-void LWidget::save( )
+void LWidget::save_( )
 {
     //- Save generic widget's data -
     string db  = owner().DB();
     string tbl = owner().tbl();
+    
+    m_attrs="";
+    vector<string> als;
+    attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+	AutoHD<Attr> attr = attrAt(als[i_a]);
+	if( attr.at().modif() && !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) )
+	m_attrs+=als[i_a]+";";
+    }
     SYS->db().at().dataSet(db+"."+tbl,mod->nodePath()+tbl,*this);
 
     //- Save widget's attributes -
     saveIO();
-
-    //- Save cotainer widgets -
-    if(isContainer())
-    {
-	vector<string> ls;
-	wdgList(ls);
-	for( int i_l = 0; i_l < ls.size(); i_l++ )
-	    wdgAt(ls[i_l]).at().save();
-    }
 }
 
 void LWidget::saveIO( )
@@ -823,6 +889,13 @@ string LWidget::resourceGet( const string &id, string *mime )
     return mimeData;
 }
 
+void LWidget::inheritAttr( const string &attr )
+{
+    bool mdf = isModify();
+    Widget::inheritAttr( attr );
+    if( !mdf )	modifClr( );
+}
+
 void LWidget::cntrCmdProc( XMLNode *opt )
 {
     if( cntrCmdServ(opt) ) return;
@@ -836,16 +909,17 @@ void LWidget::cntrCmdProc( XMLNode *opt )
         ctrMkNode("oscada_cntr",opt,-1,"/",_("Library widget: ")+id());
 	return;
     }
-    cntrCmdGeneric(opt) || cntrCmdAttributes(opt) || cntrCmdLinks(opt) || cntrCmdProcess(opt);
+    if( !(cntrCmdGeneric(opt) || cntrCmdAttributes(opt) || cntrCmdLinks(opt) || cntrCmdProcess(opt)) )
+	TCntrNode::cntrCmdProc(opt);
 }
 
 //************************************************
 //* CWidget: Container stored widget             *
 //************************************************
-CWidget::CWidget( const string &id, const string &isrcwdg ) :
-        Widget(id,isrcwdg), TConfig(&mod->elInclWdg())
+CWidget::CWidget( const string &iid, const string &isrcwdg ) :
+        Widget(iid), TConfig(&mod->elInclWdg()), m_parent(cfg("PARENT").getSd()), m_attrs(cfg("ATTRS").getSd())
 {
-    cfg("ID").setS(id);
+    cfg("ID").setS(id());
     m_lnk = true;
     setParentNm(isrcwdg);
 }
@@ -875,60 +949,49 @@ void CWidget::postEnable( int flag )
 
 void CWidget::preDisable( int flag )
 {
+    vector<string> list;
+
     if( flag && !parent().freeStat() )	wdgIherited = parent().at().isLink();
     else wdgIherited = false;
-    
-    Widget::preDisable(flag);
-}
 
-void CWidget::postDisable(int flag)
-{
     if( flag )
     {
         string fullDB = owner().owner().fullDB();
         string tbl = owner().owner().tbl();
 
         //- Remove from library table -
-	if( !wdgIherited )	SYS->db().at().dataDel(fullDB+"_incl",mod->nodePath()+tbl+"_incl",*this);
+	if( !wdgIherited || flag&0x10 )	SYS->db().at().dataDel(fullDB+"_incl",mod->nodePath()+tbl+"_incl",*this);
 	else
 	{ 
-	    cfg("PARENT").setS("<deleted>");
+	    m_parent = "<deleted>";
 	    SYS->db().at().dataSet(fullDB+"_incl",mod->nodePath()+tbl+"_incl",*this);
 	}
  	
-	//- Remove widget's work IO from library IO table -
+	//- Remove changed widget's work and users IO from library IO table -
         TConfig c_el(&mod->elWdgIO());
-	c_el.cfgViewAll(false);
+        TConfig c_uel(&mod->elWdgIO());	
         c_el.cfg("IDW").setS(owner().id());
-        c_el.cfg("ID").setS(""); 
-        int fld_cnt=0;
-        while( SYS->db().at().dataSeek(fullDB+"_io",mod->nodePath()+tbl+"_io",fld_cnt++,c_el) )
-        {
-	    string sid = c_el.cfg("ID").getS();
-            if( TSYS::pathLev(sid,0) == id() && TSYS::pathLev(sid,1).size() )
-            {
-                SYS->db().at().dataDel(fullDB+"_io",mod->nodePath()+tbl+"_io",c_el);
-                fld_cnt--;
-            }
-            c_el.cfg("ID").setS("");
-        }        
-	//- Remove widget's user IO from library IO table -
-        c_el.setElem(&mod->elWdgUIO());
-	c_el.cfgViewAll(false);
-        c_el.cfg("IDW").setS(owner().id());
-        c_el.cfg("ID").setS(""); 
-        fld_cnt=0;
-        while( SYS->db().at().dataSeek(fullDB+"_uio",mod->nodePath()+tbl+"_uio",fld_cnt++,c_el) )
-        {
-	    string sid = c_el.cfg("ID").getS();
-            if( TSYS::pathLev(sid,0) == id() && TSYS::pathLev(sid,1).size() )
-            {
-                SYS->db().at().dataDel(fullDB+"_uio",mod->nodePath()+tbl+"_uio",c_el);
-                fld_cnt--;
-            }
-            c_el.cfg("ID").setS("");
-        }
+        c_uel.cfg("IDW").setS(owner().id());
+	attrList( list );
+	AutoHD<Attr> attr;
+	for( int i_a = 0; i_a < list.size(); i_a++ )
+	{
+	    attr = attrAt(list[i_a]);
+	    if( !attr.at().modif() ) continue;
+	    if( attr.at().flgGlob()&Attr::IsUser && !(attr.at().flgGlob()&Attr::IsInher) )
+	    {
+		c_uel.cfg("ID").setS(id()+"/"+list[i_a]);
+		SYS->db().at().dataDel(fullDB+"_uio",mod->nodePath()+tbl+"_uio",c_uel);
+	    }
+	    else
+	    {
+		c_el.cfg("ID").setS(id()+"/"+list[i_a]);
+		SYS->db().at().dataDel(fullDB+"_io",mod->nodePath()+tbl+"_io",c_el);
+	    }
+	}
     }
+
+    Widget::preDisable(flag);
 }
 
 string CWidget::ico( )
@@ -947,15 +1010,24 @@ string CWidget::grp( )
     return owner().grp( );
 }
 
-short  CWidget::permit( )
+short CWidget::permit( )
 {
     return owner().permit( );
 }
 
-void CWidget::setParentNm( const string &isw )
+void CWidget::setEnable( bool val )
 {
-    cfg("PARENT").setS(isw);
-    Widget::setParentNm(isw);
+    if( enable() == val ) return;
+    
+    Widget::setEnable(val);
+    
+    //- Disable heritors widgets -
+    if( val )	    
+	for( int i_h = 0; i_h < owner().herit().size(); i_h++ )
+	    if( owner().herit()[i_h].at().wdgPresent(id()) && !owner().herit()[i_h].at().wdgAt(id()).at().enable( ) )
+            try { owner().herit()[i_h].at().wdgAt(id()).at().setEnable(true); }
+            catch(...)
+            { mess_err(nodePath().c_str(),_("Heritors widget <%s> enable error"),id().c_str()); }
 }
 
 string CWidget::calcId( )
@@ -982,13 +1054,12 @@ int CWidget::calcPer( )
     return 0;
 }
 
-void CWidget::load( )
+void CWidget::load_( )
 {
     //- Load generic widget's data -
     string db  = owner().owner().DB();
     string tbl = owner().owner().tbl()+"_incl";
     SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,*this);
-    setParentNm(cfg("PARENT").getS());
 
     //- Load widget's attributes -
     loadIO();
@@ -996,6 +1067,7 @@ void CWidget::load( )
 
 void CWidget::loadIO( )
 {
+    string tstr;
     vector<string> als;
 
     if( !enable() ) return;
@@ -1003,18 +1075,34 @@ void CWidget::loadIO( )
     //- Load widget's work attributes -
     string db  = owner().owner().DB();
     string tbl = owner().owner().tbl()+"_io";
+
+    //- Inherit modify attributes -
+    /*attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+	AutoHD<Attr> attr = attrAt(als[i_a]);
+	if( attr.at().flgGlob()&Attr::IsInher && attr.at().modif() && m_attrs.find(als[i_a]) == string::npos )
+	{	
+    	    attr.at().setModif(0);
+	    inheritAttr(als[i_a]);
+	}
+    }    
+    als.clear();*/
+    if( m_attrs != "*" ) 
+	for( int off = 0; !(tstr = TSYS::strSepParse(m_attrs,0,';',&off)).empty(); )
+	    als.push_back(tstr);
     
-    attrList( als );
+    //-- Same load --
     TConfig c_el(&mod->elWdgIO());
     c_el.cfg("IDW").setS(owner().id());    
     for( int i_a = 0; i_a < als.size(); i_a++ )
     { 
+	if( !attrPresent(als[i_a]) )    continue;
  	AutoHD<Attr> attr = attrAt(als[i_a]);
-	if( !(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser ) continue;
+	if( !(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser ) continue;	
 	c_el.cfg("ID").setS(id()+"/"+als[i_a]);
 	if( !SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,c_el) ) continue;
 	attr.at().setS(c_el.cfg("IO_VAL").getS());
-	if( attr.at().flgGlob()&Attr::Active )	attrList( als );
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
@@ -1037,31 +1125,33 @@ void CWidget::loadIO( )
 
         if( !attrPresent(sid) )
             attrAdd( new TFld(sid.c_str(),c_el.cfg("NAME").getS().c_str(),(TFld::Type)(flg&0x0f),flg>>4) );
-
 	AutoHD<Attr> attr = attrAt(sid);
         if( !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) ) continue;
-	if( attr.at().flgGlob()&TFld::Selected )
-	{
-	    attr.at().setS(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),0,'|'));
-	    attr.at().fld().setValues(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),1,'|'));
-	    attr.at().fld().setSelNames(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),2,'|'));
-	}
-	else attr.at().setS(c_el.cfg("IO_VAL").getS());
+	attr.at().setS(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),0,'|'));
+	attr.at().fld().setValues(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),1,'|'));
+	attr.at().fld().setSelNames(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),2,'|'));
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
     }
 }
 
-void CWidget::save( )
+void CWidget::save_( )
 {
     //- Save generic widget's data -
-    if( !parent().at().isLink() )
+    string db  = owner().owner().DB();
+    string tbl = owner().owner().tbl()+"_incl";
+        
+    m_attrs="";
+    vector<string> als;
+    attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
     {
-	string db  = owner().owner().DB();
-	string tbl = owner().owner().tbl()+"_incl";
-	SYS->db().at().dataSet(db+"."+tbl,mod->nodePath()+tbl,*this);
+        AutoHD<Attr> attr = attrAt(als[i_a]);
+        if( attr.at().modif() && !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) )
+        m_attrs+=als[i_a]+";";
     }
+    SYS->db().at().dataSet(db+"."+tbl,mod->nodePath()+tbl,*this);
 
     //- Save widget's attributes -
     saveIO();
@@ -1137,6 +1227,13 @@ string CWidget::resourceGet( const string &id, string *mime )
     return mimeData;
 }
 
+void CWidget::inheritAttr( const string &attr )
+{
+    bool mdf = isModify();
+    Widget::inheritAttr( attr );
+    if( !mdf )  modifClr( );
+}	    
+
 void CWidget::cntrCmdProc( XMLNode *opt )
 {
     if( cntrCmdServ(opt) ) return;
@@ -1145,8 +1242,9 @@ void CWidget::cntrCmdProc( XMLNode *opt )
     {
 	cntrCmdGeneric(opt);
 	cntrCmdAttributes(opt);
-        ctrMkNode("oscada_cntr",opt,-1,"/",_("Link to widget: ")+id());
+        ctrMkNode("oscada_cntr",opt,-1,"/",_("Link to widget: ")+id(),permit(),user().c_str(),grp().c_str());
 	return;
     }
-    cntrCmdGeneric(opt) || cntrCmdAttributes(opt);
+    if( !(cntrCmdGeneric(opt) || cntrCmdAttributes(opt)) )
+	TCntrNode::cntrCmdProc(opt);
 }
