@@ -104,7 +104,8 @@ void PrWidget::cntrCmdProc( XMLNode *opt )
     }
     
     //- Process command to page -
-    cntrCmdGeneric(opt) || cntrCmdAttributes(opt);
+    if( !(cntrCmdGeneric(opt) || cntrCmdAttributes(opt)) )
+	TCntrNode::cntrCmdProc(opt);
 }
 
 
@@ -137,14 +138,15 @@ void OrigElFigure::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect )
     {
-	attrAdd( new TFld("lineWdth",_("Line:width"),TFld::Integer,TFld::NoFlag,"2","1","0;99","",20) );
-	attrAdd( new TFld("lineClr",_("Line:color"),TFld::String,Attr::Color,"20","#000000","","",21) );
-	attrAdd( new TFld("lineDecor",_("Line:decorate"),TFld::Integer,TFld::Selected,"1","0","0;1",_("No decor;Pipe"),22) );
-	attrAdd( new TFld("bordWdth",_("Border:width"),TFld::Integer,TFld::NoFlag,"2","0","0;99","",23) );
-	attrAdd( new TFld("bordClr",_("Border:color"),TFld::String,Attr::Color,"20","#000000","","",24) );
-	attrAdd( new TFld("fillColor",_("Fill:color"),TFld::String,Attr::Color,"20","","","",25) );
-	attrAdd( new TFld("fillImg",_("Fill:image"),TFld::String,Attr::Image,"20","","","",26) );
-	attrAdd( new TFld("elLst",_("Element's list"),TFld::String,TFld::FullText|Attr::Active,"300","","","",27) );
+	attrAdd( new TFld("lineWdth",_("Line:width"),TFld::Integer,TFld::NoFlag,"2","1","0;99","","20") );
+	attrAdd( new TFld("lineClr",_("Line:color"),TFld::String,Attr::Color,"20","#000000","","","21") );
+	attrAdd( new TFld("lineDecor",_("Line:decorate"),TFld::Integer,TFld::Selected,"1","0","0;1",_("No decor;Pipe"),"22") );
+	attrAdd( new TFld("bordWdth",_("Border:width"),TFld::Integer,TFld::NoFlag,"2","0","0;99","","23") );
+	attrAdd( new TFld("bordClr",_("Border:color"),TFld::String,Attr::Color,"20","#000000","","","24") );
+	attrAdd( new TFld("fillColor",_("Fill:color"),TFld::String,Attr::Color,"20","","","","25") );
+	attrAdd( new TFld("fillImg",_("Fill:image"),TFld::String,Attr::Image,"20","","","","26") );
+        attrAdd( new TFld("orient",_("Orientation angle"),TFld::Integer,TFld::NoFlag,"3","0","-180;180","","28") );
+	attrAdd( new TFld("elLst",_("Element's list"),TFld::String,TFld::FullText|Attr::Active,"300","","","","27") );
     }
 }
 
@@ -179,9 +181,9 @@ bool OrigElFigure::attrChange( Attr &cfg, void *prev )
 		    pntls.push_back(p[i_p]);
 		    if( cfg.owner()->attrPresent("p"+TSYS::int2str(p[i_p])+"x") )	continue;
 		    cfg.owner()->attrAdd( new TFld(("p"+TSYS::int2str(p[i_p])+"x").c_str(),(_("Point ")+TSYS::int2str(p[i_p])+":x").c_str(),
-			TFld::Integer,Attr::Mutable,"","0","","",30+p[i_p]*2) );
+			TFld::Real,Attr::Mutable,"","0","","",TSYS::int2str(30+p[i_p]*2).c_str()) );
 		    cfg.owner()->attrAdd( new TFld(("p"+TSYS::int2str(p[i_p])+"y").c_str(),(_("Point ")+TSYS::int2str(p[i_p])+":y").c_str(),
-			TFld::Integer,Attr::Mutable,"","0","","",30+p[i_p]*2+1) );
+			TFld::Real,Attr::Mutable,"","0","","",TSYS::int2str(30+p[i_p]*2+1).c_str()) );
 		}
 	}
 	//- Delete points -
@@ -196,8 +198,8 @@ bool OrigElFigure::attrChange( Attr &cfg, void *prev )
 		cfg.owner()->attrDel("p"+TSYS::int2str(pntls_prev[i_p])+"y");
 	    }
 	}
-    }
-    return true;
+    }    
+    return Widget::attrChange(cfg,prev);
 }
 
 //*************************************************
@@ -224,7 +226,7 @@ void OrigFormEl::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect )
 	attrAdd( new TFld("elType",_("Element type"),TFld::Integer,TFld::Selected|Attr::Active,"2","0","0;1;2;3;4;5;6;7",
-                    	       _("Line edit;Text edit;Chek box;Button;Combo box;List;Slider;Scroll Bar"),20) );
+                    	       _("Line edit;Text edit;Chek box;Button;Combo box;List;Slider;Scroll Bar"),"20") );
 }
 								  
 bool OrigFormEl::attrChange( Attr &cfg, void *prev )
@@ -234,27 +236,34 @@ bool OrigFormEl::attrChange( Attr &cfg, void *prev )
 	//- Delete specific attributes -
 	switch(*(int*)prev)
 	{
-	    case 0: 
+	    case 0:	//Line edit
 		cfg.owner()->attrDel("value");
 		cfg.owner()->attrDel("view");
 		cfg.owner()->attrDel("cfg");
+		cfg.owner()->attrDel("font");		
 		break;
-	    case 1: 
+	    case 1:	//Text edit
 		cfg.owner()->attrDel("value");
 		cfg.owner()->attrDel("wordWrap");
+		cfg.owner()->attrDel("font");
 		break;
-	    case 2:	cfg.owner()->attrDel("value");	break;
-	    case 3:
+	    case 2:	//Check box
+		cfg.owner()->attrDel("value");
+		cfg.owner()->attrDel("font");
+		break;
+	    case 3:	//Button
 		cfg.owner()->attrDel("value");
 	        cfg.owner()->attrDel("img");
 		cfg.owner()->attrDel("color");
 		cfg.owner()->attrDel("checkable");
+		cfg.owner()->attrDel("font");		
 		break;
-	    case 4: case 5:
+	    case 4: case 5:	//Combo box and list
 		cfg.owner()->attrDel("value");
 		cfg.owner()->attrDel("items");
+		cfg.owner()->attrDel("font");		
 		break;
-	    case 6: case 7:
+	    case 6: case 7:	//Slider and scroll bar
 		cfg.owner()->attrDel("value");
 		cfg.owner()->attrDel("cfg");
 		break;
@@ -263,36 +272,64 @@ bool OrigFormEl::attrChange( Attr &cfg, void *prev )
 	//- Create specific attributes -
 	switch(cfg.getI())
 	{
-	    case 0:
-		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::String,Attr::Mutable,"200","","","",21) );		
-		cfg.owner()->attrAdd( new TFld("view",_("View"),TFld::Integer,TFld::Selected|Attr::Mutable,
-		    "1","0","0;1;2;3;4;5;6",_("Text;Combo;Integer;Real;Time;Data;Data and time"),22) );
-		cfg.owner()->attrAdd( new TFld("cfg",_("Config"),TFld::String,TFld::FullText|Attr::Mutable,"","","","",23) );
+	    case 0:	//Line edit
+		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::String,Attr::Mutable,"200","","","","21") );
+		cfg.owner()->attrAdd( new TFld("view",_("View"),TFld::Integer,TFld::Selected|Attr::Mutable|Attr::Active,
+		    "1","0","0;1;2;3;4;5;6",_("Text;Combo;Integer;Real;Time;Data;Data and time"),"22") );
+		cfg.owner()->attrAdd( new TFld("cfg",_("Config"),TFld::String,TFld::FullText|Attr::Mutable,"","","","","23") );
+		cfg.owner()->attrAdd( new TFld("font",_("Font"),TFld::String,Attr::Font,"50","Arial 11","","","25") );		
 		break;
-	    case 1: 
-		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::String,TFld::FullText|Attr::Mutable,"","","","",21) );
-		cfg.owner()->attrAdd( new TFld("wordWrap",_("Word wrap"),TFld::Boolean,Attr::Mutable,"1","1","","",22) );
+	    case 1:	//Text edit
+		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::String,TFld::FullText|Attr::Mutable,"","","","","21") );
+		cfg.owner()->attrAdd( new TFld("wordWrap",_("Word wrap"),TFld::Boolean,Attr::Mutable,"1","1","","","22") );
+		cfg.owner()->attrAdd( new TFld("font",_("Font"),TFld::String,Attr::Font,"50","Arial 11","","","25") );
 		break;
-	    case 2:
-		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::Boolean,Attr::Mutable,"","","","",21) );
+	    case 2:	//Check box
+		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::Boolean,Attr::Mutable,"","","","","21") );
+		cfg.owner()->attrAdd( new TFld("font",_("Font"),TFld::String,Attr::Font,"50","Arial 11","","","25") );
 		break;
-	    case 3:
-		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::Boolean,Attr::Mutable,"","","","",21) );
-		cfg.owner()->attrAdd( new TFld("img",_("Image"),TFld::String,Attr::Image|Attr::Mutable,"","","","",22) );
-		cfg.owner()->attrAdd( new TFld("color",_("Color"),TFld::String,Attr::Color|Attr::Mutable,"20","","","",23) );
-		cfg.owner()->attrAdd( new TFld("checkable",_("Checkable"),TFld::Boolean,Attr::Mutable,"","","","",24) );
+	    case 3:	//Button
+		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::Boolean,Attr::Mutable,"","","","","21") );
+		cfg.owner()->attrAdd( new TFld("img",_("Image"),TFld::String,Attr::Image|Attr::Mutable,"","","","","22") );
+		cfg.owner()->attrAdd( new TFld("color",_("Color"),TFld::String,Attr::Color|Attr::Mutable,"20","","","","23") );
+		cfg.owner()->attrAdd( new TFld("checkable",_("Checkable"),TFld::Boolean,Attr::Mutable,"","","","","24") );
+		cfg.owner()->attrAdd( new TFld("font",_("Font"),TFld::String,Attr::Font,"50","Arial 11","","","25") );
 		break;
-	    case 4: case 5:
-		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::String,Attr::Mutable,"200","","","",21) );
-		cfg.owner()->attrAdd( new TFld("items",_("Items"),TFld::String,TFld::FullText|Attr::Mutable,"","","","",22) );
+	    case 4: case 5:	//Combo box and list
+		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::String,Attr::Mutable,"200","","","","21") );
+		cfg.owner()->attrAdd( new TFld("items",_("Items"),TFld::String,TFld::FullText|Attr::Mutable,"","","","","22") );
+		cfg.owner()->attrAdd( new TFld("font",_("Font"),TFld::String,Attr::Font,"50","Arial 11","","","25") );
 		break;
-	    case 6: case 7:
-		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::Integer,Attr::Mutable,"20","0","","",21) );
-		cfg.owner()->attrAdd( new TFld("cfg",_("Config"),TFld::String,Attr::Mutable,"100","0:0:100:1:10","","",22) );
+	    case 6: case 7:	//Slider and scroll bar
+		cfg.owner()->attrAdd( new TFld("value",_("Value"),TFld::Integer,Attr::Mutable,"20","0","","","21") );
+		cfg.owner()->attrAdd( new TFld("cfg",_("Config"),TFld::String,Attr::Mutable,"100","0:0:100:1:10","","","22") );
 		break;
 	}
     }
-    return true;
+    else if( cfg.flgGlob()&Attr::Active && cfg.id() == "view" )
+    {
+	TFld::Type	ntp = TFld::String;
+	int 		flg = Attr::Mutable;
+	VCA::Attr::SelfAttrFlgs	sflg = cfg.owner()->attrAt("value").at().flgSelf();
+	string 		val = cfg.owner()->attrAt("value").at().getS();
+	string		cfgTmpl = cfg.owner()->attrAt("value").at().cfgTempl( );
+	string		cfgVal = cfg.owner()->attrAt("value").at().cfgVal( );
+	switch(cfg.getI())
+	{
+	    case 2: case 4:	ntp = TFld::Integer;	break;
+	    case 3:		ntp = TFld::Real;	break;
+	    case 5: case 6:	ntp = TFld::Integer; flg|=Attr::DataTime;	break;
+	}
+	int apos = cfg.owner()->attrPos("value");
+	cfg.owner()->attrDel("value");
+	cfg.owner()->attrAdd( new TFld("value",_("Value"),ntp,flg,"200","","","","21"), apos );
+	cfg.owner()->attrAt("value").at().setFlgSelf(sflg);
+	cfg.owner()->attrAt("value").at().setS(val);
+	cfg.owner()->attrAt("value").at().setCfgTempl(cfgTmpl);
+	cfg.owner()->attrAt("value").at().setCfgVal(cfgVal);
+    }
+    
+    return Widget::attrChange(cfg,prev);
 }
 
 //************************************************
@@ -319,28 +356,22 @@ void OrigText::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect )
     { 
-        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","","","",20) );
-        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","",21) );
-        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","",22) );
-        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","",23) );
+        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","","","","20") );
+        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","","21") );
+        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","","22") );
+        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","","23") );
         attrAdd( new TFld("bordStyle",_("Border:style"),TFld::Integer,TFld::Selected,"","3","0;1;2;3;4;5;6;7;8",
-						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),19) );	
-	attrAdd( new TFld("font",_("Font:full"),TFld::String,Attr::Font,"50","Arial 11","","",24) );
-	attrAdd( new TFld("fontFamily",_("Font:family"),TFld::String,TFld::NoFlag,"10","Arial","","",25) );
-	attrAdd( new TFld("fontSize",_("Font:size"),TFld::Integer,TFld::NoFlag,"2","11","","",26) );
-        attrAdd( new TFld("fontBold",_("Font:bold"),TFld::Boolean,TFld::NoFlag,"1","0","","",27) );
-        attrAdd( new TFld("fontItalic",_("Font:italic"),TFld::Boolean,TFld::NoFlag,"1","0","","",28) );
-        attrAdd( new TFld("fontUnderline",_("Font:underline"),TFld::Boolean,TFld::NoFlag,"1","0","","",29) );
-        attrAdd( new TFld("fontStrikeout",_("Font:strikeout"),TFld::Boolean,TFld::NoFlag,"1","0","","",30) );
-        attrAdd( new TFld("color",_("Color"),TFld::String,Attr::Color,"20","#000000","","",31) );
-        attrAdd( new TFld("orient",_("Orientation angle"),TFld::Integer,TFld::NoFlag,"3","0","-180;180","",32) );
-        attrAdd( new TFld("wordWrap",_("Word wrap"),TFld::Boolean,TFld::NoFlag,"1","1","","",33) );
+						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),"19") );	
+	attrAdd( new TFld("font",_("Font"),TFld::String,Attr::Font,"50","Arial 11","","","24") );
+        attrAdd( new TFld("color",_("Color"),TFld::String,Attr::Color,"20","#000000","","","25") );
+        attrAdd( new TFld("orient",_("Orientation angle"),TFld::Integer,TFld::NoFlag,"3","0","-180;180","","26") );
+        attrAdd( new TFld("wordWrap",_("Word wrap"),TFld::Boolean,TFld::NoFlag,"1","1","","","27") );
         attrAdd( new TFld("alignment",_("Alignment"),TFld::Integer,TFld::Selected,"1","0","0;1;2;3;4;5;6;7;8;9;10;11",
                           _("Top left;Top right;Top center;Top justify;"
 			    "Bottom left;Bottom right;Bottom center;Bottom justify;"
-			    "V center left; V center right; Center; V center justify"),34) );
-    	attrAdd( new TFld("text",_("Text"),TFld::String,TFld::FullText,"0","Text","","",35) );
-    	attrAdd( new TFld("numbArg",_("Arguments number"),TFld::Integer,Attr::Active,"","0","0;10","",36) );
+			    "V center left; V center right; Center; V center justify"),"28") );
+    	attrAdd( new TFld("text",_("Text"),TFld::String,TFld::FullText,"0","Text","","","29") );
+    	attrAdd( new TFld("numbArg",_("Arguments number"),TFld::Integer,Attr::Active,"","0","0;10","","30") );
     }
 } 
 
@@ -348,6 +379,7 @@ bool OrigText::attrChange( Attr &cfg, void *prev )
 {
     if( cfg.flgGlob()&Attr::Active )
     {
+	int aid = atoi(cfg.fld().reserve().c_str());
      	if( cfg.id() == "numbArg" )
 	{
 	    string fid("arg"), fnm(_("Argument ")), fidp, fnmp;
@@ -370,26 +402,28 @@ bool OrigText::attrChange( Attr &cfg, void *prev )
 		fnmp = fnm+TSYS::int2str(i_p);
 		if( cfg.owner()->attrPresent( fidp+"val" ) ) continue;
 		cfg.owner()->attrAdd( new TFld((fidp+"tp").c_str(),(fnmp+_(":type")).c_str(),
-		    TFld::Real,TFld::Selected|Attr::Mutable|Attr::Active,"","0","0;1;2",_("Integer;Real;String"),51+10*i_p) );
+		    TFld::Real,TFld::Selected|Attr::Mutable|Attr::Active,"","0","0;1;2",_("Integer;Real;String"),TSYS::int2str(51+10*i_p).c_str()) );
 		cfg.owner()->attrAdd( new TFld((fidp+"val").c_str(),(fnmp+_(":value")).c_str(),
-		    TFld::Integer,Attr::Mutable,"","","","",50+10*i_p) );		    		    
+		    TFld::Integer,Attr::Mutable,"","","","",TSYS::int2str(50+10*i_p).c_str()) );
 		cfg.owner()->attrAdd( new TFld((fidp+"cfg").c_str(),(fnmp+_(":config")).c_str(),
-		    TFld::String,Attr::Mutable,"","","","",52+10*i_p) );
+		    TFld::String,Attr::Mutable,"","","","",TSYS::int2str(52+10*i_p).c_str()) );
 	    }
 	}
-	else if( cfg.fld().reserve() >= 50 && (cfg.fld().reserve()%10) == 1 && *(int*)prev != cfg.getI() )
+	else if( aid >= 50 && (aid%10) == 1 && *(int*)prev != cfg.getI() )
 	{
-	    int narg = (cfg.fld().reserve()/10)-5;
+	    int narg = (aid/10)-5;
 	    string fid = "arg"+TSYS::int2str(narg)+"val";
 	    string fnm = _("Argument ")+TSYS::int2str(narg)+":value";
 	    int apos = cfg.owner()->attrPos(fid);
+	    VCA::Attr::SelfAttrFlgs sflg =  cfg.owner()->attrAt(fid).at().flgSelf();
 	    cfg.owner()->attrDel(fid);
 	    cfg.owner()->attrAdd( new TFld(fid.c_str(),fnm.c_str(),
 			(cfg.getI()==1) ? TFld::Real : ((cfg.getI()==2) ? TFld::String : TFld::Integer),
-			Attr::Mutable,"","","","",50+10*narg), apos );
+			Attr::Mutable,"","","","",TSYS::int2str(50+10*narg).c_str()), apos );
+	    cfg.owner()->attrAt(fid).at().setFlgSelf(sflg);
 	}
     }
-    return true;
+    return Widget::attrChange(cfg,prev);
 }
 
 //************************************************
@@ -416,16 +450,16 @@ void OrigMedia::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect )
     { 	
-        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","#FFFFFF","","",20) );
-        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","",21) );
-        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","",22) );
-        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","",23) );
+        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","#FFFFFF","","","20") );
+        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","","21") );
+        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","","22") );
+        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","","23") );
         attrAdd( new TFld("bordStyle",_("Border:style"),TFld::Integer,TFld::Selected,"","3","0;1;2;3;4;5;6;7;8",
-						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),19) );
-        attrAdd( new TFld("src",_("Source"),TFld::String,TFld::NoFlag,"50","","","",24) );
-    	attrAdd( new TFld("fit",_("Fit to widget size"),TFld::Boolean,TFld::NoFlag,"","","","",26) );
-        attrAdd( new TFld("type",_("Type"),TFld::Integer,TFld::Selected|Attr::Active,"1","0","0;1",_("Image;Movie"),25) );
-        attrAdd( new TFld("areas",_("Map areas"),TFld::Integer,Attr::Active,"2","0","0;10","",28) );
+						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),"19") );
+        attrAdd( new TFld("src",_("Source"),TFld::String,TFld::NoFlag,"50","","","","24") );
+    	attrAdd( new TFld("fit",_("Fit to widget size"),TFld::Boolean,TFld::NoFlag,"","","","","26") );
+        attrAdd( new TFld("type",_("Type"),TFld::Integer,TFld::Selected|Attr::Active,"1","0","0;1",_("Image;Movie"),"25") );
+        attrAdd( new TFld("areas",_("Map areas"),TFld::Integer,Attr::Active,"2","0","0;10","","28") );
     }
 }
 
@@ -440,7 +474,7 @@ bool OrigMedia::attrChange( Attr &cfg, void *prev )
 	
 	    //- Create specific attributes -
 	    if(cfg.getI() == 1 )
-		cfg.owner()->attrAdd( new TFld("speed",_("Play speed"),TFld::Integer,Attr::Mutable,"3","100","1;900","",27) );
+		cfg.owner()->attrAdd( new TFld("speed",_("Play speed"),TFld::Integer,Attr::Mutable,"3","100","1;900","","27") );
 	}
 	else if( cfg.id() == "areas" )
 	{
@@ -464,15 +498,15 @@ bool OrigMedia::attrChange( Attr &cfg, void *prev )
 		fnmp = fnm+TSYS::int2str(i_p);
 		if( cfg.owner()->attrPresent( fidp+"shp" ) ) continue;
     		cfg.owner()->attrAdd( new TFld((fidp+"shp").c_str(),(fnmp+_(":shape")).c_str(),
-					       TFld::Integer,TFld::Selected|Attr::Mutable,"1","0","0;1;2","Rect;Poly;Circle",40+3*i_p) );
+					       TFld::Integer,TFld::Selected|Attr::Mutable,"1","0","0;1;2","Rect;Poly;Circle",TSYS::int2str(40+3*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"coord").c_str(),(fnmp+_(":coordinates")).c_str(),
-					       TFld::String,Attr::Mutable,"","","","",41+3*i_p) );
+					       TFld::String,Attr::Mutable,"","","","",TSYS::int2str(41+3*i_p).c_str()) );
 		cfg.owner()->attrAdd( new TFld((fidp+"title").c_str(),(fnmp+_(":title")).c_str(),
-					       TFld::String,Attr::Mutable,"","","","",42+3*i_p) );
+					       TFld::String,Attr::Mutable,"","","","",TSYS::int2str(42+3*i_p).c_str()) );
 	    }
 	}
     }
-    return true;
+    return Widget::attrChange(cfg,prev);
 }
 
 //************************************************
@@ -499,14 +533,14 @@ void OrigDiagram::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect ) 
     { 
-        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","black","","",20) );
-        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","",21) );
-        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","",22) );
-        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","",23) );
+        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","black","","","20") );
+        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","","21") );
+        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","","22") );
+        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","","23") );
         attrAdd( new TFld("bordStyle",_("Border:style"),TFld::Integer,TFld::Selected,"","3","0;1;2;3;4;5;6;7;8",
-						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),19) );
-        attrAdd( new TFld("trcPer",_("Tracing period (s)"),TFld::Integer,TFld::NoFlag,"","0","0;360","",24) );
-        attrAdd( new TFld("type",_("Type"),TFld::Integer,TFld::Selected|Attr::Active,"1","0","0",_("Trend"),25) );
+						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),"19") );
+        attrAdd( new TFld("trcPer",_("Tracing period (s)"),TFld::Integer,TFld::NoFlag,"","0","0;360","","24") );
+        attrAdd( new TFld("type",_("Type"),TFld::Integer,TFld::Selected|Attr::Active,"1","0","0",_("Trend"),"25") );
     }
 } 
 
@@ -525,9 +559,9 @@ bool OrigDiagram::attrChange( Attr &cfg, void *prev )
 	    }
 	    else
 	    {
-    	        cfg.owner()->attrAdd( new TFld("curSek",_("Cursor:sek"),TFld::Integer,Attr::Mutable,"","","","",29) );
-    	        cfg.owner()->attrAdd( new TFld("curUSek",_("Cursor:usek"),TFld::Integer,Attr::Mutable,"","","","",30) );
-    		cfg.owner()->attrAdd( new TFld("curColor",_("Cursor:color"),TFld::String,Attr::Color|Attr::Mutable,"","white","","",36) );
+    	        cfg.owner()->attrAdd( new TFld("curSek",_("Cursor:sek"),TFld::Integer,Attr::DataTime|Attr::Mutable,"","","","","29") );
+    	        cfg.owner()->attrAdd( new TFld("curUSek",_("Cursor:usek"),TFld::Integer,Attr::Mutable,"","","","","30") );
+    		cfg.owner()->attrAdd( new TFld("curColor",_("Cursor:color"),TFld::String,Attr::Color|Attr::Mutable,"","white","","","36") );
 	    }
 	}
 	else if( cfg.id() == "type" )
@@ -556,24 +590,24 @@ bool OrigDiagram::attrChange( Attr &cfg, void *prev )
 	    switch(cfg.getI())
 	    {
 		case 0:
-    		    cfg.owner()->attrAdd( new TFld("tSek",_("Time:sek"),TFld::Integer,Attr::Mutable,"","","","",26) );
-    		    cfg.owner()->attrAdd( new TFld("tUSek",_("Time:usek"),TFld::Integer,Attr::Mutable,"","","","",27) );
-    		    cfg.owner()->attrAdd( new TFld("tSize",_("Size, sek"),TFld::Real,Attr::Mutable,"","60","","",28) );
+    		    cfg.owner()->attrAdd( new TFld("tSek",_("Time:sek"),TFld::Integer,Attr::DataTime|Attr::Mutable,"","","","","26") );
+    		    cfg.owner()->attrAdd( new TFld("tUSek",_("Time:usek"),TFld::Integer,Attr::Mutable,"","","","","27") );
+    		    cfg.owner()->attrAdd( new TFld("tSize",_("Size, sek"),TFld::Real,Attr::Mutable,"","60","","","28") );
 		    if( cfg.owner()->attrAt("active").at().getB() )
 		    {
-    			cfg.owner()->attrAdd( new TFld("curSek",_("Cursor:sek"),TFld::Integer,Attr::Mutable,"","","","",29) );
-    			cfg.owner()->attrAdd( new TFld("curUSek",_("Cursor:usek"),TFld::Integer,Attr::Mutable,"","","","",30) );
-    			cfg.owner()->attrAdd( new TFld("curColor",_("Cursor:color"),TFld::String,Attr::Color|Attr::Mutable,"","white","","",36) );
+    			cfg.owner()->attrAdd( new TFld("curSek",_("Cursor:sek"),TFld::Integer,Attr::DataTime|Attr::Mutable,"","","","","29") );
+    			cfg.owner()->attrAdd( new TFld("curUSek",_("Cursor:usek"),TFld::Integer,Attr::Mutable,"","","","","30") );
+    			cfg.owner()->attrAdd( new TFld("curColor",_("Cursor:color"),TFld::String,Attr::Color|Attr::Mutable,"","white","","","36") );
 		    }
-    		    cfg.owner()->attrAdd( new TFld("sclColor",_("Scale:color"),TFld::String,Attr::Color|Attr::Mutable,"","grey","","",31) );
+    		    cfg.owner()->attrAdd( new TFld("sclColor",_("Scale:color"),TFld::String,Attr::Color|Attr::Mutable,"","grey","","","31") );
     		    cfg.owner()->attrAdd( new TFld("sclHor",_("Scale:horizontal"),TFld::Integer,Attr::Mutable|TFld::Selected,
-			"1","0","0;1;2;3",_("No draw;Grid;Markers;Grid and markers"),32) );
+			"1","0","0;1;2;3",_("No draw;Grid;Markers;Grid and markers"),"32") );
     		    cfg.owner()->attrAdd( new TFld("sclVer",_("Scale:vertical"),TFld::Integer,Attr::Mutable|TFld::Selected,
-			"1","0","0;1;2;3;5;6;7",_("No draw;Grid;Markers;Grid and markers;Grid (log);Marker (log);Grid and markers (log)"),33) );
-    		    cfg.owner()->attrAdd( new TFld("sclMarkColor",_("Scale:Markers:color"),TFld::String,Attr::Color|Attr::Mutable,"","white","","",37) );
-    		    cfg.owner()->attrAdd( new TFld("sclMarkFont",_("Scale:Markers:font"),TFld::String,Attr::Font|Attr::Mutable,"","Arial 10","","",38) );
-    		    cfg.owner()->attrAdd( new TFld("valArch",_("Value archivator"),TFld::String,Attr::Mutable,"","","","",34) );
-    		    cfg.owner()->attrAdd( new TFld("parNum",_("Parameters number"),TFld::Integer,Attr::Mutable|Attr::Active,"1","1","0;10","",35) );
+			"1","0","0;1;2;3;5;6;7",_("No draw;Grid;Markers;Grid and markers;Grid (log);Marker (log);Grid and markers (log)"),"33") );
+    		    cfg.owner()->attrAdd( new TFld("sclMarkColor",_("Scale:Markers:color"),TFld::String,Attr::Color|Attr::Mutable,"","white","","","37") );
+    		    cfg.owner()->attrAdd( new TFld("sclMarkFont",_("Scale:Markers:font"),TFld::String,Attr::Font|Attr::Mutable,"","Arial 10","","","38") );
+    		    cfg.owner()->attrAdd( new TFld("valArch",_("Value archivator"),TFld::String,Attr::Mutable,"","","","","34") );
+    		    cfg.owner()->attrAdd( new TFld("parNum",_("Parameters number"),TFld::Integer,Attr::Mutable|Attr::Active,"1","1","0;10","","35") );
 		    break;
 	    }
 	}
@@ -601,20 +635,22 @@ bool OrigDiagram::attrChange( Attr &cfg, void *prev )
 		fnmp = fnm+TSYS::int2str(i_p);
 		if( cfg.owner()->attrPresent( fidp+"addr" ) ) continue;
     		cfg.owner()->attrAdd( new TFld((fidp+"addr").c_str(),(fnmp+_(":address")).c_str(),
-					       TFld::String,Attr::Address|Attr::Mutable,"","","","",50+10*i_p) );
+					       TFld::String,Attr::Address|Attr::Mutable,"","","","",TSYS::int2str(50+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"bordL").c_str(),(fnmp+_(":view border:lower")).c_str(),
-					       TFld::Real,Attr::Mutable,"","","","",51+10*i_p) );
+					       TFld::Real,Attr::Mutable,"","","","",TSYS::int2str(51+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"bordU").c_str(),(fnmp+_(":view border:upper")).c_str(),
-					       TFld::Real,Attr::Mutable,"","","","",52+10*i_p) );
+					       TFld::Real,Attr::Mutable,"","","","",TSYS::int2str(52+10*i_p).c_str()) );
+    		cfg.owner()->attrAdd( new TFld((fidp+"aScale").c_str(),(fnmp+_(":view border:autoscale")).c_str(),
+					       TFld::Integer,Attr::Mutable,"","0","","",TSYS::int2str(55+10*i_p).c_str()) );		
     		cfg.owner()->attrAdd( new TFld((fidp+"color").c_str(),(fnmp+_(":color")).c_str(),
-					       TFld::String,Attr::Color|Attr::Mutable,"","","","",53+10*i_p) );
+					       TFld::String,Attr::Color|Attr::Mutable,"","","","",TSYS::int2str(53+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"val").c_str(),(fnmp+_(":value")).c_str(),
-					       TFld::Real,Attr::Mutable,"","","","",54+10*i_p) );
+					       TFld::Real,Attr::Mutable,"","","","",TSYS::int2str(54+10*i_p).c_str()) );
 	    }
 	}
     }
     
-    return true;
+    return Widget::attrChange(cfg,prev);
 }
 
 //************************************************
@@ -641,18 +677,18 @@ void OrigProtocol::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect ) 
     { 
-        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","","","",20) );
-        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","",21) );
-    	attrAdd( new TFld("time",_("Time, sek"),TFld::Integer,TFld::NoFlag,"","","","",24) );
-        attrAdd( new TFld("tSize",_("Size, sek"),TFld::Integer,TFld::NoFlag,"","60","","",25) );
-        attrAdd( new TFld("trcPer",_("Tracing period (s)"),TFld::Integer,TFld::NoFlag,"","0","0;360","",26) );
-        attrAdd( new TFld("arch",_("Archivator"),TFld::String,TFld::NoFlag,"","","","",27) );
-        attrAdd( new TFld("tmpl",_("Template"),TFld::String,TFld::NoFlag,"","","","",28) );
-        attrAdd( new TFld("lev",_("Level"),TFld::Integer,TFld::NoFlag,"","0","","",29) );
+        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","","","","20") );
+        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","","21") );
+    	attrAdd( new TFld("time",_("Time, sek"),TFld::Integer,Attr::DataTime,"","","","","24") );
+        attrAdd( new TFld("tSize",_("Size, sek"),TFld::Integer,TFld::NoFlag,"","60","","","25") );
+        attrAdd( new TFld("trcPer",_("Tracing period (s)"),TFld::Integer,TFld::NoFlag,"","0","0;360","","26") );
+        attrAdd( new TFld("arch",_("Archivator"),TFld::String,TFld::NoFlag,"","","","","27") );
+        attrAdd( new TFld("tmpl",_("Template"),TFld::String,TFld::NoFlag,"","","","","28") );
+        attrAdd( new TFld("lev",_("Level"),TFld::Integer,TFld::NoFlag,"","0","","","29") );
         attrAdd( new TFld("viewOrd",_("View order"),TFld::Integer,TFld::Selected,"","0",
-	    "0;1;2",_("On time;On level;On level and trigered"),30) );
-        attrAdd( new TFld("col",_("View columns"),TFld::String,TFld::NoFlag,"","pos;tm;lev;cat;mess","","",31) );
-        attrAdd( new TFld("itProp",_("Items properties"),TFld::Integer,Attr::Active,"","0","0;10","",32) );
+	    "0;1;2",_("On time;On level;On level and trigered"),"30") );
+        attrAdd( new TFld("col",_("View columns"),TFld::String,TFld::NoFlag,"","pos;tm;lev;cat;mess","","","31") );
+        attrAdd( new TFld("itProp",_("Items properties"),TFld::Integer,Attr::Active,"","0","0;10","","32") );
     }
 } 
 
@@ -685,20 +721,19 @@ bool OrigProtocol::attrChange( Attr &cfg, void *prev )
 		fnmp = fnm+TSYS::int2str(i_p);
 		if( cfg.owner()->attrPresent( fidp+"lev" ) ) continue;
     		cfg.owner()->attrAdd( new TFld((fidp+"lev").c_str(),(fnmp+_(":levels")).c_str(),
-					       TFld::String,Attr::Mutable,"","","","",50+10*i_p) );
+					       TFld::String,Attr::Mutable,"","","","",TSYS::int2str(50+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"tmpl").c_str(),(fnmp+_(":template")).c_str(),
-					       TFld::String,Attr::Mutable,"","","","",51+10*i_p) );
+					       TFld::String,Attr::Mutable,"","","","",TSYS::int2str(51+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"fnt").c_str(),(fnmp+_(":font")).c_str(),
-					       TFld::String,Attr::Font|Attr::Mutable,"","","","",52+10*i_p) );
+					       TFld::String,Attr::Font|Attr::Mutable,"","","","",TSYS::int2str(52+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"color").c_str(),(fnmp+_(":color")).c_str(),
-					       TFld::String,Attr::Color|Attr::Mutable,"","","","",53+10*i_p) );
+					       TFld::String,Attr::Color|Attr::Mutable,"","","","",TSYS::int2str(53+10*i_p).c_str()) );
     		cfg.owner()->attrAdd( new TFld((fidp+"blink").c_str(),(fnmp+_(":blink")).c_str(),
-					       TFld::Boolean,Attr::Mutable,"","0","","",54+10*i_p) );
+					       TFld::Boolean,Attr::Mutable,"","0","","",TSYS::int2str(54+10*i_p).c_str()) );
 	    }
-	    return true;
 	}
     }
-    return false;
+    return Widget::attrChange(cfg,prev);    
 }
 
 //************************************************
@@ -761,17 +796,17 @@ void OrigBox::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect )  
     { 
-        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","#FFFFFF","","",20) );
-        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","",21) );
-        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","",22) );
-        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","",23) );
+        attrAdd( new TFld("backColor",_("Background:color"),TFld::String,Attr::Color,"","#FFFFFF","","","20") );
+        attrAdd( new TFld("backImg",_("Background:image"),TFld::String,Attr::Image,"","","","","21") );
+        attrAdd( new TFld("bordWidth",_("Border:width"),TFld::Integer,TFld::NoFlag,"","0","","","22") );
+        attrAdd( new TFld("bordColor",_("Border:color"),TFld::String,Attr::Color,"","#000000","","","23") );
         attrAdd( new TFld("bordStyle",_("Border:style"),TFld::Integer,TFld::Selected,"","3","0;1;2;3;4;5;6;7;8",
-						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),19) );
-	attrAdd( new TFld("pgOpen",_("Page:open state"),TFld::Boolean,TFld::NoFlag,"","","","",24) );
-	attrAdd( new TFld("pgNoOpenProc",_("Page:no open process"),TFld::Boolean,TFld::NoFlag,"","","","",25) );
-        attrAdd( new TFld("pgOpenSrc",_("Page:open source"),TFld::String,TFld::NoFlag,"","","","",26) );
-        attrAdd( new TFld("pgGrp",_("Page:group"),TFld::String,TFld::NoFlag,"","","","",27) );
-	attrAdd( new TFld("pgFullScr",_("Page:full screen"),TFld::Boolean,TFld::NoFlag,"","","","",28) );
+						_("None;Dotted;Dashed;Solid;Double;Groove;Ridge;Inset;Outset"),"19") );
+	attrAdd( new TFld("pgOpen",_("Page:open state"),TFld::Boolean,TFld::NoFlag,"","","","","24") );
+	attrAdd( new TFld("pgNoOpenProc",_("Page:no open process"),TFld::Boolean,TFld::NoFlag,"","","","","25") );
+        attrAdd( new TFld("pgOpenSrc",_("Page:open source"),TFld::String,TFld::NoFlag,"","","","","26") );
+        attrAdd( new TFld("pgGrp",_("Page:group"),TFld::String,TFld::NoFlag,"","","","","27") );
+	attrAdd( new TFld("pgFullScr",_("Page:full screen"),TFld::Boolean,TFld::NoFlag,"","","","","28") );
     }
 } 
 
@@ -799,11 +834,11 @@ void OrigLink::postEnable( int flag )
     
     if( flag&TCntrNode::NodeConnect )  
     { 
-    	attrAdd( new TFld("out",_("Output"),TFld::String,TFld::NoFlag,"50","","","",20) );
-    	attrAdd( new TFld("in",_("Input"),TFld::String,TFld::NoFlag,"50","","","",21) );
-    	attrAdd( new TFld("lineWdth",_("Line:width"),TFld::Integer,TFld::NoFlag,"2","1","0;99","",22) );
-    	attrAdd( new TFld("lineClr",_("Line:color"),TFld::String,Attr::Color,"20","#000000","","",23) );
-    	attrAdd( new TFld("lineSquare",_("Line:square angle"),TFld::Boolean,TFld::NoFlag,"1","0","","",24) );
-	//Next is dynamic created internal points    
+    	attrAdd( new TFld("out",_("Output"),TFld::String,TFld::NoFlag,"50","","","","20") );
+    	attrAdd( new TFld("in",_("Input"),TFld::String,TFld::NoFlag,"50","","","","21") );
+    	attrAdd( new TFld("lineWdth",_("Line:width"),TFld::Integer,TFld::NoFlag,"2","1","0;99","","22") );
+    	attrAdd( new TFld("lineClr",_("Line:color"),TFld::String,Attr::Color,"20","#000000","","","23") );
+    	attrAdd( new TFld("lineSquare",_("Line:square angle"),TFld::Boolean,TFld::NoFlag,"1","0","","","24") );
+	//Next is dynamic created internal points
     }
 } 
