@@ -19,6 +19,10 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+
 #include <tsys.h>
 
 #include "vcaengine.h"
@@ -46,6 +50,42 @@ Project::~Project( )
 
 }
 
+TCntrNode &Project::operator=( TCntrNode &node )
+{
+    Project *src_n = dynamic_cast<Project*>(&node);
+    if( !src_n ) return *this;
+
+    //- Copy generic configuration -
+    string tid = m_id;
+    *(TConfig *)this = *(TConfig*)src_n;
+    m_id  = tid;
+    m_dbt = string("prj_")+tid;
+    work_prj_db = src_n->work_prj_db;
+
+    if( !src_n->enable() ) return *this;
+    if( !enable() ) setEnable(true);
+
+    //- Mime data copy -
+    vector<string> pls;
+    src_n->mimeDataList(pls);
+    string mimeType, mimeData;
+    for( int i_m = 0; i_m < pls.size(); i_m++ )
+    {
+        src_n->mimeDataGet( pls[i_m], mimeType, &mimeData );
+        mimeDataSet( pls[i_m], mimeType, mimeData );
+    }
+
+    //- Copy include pages -
+    src_n->list(pls);
+    for( int i_p = 0; i_p < pls.size(); i_p++ )
+    {
+	if( !present(pls[i_p]) ) add(pls[i_p],"");
+	(TCntrNode&)at(pls[i_p]).at() = (TCntrNode&)src_n->at(pls[i_p]).at();
+    }
+    
+    return *this;
+}
+
 void Project::postEnable( int flag )
 {
     if( flag&TCntrNode::NodeRestore )	setEnable(true);
@@ -76,6 +116,10 @@ void Project::postDisable( int flag )
 	//-- Delete include widgets table --
 	SYS->db().at().open(fullDB()+"_incl");
 	SYS->db().at().close(fullDB()+"_incl",true);
+        //-- Delete mime-data table --
+        SYS->db().at().open(fullDB()+"_mime");
+        SYS->db().at().close(fullDB()+"_mime",true);
+				
     }
 }
 
@@ -106,15 +150,17 @@ void Project::setUser( const string &it )
 	SYS->security().at().usrGrpList(user(),gls);
 	setGrp(gls.size()?gls[0]:"UI");
     }
+    modif();
 }
 
 void Project::setFullDB( const string &it )
 {
     work_prj_db = TSYS::strSepParse(it,0,'.')+"."+TSYS::strSepParse(it,1,'.');
     m_dbt = TSYS::strSepParse(it,2,'.');
+    modifG();
 }
 
-void Project::load( )
+void Project::load_( )
 {
     SYS->db().at().dataGet(DB()+"."+mod->prjTable(),mod->nodePath()+"PRJ/",*this);
 
@@ -130,26 +176,32 @@ void Project::load( )
         if( !present(f_id) )	add(f_id,"","");
     }
     
-    //- Load present pages -
-    vector<string> f_lst;
-    list(f_lst);
-    for( int i_ls = 0; i_ls < f_lst.size(); i_ls++ )
-        at(f_lst[i_ls]).at().load();
+    mOldDB = TBDS::realDBName(DB());
 }
 
-void Project::save( )
+void Project::save_( )
 {
     SYS->db().at().dataSet(DB()+"."+mod->prjTable(),mod->nodePath()+"PRJ/",*this);
-
-    //- Save widgets -
-    vector<string> f_lst;
-    list(f_lst);
-    for( int i_ls = 0; i_ls < f_lst.size(); i_ls++ )
-        at(f_lst[i_ls]).at().save();
+    
+    //- Check for need copy mime data to other DB and same copy -
+    if( !mOldDB.empty() && mOldDB != TBDS::realDBName(DB()) )
+    {
+        vector<string> pls;
+        mimeDataList(pls,mOldDB);
+        string mimeType, mimeData;
+        for( int i_m = 0; i_m < pls.size(); i_m++ )
+        {
+            mimeDataGet( pls[i_m], mimeType, &mimeData, mOldDB );
+            mimeDataSet( pls[i_m], mimeType, mimeData, DB() );
+        }
+    }
+    
+    mOldDB = TBDS::realDBName(DB());
 }
 
 void Project::setEnable( bool val )
 {
+    if( val == enable() )       return;
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),val ? _("Enable project.") : _("Disable project."));
 #endif    
@@ -180,15 +232,92 @@ AutoHD<Page> Project::at( const string &id )
     return chldAt(m_page,id);
 }
 
+void Project::mimeDataList( vector<string> &list, const string &idb )
+{
+    string wtbl = tbl()+"_mime";
+    string wdb  = idb.empty() ? DB() : idb;
+    TConfig c_el(&mod->elWdgData());
+    c_el.cfgViewAll(false);
+	    
+    list.clear();
+    for( int fld_cnt = 0; SYS->db().at().dataSeek(wdb+"."+wtbl,mod->nodePath()+wtbl,fld_cnt,c_el); fld_cnt++ )
+    {
+        list.push_back(c_el.cfg("ID").getS());
+        c_el.cfg("ID").setS("");
+    }
+}
+
+bool Project::mimeDataGet( const string &iid, string &mimeType, string *mimeData, const string &idb )
+{
+    bool is_file = (iid.size()>5 && iid.substr(0,5) == "file:");
+    bool is_res  = (iid.size()>4 && iid.substr(0,4) == "res:");
+	    
+    if( !is_file )
+    {
+        //- Get resource file from DB -
+        string dbid = is_res ? iid.substr(4) : iid;
+        string wtbl = tbl()+"_mime";
+	string wdb  = idb.empty() ? DB() : idb;
+        TConfig c_el( &mod->elWdgData() );
+        if( !mimeData ) c_el.cfg("DATA").setView(false);
+        c_el.cfg("ID").setS( dbid );
+        if(SYS->db().at().dataGet( wdb+"."+wtbl, mod->nodePath()+wtbl, c_el ))
+        {
+            mimeType = c_el.cfg("MIME").getS();
+            if( mimeData )      *mimeData = c_el.cfg("DATA").getS();
+            return true;
+        }
+    }
+    if( !is_res )
+    {
+        //- Get resource file from file system -
+        string filepath = is_file ? iid.substr(5) : iid;
+        int len;
+        char buf[STR_BUF_LEN];
+        string rez;
+        int hd = open(filepath.c_str(),O_RDONLY);
+        if( hd == -1 )  return false;
+
+        while( len = read(hd,buf,sizeof(buf)) ) rez.append(buf,len);
+	close(hd);
+
+	mimeType = ((filepath.rfind(".") != string::npos) ? filepath.substr(filepath.rfind(".")+1)+";" : "file/unknown;")+TSYS::int2str(rez.size());
+    	if( mimeData )  *mimeData = TSYS::strEncode(rez,TSYS::base64);
+        return true;
+    }
+    return false;
+}
+
+void Project::mimeDataSet( const string &iid, const string &mimeType, const string &mimeData, const string &idb )
+{
+    string wtbl = tbl()+"_mime";
+    string wdb  = idb.empty() ? DB() : idb;
+    TConfig c_el( &mod->elWdgData() );
+    c_el.cfg("ID").setS(iid);
+    c_el.cfg("MIME").setS(mimeType);
+    if( !mimeData.size() ) c_el.cfg("DATA").setView(false);
+    else c_el.cfg("DATA").setS(mimeData);
+    SYS->db().at().dataSet(wdb+"."+wtbl,mod->nodePath()+wtbl,c_el);
+}
+
+void Project::mimeDataDel( const string &iid, const string &idb )
+{
+    string wtbl = tbl()+"_mime";
+    string wdb  = idb.empty() ? DB() : idb;
+    TConfig c_el(&mod->elWdgData());
+    c_el.cfg("ID").setS(iid);
+    SYS->db().at().dataDel(wdb+"."+wtbl,mod->nodePath()+wtbl,c_el);
+}
+
 void Project::cntrCmdProc( XMLNode *opt )
 {
     //- Get page info -
     if( opt->name() == "info" )
     {
-        ctrMkNode("oscada_cntr",opt,-1,"/",_("Project: ")+id());
+        ctrMkNode("oscada_cntr",opt,-1,"/",_("Project: ")+id(),permit(),user().c_str(),grp().c_str());
 	if(ico().size()) ctrMkNode("img",opt,-1,"/ico","",R_R_R_);
         if(ctrMkNode("branches",opt,-1,"/br","",R_R_R_))
-	    ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),R_R_R_,"root","UI",1,"list","/page/page");
+	    ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),permit(),user().c_str(),grp().c_str(),1,"idm","1");
         if(ctrMkNode("area",opt,-1,"/obj",_("Project")))
 	{
     	    if(ctrMkNode("area",opt,-1,"/obj/st",_("State")))
@@ -207,12 +336,18 @@ void Project::cntrCmdProc( XMLNode *opt )
 		ctrMkNode("fld",opt,-1,"/obj/cfg/u_a",_("Access: user-grp-other"),RWR_R_,user().c_str(),grp().c_str(),3,"tp","dec","dest","select","select","/obj/a_lst");
 		ctrMkNode("fld",opt,-1,"/obj/cfg/g_a","",RWR_R_,user().c_str(),grp().c_str(),3,"tp","dec","dest","select","select","/obj/a_lst");
 		ctrMkNode("fld",opt,-1,"/obj/cfg/o_a","",RWR_R_,user().c_str(),grp().c_str(),3,"tp","dec","dest","select","select","/obj/a_lst");
-    		ctrMkNode("comm",opt,-1,"/obj/cfg/load",_("Load"),permit(),user().c_str(),grp().c_str());
-    		ctrMkNode("comm",opt,-1,"/obj/cfg/save",_("Save"),permit(),user().c_str(),grp().c_str());
 	    }
 	}
 	if(ctrMkNode("area",opt,-1,"/page",_("Pages")))
     	    ctrMkNode("list",opt,-1,"/page/page",_("Pages"),permit(),user().c_str(),grp().c_str(),4,"tp","br","idm","1","s_com","add,del","br_pref","pg_");
+        if(ctrMkNode("area",opt,-1,"/mime",_("Mime data")))
+    	    if(ctrMkNode("table",opt,-1,"/mime/mime",_("Mime data"),permit(),user().c_str(),grp().c_str(),2,"s_com","add,del","key","id"))
+	    {
+		ctrMkNode("list",opt,-1,"/mime/mime/id",_("Id"),permit(),user().c_str(),grp().c_str(),1,"tp","str");
+		ctrMkNode("list",opt,-1,"/mime/mime/tp",_("Mime type"),permit(),user().c_str(),grp().c_str(),1,"tp","str");
+		ctrMkNode("list",opt,-1,"/mime/mime/dt",_("Data"),permit(),user().c_str(),grp().c_str(),2,"tp","str","dest","data");
+	    }
+												    
         return;
     }
     
@@ -220,58 +355,56 @@ void Project::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/obj/st/en" )
     {
-        if( ctrChkNode(opt,"get",RWRWR_,user().c_str(),grp().c_str(),SEQ_RD) ) opt->setText(TSYS::int2str(enable()));
-        if( ctrChkNode(opt,"set",RWRWR_,user().c_str(),grp().c_str(),SEQ_WR) ) setEnable(atoi(opt->text().c_str()));
+        if( ctrChkNode(opt,"get",RWRWR_,user().c_str(),grp().c_str(),SEQ_RD) ) opt->setText( TSYS::int2str(enable()) );
+        if( ctrChkNode(opt,"set",RWRWR_,user().c_str(),grp().c_str(),SEQ_WR) ) setEnable( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/obj/st/db" )
     {
-	if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText(fullDB());
-        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setFullDB(opt->text());
+	if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText( fullDB() );
+        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setFullDB( opt->text() );
     }
     else if( a_path == "/obj/st/user" )
     {
-        if( ctrChkNode(opt,"get",RWRWR_,"root","root",SEQ_RD) )	opt->setText(user());
-        if( ctrChkNode(opt,"set",RWRWR_,"root","root",SEQ_WR) )	setUser(opt->text());
+        if( ctrChkNode(opt,"get",RWRWR_,"root","root",SEQ_RD) )	opt->setText( user() );
+        if( ctrChkNode(opt,"set",RWRWR_,"root","root",SEQ_WR) )	setUser( opt->text() );
     }
     else if( a_path == "/obj/st/grp" )
     {
-        if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText(grp());
-        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setGrp(opt->text());
+        if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )	opt->setText( grp() );
+        if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )	setGrp( opt->text() );
     }
     else if( a_path == "/obj/cfg/u_a" || a_path == "/obj/cfg/g_a" || a_path == "/obj/cfg/o_a" )
     {
 	if( ctrChkNode(opt,"get",RWR_R_,user().c_str(),grp().c_str(),SEQ_RD) )
 	{
-	    if( a_path == "/obj/cfg/u_a" )	opt->setText(TSYS::int2str((m_permit>>6)&0x7));
-	    if( a_path == "/obj/cfg/g_a" )	opt->setText(TSYS::int2str((m_permit>>3)&0x7));
-	    if( a_path == "/obj/cfg/o_a" )	opt->setText(TSYS::int2str(m_permit&0x7));
+	    if( a_path == "/obj/cfg/u_a" )	opt->setText( TSYS::int2str((permit()>>6)&0x7) );
+	    if( a_path == "/obj/cfg/g_a" )	opt->setText( TSYS::int2str((permit()>>3)&0x7) );
+	    if( a_path == "/obj/cfg/o_a" )	opt->setText( TSYS::int2str(permit()&0x7) );
 	}
 	if( ctrChkNode(opt,"set",RWR_R_,user().c_str(),grp().c_str(),SEQ_WR) )
 	{
-	    if( a_path == "/obj/cfg/u_a" )	m_permit=(m_permit&(~(0x07<<6)))|(atoi(opt->text().c_str())<<6);
-	    if( a_path == "/obj/cfg/g_a" )	m_permit=(m_permit&(~(0x07<<3)))|(atoi(opt->text().c_str())<<3);
-	    if( a_path == "/obj/cfg/o_a" )	m_permit=(m_permit&(~0x07))|atoi(opt->text().c_str());
+	    if( a_path == "/obj/cfg/u_a" )	setPermit( (permit()&(~(0x07<<6)))|(atoi(opt->text().c_str())<<6) );
+	    if( a_path == "/obj/cfg/g_a" )	setPermit( (permit()&(~(0x07<<3)))|(atoi(opt->text().c_str())<<3) );
+	    if( a_path == "/obj/cfg/o_a" )	setPermit( (permit()&(~0x07))|atoi(opt->text().c_str()) );
 	}
     }
     else if( a_path == "/obj/cfg/ico" || a_path == "/ico" )
     {
-	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText(ico());
-	if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setIco(opt->text());
+	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText( ico() );
+	if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setIco( opt->text() );
     }
     else if( a_path == "/obj/cfg/id" && ctrChkNode(opt,"get",R_R_R_,user().c_str(),grp().c_str()) ) opt->setText(id());
     else if( a_path == "/obj/cfg/name" )
     {
-	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText(name());
-        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setName(opt->text());
+	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText( name() );
+        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setName( opt->text() );
     }
     else if( a_path == "/obj/cfg/descr" )
     {
-        if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText(descr());
-        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setDescr(opt->text());
+        if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )   opt->setText( descr() );
+        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )   setDescr( opt->text() );
     }
-    else if( a_path == "/obj/cfg/load" && ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )  load();
-    else if( a_path == "/obj/cfg/save" && ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )  save();
-    else if( a_path == "/page/page" )
+    else if( a_path == "/br/pg_" || a_path == "/page/page" )
     {
         if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )
         {
@@ -308,20 +441,85 @@ void Project::cntrCmdProc( XMLNode *opt )
 	opt->childAdd("el")->setAttr("id","2")->setText(_("Modify"));
 	opt->childAdd("el")->setAttr("id","6")->setText(_("Full"));
     }
+    else if( a_path == "/mime/mime" )
+    {
+        //-- Request data --
+        string idmime = opt->attr("key_id");
+        string idcol  = opt->attr("col");
+
+        if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )
+        {
+            if( !idmime.empty() && idcol == "dt" && atoi(opt->attr("data").c_str()) )
+            {
+                string mimeType, mimeData;
+                if( mimeDataGet( "res:"+idmime, mimeType, &mimeData ) ) opt->setText( mimeData );
+            }
+    	    else
+            {
+        	XMLNode *n_id = ctrMkNode("list",opt,-1,"/mime/mime/id","");
+                XMLNode *n_tp = ctrMkNode("list",opt,-1,"/mime/mime/tp","");
+                XMLNode *n_dt = ctrMkNode("list",opt,-1,"/mime/mime/dt","");
+                
+		vector<string> lst;
+                string mimeType;
+                mimeDataList(lst);
+                for(int i_el = 0; i_el < lst.size(); i_el++)
+                    if( mimeDataGet("res:"+lst[i_el],mimeType) )
+                    {
+                	if( n_id )      n_id->childAdd("el")->setText(lst[i_el]);
+                	if( n_tp )      n_tp->childAdd("el")->setText(TSYS::strSepParse(mimeType,0,';'));
+                        if( n_dt )      n_dt->childAdd("el")->setText(TSYS::strSepParse(mimeType,1,';'));
+                    }
+            }
+        }
+	if( ctrChkNode(opt,"add",permit(),user().c_str(),grp().c_str(),SEQ_WR) )
+            mimeDataSet("newMime","image/new;0","");
+        if( ctrChkNode(opt,"del",permit(),user().c_str(),grp().c_str(),SEQ_WR) )
+            mimeDataDel(opt->attr("key_id"));
+        if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) )
+	{
+            //-- Request data --
+            if( idcol == "id" )
+    	    {
+	        string mimeType, mimeData;
+	        //--- Copy mime data to new record ---
+	        if( mimeDataGet( "res:"+idmime, mimeType, &mimeData ) )
+	        {
+	            mimeDataSet( opt->text(), mimeType, mimeData );
+	            mimeDataDel( idmime );
+	        }
+	    }
+            else if( idcol == "tp" )
+            {
+                string mimeType;
+                //--- Copy mime data to new record ---
+                if( mimeDataGet( "res:"+idmime, mimeType ) )
+                    mimeDataSet( idmime, opt->text()+";"+TSYS::strSepParse(mimeType,1,';'), "");
+            }
+            else if( idcol == "dt" )
+            {
+                string mimeType;
+        	if( mimeDataGet( "res:"+idmime, mimeType ) )
+	            mimeDataSet( idmime, TSYS::strSepParse(mimeType,0,';')+";"+TSYS::real2str((float)opt->text().size()/1024.,6),opt->text() );
+	    }
+        }
+    }
+    else TCntrNode::cntrCmdProc(opt);
 }
 
 //************************************************
 //* Page: Project's page                         *
 //************************************************
-Page::Page( const string &id, const string &isrcwdg ) :
-        Widget(id,isrcwdg), TConfig(&mod->elPage()),
+Page::Page( const string &iid, const string &isrcwdg ) :
+        Widget(iid), TConfig(&mod->elPage()),
         m_ico(cfg("ICO").getSd()), m_proc(cfg("PROC").getSd()), m_proc_per(cfg("PROC_PER").getId()),
 	m_flgs(cfg("FLGS").getId()), m_user(cfg("USER").getSd()), m_grp(cfg("GRP").getSd()), 
-	m_permit(cfg("PERMIT").getId())
+	m_permit(cfg("PERMIT").getId()), m_parent(cfg("PARENT").getSd()), m_attrs(cfg("ATTRS").getSd())
 {
-    cfg("ID").setS(id);
+    cfg("ID").setS(id());
 
     m_page = grpAdd("pg_");
+
     setParentNm(isrcwdg);
 }
 
@@ -330,6 +528,31 @@ Page::~Page( )
 
 }
 
+TCntrNode &Page::operator=( TCntrNode &node )
+{
+    Page *src_n = dynamic_cast<Page*>(&node);
+    if( !src_n ) return Widget::operator=(node);
+	
+    if( !src_n->enable() ) return *this;
+    
+    //- Copy generic configuration -
+    setPrjFlags( src_n->prjFlags() );
+    
+    //- Widget copy -
+    Widget::operator=(node);
+    
+    //- Include widgets copy -
+    vector<string> els;
+    src_n->pageList(els);
+    for( int i_p = 0; i_p < els.size(); i_p++ )
+    {
+        if( !pagePresent(els[i_p]) ) pageAdd(els[i_p],"");
+        (TCntrNode&)pageAt(els[i_p]).at() = (TCntrNode&)src_n->pageAt(els[i_p]).at();
+    }
+    
+    return *this;									    
+}
+
 Page *Page::ownerPage( )
 {
     if( nodePrev(true) ) return dynamic_cast<Page*>(nodePrev());
@@ -393,7 +616,7 @@ void Page::postDisable( int flag )
 	
         //- Remove widget's included widgets from library include table -
         c_el.setElem(&mod->elInclWdg());
-        c_el.cfg("IDW").setS(id());
+        c_el.cfg("IDW").setS(path());
         c_el.cfg("ID").setS("");
         SYS->db().at().dataDel(fullDB+"_incl",mod->nodePath()+tbl+"_incl",c_el);						
     }
@@ -423,6 +646,7 @@ void Page::setUser( const string &iuser )
         SYS->security().at().usrGrpList(user(),gls);
         setGrp(gls.size()?gls[0]:Widget::grp());
     }
+    modif();
 }
 
 string Page::grp( )
@@ -432,12 +656,10 @@ string Page::grp( )
 
 void Page::setParentNm( const string &isw )
 {
-    string parAddr = isw;
-    if( ownerPage() && ownerPage()->prjFlags()&Page::Template && !(ownerPage()->prjFlags()&Page::Container) )
-    	parAddr = "..";
-    
-    cfg("PARENT").setS(parAddr);
-    Widget::setParentNm(parAddr);
+    m_parent = isw;
+    if( ownerPage() && ownerPage()->prjFlags()&Page::Template && !(ownerPage()->prjFlags()&Page::Container) )	
+	m_parent = "..";
+    modif();
 }
 
 string Page::calcId( )
@@ -487,6 +709,7 @@ int Page::calcPer(  )
 void Page::setCalcLang( const string &ilng )
 {
     m_proc = m_proc.replace(0,m_proc.find("\n"),ilng);
+    modif();
 }
 
 void Page::setCalcProg( const string &iprg )
@@ -499,11 +722,13 @@ void Page::setCalcProg( const string &iprg )
         lng_end=tmp_prg.find("\n");
     }
     m_proc = tmp_prg.replace(lng_end+1,string::npos,iprg);
+    modif();
 }
 
 void Page::setCalcPer( int vl )
 {
     m_proc_per = vl;
+    modif();
 }
 
 void Page::setPrjFlags( int val )
@@ -520,15 +745,16 @@ void Page::setPrjFlags( int val )
 	}
     }
     m_flgs = val;
+    modif();
 }
 
-void Page::load( )
+void Page::load_( )
 {    
     //- Load generic widget's data -
     string db  = ownerProj()->DB();
     string tbl = ownerProj()->tbl();
     SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,*this);
-    setParentNm(cfg("PARENT").getS());
+    setParentNm(m_parent);
     
     //- Create new pages -
     TConfig c_el(&mod->elPage());
@@ -555,6 +781,7 @@ void Page::load( )
 
 void Page::loadIO( )
 {
+    string tstr;
     vector<string> als;
 
     if( !enable() ) return;
@@ -563,17 +790,34 @@ void Page::loadIO( )
     string db  = ownerProj()->DB();
     string tbl = ownerProj()->tbl()+"_io";    
 
-    attrList( als );
+    //- Inherit modify attributes -
+    /*attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+        AutoHD<Attr> attr = attrAt(als[i_a]);
+        if( attr.at().flgGlob()&Attr::IsInher && attr.at().modif() && m_attrs.find(als[i_a]) == string::npos )
+        {
+            attr.at().setModif(0);
+            inheritAttr(als[i_a]);
+	}
+    }
+									    
+    als.clear();*/
+    if( m_attrs != "*" )
+	for( int off = 0; !(tstr = TSYS::strSepParse(m_attrs,0,';',&off)).empty(); )
+    	    als.push_back(tstr);
+		
+    //-- Same attributes load --
     TConfig c_el(&mod->elWdgIO());
     c_el.cfg("IDW").setS(path());    
     for( int i_a = 0; i_a < als.size(); i_a++ )
     {
-	AutoHD<Attr> attr = attrAt(als[i_a]);
+	if( !attrPresent(als[i_a]) )    continue;
+	AutoHD<Attr> attr = attrAt(als[i_a]);	
 	if( !(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser ) continue;
 	c_el.cfg("ID").setS(als[i_a]);
 	if( !SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,c_el) ) continue;
 	attr.at().setS(c_el.cfg("IO_VAL").getS());
-	if( attr.at().flgGlob()&Attr::Active )	attrList( als );
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
@@ -596,13 +840,9 @@ void Page::loadIO( )
             attrAdd( new TFld(sid.c_str(),c_el.cfg("NAME").getS().c_str(),(TFld::Type)(flg&0x0f),flg>>4) );
 	AutoHD<Attr> attr = attrAt(sid);
         if( !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) ) continue;
-	if( attr.at().flgGlob()&TFld::Selected )
-	{
-	    attr.at().setS(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),0,'|'));
-	    attr.at().fld().setValues(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),1,'|'));
-	    attr.at().fld().setSelNames(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),2,'|'));
-	}
-	else attr.at().setS(c_el.cfg("IO_VAL").getS());
+	attr.at().setS(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),0,'|'));
+	attr.at().fld().setValues(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),1,'|'));
+	attr.at().fld().setSelNames(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),2,'|'));
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
@@ -619,38 +859,38 @@ void Page::loadIO( )
     {
         string sid  = c_el.cfg("ID").getS();
 	c_el.cfg("ID").setS("");
-	if( wdgPresent(sid) && c_el.cfg("PARENT").getS() == "<deleted>" )
-	{ wdgDel(sid); continue; }
+	if( c_el.cfg("PARENT").getS() == "<deleted>" )
+	{ 
+	    if( wdgPresent(sid) )	wdgDel(sid);
+	    continue;
+	}
         if( !wdgPresent(sid) ) wdgAdd(sid,"","");
 	
         wdgAt(sid).at().load();
     }
 }
 
-void Page::save( )
+void Page::save_( )
 {
     vector<string> ls;
     
     //- Save generic widget's data -
     string db  = ownerProj()->DB();
     string tbl = ownerProj()->tbl();
+    
+    m_attrs="";
+    vector<string> als;
+    attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+        AutoHD<Attr> attr = attrAt(als[i_a]);
+        if( attr.at().modif() && !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) )
+        m_attrs+=als[i_a]+";";
+    }
     SYS->db().at().dataSet(db+"."+tbl,mod->nodePath()+tbl,*this);
 
-    //- Save include pages -
-    pageList(ls);
-    for( int i_l = 0; i_l < ls.size(); i_l++ )
-	pageAt(ls[i_l]).at().save();
-
     //- Save widget's attributes -
     saveIO();
-
-    //- Save cotainer widgets -
-    if(isContainer())
-    {
-	wdgList(ls);
-	for( int i_l = 0; i_l < ls.size(); i_l++ )
-	    wdgAt(ls[i_l]).at().save();
-    }
 }
 
 void Page::saveIO( )
@@ -718,7 +958,7 @@ void Page::saveIO( )
 void Page::setEnable( bool val )
 {
     if( enable() == val ) return;
-    
+
     Widget::setEnable(val);
 
     //- Enable/disable included pages -
@@ -735,7 +975,7 @@ void Page::wdgAdd( const string &wid, const string &name, const string &path )
 
     chldAdd(inclWdg,new PageWdg(wid,path));
     wdgAt(wid).at().setName(name);
-    
+
     //- Call heritors include widgets update -
     for( int i_h = 0; i_h < m_herit.size(); i_h++ )
         if( m_herit[i_h].at().enable( ) )
@@ -774,21 +1014,29 @@ AutoHD<Page> Page::pageAt( const string &id )
 
 string Page::resourceGet( const string &id, string *mime )
 {
-    string mimeType;
-    
-    string mimeData = parent().at().resourceGet( id, &mimeType );
-    if( mime )	*mime = mimeType;
+    string mimeType, mimeData;
     
+    if( !ownerProj()->mimeDataGet( id, mimeType, &mimeData ) && !parent().freeStat() )
+        mimeData = parent().at().resourceGet( id, &mimeType );
+    if( mime )  *mime = mimeType;
+		    
     return mimeData;
 }
 
+void Page::inheritAttr( const string &attr )
+{
+    bool mdf = isModify();
+    Widget::inheritAttr( attr );
+    if( !mdf )  modifClr( );
+}	    
+
 bool Page::cntrCmdGeneric( XMLNode *opt )
 {   
     //- Get page info -
     if( opt->name() == "info" )
     {
         Widget::cntrCmdGeneric(opt);
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Project page: ")+path());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Project page: ")+path(),permit(),user().c_str(),grp().c_str());
 	if(ctrMkNode("area",opt,-1,"/wdg",_("Widget")) && ctrMkNode("area",opt,-1,"/wdg/cfg",_("Config")))
         {
 	    if( prjFlags()&Page::Empty || (ownerPage() && ownerPage()->prjFlags()&(Page::Template) && !(ownerPage()->prjFlags()&Page::Container)) )
@@ -800,7 +1048,7 @@ bool Page::cntrCmdGeneric( XMLNode *opt )
 	    if(ctrMkNode("area",opt,1,"/page",_("Pages")))
     		ctrMkNode("list",opt,-1,"/page/page",_("Pages"),permit(),user().c_str(),grp().c_str(),4,"tp","br","idm","1","s_com","add,del","br_pref","pg_");
 	    if(ctrMkNode("branches",opt,-1,"/br","",R_R_R_))
-		ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),R_R_R_,"root","UI",1,"list","/page/page");
+		ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),permit(),user().c_str(),grp().c_str(),1,"idm","1");
 	}
 	return true;
     }
@@ -812,9 +1060,9 @@ bool Page::cntrCmdGeneric( XMLNode *opt )
     else if( a_path == "/wdg/st/pgTp" )
     {
 	if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) ) 
-	    opt->setText(TSYS::int2str(prjFlags()&(Page::Container|Page::Template|Page::Empty)));
+	    opt->setText( TSYS::int2str(prjFlags()&(Page::Container|Page::Template|Page::Empty)) );
 	if( ctrChkNode(opt,"set",permit(),user().c_str(),grp().c_str(),SEQ_WR) ) 
-	    setPrjFlags(prjFlags()^((prjFlags()^atoi(opt->text().c_str()))&(Page::Container|Page::Template|Page::Empty)));    
+	    setPrjFlags( prjFlags()^((prjFlags()^atoi(opt->text().c_str()))&(Page::Container|Page::Template|Page::Empty)) );    
     }
     else if( a_path == "/wdg/st/pgTpLst" && ctrChkNode(opt) )
     {
@@ -824,7 +1072,7 @@ bool Page::cntrCmdGeneric( XMLNode *opt )
 	opt->childAdd("el")->setAttr("id",TSYS::int2str(Page::Template))->setText(_("Template"));
 	opt->childAdd("el")->setAttr("id",TSYS::int2str(Page::Container|Page::Template))->setText(_("Container and template"));
     }
-    else if( a_path == "/page/page" )
+    else if( a_path == "/br/pg_" || a_path == "/page/page" )
     {
         if( ctrChkNode(opt,"get",permit(),user().c_str(),grp().c_str(),SEQ_RD) )
         {
@@ -864,16 +1112,18 @@ void Page::cntrCmdProc( XMLNode *opt )
     }
     
     //- Process command to page -
-    cntrCmdGeneric(opt) || (parent( ).freeStat() ? false : cntrCmdAttributes(opt) || cntrCmdLinks(opt) || cntrCmdProcess(opt));
+    if( !(cntrCmdGeneric(opt) || (parent( ).freeStat() ? false : cntrCmdAttributes(opt) || 
+	    cntrCmdLinks(opt) || cntrCmdProcess(opt))) )
+	TCntrNode::cntrCmdProc(opt);
 }
 
 //************************************************
 //* PageWdg: Container stored widget             *
 //************************************************
-PageWdg::PageWdg( const string &id, const string &isrcwdg ) :
-        Widget(id,isrcwdg), TConfig(&mod->elInclWdg())
+PageWdg::PageWdg( const string &iid, const string &isrcwdg ) :
+        Widget(iid), TConfig(&mod->elInclWdg()), m_parent(cfg("PARENT").getSd()), m_attrs(cfg("ATTRS").getSd())
 {
-    cfg("ID").setS(id);
+    cfg("ID").setS(id());
     m_lnk = true;
     setParentNm(isrcwdg);
 }
@@ -894,64 +1144,53 @@ void PageWdg::postEnable( int flag )
     Widget::postEnable(flag);
     //- Set parent page for this widget -
     cfg("IDW").setS(owner().path());
-    cfg("PARENT").setS(parentNm());
 }
 
 void PageWdg::preDisable( int flag )
 {
+    vector<string> list;
+
     if( flag && !parent().freeStat() )  wdgIherited = parent().at().isLink();
     else wdgIherited = false;
-	
-    Widget::preDisable(flag);
-}
 
-void PageWdg::postDisable(int flag)
-{
     if( flag )
     {
         string fullDB = owner().ownerProj()->fullDB();
         string tbl    = owner().ownerProj()->tbl();
 
         //- Remove from library table -
-        if( !wdgIherited )      SYS->db().at().dataDel(fullDB+"_incl",mod->nodePath()+tbl+"_incl",*this);
+        if( !wdgIherited || flag&0x10 )      SYS->db().at().dataDel(fullDB+"_incl",mod->nodePath()+tbl+"_incl",*this);
         else
         {
-            cfg("PARENT").setS("<deleted>");
+            m_parent = "<deleted>";
             SYS->db().at().dataSet(fullDB+"_incl",mod->nodePath()+tbl+"_incl",*this);
         }
- 	//- Remove widget's work IO from library IO table -
+
+	//- Remove changed widget's work and users IO from library IO table -	
         TConfig c_el(&mod->elWdgIO());
-	c_el.cfgViewAll(false);
-        c_el.cfg("IDW").setS(owner().path());
-        c_el.cfg("ID").setS(""); 
-        int fld_cnt=0;
-        while( SYS->db().at().dataSeek(fullDB+"_io",mod->nodePath()+tbl+"_io",fld_cnt++,c_el) )
-        {
-	    string sid = c_el.cfg("ID").getS();
-            if( TSYS::pathLev(sid,0) == id() && TSYS::pathLev(sid,1).size() )
-            {
+        TConfig c_uel(&mod->elWdgUIO());
+        c_el.cfg("IDW").setS(owner().path());	
+        c_uel.cfg("IDW").setS(owner().path());
+	attrList( list );
+	AutoHD<Attr> attr;
+	for( int i_a = 0; i_a < list.size(); i_a++ )
+	{
+	    attr = attrAt(list[i_a]);
+	    if( !attr.at().modif() ) continue;
+	    if( attr.at().flgGlob()&Attr::IsUser && !(attr.at().flgGlob()&Attr::IsInher) )
+	    {
+	        c_uel.cfg("ID").setS(id()+"/"+list[i_a]);
+	        SYS->db().at().dataDel(fullDB+"_uio",mod->nodePath()+tbl+"_uio",c_uel);
+	    }
+            else
+    	    {
+                c_el.cfg("ID").setS(id()+"/"+list[i_a]);
                 SYS->db().at().dataDel(fullDB+"_io",mod->nodePath()+tbl+"_io",c_el);
-                fld_cnt--;
             }
-            c_el.cfg("ID").setS("");
-        }        
-	//- Remove widget's user IO from library IO table -
-        c_el.setElem(&mod->elWdgUIO());
-	c_el.cfgViewAll(false);
-        c_el.cfg("IDW").setS(owner().path());
-        c_el.cfg("ID").setS(""); 
-        fld_cnt=0;
-        while( SYS->db().at().dataSeek(fullDB+"_uio",mod->nodePath()+tbl+"_uio",fld_cnt++,c_el) )
-        {
-	    string sid = c_el.cfg("ID").getS();
-            if( TSYS::pathLev(sid,0) == id() && TSYS::pathLev(sid,1).size() )
-            {
-                SYS->db().at().dataDel(fullDB+"_uio",mod->nodePath()+tbl+"_uio",c_el);
-                fld_cnt--;
-            }
-            c_el.cfg("ID").setS("");
-        }
+	}
     }
+
+    Widget::preDisable(flag);
 }
 
 string PageWdg::path( )
@@ -980,10 +1219,19 @@ short PageWdg::permit( )
     return owner().permit( );
 }
 
-void PageWdg::setParentNm( const string &isw )
+void PageWdg::setEnable( bool val )
 {
-    cfg("PARENT").setS(isw);
-    Widget::setParentNm(isw);
+    if( enable() == val ) return;
+    
+    Widget::setEnable(val);
+	
+    //- Disable heritors widgets -
+    if( val )
+        for( int i_h = 0; i_h < owner().herit().size(); i_h++ )
+            if( owner().herit()[i_h].at().wdgPresent(id()) && !owner().herit()[i_h].at().wdgAt(id()).at().enable( ) )
+        	try { owner().herit()[i_h].at().wdgAt(id()).at().setEnable(true); }
+		catch(...)
+		{ mess_err(nodePath().c_str(),_("Heritors widget <%s> enable error"),id().c_str()); }
 }
 
 string PageWdg::calcId( )
@@ -1010,13 +1258,12 @@ int PageWdg::calcPer(  )
     return 0;
 }
 
-void PageWdg::load( )
+void PageWdg::load_( )
 {
     //- Load generic widget's data -
     string db  = owner().ownerProj()->DB();
     string tbl = owner().ownerProj()->tbl()+"_incl";
     SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,*this);
-    setParentNm(cfg("PARENT").getS());
     
     //- Load widget's attributes -
     loadIO();
@@ -1024,29 +1271,48 @@ void PageWdg::load( )
 
 void PageWdg::loadIO( )
 {
+    string         tstr;
     vector<string> als;
     
     if( !enable() ) return;
-    
+
     //- Load widget's work attributes -
     string db  = owner().ownerProj()->DB();
     string tbl = owner().ownerProj()->tbl()+"_io";
+
+    //- Inherit modify attributes -
+    /*attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+        AutoHD<Attr> attr = attrAt(als[i_a]);
+        if( attr.at().flgGlob()&Attr::IsInher && attr.at().modif() && m_attrs.find(als[i_a]) == string::npos )
+        {
+            attr.at().setModif(0);
+    	    inheritAttr(als[i_a]);
+        }
+    }
     
-    attrList( als );
+    als.clear();*/
+    if( m_attrs != "*" )
+	for( int off = 0; !(tstr = TSYS::strSepParse(m_attrs,0,';',&off)).empty(); )
+    	    als.push_back(tstr);
+	
+    //-- Same load --
     TConfig c_el(&mod->elWdgIO());
     c_el.cfg("IDW").setS(owner().path());
     for( int i_a = 0; i_a < als.size(); i_a++ )
     { 
- 	AutoHD<Attr> attr = attrAt(als[i_a]);
+	if( !attrPresent(als[i_a]) )	continue;
+ 	AutoHD<Attr> attr = attrAt(als[i_a]);	
 	if( !(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser ) continue;
 	c_el.cfg("ID").setS(id()+"/"+als[i_a]);
 	if( !SYS->db().at().dataGet(db+"."+tbl,mod->nodePath()+tbl,c_el) ) continue;
 	attr.at().setS(c_el.cfg("IO_VAL").getS());
-	if( attr.at().flgGlob()&Attr::Active )	attrList( als );
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
-    } 
+    }
+    
     //- Load widget's user attributes -
     tbl = owner().ownerProj()->tbl()+"_uio";
     c_el.setElem(&mod->elWdgUIO());
@@ -1065,31 +1331,33 @@ void PageWdg::loadIO( )
 
         if( !attrPresent(sid) )
             attrAdd( new TFld(sid.c_str(),c_el.cfg("NAME").getS().c_str(),(TFld::Type)(flg&0x0f),flg>>4) );
-
 	AutoHD<Attr> attr = attrAt(sid);
         if( !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) ) continue;
-	if( attr.at().flgGlob()&TFld::Selected )
-	{
-	    attr.at().setS(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),0,'|'));
-	    attr.at().fld().setValues(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),1,'|'));
-	    attr.at().fld().setSelNames(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),2,'|'));
-	}
-	else attr.at().setS(c_el.cfg("IO_VAL").getS());
+	attr.at().setS(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),0,'|'));
+	attr.at().fld().setValues(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),1,'|'));
+	attr.at().fld().setSelNames(TSYS::strSepParse(c_el.cfg("IO_VAL").getS(),2,'|'));
 	attr.at().setFlgSelf((Attr::SelfAttrFlgs)c_el.cfg("SELF_FLG").getI());
 	attr.at().setCfgTempl(c_el.cfg("CFG_TMPL").getS());
 	attr.at().setCfgVal(c_el.cfg("CFG_VAL").getS());
     }
 }
 
-void PageWdg::save( )
+void PageWdg::save_( )
 {
     //- Save generic widget's data -
-    if( !parent().at().isLink() )
-    {    
-	string db  = owner().ownerProj()->DB();
-	string tbl = owner().ownerProj()->tbl()+"_incl";
-	SYS->db().at().dataSet(db+"."+tbl,mod->nodePath()+tbl,*this);
+    string db  = owner().ownerProj()->DB();
+    string tbl = owner().ownerProj()->tbl()+"_incl";
+	
+    m_attrs="";
+    vector<string> als;
+    attrList( als );
+    for( int i_a = 0; i_a < als.size(); i_a++ )
+    {
+ 	AutoHD<Attr> attr = attrAt(als[i_a]);	
+	if( attr.at().modif() && !(!(attr.at().flgGlob()&Attr::IsInher) && attr.at().flgGlob()&Attr::IsUser) )
+	m_attrs+=als[i_a]+";";
     }
+    SYS->db().at().dataSet(db+"."+tbl,mod->nodePath()+tbl,*this);
 
     //- Save widget's attributes -
     saveIO();
@@ -1156,13 +1424,21 @@ void PageWdg::saveIO( )
     }
 }
 
+void PageWdg::inheritAttr( const string &attr )
+{
+    bool mdf = isModify();
+    Widget::inheritAttr( attr );
+    if( !mdf )  modifClr( );
+}
+
 string PageWdg::resourceGet( const string &id, string *mime )
 {
     string mimeType, mimeData;
     
-    mimeData = parent().at().resourceGet( id, &mimeType );    
-    if( mime )	*mime = mimeType;
-    
+    if( (mimeData=owner().resourceGet( id, &mimeType )).empty() && !parent().freeStat() )
+	mimeData = parent().at().resourceGet( id, &mimeType );
+    if( mime )  *mime = mimeType;
+		    
     return mimeData;
 }
 
@@ -1174,8 +1450,9 @@ void PageWdg::cntrCmdProc( XMLNode *opt )
     {
         cntrCmdGeneric(opt);
         cntrCmdAttributes(opt);
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Widget link: ")+id());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Widget link: ")+id(),permit(),user().c_str(),grp().c_str());
         return;
     }
-    cntrCmdGeneric(opt) || cntrCmdAttributes(opt);
+    if( !(cntrCmdGeneric(opt) || cntrCmdAttributes(opt)) )
+	TCntrNode::cntrCmdProc(opt);
 }
