@@ -58,27 +58,34 @@ void Session::preDisable( int flag )
 
 void Session::setEnable( bool val )
 {
-    vector<string> pg_ls;
+    if( val == enable() )	return;
     
+    vector<string> pg_ls;
+
     if( val )
     {
-	//- Connect to project -
-	m_parent = mod->prjAt(m_prjnm);
+	try
+	{
+	    //- Connect to project -
+	    m_parent = mod->prjAt(m_prjnm);
 	
-	//- Create root pages -	
-	parent().at().list(pg_ls);
-	for( int i_p = 0; i_p < pg_ls.size(); i_p++ )
-	    if( !present(pg_ls[i_p]) )
-		add(pg_ls[i_p],parent().at().at(pg_ls[i_p]).at().path());
+	    //- Create root pages -	
+	    parent().at().list(pg_ls);
+	    for( int i_p = 0; i_p < pg_ls.size(); i_p++ )
+		if( !present(pg_ls[i_p]) )
+		    add(pg_ls[i_p],parent().at().at(pg_ls[i_p]).at().path());
     
-	//- Pages enable -
-	list(pg_ls);
-	for( int i_ls = 0; i_ls < pg_ls.size(); i_ls++ )
-    	    at(pg_ls[i_ls]).at().setEnable(true);
+	    //- Pages enable -
+	    list(pg_ls);
+	    for( int i_ls = 0; i_ls < pg_ls.size(); i_ls++ )
+    		at(pg_ls[i_ls]).at().setEnable(true);
+	}
+	catch(...){ m_parent.free(); }
     }
     else
     {
 	if( start() )	setStart(false);
+	
 	//- Pages disable -
 	list(pg_ls);
 	for( int i_ls = 0; i_ls < pg_ls.size(); i_ls++ )
@@ -87,7 +94,7 @@ void Session::setEnable( bool val )
 	//- Delete pages -
 	for( int i_ls = 0; i_ls < pg_ls.size(); i_ls++ )
     	    del(pg_ls[i_ls]);
-	    
+	
 	//- Disconnect from project -
 	m_parent.free();
     }
@@ -98,17 +105,17 @@ void Session::setEnable( bool val )
 void Session::setStart( bool val )
 {
     vector<string> pg_ls;
-    
+
     if( val )
     {
 	//- Enable session if it disabled -
 	if( !enable() )	setEnable(true);
-	
+
 	//- Process all pages is on -
 	list(pg_ls);
 	for( int i_ls = 0; i_ls < pg_ls.size(); i_ls++ )
     	    at(pg_ls[i_ls]).at().setProcess(true);
-	
+
 	//- Start process task -
 	if( !m_start )
 	{
@@ -118,7 +125,7 @@ void Session::setStart( bool val )
 	    pthread_attr_setschedpolicy(&pthr_attr,SCHED_OTHER);
 	    prior.__sched_priority=2;
     	    pthread_attr_setschedparam(&pthr_attr,&prior);
-	
+
 	    pthread_create(&calcPthr,&pthr_attr,Session::Task,this);
     	    pthread_attr_destroy(&pthr_attr);
     	    if( TSYS::eventWait(m_start, true, nodePath()+"start",5) )
@@ -180,7 +187,7 @@ AutoHD<SessPage> Session::at( const string &id )
     return chldAt(m_page,id);
 }
 
-void Session::uiComm( const string &com, const string &prm, const string &src )
+void Session::uiComm( const string &com, const string &prm, SessWdg *src )
 {
     //- Find of pattern adequancy for opened page -
     string oppg;		//Opened page according of pattern
@@ -254,7 +261,47 @@ void Session::uiComm( const string &com, const string &prm, const string &src )
 	    //-- Close previous page --
 	    if( !oppg.empty() ) 
 		((AutoHD<SessPage>)mod->nodeAt(oppg)).at().attrAt("pgOpen").at().setB(false);
-	    //-- Open new page --
+	    //--- Set interwidget's links for new page ---
+	    bool emptyPresnt = false;
+	    string atr_id, prm_lnk;
+	    vector<string> cAtrLs;
+	    cpg.at().attrList(cAtrLs);
+	    for( int i_al = 0; i_al < cAtrLs.size(); i_al++ )
+	    {
+		AutoHD<Attr> attr = cpg.at().attrAt(cAtrLs[i_al]);
+		if( !(attr.at().flgSelf()&(Attr::CfgLnkIn|Attr::CfgLnkOut) && TSYS::strSepParse(attr.at().cfgTempl(),0,'|') == "<page>" ) ) continue;
+		atr_id = TSYS::strSepParse(attr.at().cfgTempl(),1,'|');
+		if( src->attrPresent(atr_id) )
+		{
+		    attr.at().setCfgVal("wdg:"+src->path()+"/a_"+atr_id);
+		    if( prm_lnk.empty() && src->attrAt(atr_id).at().cfgVal().size() > 4 && 
+			    src->attrAt(atr_id).at().cfgVal().substr(0,4) == "prm:" )
+			prm_lnk = src->attrAt(atr_id).at().cfgVal().substr(4);
+		}
+		else 
+		{ 
+		    attr.at().setCfgVal("");
+		    attr.at().setS(EVAL_STR);
+		    emptyPresnt = true; 
+		}
+	    }
+	    //--- Fill parameter's links for other attributes ---
+	    if( emptyPresnt && !prm_lnk.empty() )
+	    {
+		AutoHD<TValue> prm;
+		prm_lnk = "/"+TSYS::pathLev(prm_lnk,0)+"/"+TSYS::pathLev(prm_lnk,1)+"/"+TSYS::pathLev(prm_lnk,2);
+		try{ prm = SYS->daq().at().nodeAt(prm_lnk); } catch(TError err) { }
+		for( int i_al = 0; !prm.freeStat() && i_al < cAtrLs.size(); i_al++ )
+		{
+		    AutoHD<Attr> attr = cpg.at().attrAt(cAtrLs[i_al]);		
+		    if( !(attr.at().flgSelf()&(Attr::CfgLnkIn|Attr::CfgLnkOut) && 
+			    TSYS::strSepParse(attr.at().cfgTempl(),0,'|') == "<page>" &&
+			    attr.at().cfgVal().empty() ) )	continue;
+		    atr_id = TSYS::strSepParse(attr.at().cfgTempl(),1,'|');
+		    if( prm.at().vlPresent(atr_id) )	attr.at().setCfgVal("prm:"+prm_lnk+"/a_"+atr_id);
+		}
+	    }
+	    //--- Open new page ---
 	    cpg.at().attrAt("pgOpen").at().setB(true);
 	}
     }catch(...){ }
@@ -281,7 +328,12 @@ void *Session::Task( void *icontr )
 
 	//- Calc session pages and all other items at recursion -
 	for( int i_l = 0; i_l < pls.size(); i_l++ )
-	    ses.at(pls[i_l]).at().calc(is_start,is_stop);
+	    try{ ses.at(pls[i_l]).at().calc(is_start,is_stop); }
+	    catch( TError err )	
+	    { 
+		mess_err(err.cat.c_str(),"%s",err.mess.c_str());
+		mess_err(ses.nodePath().c_str(),_("Session '%s' calc error."),pls[i_l].c_str());
+	    }
 
 	if( (ses.m_calcClk++) == 0 ) ses.m_calcClk = 1;
 
@@ -342,10 +394,10 @@ void Session::cntrCmdProc( XMLNode *opt )
     //- Get page info -
     if( opt->name() == "info" )
     {
-        ctrMkNode("oscada_cntr",opt,-1,"/",_("Session: ")+id());
+        ctrMkNode("oscada_cntr",opt,-1,"/",_("Session: ")+id(),RWRWR_,user().c_str(),"UI");
 	if(ico().size()) ctrMkNode("img",opt,-1,"/ico","",R_R_R_);
-        if(ctrMkNode("branches",opt,-1,"/br","",R_R_R_))
-	    ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),R_R_R_,"root","UI",1,"list","/page/page");
+        if(ctrMkNode("branches",opt,-1,"/br","",R_R_R_)) 
+	    ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),R_R_R_,"root","root",1,"idm","1");
         if(ctrMkNode("area",opt,-1,"/obj",_("Session")))
 	{
     	    if(ctrMkNode("area",opt,-1,"/obj/st",_("State")))
@@ -408,13 +460,14 @@ void Session::cntrCmdProc( XMLNode *opt )
 	for( unsigned i_f=0; i_f < lst.size(); i_f++ )
 	    opt->childAdd("el")->setText(lst[i_f]);
     }    
-    else if( a_path == "/page/page" && ctrChkNode(opt) )
+    else if( (a_path == "/br/pg_" || a_path == "/page/page") && ctrChkNode(opt) )
     {
 	vector<string> lst;
 	list(lst);
 	for( unsigned i_f=0; i_f < lst.size(); i_f++ )
 	    opt->childAdd("el")->setAttr("id",lst[i_f])->setText(at(lst[i_f]).at().name());
     }
+    else TCntrNode::cntrCmdProc(opt);
 }
 
 //************************************************
@@ -441,9 +494,9 @@ void SessPage::setEnable( bool val )
 
     if( !val )
     {
-	vector<string> pg_ls;        
+	vector<string> pg_ls;
 	//- Unregister opened page -
-	if( !(parent().at().prjFlags( )&Page::Empty) && attrAt("pgOpen").at().getB() ) 
+	if( !(parent().at().prjFlags( )&Page::Empty) && attrPresent("pgOpen") && attrAt("pgOpen").at().getB() ) 
 	    ownerSess()->openUnreg(path());
 	//- Disable include pages -
 	pageList(pg_ls);
@@ -553,7 +606,7 @@ bool SessPage::cntrCmdGeneric( XMLNode *opt )
 	    if(ctrMkNode("area",opt,1,"/page",_("Pages")))
 	        ctrMkNode("list",opt,-1,"/page/page",_("Pages"),R_R_R_,"root","UI",3,"tp","br","idm","1","br_pref","pg_");
 	    if(ctrMkNode("branches",opt,-1,"/br","",R_R_R_))
-	        ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),R_R_R_,"root","UI",1,"list","/page/page");
+	        ctrMkNode("grp",opt,-1,"/br/pg_",_("Page"),R_R_R_,"root","UI",1,"idm","1");
 	}
         return true;
     }
@@ -567,7 +620,7 @@ bool SessPage::cntrCmdGeneric( XMLNode *opt )
 	if( ctrChkNode(opt,"set",RWRWR_,user().c_str(),grp().c_str(),SEQ_WR) ) 
 	    attrAt("pgOpen").at().setB(atoi(opt->text().c_str()));
     }        
-    else if( a_path == "/page/page" && ctrChkNode(opt) )
+    else if( (a_path == "/br/pg_" || a_path == "/page/page") && ctrChkNode(opt) )
     {
 	vector<string> lst;
 	pageList(lst);
@@ -594,6 +647,16 @@ SessWdg::~SessWdg( )
     
 }
 
+void SessWdg::postEnable( int flag )
+{
+    Widget::postEnable(flag);
+    
+    if( flag&TCntrNode::NodeConnect )
+    {
+	attrAdd( new TFld("event",_("Events"),TFld::String,TFld::FullText,"200") );
+    }
+}
+
 SessWdg *SessWdg::ownerSessWdg( bool base )
 {
     if( nodePrev(true) ) 
@@ -653,19 +716,36 @@ void SessWdg::setProcess( bool val )
 	fio.ioIns( new IO("f_start",_("Function start flag"),IO::Boolean,IO::Default,"0",false),1);
 	fio.ioIns( new IO("f_stop",_("Function stop flag"),IO::Boolean,IO::Default,"0",false),2);
 	//--- Add calc widget's attributes ---
-	AutoHD<Widget> fulw = parentNoLink();
 	vector<string> iwls, als;
-	fulw.at().wdgList(iwls);
-	for( int i_w = -1; i_w < (int)iwls.size(); i_w++ )
+	//--- Self attributes check ---
+	attrList(als);
+	AutoHD<Widget> fulw = parentNoLink();	
+	for( int i_a = 0; i_a < als.size(); i_a++ )
+	{
+	    AutoHD<Attr> cattr = attrAt(als[i_a]);
+	    if( (fulw.at().attrPresent(als[i_a])&&fulw.at().attrAt(als[i_a]).at().flgSelf()&Attr::ProcAttr) || als[i_a] == "focus" )
+	    {
+		IO::Type tp = IO::String;
+		switch( cattr.at().type() )
+		{
+		    case TFld::Boolean: tp = IO::Boolean;	break;
+		    case TFld::Integer: tp = IO::Integer;	break;
+		    case TFld::Real:    tp = IO::Real;	break;
+		    case TFld::String:  tp = IO::String;	break;
+		}
+		fio.ioAdd( new IO(als[i_a].c_str(),cattr.at().name().c_str(),tp,IO::Output,"",false,("./"+als[i_a]).c_str()) );
+	    }
+	}
+	//--- Include attributes check ---
+	wdgList(iwls);
+	for( int i_w = 0; i_w < iwls.size(); i_w++ )
 	{	
-	    AutoHD<Widget> curw = fulw;
-	    if( i_w >= 0 ) curw = fulw.at().wdgAt(iwls[i_w]);
-	
+	    AutoHD<Widget> curw = wdgAt(iwls[i_w]);
 	    curw.at().attrList(als);
 	    for( int i_a = 0; i_a < als.size(); i_a++ )
 	    {
 		AutoHD<Attr> cattr = curw.at().attrAt(als[i_a]);
-		if( cattr.at().flgSelf()&Attr::ProcAttr )
+		if( cattr.at().flgSelf()&Attr::ProcAttr || als[i_a] == "focus" )
 		{
 		    IO::Type tp = IO::String;
 		    switch( cattr.at().type() )
@@ -675,22 +755,26 @@ void SessWdg::setProcess( bool val )
 			case TFld::Real:    tp = IO::Real;	break;
 			case TFld::String:  tp = IO::String;	break;
 		    }
-		    fio.ioAdd( new IO((((i_w<0)?"":iwls[i_w]+"_")+als[i_a]).c_str(),
-				      (((i_w<0)?"":curw.at().name()+".")+cattr.at().name()).c_str(),
-				      tp,IO::Output,"",false,
-				      (((i_w<0)?"./":iwls[i_w]+"/")+als[i_a]).c_str()) );
+		    fio.ioAdd( new IO((iwls[i_w]+"_"+als[i_a]).c_str(),(curw.at().name()+"."+cattr.at().name()).c_str(),tp,IO::Output,"",false,(iwls[i_w]+"/"+als[i_a]).c_str()) );
 		}
 	    }
 	}
 	if( attrPresent("event") ) fio.ioAdd( new IO("event",_("Event"),IO::String,IO::Output) );
 	
-	//-- Compile function --	
-	work_prog = SYS->daq().at().at(TSYS::strSepParse(calcLang(),0,'.')).at().
+	//-- Compile function --
+	try
+	{ 
+	    work_prog = SYS->daq().at().at(TSYS::strSepParse(calcLang(),0,'.')).at().
                     compileFunc(TSYS::strSepParse(calcLang(),1,'.'),fio,calcProg());
-	//-- Connect to compiled function --
-	TValFunc::setFunc(&((AutoHD<TFunction>)SYS->nodeAt(work_prog,1)).at());
+	    //-- Connect to compiled function --
+	    TValFunc::setFunc(&((AutoHD<TFunction>)SYS->nodeAt(work_prog,1)).at());
+	}catch( TError err )	{ mess_err(nodePath().c_str(),_("Compile function for widget is error: %s"),err.mess.c_str()); }
+    }
+    if( !val )
+    {
+	m_proc = false;
+	TValFunc::setFunc(NULL);
     }
-    if( !val )	TValFunc::setFunc(NULL);
 
     //- Change process for included widgets -
     vector<string> ls;
@@ -809,6 +893,8 @@ void SessWdg::prcElListUpdate( )
 	if( attr.at().flgSelf()&(Attr::CfgConst|Attr::CfgLnkIn|Attr::CfgLnkOut) && !attr.at().cfgVal().empty() )
 	    m_attrLnkLs.push_back(ls[i_a]);
 	if( !(attr.at().flgGlob()&Attr::IsUser) ) m_attrUILs.push_back(ls[i_a]);
+	if( attr.at().flgSelf()&Attr::CfgLnkIn && attr.at().cfgVal().empty() )
+	    attr.at().setS(EVAL_STR);
     }
 }
 
@@ -823,7 +909,7 @@ void SessWdg::getUpdtWdg( const string &path, unsigned int tm, vector<string> &e
 unsigned int SessWdg::modifVal( Attr &cfg )
 { 
     int m_clc = ownerSess()->calcClk( );
-    if( !(cfg.flgGlob()&Attr::IsUser) )	m_mdfClc = m_clc;
+    if( atoi(cfg.fld().reserve().c_str()) )	m_mdfClc = m_clc;
     return m_clc; 
 }
 
@@ -837,16 +923,18 @@ void SessWdg::calc( bool first, bool last )
 
     //- Calculate include widgets -
     for(int i_l = 0; i_l < m_wdgChldAct.size(); i_l++ )
-        wdgAt(m_wdgChldAct[i_l]).at().calc(first,last);
-	
+	if( wdgPresent(m_wdgChldAct[i_l]) )
+    	    wdgAt(m_wdgChldAct[i_l]).at().calc(first,last);
+
     try
     {    
 	//- Load events to process -
-	string wevent = eventGet(true);
 	if( !((ownerSess()->calcClk())%(vmax(calcPer()/ownerSess()->period(),1))) )
 	{
+	    string wevent = eventGet(true);
 	    //- Process input links and constants -    
-	    AutoHD<Attr> attr;
+	    AutoHD<Attr> attr, attr1;
+	    AutoHD<TVal> vl;
 	    inLnkGet = true;
 	    for( int i_a = 0; i_a < m_attrLnkLs.size(); i_a++ )
 	    {
@@ -857,32 +945,37 @@ void SessWdg::calc( bool first, bool last )
 		    obj_tp = TSYS::strSepParse(attr.at().cfgVal(),0,':')+":";
 		    if( obj_tp == "val:" )	attr.at().setS(attr.at().cfgVal().substr(obj_tp.size()));
 		    else if( obj_tp == "prm:" )
-		    {			
+		    {	
+			try{ vl = SYS->daq().at().nodeAt(attr.at().cfgVal(),0,0,obj_tp.size()); }
+			catch(TError err) { attr.at().setS(EVAL_STR); continue; }
+			
 			if( attr.at().flgGlob()&Attr::Address )	
 		    	    attr.at().setS("/DAQ"+attr.at().cfgVal().substr(obj_tp.size()));
 			else switch( attr.at().type() )
 			{
-			    case TFld::Boolean:
-				attr.at().setB(((AutoHD<TVal>)SYS->daq().at().nodeAt(
-				    attr.at().cfgVal(),0,0,obj_tp.size())).at().getB());
-				break;
-			    case TFld::Integer:
-				attr.at().setI(((AutoHD<TVal>)SYS->daq().at().nodeAt(
-				    attr.at().cfgVal(),0,0,obj_tp.size())).at().getI());
-				break;
-			    case TFld::Real:
-				attr.at().setR(((AutoHD<TVal>)SYS->daq().at().nodeAt(
-				    attr.at().cfgVal(),0,0,obj_tp.size())).at().getR());
-				break;
-			    case TFld::String:
-				attr.at().setS(((AutoHD<TVal>)SYS->daq().at().nodeAt(
-				    attr.at().cfgVal(),0,0,obj_tp.size())).at().getS());
-				break;
+			    case TFld::Boolean:	attr.at().setB(vl.at().getB());	break;
+			    case TFld::Integer: attr.at().setI(vl.at().getI());	break;
+			    case TFld::Real:	attr.at().setR(vl.at().getR());	break;
+			    case TFld::String:	attr.at().setS(vl.at().getS());	break;
 			}
 		    }
 		    else if( obj_tp == "addr:" )
 			attr.at().setS(attr.at().cfgVal().substr(obj_tp.size()));
+		    else if( obj_tp == "wdg:" )
+		    {
+			try{ attr1 = mod->nodeAt(attr.at().cfgVal(),0,0,obj_tp.size()); }
+			catch(TError err) { attr.at().setS(EVAL_STR); continue; }
+			
+			switch( attr.at().type() )
+			{
+			    case TFld::Boolean:	attr.at().setB(attr1.at().getB()); break;
+			    case TFld::Integer:	attr.at().setI(attr1.at().getI()); break;
+			    case TFld::Real:	attr.at().setR(attr1.at().getR()); break;
+			    case TFld::String:	attr.at().setS(attr1.at().getS()); break;
+			}
+		    }
 		}
+		else if( attr.at().flgSelf()&Attr::CfgLnkIn )	attr.at().setS(EVAL_STR);
 	    }
 	    inLnkGet = false;
 
@@ -924,35 +1017,45 @@ void SessWdg::calc( bool first, bool last )
 			case IO::String:	attr.at().setS(getS(i_io));	break;
 			case IO::Integer:	attr.at().setI(getI(i_io));	break;
 			case IO::Real:     	attr.at().setR(getR(i_io));	break;
-			case IO::Boolean:   attr.at().setB(getB(i_io));	break;
+			case IO::Boolean:	attr.at().setB(getB(i_io));	break;
 		    }
 		}
 		//-- Save events from calc procedure --
 		if( evId >= 0 ) wevent = getS(evId);
 	    }
-	}
     
-	//-- Process widget's events --
-	if( !wevent.empty() )
-	{
-	    string sevup, sev;
-	    for( int el_off = 0; (sev=TSYS::strSepParse(wevent,0,';',&el_off)).size(); )
+	    //-- Process widget's events --
+	    if( !wevent.empty() )
 	    {
-		//-- Check for process events --
-		string sprc_lst = attrAt("evProc").at().getS(), 
-		       sprc;	
-		bool evProc = false;
-		for( int elp_off = 0; (sprc=TSYS::strSepParse(sprc_lst,0,'\n',&elp_off)).size(); )
-		    if( TSYS::strSepParse(sprc,0,':') == sev )
+		int t_off;
+		string sevup, sev, sev_ev, sev_path, sprc_lst, sprc, sprc_ev, sprc_path;
+		for( int el_off = 0; (sev=TSYS::strSepParse(wevent,0,'\n',&el_off)).size(); )
+		{
+		    //-- Check for process events --
+		    t_off = 0;
+		    sev_ev   = TSYS::strSepParse(sev,0,':',&t_off);
+		    sev_path = TSYS::strSepParse(sev,0,':',&t_off);
+		    sprc_lst = attrAt("evProc").at().getS();
+		    bool evProc = false;
+		    for( int elp_off = 0; (sprc=TSYS::strSepParse(sprc_lst,0,'\n',&elp_off)).size(); )
 		    {
-	    		ownerSess()->uiComm(TSYS::strSepParse(sprc,1,':'),TSYS::strSepParse(sprc,2,':'),path());
-			evProc = true;
+			t_off = 0;
+			sprc_ev   = TSYS::strSepParse(sprc,0,':',&t_off);
+			sprc_path = TSYS::strSepParse(sprc,0,':',&t_off);
+			if( sprc_ev == sev_ev && (sprc_path == "*" || sprc_path == sev_path) )
+			{
+			    sprc_path = TSYS::strSepParse(sprc,0,':',&t_off);
+	    		    ownerSess()->uiComm(sprc_path,TSYS::strSepParse(sprc,0,':',&t_off),
+				sev_path.empty() ? this : &((AutoHD<SessWdg>)nodeAt(sev_path)).at());			    
+			    evProc = true;
+			}
 		    }
-		if( !evProc ) sevup+=sev+";";
+		    if( !evProc ) sevup+=sev_ev+":/"+id()+sev_path+"\n";
+		}
+		//-- Put left events to parent widget --
+		SessWdg *owner = ownerSessWdg(true);
+		if( owner && !sevup.empty() ) owner->eventAdd(sevup);
 	    }
-	    //-- Put left events to parent widget --
-	    SessWdg *owner = ownerSessWdg(true);
-	    if( owner && !sevup.empty() ) owner->eventAdd(sevup);
 	}	
     }
     catch(TError err)
@@ -966,19 +1069,26 @@ void SessWdg::calc( bool first, bool last )
 bool SessWdg::attrChange( Attr &cfg, void *prev )
 {
     Widget::attrChange( cfg, prev );
+    
+    //- Special session atributes process -
     if( cfg.id() == "active" )
     {
-        if( cfg.getB() && !attrPresent("event") )
-	    attrAdd( new TFld("event",_("Events"),TFld::String,Attr::Mutable,"200") );
-	if( !cfg.getB() && attrPresent("event") ) attrDel("event");
+	if( cfg.getB() )
+	{
+	    cfg.owner()->attrAdd( new TFld("focus",_("Focus"),TFld::Boolean,TFld::NoFlag,"1","false","","","-2") );
+	    //attrAt("focus").at().setFlgSelf(Attr::ProcAttr);
+	    //prcElListUpdate();
+	}
+	else	cfg.owner()->attrDel("focus");
     }
+    
     //- External link process -
-    if( !inLnkGet && cfg.flgSelf()&Attr::CfgLnkOut && !cfg.cfgVal().empty() )
+    if( !inLnkGet && prev && cfg.flgSelf()&Attr::CfgLnkOut && !cfg.cfgVal().empty() )
     {
         string obj_tp = TSYS::strSepParse(cfg.cfgVal(),0,':')+":";
-        if( obj_tp == "prm:" )
-	    try
-	    {
+	try
+	{
+    	    if( obj_tp == "prm:" )
 	        switch( cfg.type() )
 	        {
 		    case TFld::Boolean:		
@@ -994,7 +1104,23 @@ bool SessWdg::attrChange( Attr &cfg, void *prev )
 		        ((AutoHD<TVal>)SYS->daq().at().nodeAt(cfg.cfgVal(),0,0,obj_tp.size())).at().setS(cfg.getS());
 		        break;
 		}
-	    }catch(...)	{ }
+	    else if( obj_tp == "wdg:" )
+                switch( cfg.type() )
+		{
+		    case TFld::Boolean:		
+		        ((AutoHD<Attr>)mod->nodeAt(cfg.cfgVal(),0,0,obj_tp.size())).at().setB(cfg.getB());
+		        break;
+		    case TFld::Integer:
+		        ((AutoHD<Attr>)mod->nodeAt(cfg.cfgVal(),0,0,obj_tp.size())).at().setI(cfg.getI());
+		        break;
+		    case TFld::Real:
+		        ((AutoHD<Attr>)mod->nodeAt(cfg.cfgVal(),0,0,obj_tp.size())).at().setR(cfg.getR());
+		        break;
+		    case TFld::String:
+		        ((AutoHD<Attr>)mod->nodeAt(cfg.cfgVal(),0,0,obj_tp.size())).at().setS(cfg.getS());
+		        break;
+		}
+	}catch(...)	{ }
     }    
     return true;
 }
@@ -1012,9 +1138,9 @@ bool SessWdg::cntrCmdServ( XMLNode *opt )
 		for( int i_l = 0; i_l < m_attrUILs.size(); i_l++ )
 		{
 		    attr = attrAt(m_attrUILs[i_l]);
-		    if( !(attr.at().flgGlob()&Attr::IsUser) && attr.at().modif() >= tm )
+		    if( attr.at().modif() >= tm && atoi(attr.at().fld().reserve().c_str()) )
 			opt->childAdd("el")->setAttr("id",m_attrUILs[i_l].c_str())->
-				    	     setAttr("pos",TSYS::int2str(attr.at().fld().reserve()))->
+				    	     setAttr("pos",attr.at().fld().reserve())->
 					     setText(attr.at().getS());
 		}
 	    opt->setAttr("tm",TSYS::uint2str(ownerSess()->calcClk( )));
@@ -1023,7 +1149,7 @@ bool SessWdg::cntrCmdServ( XMLNode *opt )
 	    for( int i_ch = 0; i_ch < opt->childSize(); i_ch++ )
 	    {
 	        string aid = opt->childGet(i_ch)->attr("id");
-	        if( aid == "event" ) eventAdd(opt->childGet(i_ch)->text()+";");
+	        if( aid == "event" ) eventAdd(opt->childGet(i_ch)->text()+"\n");
 	        else attrAt(aid).at().setS(opt->childGet(i_ch)->text());
 	    }
 	return true;
@@ -1063,7 +1189,7 @@ bool SessWdg::cntrCmdGeneric( XMLNode *opt )
 	}
         if( ctrChkNode(opt,"set",(attr.at().fld().flg()&TFld::NoWrite)?(permit()&~0222):permit(),user().c_str(),grp().c_str(),SEQ_WR) )
         {
-	    if( attr.at().id() == "event" )	eventAdd(opt->text()+";");
+	    if( attr.at().id() == "event" )	eventAdd(opt->text()+"\n");
             else if( attr.at().fld().flg()&TFld::Selected )  
 						attr.at().setSEL(opt->text());
             else				attr.at().setS(opt->text());
@@ -1089,5 +1215,8 @@ void SessWdg::cntrCmdProc( XMLNode *opt )
         cntrCmdAttributes(opt);
         return;
     }
-    cntrCmdGeneric(opt) || cntrCmdAttributes(opt);
+    if( !(cntrCmdGeneric(opt) || cntrCmdAttributes(opt)) )
+	TCntrNode::cntrCmdProc(opt);
 }
+
+
