@@ -36,7 +36,7 @@
 #define MOD_TYPE    "UI"
 #define MOD_SUBTYPE "VCAEngine"
 #define VER_TYPE    VER_UI
-#define VERSION     "0.5.0"
+#define VERSION     "0.6.0"
 #define AUTORS      "Roman Savochenko"
 #define DESCRIPTION "Generic visual control area engine."
 #define LICENSE     "GPL"
@@ -119,7 +119,7 @@ void Engine::postEnable( int flag )
     if( !(flag&TCntrNode::NodeConnect) ) return;
     
     //- Make lib's DB structure -
-    lbwdg_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"20") );
+    lbwdg_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"30") );
     lbwdg_el.fldAdd( new TFld("NAME",_("Name"),TFld::String,TFld::NoFlag,"50") );
     lbwdg_el.fldAdd( new TFld("DESCR",_("Description"),TFld::String,TFld::NoFlag,"300") );
     lbwdg_el.fldAdd( new TFld("DB_TBL",_("Data base"),TFld::String,TFld::NoFlag,"30") );
@@ -134,7 +134,7 @@ void Engine::postEnable( int flag )
     wdgdata_el.fldAdd( new TFld("DATA",_("Mime data"),TFld::String,TFld::NoFlag,"500000") );
     
     //- Make widgets DB structure -
-    wdg_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"20") );
+    wdg_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"30") );
     wdg_el.fldAdd( new TFld("ICO",_("Icon"),TFld::String,TFld::NoFlag,"10000") );
     wdg_el.fldAdd( new TFld("PARENT",_("Parent widget"),TFld::String,TFld::NoFlag,"200") );
     wdg_el.fldAdd( new TFld("PROC",_("Procedure text and language"),TFld::String,TFld::NoFlag,"10000") );
@@ -142,15 +142,17 @@ void Engine::postEnable( int flag )
     wdg_el.fldAdd( new TFld("USER",_("User"),TFld::String,TFld::NoFlag,"20","root") );
     wdg_el.fldAdd( new TFld("GRP",_("Group"),TFld::String,TFld::NoFlag,"20","UI") );
     wdg_el.fldAdd( new TFld("PERMIT",_("Permision"),TFld::Integer,TFld::OctDec,"3","436") );
+    wdg_el.fldAdd( new TFld("ATTRS",_("Changed attributes"),TFld::String,TFld::NoFlag,"10000","*") );
 
     //- Make include widgets DB structure -
     inclwdg_el.fldAdd( new TFld("IDW",_("IDW"),TFld::String,TCfg::Key,"100") );
-    inclwdg_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"20") );
+    inclwdg_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"30") );
     inclwdg_el.fldAdd( new TFld("PARENT",_("Parent widget"),TFld::String,TFld::NoFlag,"200") );
+    inclwdg_el.fldAdd( new TFld("ATTRS",_("Changed attributes"),TFld::String,TFld::NoFlag,"10000","*") );
 
     //- Make widget's IO DB structure -
     wdgio_el.fldAdd( new TFld("IDW",_("Widget ID"),TFld::String,TCfg::Key,"100") );
-    wdgio_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"40") );
+    wdgio_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"61") );
     wdgio_el.fldAdd( new TFld("IO_VAL",_("Attribute value"),TFld::String,TFld::NoFlag,"100000") );
     wdgio_el.fldAdd( new TFld("SELF_FLG",_("Attribute self flags"),TFld::Integer,TFld::NoFlag,"5") );
     wdgio_el.fldAdd( new TFld("CFG_TMPL",_("Configuration template"),TFld::String,TFld::NoFlag,"30") );
@@ -158,7 +160,7 @@ void Engine::postEnable( int flag )
     
     //- Make widget's user IO DB structure -
     wdguio_el.fldAdd( new TFld("IDW",_("Widget ID"),TFld::String,TCfg::Key,"100") );
-    wdguio_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"40") );
+    wdguio_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"61") );
     wdguio_el.fldAdd( new TFld("NAME",_("Name"),TFld::String,TFld::NoFlag,"50") );
     wdguio_el.fldAdd( new TFld("IO_TYPE",_("Attribute generic flags and type"),TFld::Integer,TFld::NoFlag,"10") );
     wdguio_el.fldAdd( new TFld("IO_VAL",_("Attribute value"),TFld::String,TFld::NoFlag,"100000") );
@@ -167,7 +169,7 @@ void Engine::postEnable( int flag )
     wdguio_el.fldAdd( new TFld("CFG_VAL",_("Configuration value"),TFld::String,TFld::NoFlag,"1000") );    
 
     //- Make project's DB structure -
-    prj_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"20") );
+    prj_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"30") );
     prj_el.fldAdd( new TFld("NAME",_("Name"),TFld::String,TFld::NoFlag,"50") );
     prj_el.fldAdd( new TFld("DESCR",_("Description"),TFld::String,TFld::NoFlag,"300") );
     prj_el.fldAdd( new TFld("DB_TBL",_("Data base"),TFld::String,TFld::NoFlag,"30") );
@@ -178,7 +180,7 @@ void Engine::postEnable( int flag )
 
     //- Make pages DB structure -
     page_el.fldAdd( new TFld("OWNER",_("Owner"),TFld::String,TCfg::Key,"100") );
-    page_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"20") );
+    page_el.fldAdd( new TFld("ID",_("ID"),TFld::String,TCfg::Key,"30") );
     page_el.fldAdd( new TFld("ICO",_("Icon"),TFld::String,TFld::NoFlag,"10000") );
     page_el.fldAdd( new TFld("PARENT",_("Parent widget"),TFld::String,TFld::NoFlag,"200") );
     page_el.fldAdd( new TFld("PROC",_("Procedure text and language"),TFld::String,TFld::NoFlag,"10000") );
@@ -187,6 +189,7 @@ void Engine::postEnable( int flag )
     page_el.fldAdd( new TFld("GRP",_("Group"),TFld::String,TFld::NoFlag,"20","UI") );
     page_el.fldAdd( new TFld("PERMIT",_("Permision"),TFld::Integer,TFld::OctDec,"3","436") );
     page_el.fldAdd( new TFld("FLGS",_("Flags"),TFld::Integer,TFld::NoFlag,"1","0") );
+    page_el.fldAdd( new TFld("ATTRS",_("Changed attributes"),TFld::String,TFld::NoFlag,"10000","*") );
 
     //- Init original widgets library -
     wlbAdd("originals",_("Original widget's library"));
@@ -213,7 +216,7 @@ void Engine::preDisable( int flag )
     TModule::preDisable( flag );
 }
 
-void Engine::modLoad( )
+void Engine::load_( )
 {
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),_("Load module."));
@@ -329,25 +332,18 @@ void Engine::modLoad( )
     {
 	mess_err(err.cat.c_str(),"%s",err.mess.c_str());
         mess_err(nodePath().c_str(),_("Load projects error."));
-    }    
-}
-
-void Engine::modSave( )
-{
-#if OSC_DEBUG
-    mess_debug(nodePath().c_str(),_("Save module."));
-#endif
-
-    //- Save parameters -
-    //-- Save widget's libraries --
+    }
+    
+    //- Libraries enable -
     vector<string> ls;
     wlbList(ls);
     for( int l_id = 0; l_id < ls.size(); l_id++ )
-	wlbAt(ls[l_id]).at().save();
-    //-- Save projects --
+	wlbAt(ls[l_id]).at().setEnable(true);
+	
+    //- Projects enable -
     prjList(ls);
-    for( int p_id = 0; p_id < ls.size(); p_id++ )
-	prjAt(ls[p_id]).at().save();
+    for( int l_id = 0; l_id < ls.size(); l_id++ )
+	prjAt(ls[l_id]).at().setEnable(true);    
 }
 
 void Engine::modStart()
@@ -356,13 +352,13 @@ void Engine::modStart()
     mess_debug(nodePath().c_str(),_("Start module."));
 #endif
 
-    //- Libraries start -
+    //- Libraries enable -
     vector<string> ls;
     wlbList(ls);
     for( int l_id = 0; l_id < ls.size(); l_id++ )
 	wlbAt(ls[l_id]).at().setEnable(true);
 	
-    //- Projects start -
+    //- Projects enable -
     prjList(ls);
     for( int l_id = 0; l_id < ls.size(); l_id++ )
 	prjAt(ls[l_id]).at().setEnable(true);
@@ -476,72 +472,70 @@ void Engine::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
         TUI::cntrCmdProc(opt);
-        ctrMkNode("grp",opt,-1,"/br/prj_",_("Project"),0444,"root","root",1,"list","/prm/cfg/prj");	
-        ctrMkNode("grp",opt,-1,"/br/wlb_",_("Widget's library"),0444,"root","root",1,"list","/prm/cfg/wlb");
-        ctrMkNode("grp",opt,-1,"/br/ses_",_("Session"),0444,"root","root",1,"list","/ses/ses");	
-	if(ctrMkNode("area",opt,-1,"/prm/cfg",_("Configuration"),0444,"root","root"))
+        ctrMkNode("grp",opt,-1,"/br/prj_",_("Project"),0664,"root","UI",1,"idm","1");	
+        ctrMkNode("grp",opt,-1,"/br/wlb_",_("Widget's library"),0664,"root","UI",1,"idm","1");
+        ctrMkNode("grp",opt,-1,"/br/ses_",_("Session"),0664,"root","UI",1,"idm","1");	
+	if(ctrMkNode("area",opt,-1,"/prm/cfg",_("Configuration"),0444,"root","UI"))
 	{
     	    ctrMkNode("list",opt,-1,"/prm/cfg/prj",_("Project"),0664,"root","UI",4,"tp","br","idm","1","s_com","add,del","br_pref","prj_");
-    	    ctrMkNode("list",opt,-1,"/prm/cfg/wlb",_("Widget's libraries"),0664,"root","UI",4,"tp","br","idm","1","s_com","add,del","br_pref","wlb_");	    
-	    ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660);
-    	    ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660);
+    	    ctrMkNode("list",opt,-1,"/prm/cfg/wlb",_("Widget's libraries"),0664,"root","UI",4,"tp","br","idm","1","s_com","add,del","br_pref","wlb_");
 	}
-	if(ctrMkNode("area",opt,1,"/ses",_("Sessions"),0444,"root","root"))
+	if(ctrMkNode("area",opt,1,"/ses",_("Sessions"),0444,"root","UI"))
     	    ctrMkNode("list",opt,-1,"/ses/ses",_("Sessions"),0664,"root","UI",3,"tp","br","s_com","add,del","br_pref","ses_");
         return;
     }
     
     //- Process command for page -
-    if( a_path == "/prm/cfg/prj" )
+    if( a_path == "/br/prj_" || a_path == "/prm/cfg/prj" )
     {
-        if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )
+        if( ctrChkNode(opt,"get",0664,"root","UI",SEQ_RD) )
         {
             vector<string> lst;
             prjList(lst);
             for( unsigned i_a=0; i_a < lst.size(); i_a++ )
                 opt->childAdd("el")->setAttr("id",lst[i_a])->setText(prjAt(lst[i_a]).at().name());
         }
-        if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )
+        if( ctrChkNode(opt,"add",0664,"root","UI",SEQ_WR) )
 	{
 	    prjAdd(opt->attr("id"),opt->text());
 	    prjAt(opt->attr("id")).at().setUser(opt->attr("user"));
 	}
-        if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )   prjDel(opt->attr("id"),true);
+        if( ctrChkNode(opt,"del",0664,"root","UI",SEQ_WR) )   prjDel(opt->attr("id"),true);
     }    
-    else if( a_path == "/prm/cfg/wlb" )
+    else if( a_path == "/br/wlb_" || a_path == "/prm/cfg/wlb" )
     {
-        if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )
+        if( ctrChkNode(opt,"get",0664,"root","UI",SEQ_RD) )
         {
             vector<string> lst;
             wlbList(lst);
             for( unsigned i_a=0; i_a < lst.size(); i_a++ )
                 opt->childAdd("el")->setAttr("id",lst[i_a])->setText(wlbAt(lst[i_a]).at().name());
         }
-        if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )
+        if( ctrChkNode(opt,"add",0664,"root","UI",SEQ_WR) )
 	{
 	    wlbAdd(opt->attr("id"),opt->text());
 	    wlbAt(opt->attr("id")).at().setUser(opt->attr("user"));
 	}
-        if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )   wlbDel(opt->attr("id"),true);
-    }    
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	modLoad();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	modSave();
-    else if( a_path == "/ses/ses" )
+        if( ctrChkNode(opt,"del",0664,"root","UI",SEQ_WR) )   wlbDel(opt->attr("id"),true);
+    }
+    else if( a_path == "/prm/cfg/cp/cp" && ctrChkNode(opt,"set",0660,"root","UI",SEQ_WR) )
+	nodeCopy( nodePath(0,true)+opt->attr("src"), nodePath(0,true)+opt->attr("dst"), opt->attr("user") );
+    else if( a_path == "/br/ses_" || a_path == "/ses/ses" )
     {
-        if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )
+        if( ctrChkNode(opt,"get",0664,"root","UI",SEQ_RD) )
         {
             vector<string> lst;
             sesList(lst);
             for( unsigned i_a=0; i_a < lst.size(); i_a++ )
                 opt->childAdd("el")->setText(lst[i_a]);
         }
-        if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )
+        if( ctrChkNode(opt,"add",0664,"root","UI",SEQ_WR) )
 	{
 	    sesAdd(opt->text());
 	    sesAt(opt->text()).at().setUser(opt->attr("user"));
 	    sesAt(opt->text()).at().setBackgrnd(true);
 	}
-        if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )   sesDel(opt->text(),true);
+        if( ctrChkNode(opt,"del",0664,"root","UI",SEQ_WR) )   sesDel(opt->text(),true);
     }        
     else TUI::cntrCmdProc(opt);
 }
