@@ -45,8 +45,9 @@
 #define MOD_TYPE    "UI"
 #define VER_TYPE    VER_UI
 #define SUB_TYPE    "QT"
-#define VERSION     "0.5.0"
+#define VERSION     "0.6.0"
 #define AUTORS      "Roman Savochenko"
+#define DEVELOPERS  "Roman Savochenko, Lysenko Maxim, Yashina Kseniya"
 #define DESCRIPTION "Visual operation user interface."
 #define LICENSE     "GPL"
 //*************************************************
@@ -116,11 +117,13 @@ void TVision::modInfo( vector<string> &list )
 {
     TModule::modInfo(list);
     list.push_back("SubType");
+    list.push_back(_("Developers"));    
 }
 
 string TVision::modInfo( const string &name )
 {
-    if( name == "SubType" ) return SUB_TYPE;
+    if( name == "SubType" ) 		return SUB_TYPE;
+    else if( name == _("Developers") )	return DEVELOPERS;
     else return TModule::modInfo( name);
 }
 
@@ -141,7 +144,7 @@ string TVision::optDescr( )
     return buf;
 }
 
-void TVision::modLoad( )
+void TVision::load_( )
 {
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),_("Load module."));
@@ -174,7 +177,7 @@ void TVision::modLoad( )
     setRunTimeUpdt(atoi(TBDS::genDBGet(nodePath()+"RunTimeUpdt",TSYS::int2str(runTimeUpdt())).c_str()));
 }
 
-void TVision::modSave( )
+void TVision::save_( )
 {
 #if OSC_DEBUG
     mess_debug(nodePath().c_str(),_("Save module."));
@@ -313,8 +316,6 @@ void TVision::cntrCmdProc( XMLNode *opt )
             ctrMkNode("fld",opt,-1,"/prm/cfg/runModUpd",_("RunTime update mode"),0664,"root","root",4,"tp","dec","idm","1","dest","select","select","/prm/cfg/rt_upd_lst");
             ctrMkNode("fld",opt,-1,"/prm/cfg/stationVCA",_("VCA engine station"),0664,"root","root",4,"tp","str","idm","1","dest","select","select","/prm/cfg/vca_lst");
 	    ctrMkNode("comm",opt,-1,"/prm/cfg/host_lnk",_("Go to remote stations list configuration"),0660,"root","root",1,"tp","lnk");
-            ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660);
-            ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660);
         }
         ctrMkNode("fld",opt,-1,"/help/g_help",_("Options help"),0440,"root","root",3,"tp","str","cols","90","rows","5");
 	return;
@@ -349,8 +350,6 @@ void TVision::cntrCmdProc( XMLNode *opt )
         opt->setText("/Transport");
     }
     else if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440) )   opt->setText(optDescr());
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )  modLoad();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )  modSave();
     else if( a_path == "/prm/cfg/u_lst" && ctrChkNode(opt) )
     {
         vector<string> ls;
@@ -415,3 +414,9 @@ int TVision::cntrIfCmd( XMLNode &node, const string &user, const string &stat, b
     node.load(tr.at().messProtIO(host.user+"\n"+host.pass+"\n"+node.save(),"SelfSystem"));
     return atoi(node.attr("rez").c_str());    
 }
+
+QWidget *TVision::getFocusedWdg( QWidget *wcntr )
+{
+    while( wcntr->focusProxy() ) wcntr = wcntr->focusProxy();
+    return wcntr;
+}
