@@ -55,17 +55,13 @@ class TVision : public TUI
 	string VCAStation( )			{ return vca_station; }
 	int    runTimeUpdt( )			{ return run_tm_upd; }
 	
-	void setStartUser( const string &user )	{ start_user = user; }
-	void setRunPrjs( const string &prj )	{ run_prjs = prj; }
-	void setVCAStation( const string &stat ){ vca_station = stat; }
-	void setRunTimeUpdt( int mod )		{ run_tm_upd = mod; }
+	void setStartUser( const string &user )	{ start_user = user; modif(); }
+	void setRunPrjs( const string &prj )	{ run_prjs = prj; modif(); }
+	void setVCAStation( const string &stat ){ vca_station = stat; modif(); }
+	void setRunTimeUpdt( int mod )		{ run_tm_upd = mod; modif(); }
 	
 	void modStart();
 	void modStop();
-
-	void postEnable( int flag );
-	void modLoad( );
-	void modSave( );
 	
 	string modInfo( const string &name );
 	void   modInfo( vector<string> &list );
@@ -80,9 +76,17 @@ class TVision : public TUI
 	//- Put message -
         void postMess( const QString &cat, const QString &mess, 
 		MessLev type = Info, QWidget *parent = NULL );
-	
+
+	static QWidget *getFocusedWdg( QWidget *wcntr );
+
 	//- Request to OpenSCADA control interface -
-	int cntrIfCmd( XMLNode &node, const string &user, const string &stat, bool glob = false );
+	int cntrIfCmd( XMLNode &node, const string &user, const string &stat, bool glob = false );	 
+
+    protected:
+	//Methods
+	void postEnable( int flag );
+	void load_( );
+	void save_( );
 
     private:
 	//Methods
@@ -108,4 +112,3 @@ extern TVision *mod;
 }
 
 #endif //TVISION_H
-
