@@ -20,6 +20,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include <QApplication>
 #include <QWorkspace>
 #include <QMenu>
 #include <QMenuBar>
@@ -44,7 +45,7 @@
 using namespace VISION;
 
 VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) : 
-    prjLibPropDlg(NULL), visItPropDlg(NULL), winClose(false)
+    prjLibPropDlg(NULL), visItPropDlg(NULL), winClose(false), copy_buf("0")
 {
     setAttribute(Qt::WA_DeleteOnClose,true);
 #if QT_VERSION >= 0x040301
@@ -104,7 +105,7 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     
     //-- Page, project, widget and this library actions --
     //--- Load item from db ---
-    if(!ico_t.load(TUIS::icoPath("vision_db_load").c_str())) ico_t.load(":/images/db_load.png");
+    if(!ico_t.load(TUIS::icoPath("load").c_str())) ico_t.load(":/images/load.png");
     actDBLoad = new QAction(QPixmap::fromImage(ico_t),_("Load from DB"),this);
     actDBLoad->setToolTip(_("Load item data from DB"));
     actDBLoad->setWhatsThis(_("The button for loading item data from DB"));
@@ -112,11 +113,12 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     actDBLoad->setEnabled(false);
     connect(actDBLoad, SIGNAL(activated()), this, SLOT(itDBLoad()));
     //--- Save item to db ---
-    if(!ico_t.load(TUIS::icoPath("vision_db_save").c_str())) ico_t.load(":/images/db_save.png");
+    if(!ico_t.load(TUIS::icoPath("save").c_str())) ico_t.load(":/images/save.png");
     actDBSave = new QAction(QPixmap::fromImage(ico_t),_("Save to DB"),this);
     actDBSave->setToolTip(_("Save item data to DB"));
     actDBSave->setWhatsThis(_("The button for saving item data to DB"));
     actDBSave->setStatusTip(_("Press for saving item data to DB."));
+    actDBSave->setShortcut(QKeySequence("Ctrl+S"));    
     actDBSave->setEnabled(false);
     connect(actDBSave, SIGNAL(activated()), this, SLOT(itDBSave()));
     //--- Run project execution ---
@@ -177,6 +179,33 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     actVisItEdit->setShortcut(QKeySequence("Ctrl+E"));
     actVisItEdit->setEnabled(false);
     connect(actVisItEdit, SIGNAL(activated()), this, SLOT(visualItEdit()));
+    //--- Cut visual item ---
+    if(!ico_t.load(TUIS::icoPath("editcut").c_str())) ico_t.load(":/images/editcut.png");
+    actVisItCut = new QAction(QPixmap::fromImage(ico_t),_("Visual item cut"),this);
+    actVisItCut->setToolTip(_("Goes visual item cut"));
+    actVisItCut->setWhatsThis(_("The button for goes to visual item cut"));
+    actVisItCut->setStatusTip(_("Press for goes to visual item cut."));
+    actVisItCut->setShortcut(QKeySequence("Ctrl+X"));
+    actVisItCut->setEnabled(false);
+    connect(actVisItCut, SIGNAL(activated()), this, SLOT(visualItCut()));
+    //--- Copy visual item ---
+    if(!ico_t.load(TUIS::icoPath("editcopy").c_str())) ico_t.load(":/images/editcopy.png");
+    actVisItCopy = new QAction(QPixmap::fromImage(ico_t),_("Visual item copy"),this);
+    actVisItCopy->setToolTip(_("Goes visual item copy"));
+    actVisItCopy->setWhatsThis(_("The button for goes to visual item copy"));
+    actVisItCopy->setStatusTip(_("Press for goes to visual item copy."));
+    actVisItCopy->setShortcut(QKeySequence("Ctrl+C"));
+    actVisItCopy->setEnabled(false);
+    connect(actVisItCopy, SIGNAL(activated()), this, SLOT(visualItCopy()));
+    //--- Paste visual item ---
+    if(!ico_t.load(TUIS::icoPath("editpaste").c_str())) ico_t.load(":/images/editpaste.png");
+    actVisItPaste = new QAction(QPixmap::fromImage(ico_t),_("Visual item paste"),this);
+    actVisItPaste->setToolTip(_("Goes visual item paste"));
+    actVisItPaste->setWhatsThis(_("The button for goes to visual item paste"));
+    actVisItPaste->setStatusTip(_("Press for goes to visual item paste."));
+    actVisItPaste->setShortcut(QKeySequence("Ctrl+V"));
+    actVisItPaste->setEnabled(false);
+    connect(actVisItPaste, SIGNAL(activated()), this, SLOT(visualItPaste()));
 
     //-- Widgets level actions --
     //--- Level up for widget ---
@@ -263,9 +292,20 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     actAlignBottom->setEnabled(false);
     
     //-- Elementar figure actions --
+    //--- Unset cursor ---
+    if(!ico_t.load(TUIS::icoPath("vision_elfig_cursor").c_str())) ico_t.load(":/images/elfig_cursor.png");
+    actElFigCursorAct = new QAction(QPixmap::fromImage(ico_t),_("Cursor"),this);
+    actElFigCursorAct->setCheckable(true);
+    actElFigCursorAct->setChecked(true);
+    actElFigCursorAct->setObjectName("cursor");
+    actElFigCursorAct->setToolTip(_("Unset cursor"));
+    actElFigCursorAct->setWhatsThis(_("The button to unset cursor"));
+    actElFigCursorAct->setStatusTip(_("Press for cursor to be unseted"));
+    actElFigCursorAct->setEnabled(false);    
     //--- Line creation ---
     if(!ico_t.load(TUIS::icoPath("vision_elfig_line").c_str())) ico_t.load(":/images/elfig_line.png");
     actElFigLine = new QAction(QPixmap::fromImage(ico_t),_("Add line"),this);
+    //actElFigCursorAct->setCheckable(true);
     actElFigLine->setObjectName("line");
     actElFigLine->setToolTip(_("Add line to elementary figure"));
     actElFigLine->setWhatsThis(_("The button for adding line to elementary figure"));
@@ -274,6 +314,7 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     //--- Arc creation ---
     if(!ico_t.load(TUIS::icoPath("vision_elfig_arc").c_str())) ico_t.load(":/images/elfig_arc.png");
     actElFigArc = new QAction(QPixmap::fromImage(ico_t),_("Add arc"),this);
+    //actElFigCursorAct->setCheckable(true);
     actElFigArc->setObjectName("arc");
     actElFigArc->setToolTip(_("Add arc to elementary figure"));
     actElFigArc->setWhatsThis(_("The button for adding arc to elementary figure"));
@@ -282,6 +323,7 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     //--- Add Besie curve ---
     if(!ico_t.load(TUIS::icoPath("vision_elfig_besie").c_str())) ico_t.load(":/images/elfig_besie.png");
     actElFigBesie = new QAction(QPixmap::fromImage(ico_t),_("Add besier curve"),this);
+    //actElFigCursorAct->setCheckable(true);
     actElFigBesie->setObjectName("besier");
     actElFigBesie->setToolTip(_("Add Besier curve to elementary figure"));
     actElFigBesie->setWhatsThis(_("The button for adding Besier curve to elementary figure"));
@@ -290,7 +332,9 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     //--- Add Hold points check ---
     if(!ico_t.load(TUIS::icoPath("vision_elfig_lock").c_str())) ico_t.load(":/images/elfig_lock.png");
     actElFigCheckAct=new QAction(QPixmap::fromImage(ico_t),_("Holds"),this);
-    actElFigCheckAct->setCheckable(true);
+    //actElFigCheckAct->setCheckable(true);
+    actElFigCursorAct->setCheckable(true);
+    actElFigCursorAct->setChecked(true);
     actElFigCheckAct->setObjectName("hold");
     actElFigCheckAct->setToolTip(_("Enable holds"));
     actElFigCheckAct->setWhatsThis(_("The button for enabling holds"));
@@ -349,7 +393,11 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     mn_file->addAction(actDBSave);
     mn_file->addSeparator();
     mn_file->addAction(actClose);
-    mn_file->addAction(actQuit);	
+    mn_file->addAction(actQuit);
+    mn_edit = menuBar()->addMenu(_("&Edit"));
+    mn_edit->addAction(actVisItCut);    
+    mn_edit->addAction(actVisItCopy);
+    mn_edit->addAction(actVisItPaste);
     mn_proj = menuBar()->addMenu(_("&Project"));
     mn_proj->addAction(actPrjRun);
     mn_proj->addSeparator();
@@ -406,6 +454,10 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     visItToolBar->addAction(actVisItDel);
     visItToolBar->addAction(actVisItProp);
     visItToolBar->addAction(actVisItEdit);
+    visItToolBar->addSeparator();
+    visItToolBar->addAction(actVisItCut);
+    visItToolBar->addAction(actVisItCopy);
+    visItToolBar->addAction(actVisItPaste);
     mn_view->addAction(visItToolBar->toggleViewAction());
     mn_view->addSeparator(); 
     //-- Widget view functions toolbar --
@@ -428,6 +480,7 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     elFigTool = new QToolBar(_("Elementars figure tools"),this);
     elFigTool->setObjectName("elFigTool");
     addToolBar(elFigTool);
+    elFigTool->addAction(actElFigCursorAct);    
     elFigTool->addAction(actElFigLine);
     elFigTool->addAction(actElFigArc);
     elFigTool->addAction(actElFigBesie);
@@ -444,16 +497,25 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     w_stat->setWhatsThis(_("This label display used VCA engine station."));
     w_stat->setToolTip(_("Field for display of the used VCA engine station."));
     w_stat->setStatusTip(_("Double click for change VCA engine station."));
-    statusBar()->insertPermanentWidget(0,w_stat);    
+    statusBar()->insertPermanentWidget(0,w_stat);
+    w_scale = new WScaleStBar( this );
+    w_scale->setWhatsThis(_("This label display widgets' scaling mode."));
+    w_scale->setToolTip(_("Field for display of widgets' scaling mode."));
+    w_scale->setStatusTip(_("Click for change widgets' scaling mode."));
+    statusBar()->insertPermanentWidget(0,w_scale);
+    mStModify = new QLabel(" ",this);
+    mStModify->setWhatsThis(_("This label display modifying."));
+    mStModify->setToolTip(_("Field for display of modifying."));
+    statusBar()->insertPermanentWidget(0,mStModify);
 
     //- Init dock windows -
     prjTree = new ProjTree(this);
     connect(this,SIGNAL(modifiedItem(const string&)),prjTree,SLOT(updateTree(const string&)));    
-    connect(prjTree,SIGNAL(selectItem(const string&)),this,SLOT(selectItem(const string&)));
+    connect(prjTree,SIGNAL(selectItem(const string&,bool)),this,SLOT(selectItem(const string&,bool)));
     prjTree->setWhatsThis(_("Dock window for projects management."));
     wdgTree = new WdgTree(this);
     connect(this,SIGNAL(modifiedItem(const string&)),wdgTree,SLOT(updateTree(const string&)));
-    connect(wdgTree,SIGNAL(selectItem(const string&)),this,SLOT(selectItem(const string&)));
+    connect(wdgTree,SIGNAL(selectItem(const string&,bool)),this,SLOT(selectItem(const string&,bool)));
     wdgTree->setWhatsThis(_("Dock window for widgets and this libraries management."));
     addDockWidget(Qt::LeftDockWidgetArea,prjTree);
     addDockWidget(Qt::LeftDockWidgetArea,wdgTree);
@@ -464,6 +526,7 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
     
     attrInsp = new InspAttrDock(this);
     connect(attrInsp, SIGNAL(modified(const string &)), this, SIGNAL(modifiedItem(const string &)));
+    connect(attrInsp, SIGNAL(modified(const string &)), this, SLOT(modifyToolUpdate(const string &)));
     attrInsp->setWhatsThis(_("Dock window for widget's attributes inspection."));
     lnkInsp  = new InspLnkDock(this);
     lnkInsp->setWhatsThis(_("Dock window for widget's links inspection."));
@@ -491,7 +554,7 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
 
     setVCAStation(VCAstat);
 
-    connect(this, SIGNAL(modifiedItem(const string&)), this, SLOT(updateLibToolbar()));
+    connect(this, SIGNAL(modifiedItem(const string&)), this, SLOT(updateLibToolbar(const string&)));
     updateLibToolbar();
     wdgTree->updateTree();
     prjTree->updateTree();
@@ -511,15 +574,16 @@ VisDevelop::VisDevelop( const string &open_user, const string &VCAstat ) :
 VisDevelop::~VisDevelop()
 {
     winClose = true;
+
+    //- Save main window state -
+    QByteArray st = saveState();
+    TBDS::genDBSet(mod->nodePath()+"devWinState",TSYS::strEncode(string(st.data(),st.size()),TSYS::base64),user());
+
+    //- Timers stop -
     endRunTimer->stop();
     work_wdgTimer->stop();
     
-    //Save main window state
-    QByteArray st = saveState();
-    TBDS::genDBSet(mod->nodePath()+"devWinState",
-	    TSYS::strEncode(string(st.data(),st.size()),TSYS::base64),user());
-    
-    //Other data clean
+    //- Other data clean -
     if( prjLibPropDlg )	delete prjLibPropDlg;
     if( visItPropDlg )	delete visItPropDlg;
 
@@ -542,12 +606,52 @@ string VisDevelop::user()
     return w_user->user().toAscii().data();
 }
 
+bool VisDevelop::wdgScale( )
+{ 
+    return w_scale->scale();
+}
+
+void VisDevelop::setWdgScale( bool val )
+{ 
+    w_scale->setScale(val);
+}
+
 void VisDevelop::closeEvent( QCloseEvent* ce )
 {
     winClose = true;
+    
+    work_space->closeAllWindows();
+
+    if( !SYS->stopSignal() )	exitModifChk( );
+    
     ce->accept();
 }
 
+void VisDevelop::exitModifChk( )
+{
+    XMLNode req("modify");
+    req.setAttr("path","/%2fobj");
+    if( !cntrIfCmd(req) && atoi(req.text().c_str()) )
+    {
+        bool saveExit = false;
+        req.clear()->setName("get")->setAttr("path","/%2fgen%2fsaveExit");
+        if( !cntrIfCmd(req,true) )   saveExit |= atoi(req.text().c_str());
+        req.setAttr("path","/%2fgen%2fsavePeriod");
+	if( !cntrIfCmd(req,true) )   saveExit |= atoi(req.text().c_str());
+        if( !saveExit )
+        {
+            InputDlg dlg(this,actDBSave->icon(),
+                    _("Some visual items is changed. Save changing to DB on exit?"),
+                    _("Visual items save"),false,false);
+            if( dlg.exec() == QDialog::Accepted )
+            {
+                req.clear()->setName("save")->setAttr("path","/%2fobj");
+                cntrIfCmd(req);
+            }
+        }
+    }
+}
+
 void VisDevelop::endRunChk( )
 {
     if( mod->endRun() )	close();
@@ -555,7 +659,9 @@ void VisDevelop::endRunChk( )
 
 void VisDevelop::quitSt()
 {
-    SYS->stop();
+    exitModifChk( );
+
+    SYS->stop( );
 }
 
 void VisDevelop::about()
@@ -578,16 +684,22 @@ void VisDevelop::enterWhatsThis()
     QWhatsThis::enterWhatsThisMode();
 }
 
-void VisDevelop::updateLibToolbar()
+void VisDevelop::updateLibToolbar( const string &vca_it )
 {
     bool is_create, root_allow;
     int i_lb, i_t, i_m, i_a, i_w;
     vector<string> lbls;
     QImage ico_t;
-    string simg;
+    string t_el, simg;
 
     XMLNode req("get");
+
+    //- Get elements number into VCA item -
+    int vca_lev = 0;
+    for( int off = 0; !(t_el=TSYS::pathLev(vca_it,0,true,&off)).empty(); )  vca_lev++;
     
+    if( vca_lev == 3 )	return;
+
     //- Update library toolbars list -
     XMLNode lb_req("get");    
     lb_req.setAttr("path","/%2fprm%2fcfg%2fwlb");
@@ -654,7 +766,6 @@ void VisDevelop::updateLibToolbar()
 	    if( ico_t.loadFromData((const uchar*)simg.c_str(),simg.size()) )
 		lb_menu[i_m]->setIcon(QPixmap::fromImage(ico_t));
 	}
-	
 	//-- Get widget's actions list --	
     	vector<string> wdgls;  
 	lb_req.clear()->setAttr("path","/wlb_"+lbls[i_lb]+"/%2fwdg%2fwdg");
@@ -715,17 +826,21 @@ void VisDevelop::updateLibToolbar()
     }
 }
 
-void VisDevelop::selectItem( const string &item )
+void VisDevelop::selectItem( const string &item, bool force )
 {
     if( winClose )	return;
     
     work_wdg_new = item;
-    work_wdgTimer->start();
+    if( force )	applyWorkWdg( );    
+    else work_wdgTimer->start( );
 }    
     
 void VisDevelop::applyWorkWdg( )
-{    
+{
+    if( winClose )      return;
     bool isEn = false;
+
+    modifyToolUpdate(work_wdg_new);
     
     //Set/update attributes inspector
     attrInsp->setWdg(work_wdg_new);
@@ -745,8 +860,6 @@ void VisDevelop::applyWorkWdg( )
 
     //- Process main actions -
     actPrjRun->setEnabled(isProj);
-    actDBLoad->setEnabled(sel1.size());
-    actDBSave->setEnabled(sel1.size());
     
     //- Set visual item's actions -
     actVisItAdd->setEnabled(isProj || (isLib&&sel3.empty()));    
@@ -757,9 +870,35 @@ void VisDevelop::applyWorkWdg( )
     actVisItDel->setEnabled(isProj || isLib);
     actVisItProp->setEnabled(isProj || isLib);
     actVisItEdit->setEnabled((isProj || isLib) && sel2.size());
+    //- Edit actions update -
+    editToolUpdate( );
 }
 
-void VisDevelop::updateMenuWindow()
+void VisDevelop::modifyToolUpdate( const string &wdgs )
+{
+    actDBLoad->setEnabled(false); actDBSave->setEnabled(false);
+
+    //- Request modify flag for select widgets -
+    string cur_wdg;
+    XMLNode req("modify");
+    for( int i_off = 0; (cur_wdg=TSYS::strSepParse(wdgs,0,';',&i_off)).size(); )
+    {
+	req.setAttr("path",cur_wdg+"/%2fobj");
+	if( !cntrIfCmd(req) && atoi(req.text().c_str()) )
+	{
+	    actDBLoad->setEnabled(true);
+	    actDBSave->setEnabled(true);
+	}
+    }
+
+    //- Request global VCA modify -
+    mStModify->setText(" ");
+    req.setAttr("path","/%2fobj");
+    if( !cntrIfCmd(req) && atoi(req.text().c_str()) )
+	mStModify->setText("*");
+}
+
+void VisDevelop::updateMenuWindow( )
 {
     mn_window->clear();
     //- Add actions to menu -
@@ -809,13 +948,11 @@ void VisDevelop::itDBLoad( )
 	for( int i_off = 0; (cur_wdg=TSYS::strSepParse(own_wdg,0,';',&i_off)).size(); )
 	{
 	    //-- Send load request --
-	    string sel2 = TSYS::pathLev(cur_wdg,1);
-	    
-	    XMLNode req("set");
-	    req.setAttr("path",cur_wdg+"/"+TSYS::strEncode(sel2.empty()?"/obj/cfg/load":"/wdg/cfg/load",TSYS::PathEl));
-        
+	    XMLNode req("load");
+	    req.setAttr("path",cur_wdg+"/%2fobj");        
 	    if( cntrIfCmd(req) )
 		mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
+	    else emit modifiedItem(cur_wdg);
 	}
     }
 }
@@ -834,11 +971,8 @@ void VisDevelop::itDBSave( )
 	for( int i_off = 0; (cur_wdg=TSYS::strSepParse(own_wdg,0,';',&i_off)).size(); )
 	{
 	    //-- Send load request --
-	    string sel2 = TSYS::pathLev(cur_wdg,1);
-	    
-	    XMLNode req("set");
-	    req.setAttr("path",cur_wdg+"/"+TSYS::strEncode(sel2.empty()?"/obj/cfg/save":"/wdg/cfg/save",TSYS::PathEl));
-        
+	    XMLNode req("save");
+	    req.setAttr("path",cur_wdg+"/%2fobj");
 	    if( cntrIfCmd(req) )
 		mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
 	}
@@ -927,7 +1061,8 @@ void VisDevelop::visualItAdd( QAction *cact, const QPointF &pnt )
     {
 	//-- New include item id generator --
 	//--- Present include widgets list request ---
-	req.setAttr("path",own_wdg+"/%2finclwdg%2fwdg");	
+	if( sid1.substr(0,4) == "prj_" && pnt.isNull() ) req.setAttr("path",own_wdg+"/%2fpage%2fpage");
+	else req.setAttr("path",own_wdg+"/%2finclwdg%2fwdg");
     	if( cntrIfCmd(req) ) mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
 	else
 	{
@@ -947,7 +1082,7 @@ void VisDevelop::visualItAdd( QAction *cact, const QPointF &pnt )
     if( dlg.exec() == QDialog::Accepted )
     {    
         string w_id = dlg.id().toAscii().data();
-        string w_nm = dlg.name().toAscii().data();			
+        string w_nm = dlg.name().toAscii().data();
     
 	//-- Check for widget's library --
 	req.clear()->setName("add");
@@ -996,69 +1131,72 @@ void VisDevelop::visualItAdd( QAction *cact, const QPointF &pnt )
 		err = cntrIfCmd(req);
 	    }
 	    if( err ) mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
-	    else emit modifiedItem(own_wdg);
+	    else emit modifiedItem(new_wdg);
 	}
     }
     cact->setChecked(false);    
 }
 
-void VisDevelop::visualItDel( )
+void VisDevelop::visualItDel( const string &itms )
 {
-    string work_wdg_loc = work_wdg;
+    string work_wdg_loc = itms.empty() ? work_wdg : itms;
     string del_wdg;
+
+    //- Request to confirm -
+    if( itms.empty() )
+    {
+	InputDlg dlg(this,actVisItDel->icon(),
+    		QString(_("You sure for delete visual items: '%1'?")).arg(work_wdg_loc.c_str()),
+		_("Delete visual items"),false,false);
+	if( dlg.exec() != QDialog::Accepted )	return;
+    }
     for( int w_off = 0; (del_wdg=TSYS::strSepParse(work_wdg_loc,0,';',&w_off)).size(); )
     {
-	//- Get owner object path and deleted item identifier -
-	string it_own, it_id;
-	int p_el_cnt = 0;
+        //- Get owner object path and deleted item identifier -
+        string it_own, it_id;
+        int p_el_cnt = 0;
 	string it_tmp = TSYS::pathLev(del_wdg,p_el_cnt++);
-	do 
+    	do 
 	{
 	    it_own= it_own+(it_id.empty() ? "" : ("/"+it_id));
 	    it_id = it_tmp;
 	}	
 	while( (it_tmp=TSYS::pathLev(del_wdg,p_el_cnt++)).size() );
 	p_el_cnt--;
-	//- Request to confirm -
-	InputDlg dlg(this,actVisItDel->icon(),
-		QString(_("You sure for delete visual item '%1'.")).arg(del_wdg.c_str()),
-			_("Delete visual item"),false,false);
-	if( dlg.exec() == QDialog::Accepted )
+
+	XMLNode req("del");	    
+	string sid1 = TSYS::pathLev(it_own,0);
+	//Check for widget's library
+	if( sid1.empty() )
 	{
-	    XMLNode req("del");
-	    
-	    string sid1 = TSYS::pathLev(it_own,0);
-	    //Check for widget's library
-	    if( sid1.empty() )
-	    {
-		if( it_id.substr(0,4) == "wlb_" )
-	    	    req.setAttr("path","/%2fprm%2fcfg%2fwlb")->setAttr("id",it_id.substr(4));
-		else if( it_id.substr(0,4) == "prj_" )
-	    	    req.setAttr("path","/%2fprm%2fcfg%2fprj")->setAttr("id",it_id.substr(4));
-	    }
-	    else if( sid1.substr(0,4) == "wlb_" )
-	    {
-		if( p_el_cnt <= 2 )
-		    req.setAttr("path",it_own+"/%2fwdg%2fwdg")->setAttr("id",it_id.substr(4));
-		else req.setAttr("path",it_own+"/%2finclwdg%2fwdg")->setAttr("id",it_id.substr(4));
-	    }
-	    else if( sid1.substr(0,4) == "prj_" )
-	    {
-		if( p_el_cnt <= 2 )
-		    req.setAttr("path",it_own+"/%2fpage%2fpage")->setAttr("id",it_id.substr(3));
-		else if( it_id.substr(0,3) == "pg_" )
-		    req.setAttr("path",it_own+"/%2fpage%2fpage")->setAttr("id",it_id.substr(3));
-		else req.setAttr("path",it_own+"/%2finclwdg%2fwdg")->setAttr("id",it_id.substr(4));
-	    }
-    	    if( cntrIfCmd(req) )	    
-		mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
-	    else emit modifiedItem(it_own);
-	}	
+	    if( it_id.substr(0,4) == "wlb_" )
+		req.setAttr("path","/%2fprm%2fcfg%2fwlb")->setAttr("id",it_id.substr(4));
+	    else if( it_id.substr(0,4) == "prj_" )
+	        req.setAttr("path","/%2fprm%2fcfg%2fprj")->setAttr("id",it_id.substr(4));
+	}
+	else if( sid1.substr(0,4) == "wlb_" )
+	{
+	    if( p_el_cnt <= 2 )
+	        req.setAttr("path",it_own+"/%2fwdg%2fwdg")->setAttr("id",it_id.substr(4));
+	    else req.setAttr("path",it_own+"/%2finclwdg%2fwdg")->setAttr("id",it_id.substr(4));
+	}
+	else if( sid1.substr(0,4) == "prj_" )
+	{
+	    if( p_el_cnt <= 2 )
+	        req.setAttr("path",it_own+"/%2fpage%2fpage")->setAttr("id",it_id.substr(3));
+	    else if( it_id.substr(0,3) == "pg_" )
+	        req.setAttr("path",it_own+"/%2fpage%2fpage")->setAttr("id",it_id.substr(3));
+	    else req.setAttr("path",it_own+"/%2finclwdg%2fwdg")->setAttr("id",it_id.substr(4));
+	}
+    	if( cntrIfCmd(req) )
+	    mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);	
+	else emit modifiedItem(del_wdg);
     }
 }
 
 void VisDevelop::visualItProp( )
 {
+    //if( work_wdg.empty() )	return;
     string prop_wdg=TSYS::strSepParse(work_wdg,0,';');
     
     string sel1 = TSYS::pathLev(prop_wdg,0);
@@ -1133,3 +1271,158 @@ void VisDevelop::visualItEdit( )
     }
 }
 
+void VisDevelop::visualItCut( )
+{
+    copy_buf = "1"+work_wdg;
+    editToolUpdate();
+}
+
+void VisDevelop::visualItCopy( )
+{
+    copy_buf = "0"+work_wdg;
+    editToolUpdate();
+}
+
+void VisDevelop::visualItPaste( )
+{
+    string copy_buf_el;
+    string work_wdg_work = work_wdg;
+    vector<string> copy_els, del_els;    
+    
+    InputDlg dlg(this,actVisItPaste->icon(),"",_("Visual items move or copy"),true,true);    
+    for( int w_off = 0; (copy_buf_el=TSYS::strSepParse(copy_buf.substr(1),0,';',&w_off)).size(); )
+    {   
+	string s_elp, d_elp, s_el, d_el, t_el, t1_el;     
+	//- Destination elements calc -
+	int n_del = 0;
+	for( int off = 0; !(t_el=TSYS::pathLev(work_wdg_work,0,true,&off)).empty(); n_del++ )
+	{ if( n_del ) d_elp += ("/"+d_el); d_el = t_el; }
+	//- Src elements calc -
+	int n_sel = 0;
+	for( int off = 0; !(t_el=TSYS::pathLev(copy_buf_el,0,true,&off)).empty(); n_sel++ )
+	{ if( n_sel ) s_elp += ("/"+s_el); s_el = t_el; }
+
+	//- Copy visual item -
+	XMLNode req("get");
+	//-- Project copy --
+	if( s_el.substr(0,4)=="prj_" )
+	{
+	    t_el = (QString((copy_buf[0] == '1') ? _("Project '%1' move.\n") : _("Project '%1' copy.\n"))+
+		_("Enter new project's identifier and name.")).arg(s_el.substr(4).c_str()).toAscii().data();
+	    req.setAttr("path","/%2fprm%2fcfg%2fprj");
+	    d_el = "prj_";
+	    t1_el = s_el.substr(4);
+	}
+	//-- Widget's library copy --
+	else if( s_el.substr(0,4)=="wlb_" )
+	{
+	    t_el = (QString((copy_buf[0] == '1') ? _("Widget's library '%1' move.\n") : _("Widget's library '%1' copy.\n"))+
+		_("Enter new widget's library identifier and name.")).arg(s_el.substr(4).c_str()).toAscii().data();
+	    req.setAttr("path","/%2fprm%2fcfg%2fwlb");
+	    d_el = "wlb_"; 
+	    t1_el = s_el.substr(4);
+	}
+	//-- Page copy --
+	else if( s_el.substr(0,3)=="pg_" && (d_el.substr(0,4)=="prj_" || d_el.substr(0,3)=="pg_" || d_el.substr(0,4)=="wlb_") )
+	{
+	    t_el = (QString((copy_buf[0] == '1') ? _("Move page '%1' to '%2'.\n") : _("Copy page '%1' to '%2'.\n"))+
+		_("Enter new widget/page identifier and name.")).arg(copy_buf_el.c_str()).arg(work_wdg_work.c_str()).toAscii().data();
+	    if( d_el.substr(0,4)=="wlb_" ) 	req.setAttr("path",work_wdg_work+"/%2fwdg%2fwdg");
+	    else req.setAttr("path",work_wdg_work+"/%2fpage%2fpage");
+	    d_elp += ("/"+d_el);
+	    d_el = (d_el.substr(0,4)=="wlb_") ? "wdg_" : "pg_";
+	    t1_el = s_el.substr(3);
+	}
+	//-- Widget copy --
+	else if( s_el.substr(0,4)=="wdg_" && (d_el.substr(0,3)=="pg_" || d_el.substr(0,4)=="wlb_" || (TSYS::pathLev(d_elp,0).substr(0,4)=="wlb_" && n_del==2)) )
+	{
+	    t_el = (QString((copy_buf[0] == '1') ? _("Move widget '%1' to '%2'.\n") : _("Copy widget '%1' to '%2'.\n"))+
+		_("Enter new widget identifier and name.")).arg(copy_buf_el.c_str()).arg(work_wdg_work.c_str()).toAscii().data();
+	    if( d_el.substr(0,4)=="wlb_" )	req.setAttr("path",work_wdg_work+"/%2fwdg%2fwdg");
+	    else req.setAttr("path",work_wdg_work+"/%2finclwdg%2fwdg");
+	    d_elp += ("/"+d_el);
+	    d_el = "wdg_";
+	    t1_el = s_el.substr(4);
+	}
+	//-- Copy scheme error --
+	else 
+	{
+	    mod->postMess(mod->nodePath().c_str(),QString(_("Copy/move scheme from '%1' to '%2' no support.")).
+		arg(copy_buf_el.c_str()).arg(work_wdg_work.c_str()),TVision::Error,this);
+	    return;
+	}
+	//-- Prepare new widget identifier --
+	//--- Remove digits from end of new identifier ---
+	int no_numb = t1_el.size()-1;
+	while( no_numb >= 0 && t1_el[no_numb]>='0' && t1_el[no_numb]<='9' ) no_numb--;
+	if( no_numb >= 0 ) t1_el = t1_el.substr(0,no_numb+1);
+	//--- New identifier generator ---
+    	if( cntrIfCmd(req) ) mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
+	else
+	{
+	    int i_c = 1, i_w = 0;
+	    while( i_w < req.childSize() )
+		if( req.childGet(i_w)->attr("id") == t1_el+TSYS::int2str(i_c) ) { i_w = 0; i_c++; }
+		else i_w++;
+	    t1_el += TSYS::int2str(i_c);
+	}	
+	//-- Make request dialog --
+	dlg.setMess(t_el.c_str());
+	dlg.setId(t1_el.c_str());
+	if( dlg.exec() == QDialog::Accepted )
+	{
+    	    d_el += dlg.id().toAscii().data();
+    	    string it_nm = dlg.name().toAscii().data();
+	
+	    req.clear()->setName("set")->
+		setAttr( "path", "/%2fprm%2fcfg%2fcp%2fcp" )->
+		setAttr( "src", s_elp+"/"+s_el )->
+		setAttr( "dst", d_elp+"/"+d_el );
+    	    if( cntrIfCmd(req) )	    
+		mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
+	    else
+	    {
+		if( it_nm.size() )
+		{
+		    req.clear()->setName("set")->setText(it_nm);
+		    if( d_el.substr(0,4) == "prj_" || d_el.substr(0,4) == "wlb_" )	
+			req.setAttr("path",d_elp+"/"+d_el+"/%2fobj%2fcfg%2fname");
+		    else req.setAttr("path",d_elp+"/"+d_el+"/%2fwdg%2fcfg%2fname");
+		    cntrIfCmd(req);
+		}
+		copy_els.push_back(d_elp+"/"+d_el);
+		del_els.push_back(copy_buf_el);
+	    }
+	}
+    }
+    
+    //- Send created widgets events-     
+    for( int i_e = 0; i_e < copy_els.size(); i_e++ )
+	emit modifiedItem(copy_els[i_e]);
+    //- Remove source widget -
+    if( copy_buf[0] == '1' )
+    {
+	for( int i_e = 0; i_e < del_els.size(); i_e++ )
+	    visualItDel(del_els[i_e]);
+	copy_buf = "0";
+    }
+}
+
+void VisDevelop::editToolUpdate( )
+{
+    actVisItCut->setEnabled(!work_wdg.empty());
+    actVisItCopy->setEnabled(!work_wdg.empty());    
+    //- Src and destination elements calc -
+    string s_elp, d_elp, s_el, d_el, t_el;
+    int n_sel = 0;
+    int n_del = 0;
+    for( int off = 0; !(t_el=TSYS::pathLev(copy_buf.substr(1),0,true,&off)).empty(); n_sel++ )
+    { s_elp += ("/"+s_el); s_el = t_el; }
+    for( int off = 0; !(t_el=TSYS::pathLev(work_wdg,0,true,&off)).empty(); n_del++ )
+    { d_elp += ("/"+d_el); d_el = t_el; }
+    if( (s_el.substr(0,4)=="prj_" || s_el.substr(0,4)=="wlb_") ||										//Project and library copy
+	    (s_el.substr(0,3)=="pg_" && (d_el.substr(0,4)=="prj_" || d_el.substr(0,3)=="pg_" || d_el.substr(0,4)=="wlb_")) ||			//Page copy
+	    (s_el.substr(0,4)=="wdg_" && (d_el.substr(0,3)=="pg_" || d_el.substr(0,4)=="wlb_" || (TSYS::pathLev(d_elp,0).substr(0,4)=="wlb_" && n_del==2))) )	//Widget copy
+	actVisItPaste->setEnabled(true);
+    else actVisItPaste->setEnabled(false);
+}
