@@ -96,7 +96,7 @@ LibProjProp::LibProjProp( VisDevelop *parent ) :
     connect(obj_enable, SIGNAL(stateChanged(int)), this, SLOT(isModify()));
     glay->addWidget(obj_enable,0,2,1,2);
 
-    lab = new QLabel(_("Library DB:"),tab_w);
+    lab = new QLabel(_("Container DB:"),tab_w);
     lab->setSizePolicy( QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred) );    
     glay->addWidget(lab,1,1);
     obj_db = new LineEdit(tab_w);
@@ -155,6 +155,7 @@ LibProjProp::LibProjProp( VisDevelop *parent ) :
 
     glay->addWidget(new QLabel(_("Id:"),tab_w),0,0);
     obj_id = new QLabel(this);
+    obj_id->setTextInteractionFlags(Qt::TextSelectableByMouse);
     obj_id->setObjectName("/obj/cfg/id");
     obj_id->setFrameStyle(QFrame::Panel | QFrame::Sunken);
     glay->addWidget(obj_id,0,1);
@@ -207,23 +208,10 @@ LibProjProp::LibProjProp( VisDevelop *parent ) :
 
     //- Add button box -
     //------------------ 
-    butbox = new QDialogButtonBox(QDialogButtonBox::Apply|
-				  QDialogButtonBox::Cancel|
-				  QDialogButtonBox::Close, Qt::Horizontal,this);
-    //-- Init Apply button --
-    butbox->button(QDialogButtonBox::Apply)->setText(_("Save to DB"));
-    if(!ico_t.load(TUIS::icoPath("vision_db_save").c_str())) ico_t.load(":/images/db_save.png");
-    butbox->button(QDialogButtonBox::Apply)->setIcon(QPixmap::fromImage(ico_t));
-    connect(butbox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), this, SLOT(pressApply()));    
-    //-- Init Cancel button --
-    butbox->button(QDialogButtonBox::Cancel)->setText(_("Load from DB"));
-    if(!ico_t.load(TUIS::icoPath("vision_db_load").c_str())) ico_t.load(":/images/db_load.png");
-    butbox->button(QDialogButtonBox::Cancel)->setIcon(QPixmap::fromImage(ico_t));
-    //butbox->button(QDialogButtonBox::Cancel)->setShortcut(QKeySequence("Esc"));
-    connect(butbox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()), this, SLOT(pressCancel()));
+    butbox = new QDialogButtonBox( QDialogButtonBox::Close, Qt::Horizontal, this );
     //-- Init close button --
     butbox->button(QDialogButtonBox::Close)->setText(_("Close"));    
-    connect(butbox->button(QDialogButtonBox::Close), SIGNAL(clicked()), this, SLOT(pressClose()));
+    connect(butbox->button(QDialogButtonBox::Close), SIGNAL(clicked()), this, SLOT(close()));
 
     tab_lay->addWidget(butbox);
 
@@ -427,7 +415,7 @@ void LibProjProp::tabChanged( int itb )
 	{
 	    QTableWidgetItem *w_it;            
             XMLNode *id_col = req.childGet(0);
-	    mimeDataTable->setRowCount(id_col->childSize());        	
+	    mimeDataTable->setRowCount(id_col->childSize());
     	    for( int i_l = 0; i_l < id_col->childSize(); i_l++ )
 	    {
 		if( !mimeDataTable->item(i_l,0) ) 	
@@ -450,7 +438,7 @@ void LibProjProp::tabChanged( int itb )
 		}
 		mimeDataTable->item(i_l,2)->setText(req.childGet(2)->childGet(i_l)->text().c_str());
 	    }
-	    mimeDataTable->resizeColumnsToContents();
+	    mimeDataTable->resizeColumnsToContents();	    
 	}
 	show_init = false;
     }
@@ -526,41 +514,14 @@ void LibProjProp::isModify( )
     is_modif = true;
 }
 
-void LibProjProp::pressApply( )
-{    
-    XMLNode req("set");
-    req.setAttr("path",ed_it+"/"+TSYS::strEncode("/obj/cfg/save",TSYS::PathEl));
-        
-    if( owner()->cntrIfCmd(req) )
-	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
-
-    is_modif = false; 
-    
-    emit apply(ed_it);
-}
-
-void LibProjProp::pressCancel( )
-{    
-    XMLNode req("set");
-    req.setAttr("path",ed_it+"/"+TSYS::strEncode("/obj/cfg/load",TSYS::PathEl));
-        
-    if( owner()->cntrIfCmd(req) )
-	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
-    else showDlg(ed_it,true);
-}
-
-void LibProjProp::pressClose( )
+void LibProjProp::closeEvent( QCloseEvent *ce )
 {
-    if( is_modif )
-    {
-	InputDlg dlg(this,obj_ico->icon(),
-             _("Some attributes is changed. You sure to close window?"),_("Close window"),false,false);
-	if( dlg.exec() != QDialog::Accepted )	return;
-    }			    
-
+    if( is_modif )  emit apply(ed_it);
+    
     is_modif = false;
     ed_it = "";
-    hide();
+	    
+    ce->accept();
 }
 
 void LibProjProp::addMimeData( )
@@ -787,18 +748,21 @@ VisItProp::VisItProp( VisDevelop *parent ) :
     
     glay->addWidget(new QLabel(_("Id:"),tab_w),0,0);
     obj_id = new QLabel(tab_w);
+    obj_id->setTextInteractionFlags(Qt::TextSelectableByMouse);
     obj_id->setObjectName("/wdg/cfg/id");
     obj_id->setFrameStyle(QFrame::Panel | QFrame::Sunken);
     glay->addWidget(obj_id,0,1);
     
     glay->addWidget(new QLabel(_("Root:"),tab_w),1,0);
     obj_root = new QLabel(tab_w);
+    obj_root->setTextInteractionFlags(Qt::TextSelectableByMouse);
     obj_root->setObjectName("/wdg/cfg/root");
     obj_root->setFrameStyle(QFrame::Panel | QFrame::Sunken);
     glay->addWidget(obj_root,1,1);        
     
     glay->addWidget(new QLabel(_("Path:"),tab_w),2,0);
     obj_path = new QLabel(tab_w);
+    obj_path->setTextInteractionFlags(Qt::TextSelectableByMouse);
     obj_path->setObjectName("/wdg/cfg/path");
     obj_path->setFrameStyle(QFrame::Panel | QFrame::Sunken);
     glay->addWidget(obj_path,2,1);
@@ -912,22 +876,8 @@ VisItProp::VisItProp( VisDevelop *parent ) :
 
     //- Add button box -
     //------------------
-    butbox = new QDialogButtonBox(QDialogButtonBox::Apply|
-				  QDialogButtonBox::Cancel|
-				  QDialogButtonBox::Close, Qt::Horizontal,this);
-    //-- Init Apply button --
-    butbox->button(QDialogButtonBox::Apply)->setText(_("Save to DB"));
-    if(!ico_t.load(TUIS::icoPath("vision_db_save").c_str())) ico_t.load(":/images/db_save.png");
-    butbox->button(QDialogButtonBox::Apply)->setIcon(QPixmap::fromImage(ico_t));
-    connect(butbox->button(QDialogButtonBox::Apply), SIGNAL(clicked()), this, SLOT(pressApply()));    
-    //-- Init Cancel button --
-    butbox->button(QDialogButtonBox::Cancel)->setText(_("Load from DB"));
-    if(!ico_t.load(TUIS::icoPath("vision_db_load").c_str())) ico_t.load(":/images/db_load.png");
-    butbox->button(QDialogButtonBox::Cancel)->setIcon(QPixmap::fromImage(ico_t));
-    //butbox->button(QDialogButtonBox::Cancel)->setShortcut(QKeySequence("Esc"));
-    connect(butbox->button(QDialogButtonBox::Cancel), SIGNAL(clicked()), this, SLOT(pressCancel()));
-    //-- Init close button --
-    connect(butbox->button(QDialogButtonBox::Close), SIGNAL(clicked()), this, SLOT(pressClose()));
+    butbox = new QDialogButtonBox( QDialogButtonBox::Close, Qt::Horizontal, this );
+    connect(butbox->button(QDialogButtonBox::Close), SIGNAL(clicked()), this, SLOT(close()));
 
     tab_lay->addWidget(butbox);
 
@@ -958,7 +908,7 @@ void VisItProp::showDlg( const string &iit, bool reload )
     //- Update elements present, visible and values -
     //-----------------------------------------------
     XMLNode req("get");
-    
+
     XMLNode info_req("info");
     info_req.setAttr("path",ed_it);
     if( owner()->cntrIfCmd(info_req) )
@@ -1163,7 +1113,7 @@ void VisItProp::showDlg( const string &iit, bool reload )
 }
 
 void VisItProp::tabChanged( int itb )
-{    
+{
     switch(itb)
     {
 	case 1:	obj_attr->setWdg(ed_it);	break;
@@ -1182,11 +1132,9 @@ void VisItProp::tabChanged( int itb )
 			QString(_("Get node '%1' information error.")).arg(ed_it.c_str()),TVision::Error, this );
 		return;
 	    }
-    
 	    string sval;
 	    XMLNode *root, *gnd;    
 	    root = info_req.childGet(0);     
-
 	    //-- Get widgets list --
 	    vector<string>	wlst;
 	    req.clear()->setAttr("path",ed_it+"/"+TSYS::strEncode("/proc/w_lst",TSYS::PathEl));
@@ -1194,7 +1142,6 @@ void VisItProp::tabChanged( int itb )
 		for( int i_w = 0; i_w < req.childSize(); i_w++ )
 		    wlst.push_back(req.childGet(i_w)->text());
 		    //wlst.push_back(req.childGet(i_w)->attr("id"));
-	
 	    //--- Fill table ---
 	    //--- Delete no present root items ---
 	    for( int i_r = 0; i_r < obj_attr_cfg->topLevelItemCount(); i_r++ )
@@ -1204,7 +1151,6 @@ void VisItProp::tabChanged( int itb )
 		    if( obj_attr_cfg->topLevelItem(i_r)->text(0) == wlst[i_w].c_str() ) break;
 		if( i_w >= wlst.size() )	delete obj_attr_cfg->topLevelItem(i_r--);
 	    }
-	
 	    //--- Add root items ---
 	    for( int i_w = 0; i_w < wlst.size(); i_w++ )
 	    {
@@ -1260,14 +1206,16 @@ void VisItProp::tabChanged( int itb )
 	    if( !owner()->cntrIfCmd(req) )
 		for( int i_el = 0; i_el < req.childSize(); i_el++ )
 		    atypes.push_back( (req.childGet(i_el)->text()+"|"+req.childGet(i_el)->attr("id")).c_str() );
-	    obj_attr_cfg->topLevelItem(0)->setData(0,Qt::UserRole,atypes);
+	    if( obj_attr_cfg->topLevelItemCount() )
+		obj_attr_cfg->topLevelItem(0)->setData(0,Qt::UserRole,atypes);
 	    atypes.clear();
 	    req.clear()->setAttr("path",ed_it+"/"+TSYS::strEncode("/proc/lnk_ls",TSYS::PathEl));
 	    if( !owner()->cntrIfCmd(req) )
 		for( int i_el = 0; i_el < req.childSize(); i_el++ )
 		    atypes.push_back( (req.childGet(i_el)->text()+"|"+req.childGet(i_el)->attr("id")).c_str() );
-	    obj_attr_cfg->topLevelItem(0)->setData(0,Qt::UserRole+1,atypes);
-
+	    if( obj_attr_cfg->topLevelItemCount() )
+		obj_attr_cfg->topLevelItem(0)->setData(0,Qt::UserRole+1,atypes);
+	    
 	    //--- Calc period ---
 	    gnd = TCntrNode::ctrId(root,proc_per->objectName().toAscii().data(),true);
 	    proc_per->setEnabled(gnd && atoi(gnd->attr("acs").c_str())&SEQ_WR);
@@ -1414,41 +1362,14 @@ void VisItProp::isModify( )
     is_modif = true;
 }
 
-void VisItProp::pressApply( )
-{    
-    XMLNode req("set");
-    req.setAttr("path",ed_it+"/"+TSYS::strEncode("/wdg/cfg/save",TSYS::PathEl));
-        
-    if( owner()->cntrIfCmd(req) )
-	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this); 
-
-    emit apply(ed_it);
-    
-    is_modif = false;
-}
-
-void VisItProp::pressCancel( )
-{  
-    XMLNode req("set");
-    req.setAttr("path",ed_it+"/"+TSYS::strEncode("/wdg/cfg/load",TSYS::PathEl));
-        
-    if( owner()->cntrIfCmd(req) )
-	mod->postMess(req.attr("mcat").c_str(),req.text().c_str(),TVision::Error,this);
-    else showDlg(ed_it,true);     
-}
-
-void VisItProp::pressClose( )
+void VisItProp::closeEvent( QCloseEvent *ce )
 {
-    if( is_modif )
-    {
-	InputDlg dlg(this,obj_ico->icon(),
-             _("Some attributes is changed. You sure to close window?"),_("Close window"),false,false);
-	if( dlg.exec() != QDialog::Accepted )	return;
-    }			    
+    if( is_modif )  emit apply(ed_it);
 
     is_modif = false;
     ed_it = "";
-    hide();
+    
+    ce->accept();
 }
 
 void VisItProp::addAttr( )
