@@ -33,6 +33,9 @@
 #include <QTimeEdit>
 #include <QKeyEvent>
 #include <QTextEdit>
+#include <QFontComboBox>
+#include <QGroupBox>
+#include <QCheckBox>
 
 #include <tsys.h>
 
@@ -67,7 +70,7 @@ InputDlg::InputDlg( QWidget *parent, const QIcon &icon, const QString &mess,
     icon_lab->setPixmap(icon.pixmap(48));
     intr_lay->addWidget(icon_lab);
     
-    QLabel *inp_lab = new QLabel(mess,this);
+    inp_lab = new QLabel(mess,this);
     //inp_lab->setAlignment(Qt::AlignHCenter);
     inp_lab->setWordWrap(true);
     intr_lay->addWidget(inp_lab);
@@ -114,7 +117,7 @@ InputDlg::InputDlg( QWidget *parent, const QIcon &icon, const QString &mess,
     connect(but_box, SIGNAL(rejected()), this, SLOT(reject()));
     dlg_lay->addWidget( but_box );
     
-    resize(250,120+(40*with_nm)+(40*with_id));
+    resize(400,120+(40*with_nm)+(40*with_id));
 }
 
 QString InputDlg::id()
@@ -129,6 +132,11 @@ QString InputDlg::name()
     return "";
 }
 
+QString InputDlg::mess( )
+{
+    return inp_lab->text();
+}
+
 void InputDlg::setId(const QString &val)
 {
     if( m_id )	m_id->setText(val);
@@ -139,6 +147,11 @@ void InputDlg::setName(const QString &val)
     if( m_name )m_name->setText(val);
 }
 
+void InputDlg::setMess( const QString &val )
+{
+    inp_lab->setText( val );
+}
+
 //*************************************************
 //* User select dialog                            *
 //*************************************************
@@ -219,6 +232,116 @@ void DlgUser::finish( int result )
     else setResult(SelCancel);
 }
 
+//*********************************************
+//* Font select dialog                        *
+//*********************************************
+FontDlg::FontDlg( QWidget *parent, const QString &ifnt )
+{
+    setWindowTitle(_("Font select"));
+    
+    QGridLayout *dlg_lay = new QGridLayout(this);
+    dlg_lay->setMargin(10);
+    dlg_lay->setSpacing(6);    
+    
+    QLabel *lab = new QLabel(_("Font:"),this);
+    lab->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed) );
+    dlg_lay->addWidget(lab,0,0,1,2);    
+    fntSel = new QFontComboBox(this);
+    connect(fntSel, SIGNAL(currentFontChanged(const QFont&)), this, SLOT(cfgChange()));
+    dlg_lay->addWidget(fntSel,1,0,1,2);
+    
+    QVBoxLayout *sz_lay = new QVBoxLayout;
+    sz_lay->setSpacing(6);
+    lab = new QLabel(_("Size:"),this);
+    lab->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed) );
+    sz_lay->addWidget(lab);
+    spBox = new QSpinBox(this);
+    spBox->setValue(10);
+    connect(spBox, SIGNAL(valueChanged(int)), this, SLOT(cfgChange()));
+    sz_lay->addWidget(spBox);
+    QGroupBox *grpBox = new QGroupBox(_("Style:"),this);
+    QVBoxLayout *grpLay = new QVBoxLayout;
+    grpLay->setMargin(5);
+    chBold = new QCheckBox(_("Bold"), this);		grpLay->addWidget(chBold);
+    connect(chBold, SIGNAL(stateChanged(int)), this, SLOT(cfgChange()));
+    chItalic = new QCheckBox(_("Italic"), this);	grpLay->addWidget(chItalic);
+    connect(chItalic, SIGNAL(stateChanged(int)), this, SLOT(cfgChange()));
+    chStrike = new QCheckBox(_("Strikeout"), this);	grpLay->addWidget(chStrike);
+    connect(chStrike, SIGNAL(stateChanged(int)), this, SLOT(cfgChange()));
+    chUnder = new QCheckBox(_("Underline"), this);	grpLay->addWidget(chUnder);
+    connect(chUnder, SIGNAL(stateChanged(int)), this, SLOT(cfgChange()));
+    grpBox->setLayout(grpLay);
+    sz_lay->addWidget(grpBox);
+    dlg_lay->addItem(sz_lay,2,0);
+    
+    grpBox = new QGroupBox(_("Sample:"),this);
+    grpLay = new QVBoxLayout;
+    grpLay->setMargin(5);
+    sampleText = new QLineEdit(_("AaBbCcDdEeFf"),this);
+    sampleText->setSizePolicy( QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred) );
+    sampleText->setAlignment(Qt::AlignCenter);
+    grpLay->addWidget(sampleText);
+    grpBox->setLayout(grpLay);
+    dlg_lay->addWidget(grpBox,2,1);
+    
+    dlg_lay->addItem( new QSpacerItem( 20, 0, QSizePolicy::Minimum, QSizePolicy::Expanding ), 3, 0, 1, 2 );
+
+    QFrame *sep = new QFrame(this);
+    sep->setFrameShape( QFrame::HLine );
+    sep->setFrameShadow( QFrame::Raised );
+    dlg_lay->addWidget( sep, 4, 0, 1, 2 );
+
+    QDialogButtonBox *but_box = new QDialogButtonBox(QDialogButtonBox::Ok|
+                                    		     QDialogButtonBox::Cancel,Qt::Horizontal,this);
+    QImage ico_t;    
+    but_box->button(QDialogButtonBox::Ok)->setText(_("Ok"));
+    if(!ico_t.load(TUIS::icoPath("button_ok").c_str())) ico_t.load(":/images/button_ok.png");
+    but_box->button(QDialogButtonBox::Ok)->setIcon(QPixmap::fromImage(ico_t));
+    connect(but_box, SIGNAL(accepted()), this, SLOT(accept()));
+    but_box->button(QDialogButtonBox::Cancel)->setText(_("Cancel"));
+    if(!ico_t.load(TUIS::icoPath("button_cancel").c_str())) ico_t.load(":/images/button_cancel.png");
+    but_box->button(QDialogButtonBox::Cancel)->setIcon(QPixmap::fromImage(ico_t));
+    connect(but_box, SIGNAL(rejected()), this, SLOT(reject()));
+    dlg_lay->addWidget( but_box, 5, 0, 1, 2 );
+    
+    setFont(ifnt);
+}
+
+QString	FontDlg::font( )
+{
+    return QString("%1 %2 %3 %4 %5 %6").arg(fntSel->currentFont().family().replace(QRegExp(" "),"_")).
+					arg(spBox->value()).
+                			arg(chBold->checkState()?"1":"0").
+					arg(chItalic->checkState()?"1":"0").
+					arg(chUnder->checkState()?"1":"0").
+					arg(chStrike->checkState()?"1":"0");
+}
+					
+void FontDlg::setFont( const QString &fnt )
+{
+    char family[101]; strcpy(family,"Arial");
+    int size = 10, bold = 0, italic = 0, underline = 0, strike = 0;
+    sscanf(fnt.toAscii().data(),"%100s %d %d %d %d %d",family,&size,&bold,&italic,&underline,&strike);
+    fntSel->setCurrentFont(QFont(QString(family).replace(QRegExp("_")," ")));
+    spBox->setValue(size);
+    chBold->setCheckState(bold?Qt::Checked:Qt::Unchecked);
+    chItalic->setCheckState(italic?Qt::Checked:Qt::Unchecked);
+    chStrike->setCheckState(strike?Qt::Checked:Qt::Unchecked);
+    chUnder->setCheckState(underline?Qt::Checked:Qt::Unchecked);
+}
+
+void FontDlg::cfgChange()
+{
+    QFont fnt;
+    fnt.setFamily(fntSel->currentFont().family());
+    fnt.setPixelSize(spBox->value());
+    fnt.setBold(chBold->checkState());
+    fnt.setItalic(chItalic->checkState());
+    fnt.setUnderline(chUnder->checkState());
+    fnt.setStrikeOut(chStrike->checkState());
+    sampleText->setFont(fnt);
+}
+
 //*********************************************
 //* Status bar user widget                    *
 //*********************************************
@@ -277,14 +400,23 @@ LineEdit::LineEdit( QWidget *parent, LType tp, bool prev_dis ) :
         bt_fld->setIcon(QIcon(":/images/ok.png"));
 	bt_fld->setIconSize(QSize(12,12));
 	bt_fld->setSizePolicy( QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed) );
-        bt_fld->setEnabled(false);
-        bt_fld->setVisible(false);
-        connect( bt_fld, SIGNAL( released() ), this, SLOT( applySlot() ) );
+	bt_fld->setMaximumWidth(15);
+	//bt_fld->setMinimumSize(15,15);
+	//bt_fld->setFlat( true );
+        bt_fld->setEnabled( false );
+        bt_fld->setVisible( false );
+        connect( bt_fld, SIGNAL( pressed() ), this, SLOT( applySlot() ) );
         box->addWidget(bt_fld);
     }
     setType(tp);
 }											
 
+bool LineEdit::isEdited( )
+{
+    if( bt_fld && bt_fld->isVisible() )	return true;
+    return false;
+}
+
 void LineEdit::setType( LType tp )
 {
     if( tp == m_tp ) return;
@@ -324,9 +456,10 @@ void LineEdit::setType( LType tp )
 	    ((QComboBox*)ed_fld)->setEditable(true);
 	    connect( (QComboBox*)ed_fld, SIGNAL( editTextChanged(const QString&) ), SLOT( changed() ) );
 	    break;	    
-    }    
+    }
     ((QBoxLayout*)layout())->insertWidget(0,ed_fld);
-    if( bt_fld ) setTabOrder(ed_fld,bt_fld);
+    setFocusProxy( ed_fld );
+
     
     m_tp = tp;
 }
@@ -338,6 +471,7 @@ void LineEdit::changed( )
     {
 	bt_fld->setEnabled(true);
         bt_fld->setVisible(true);
+	//QWidget::setTabOrder( mod->getFocusedWdg(ed_fld), mod->getFocusedWdg(bt_fld) );	
     }
     
     emit valChanged(value());
@@ -464,7 +598,7 @@ void LineEdit::applySlot( )
 {
     bt_fld->setEnabled(false);
     bt_fld->setVisible(false);
-    
+
     m_val = value();
 	
     emit apply();
@@ -501,24 +635,24 @@ TextEdit::TextEdit( QWidget *parent, bool prev_dis ) :
     box->setSpacing(0);
 		    
     ed_fld = new QTextEdit(this);
+    setFocusProxy( ed_fld );
     connect( ed_fld, SIGNAL( textChanged() ), this, SLOT( changed() ) );
     box->addWidget(ed_fld);
 				
     if( !prev_dis )
     {
-        but_box = new QDialogButtonBox(QDialogButtonBox::Apply|
-        QDialogButtonBox::Cancel,Qt::Horizontal,this);
+        but_box = new QDialogButtonBox(QDialogButtonBox::Apply|QDialogButtonBox::Cancel,Qt::Horizontal,this);
         QImage ico_t;
         but_box->button(QDialogButtonBox::Apply)->setText("");
         if(!ico_t.load(TUIS::icoPath("button_ok").c_str())) ico_t.load(":/images/button_ok.png");
         but_box->button(QDialogButtonBox::Apply)->setIcon(QPixmap::fromImage(ico_t));
 	but_box->button(QDialogButtonBox::Apply)->setIconSize(QSize(12,12));
-        connect(but_box->button(QDialogButtonBox::Apply), SIGNAL(clicked()), this, SLOT(applySlot()));
+        connect(but_box->button(QDialogButtonBox::Apply), SIGNAL(pressed()), this, SLOT(applySlot()));
         but_box->button(QDialogButtonBox::Cancel)->setText("");
 	if(!ico_t.load(TUIS::icoPath("button_cancel").c_str())) ico_t.load(":/images/button_cancel.png");
         but_box->button(QDialogButtonBox::Cancel)->setIcon(QPixmap::fromImage(ico_t));
 	but_box->button(QDialogButtonBox::Cancel)->setIconSize(QSize(12,12));
-        connect(but_box, SIGNAL(rejected()), this, SLOT(cancelSlot()));
+        connect(but_box->button(QDialogButtonBox::Cancel), SIGNAL(pressed()), this, SLOT(cancelSlot()));
         but_box->setVisible(false);
 	but_box->setEnabled(false);
         box->addWidget(but_box);
@@ -578,11 +712,11 @@ void TextEdit::cancelSlot( )
 //****************************************
 //* Shape widget view                    *
 //****************************************
-WdgView::WdgView( const string &iwid, int ilevel, QMainWindow *mainWind, QWidget *parent ) :
-    QWidget(parent), idWidget(iwid), shape(NULL), w_level(ilevel), main_win(mainWind), 
+WdgView::WdgView( const string &iwid, int ilevel, QMainWindow *mainWind, QWidget *parent, Qt::WindowFlags f ) :
+    QWidget(parent,f), idWidget(iwid), shape(NULL), w_level(ilevel), main_win(mainWind), 
     x_scale(1.0), y_scale(1.0), z_coord(0), all_attr_load(false)
 {
-
+    //setAttribute(Qt::WA_OpaquePaintEvent,true);
 }
 
 WdgView::~WdgView( )
@@ -611,13 +745,15 @@ string WdgView::root( )
 void WdgView::moveF( const QPointF &pos )
 {
     w_pos = pos;
-    move(pos.toPoint() );
+    move( pos.toPoint() );
 }
 
 void WdgView::resizeF( const QSizeF &size )
 {
     w_size = size;
-    resize(size.toSize());
+    w_size.setWidth(vmax(w_size.width(),3));
+    w_size.setHeight(vmax(w_size.height(),3));
+    resize( w_size.toSize() );
 }
 
 WdgView *WdgView::newWdgItem( const string &iwid )
@@ -627,7 +763,6 @@ WdgView *WdgView::newWdgItem( const string &iwid )
 
 bool WdgView::attrSet( const string &attr, const string &val, int uiPrmPos )
 {
-    //printf("TEST 00: %s(%d): %s\n",attr.c_str(),uiPrmPos,val.c_str());
     //- Send value to model -
     if( !attr.empty() )
     {
@@ -649,7 +784,7 @@ bool WdgView::attrSet( const string &attr, const string &val, int uiPrmPos )
 	    break;
 	case 9:	resizeF(QSizeF(xScale(true)*atof(val.c_str()),sizeF().height()));	break;
 	case 10:resizeF(QSizeF(sizeF().width(),yScale(true)*atof(val.c_str())));	break;
-	case 11: if(wLevel( )>0) z_coord = atoi(val.c_str());		break;
+	case 11:if(wLevel( )>0) z_coord = atoi(val.c_str());				break;
 	case 13:
 	    resizeF(QSizeF((atof(val.c_str())/x_scale)*sizeF().width(),sizeF().height()));
 	    x_scale = atof(val.c_str());
@@ -659,7 +794,6 @@ bool WdgView::attrSet( const string &attr, const string &val, int uiPrmPos )
 	    y_scale = atof(val.c_str());
 	    break;
     }
-    
     return shape ? shape->attrSet(this,uiPrmPos,val) : true;
 }
 
@@ -672,31 +806,63 @@ string WdgView::resGet( const string &res )
     return "";
 }
 
-void WdgView::load( const string& item )
-{
-    setAllAttrLoad(true);
+void WdgView::load( const string& item, bool load, bool init )
+{   
+    //printf("TEST 00: Load: %s (%d:%d)\n",id().c_str(),load,init);
     
-    if( item.empty() || item == id() )
+    unsigned long long t_cnt;
+    if( wLevel() == 0 ) t_cnt = SYS->shrtCnt();
+    
+    //- Load from data model - 
+    if( load )
     {
-	childsUpdate( item==id() );
-	shapeUpdate( );
+        childsUpdate( false );    
+	setAllAttrLoad( true );    
+	if( item.empty() || item == id() )
+	{
+	    shapeUpdate( );
 	
-	//- Request to widget for last attributes -
-	XMLNode req("get");	
-	req.setAttr("path",id()+"/%2fserv%2f0");
-	if( !cntrIfCmd(req) )
-	    for( int i_el = 0; i_el < req.childSize(); i_el++ )
-		attrSet("",req.childGet(i_el)->text(),atoi(req.childGet(i_el)->attr("pos").c_str()));
+	    //-- Request to widget for last attributes --
+	    XMLNode req("get");	
+	    req.setAttr("path",id()+"/%2fserv%2f0");
+	    if( !cntrIfCmd(req) )
+		for( int i_el = 0; i_el < req.childSize(); i_el++ )
+		    attrSet("",req.childGet(i_el)->text(),atoi(req.childGet(i_el)->attr("pos").c_str()));
+	}
+	setAllAttrLoad( false );
     }
 
-    setAllAttrLoad(false);
-    attrSet("","load",-1);
-    
-    for( int i_c = 0; i_c < children().size(); i_c++ )
-        if( qobject_cast<WdgView*>(children().at(i_c)) )
-    	    ((WdgView*)children().at(i_c))->load((item==id())?"":item);
+    //- Init loaded data -     
+    if( init && (item.empty() || item == id()) && wLevel()>0 )	attrSet("","load",-1);
 
-    orderUpdate( );
+    //- Going to children load and/or init -
+    for( int i_c = 0; i_c < children().size(); i_c++ )
+    {
+	WdgView *wdg = qobject_cast<WdgView*>(children().at(i_c));
+        if( wdg && (item.empty() || item == id() || wdg->id() == item.substr(0,wdg->id().size())) )
+    	    wdg->load((item==id())?"":item,load,(wLevel()>0)?init:false);
+    }
+
+    //- Children widgets order update -
+    if( load ) orderUpdate( );
+
+    //- Post load init for root widget -
+    if( wLevel() == 0 )
+    {
+	//printf("TEST 01: Load '%s' time %fms\n",item.c_str(),1.0e3*((double)(SYS->shrtCnt()-t_cnt))/((double)SYS->sysClk()));
+	//t_cnt = SYS->shrtCnt();
+    
+	attrSet("","load",-1);
+	for( int i_c = 0; i_c < children().size(); i_c++ )
+	{
+	    WdgView *wdg = qobject_cast<WdgView*>(children().at(i_c));
+    	    if( wdg && (item.empty() || item == id() || wdg->id() == item.substr(0,wdg->id().size())) )
+    		wdg->load((item==id())?"":item,false,true);
+	}
+	update();
+
+	//printf("TEST 02: Init '%s' time %fms\n",item.c_str(),1.0e3*((double)(SYS->shrtCnt()-t_cnt))/((double)SYS->sysClk()));
+    }
 }
 
 void WdgView::childsUpdate( bool newLoad )
@@ -764,13 +930,13 @@ void WdgView::orderUpdate( )
     {
 	WdgView *cw = qobject_cast<WdgView*>(children().at(i_c));
 	if( !cw ) continue;
-	if( !lw || (cw->z() >= lw->z()) ) lw = cw;
-	else
-	{	
+	if( lw && (cw->z() < lw->z()) )
+	{
 	    cw->stackUnder(lw);
 	    i_c = -1;
 	    lw = NULL;
 	}
+	else lw = cw;
     }
 }
 
@@ -780,7 +946,6 @@ bool WdgView::event( QEvent *event )
     if( event->type() == QEvent::Paint )
     {
 	//- Self widget view -
-	//printf("TEST 20: Paint %s\n",id().c_str());
 	if( shape )	return shape->event(this,event);
 	return true;
     }
