@@ -130,7 +130,7 @@ string TWEB::optDescr( )
     return buf;
 }
 
-void TWEB::modLoad( )
+void TWEB::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -157,7 +157,7 @@ void TWEB::modLoad( )
     m_CSStables = TBDS::genDBGet(nodePath()+"CSSTables",m_CSStables);
 }
 
-void TWEB::modSave( )
+void TWEB::save_( )
 {
     TBDS::genDBSet(nodePath()+"SessTimeLife",TSYS::int2str(m_t_auth));
     TBDS::genDBSet(nodePath()+"CSSTables",m_CSStables);
@@ -1392,8 +1392,6 @@ void TWEB::cntrCmdProc( XMLNode *opt )
 	{
 	    ctrMkNode("fld",opt,-1,"/prm/cfg/lf_tm",_("Life time of auth sesion(min)"),0660,"root","root",1,"tp","dec");
 	    ctrMkNode("fld",opt,-1,"/prm/cfg/CSS",_("CSS"),0660,"root","root",3,"tp","str","cols","90","rows","7");
-	    ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660);
-    	    ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660);
 	}
 	ctrMkNode("fld",opt,-1,"/help/g_help",_("Options help"),0440,"root","root",3,"tp","str","cols","90","rows","5");
         return;
@@ -1403,17 +1401,15 @@ void TWEB::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/prm/cfg/lf_tm" )
     {
-	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText(TSYS::int2str(m_t_auth));
-	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	m_t_auth = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText( TSYS::int2str(authTime()) );
+	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	setAuthTime( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/prm/cfg/CSS" )
     {
-    	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText(m_CSStables);
-	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	m_CSStables = opt->text();
+    	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText( CSStables() );
+	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	setCSStables( opt->text() );
     }
     else if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440) )	opt->setText(optDescr());
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )  modLoad();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )  modSave();
     else TUI::cntrCmdProc(opt);
 }
 
