@@ -82,12 +82,20 @@ class TWEB: public TUI
 	//Methods
 	TWEB( string name );
 	~TWEB( );
-	    
-	void modLoad( );
-	void modSave( );
-	    
+
+	int authTime( )                              	{ return m_t_auth; }
+        string CSStables( )                             { return m_CSStables; }
+		
+        void setAuthTime( int vl )                   	{ m_t_auth = vl; modif(); }
+        void setCSStables( const string &vl )           { m_CSStables = vl; modif(); }
+
 	void modStart( );
         void modStop( );
+
+    protected:
+	//Methods
+	void load_( );
+	void save_( );	
     
     private:
         //Methods
