@@ -113,7 +113,7 @@ string TWEB::optDescr( )
     return buf;
 }
 
-void TWEB::modLoad( )
+void TWEB::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -147,7 +147,7 @@ void TWEB::modLoad( )
     trnd_tm  = atoi(TBDS::genDBGet(nodePath()+"trnd_tm",TSYS::int2str(trnd_tm)).c_str());
 }
 
-void TWEB::modSave( )
+void TWEB::save_( )
 {
     //- Save parameters to config file -
     string trnds;
@@ -235,7 +235,6 @@ void TWEB::HttpGet( const string &url, string &page, const string &sender, vecto
     {
 	AutoHD<TVArchive> arch;
 	int imgn = atoi(ntrnd.c_str());
-	//printf("TEST 10 %s\n",trnd_lst[imgn].c_str());
 	if( dynamic_cast<TVal *>(&SYS->nodeAt(trnd_lst[imgn],0,'.').at()) )
 	    arch = dynamic_cast<TVal&>(SYS->nodeAt(trnd_lst[imgn],0,'.').at()).arch();
 	else if( dynamic_cast<TVArchive *>(&SYS->nodeAt(trnd_lst[imgn],0,'.').at()) )
@@ -246,9 +245,7 @@ void TWEB::HttpGet( const string &url, string &page, const string &sender, vecto
 	    long long v_beg = ((trnd_tm+trnd_len)>time(NULL))?time(NULL)-trnd_len:trnd_tm;
 	    long long v_end = v_beg+trnd_len;
 	
-	    //printf("TEST 11 %s\n",trnd_lst[imgn].c_str());
 	    page = arch.at().makeTrendImg(v_beg*1000000,v_end*1000000,"",h_sz, v_sz );
-	    //printf("TEST 12 %s\n",trnd_lst[imgn].c_str());
 	}
 	page = http_head("200 OK",page.size(),string("image/png"))+page;
     }    
@@ -273,8 +270,6 @@ void TWEB::cntrCmdProc( XMLNode *opt )
 	    ctrMkNode("fld",opt,-1,"/prm/cfg/vsize",_("Vertical trend size (pixel)"),0664,"root","root",1,"tp","dec");
 	    ctrMkNode("fld",opt,-1,"/prm/cfg/trnd_tm",_("Trend start time (sec)"),0664,"root","root",1,"tp","time");
 	    ctrMkNode("fld",opt,-1,"/prm/cfg/trnd_len",_("Trend length (sec)"),0664,"root","root",1,"tp","dec");	
-    	    ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0666);
-    	    ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0666);
 	}
         ctrMkNode("fld",opt,-1,"/help/g_help",_("Options help"),0440,"root","root",3,"tp","str","cols","90","rows","5");
         return;
@@ -287,42 +282,41 @@ void TWEB::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )
             for( unsigned i_el=0; i_el < trnd_lst.size(); i_el++ )
 		opt->childAdd("el")->setText(trnd_lst[i_el]);
-	if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )	trnd_lst.push_back(opt->text());
+	if( ctrChkNode(opt,"add",0664,"root","root",SEQ_WR) )	{ trnd_lst.push_back(opt->text()); modif(); }
 	if( ctrChkNode(opt,"del",0664,"root","root",SEQ_WR) )
 	    for( unsigned i_el=0; i_el < trnd_lst.size(); i_el++ )
 		if( trnd_lst[i_el] == opt->text() )
 		{
 		    trnd_lst.erase(trnd_lst.begin()+i_el);
+		    modif();
 		    break;
 		}
     }
     else if( a_path == "/prm/cfg/col" )
     {
-	if( ctrChkNode(opt,"get",0664) )	opt->setText(TSYS::int2str(n_col));
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	n_col = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664) )			opt->setText( TSYS::int2str(nCol()) );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setNCol( atoi(opt->text().c_str()) );
     }    
     else if( a_path == "/prm/cfg/hsize" )
     {
-	if( ctrChkNode(opt,"get",0664) )	opt->setText(TSYS::int2str(h_sz));
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	h_sz = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664) )			opt->setText( TSYS::int2str(hSize()) );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setHSize( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/prm/cfg/vsize" )	
     {
-	if( ctrChkNode(opt,"get",0664) )	opt->setText(TSYS::int2str(v_sz));
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	v_sz = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664) )			opt->setText( TSYS::int2str(vSize()) );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setVSize( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/prm/cfg/trnd_tm" )	
     {
-	if( ctrChkNode(opt,"get",0664) )	opt->setText(TSYS::int2str(trnd_tm));
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	trnd_tm = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664) )			opt->setText( TSYS::int2str(trndTm()) );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setTrndTm( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/prm/cfg/trnd_len" )
     {
-	if( ctrChkNode(opt,"get",0664) )	opt->setText(TSYS::int2str(trnd_len));
-	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	trnd_len = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664) )			opt->setText( TSYS::int2str(trndLen()) );
+	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	setTrndLen( atoi(opt->text().c_str()) );
     }		
     else if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440) )	opt->setText(optDescr());
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0666,"root","root",SEQ_WR) )  modLoad();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0666,"root","root",SEQ_WR) )  modSave();
     else TUI::cntrCmdProc(opt);
 }		    
