@@ -781,6 +781,23 @@ TVArchive::~TVArchive( )
 
 }
 
+TCntrNode &TVArchive::operator=( TCntrNode &node )
+{
+    TVArchive *src_n = dynamic_cast<TVArchive*>(&node);
+    if( !src_n ) return *this;
+	
+    //- Configuration copy -
+    string tid = id();
+    *(TConfig*)this = *(TConfig*)src_n;
+    m_id = tid;
+    m_db = src_n->m_db;
+
+    if( src_n->startStat() && toStart() && !startStat() )
+	start( );
+    
+    return *this;
+}
+
 void TVArchive::preDisable(int flag)
 {
     stop(flag);
@@ -852,25 +869,29 @@ long long TVArchive::begin( const string &arch )
 void TVArchive::setValType( TFld::Type vl )
 { 
     m_vtype = vl; 
-    setUpBuf(); 
+    setUpBuf();
+    modif();
 }
 
 void TVArchive::setHardGrid( bool vl ) 	
 { 
     m_bhgrd = vl; 
-    setUpBuf(); 
+    setUpBuf();
+    modif();
 }
 
 void TVArchive::setHighResTm( bool vl )	
 { 
     m_bhres = vl; 
     setUpBuf(); 
+    modif();
 }
 
 void TVArchive::setSize( int vl ) 		
 {     
     m_bsize = vmax(10,vmin(10000000,vl));
     setUpBuf();
+    modif();
 }
 
 void TVArchive::setPeriod( long long vl ) 	
@@ -879,6 +900,7 @@ void TVArchive::setPeriod( long long vl )
     m_bper = (double)vl/1000000.;
     m_bsize = vmax(10,(int)vmin(1e7,100.0/m_bper));    
     setUpBuf();
+    modif();
 }
 
 void TVArchive::setUpBuf()
@@ -886,13 +908,13 @@ void TVArchive::setUpBuf()
     makeBuf((TFld::Type)m_vtype, m_bsize, (long long)(m_bper*1000000.), m_bhgrd, m_bhres );
 }
 
-void TVArchive::load( )
+void TVArchive::load_( )
 {
     SYS->db().at().dataGet(fullDB(),owner().nodePath()+tbl(),*this);
     setUpBuf();
 }
 
-void TVArchive::save( )
+void TVArchive::save_( )
 {
     //- Update Archivators list -
     if( startStat() )
@@ -901,7 +923,7 @@ void TVArchive::save( )
 	archivatorList(arch_ls);
 	m_archs = "";
 	for( int i_l = 0; i_l < arch_ls.size(); i_l++ )
-	    m_archs+=arch_ls[i_l]+";";
+	    m_archs += arch_ls[i_l]+";";
     }
 
     SYS->db().at().dataSet(fullDB(),owner().nodePath()+tbl(),*this);
@@ -918,7 +940,9 @@ void TVArchive::start( )
     //- Attach to archivators -
     string arch;
     for( int i_off = 0; (arch = TSYS::strSepParse(m_archs,0,';',&i_off)).size();  )
-	if(!archivatorPresent(arch)) archivatorAttach(arch);
+	if(!archivatorPresent(arch)) 
+	    try{ archivatorAttach(arch); }
+	    catch(TError err)	{ mess_err(err.cat.c_str(),"%s",err.mess.c_str()); }
 }
 
 void TVArchive::stop( bool full_del )
@@ -943,27 +967,29 @@ void TVArchive::setSrcMode( SrcMode vl, const string &isrc )
     {
 	owner().setActValArch( id(), false );
 	pattr_src.free();
-	dynamic_cast<TVal&>(SYS->nodeAt(m_dsourc,0,'.').at()).arch(AutoHD<TVArchive>());
+	dynamic_cast<TVal&>(SYS->nodeAt(m_dsourc,0,'.').at()).setArch(AutoHD<TVArchive>());
     }
     
     try
     {
 	if( (!run_st || vl != PassiveAttr || isrc != m_dsourc) && 
 		dynamic_cast<TVal *>(&SYS->nodeAt(m_dsourc,0,'.').at()) )
-    	    dynamic_cast<TVal&>(SYS->nodeAt(m_dsourc,0,'.').at()).arch(AutoHD<TVArchive>());
+    	    dynamic_cast<TVal&>(SYS->nodeAt(m_dsourc,0,'.').at()).setArch(AutoHD<TVArchive>());
     }catch(...){  }
 	
     //- Set all links -
     if( run_st && vl == ActiveAttr && dynamic_cast<TVal *>(&SYS->nodeAt(isrc,0,'.').at()) )
     {
-	dynamic_cast<TVal&>(SYS->nodeAt(isrc,0,'.').at()).arch(AutoHD<TVArchive>(this));
+	dynamic_cast<TVal&>(SYS->nodeAt(isrc,0,'.').at()).setArch(AutoHD<TVArchive>(this));
 	pattr_src = SYS->nodeAt(isrc,0,'.');
 	owner().setActValArch( id(), true );
     }
     
     if( run_st && vl == PassiveAttr && dynamic_cast<TVal *>(&SYS->nodeAt(isrc,0,'.').at()) )
-	dynamic_cast<TVal&>(SYS->nodeAt(isrc,0,'.').at()).arch(AutoHD<TVArchive>(this));
+	dynamic_cast<TVal&>(SYS->nodeAt(isrc,0,'.').at()).setArch(AutoHD<TVArchive>(this));
 
+    if( m_srcmode != vl || m_dsourc != isrc )	modif();
+    
     m_srcmode = vl;
     m_dsourc = isrc;
 }
@@ -1124,7 +1150,7 @@ void TVArchive::archivatorAttach( const string &arch )
 	    arch_el.insert(arch_el.begin()+i_l,archivat.at().archivePlace(*this));
 	    return;
 	}
-    arch_el.push_back(archivat.at().archivePlace(*this));	
+    arch_el.push_back(archivat.at().archivePlace(*this));
 }
 
 void TVArchive::archivatorDetach( const string &arch, bool full )
@@ -1163,7 +1189,7 @@ void TVArchive::archivatorSort()
     while(rep_try);	    
 }
 
-string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &iarch, int hsz, int vsz )
+string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &iarch, int hsz, int vsz, double valmax, double valmin )
 {
     char c_buf[30], c_buf1[30];
     time_t tm_t;
@@ -1204,18 +1230,18 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
     long long h_div = 1, hDivBase = 1;
     long long h_min = ibeg;
     long long h_max = iend;
-    int hmax_ln = vsz/30;
+    int hmax_ln = vsz/40;
     if( hmax_ln >= 2 )
     {
         int hvLev = 0;
         long long hLen = iend - ibeg;
-        if( hLen/86400000000ll > 2 )    { hvLev = 5; hDivBase = h_div = 86400000000ll; } //Days
-        else if( hLen/3600000000ll > 2 ){ hvLev = 4; hDivBase = h_div =  3600000000ll; } //Hours
-        else if( hLen/60000000 > 2 )    { hvLev = 3; hDivBase = h_div =    60000000; }   //Minutes
-        else if( hLen/1000000 > 2 )     { hvLev = 2; hDivBase = h_div =     1000000; }   //Seconds
-        else if( hLen/1000 > 2 )        { hvLev = 1; hDivBase = h_div =        1000; }   //Milliseconds
+        if( hLen/86400000000ll >= 2 )    { hvLev = 5; hDivBase = h_div = 86400000000ll; } //Days
+        else if( hLen/3600000000ll >= 2 ){ hvLev = 4; hDivBase = h_div =  3600000000ll; } //Hours
+        else if( hLen/60000000 >= 2 )    { hvLev = 3; hDivBase = h_div =    60000000; }   //Minutes
+        else if( hLen/1000000 >= 2 )     { hvLev = 2; hDivBase = h_div =     1000000; }   //Seconds
+        else if( hLen/1000 >= 2 )        { hvLev = 1; hDivBase = h_div =        1000; }   //Milliseconds
         while( hLen/h_div > hmax_ln )    h_div *= 10;
-        while( hLen/h_div < hmax_ln/2 && !((h_div/2)%hDivBase) )  h_div/=2;
+        while( hLen/h_div < hmax_ln/2 )  h_div /= 2;
     
 	//--- Select most like archivator ---
 	string rarch = iarch;
@@ -1233,7 +1259,7 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
 	}
     
 	getVal(buf,h_min,h_max,rarch,600000);
-	if(!buf.end() || !buf.begin())      return rez;
+	if(!buf.end() || !buf.begin())	{ gdImageDestroy(im); return rez; }
 	
 	//---- Draw full trend's data and time to the trend end position ----
 	tm_t = iend/1000000;
@@ -1243,9 +1269,10 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
 	    snprintf(c_buf1,sizeof(c_buf1),"%d:%02d",ttm->tm_hour,ttm->tm_min);
 	else if( iend%1000000 == 0 )
 	    snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%02d",ttm->tm_hour,ttm->tm_min,ttm->tm_sec);
-	else snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%02d.%d",ttm->tm_hour,ttm->tm_min,ttm->tm_sec,iend%1000000);
+	else snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%g",ttm->tm_hour,ttm->tm_min,(float)ttm->tm_sec+(float)(iend%1000000)/1e6);
 	gdImageString(im,gdFontTiny,h_w_start+h_w_size-gdFontTiny->w*strlen(c_buf),v_w_start+v_w_size+3+gdFontTiny->h,(unsigned char *)c_buf,clr_symb);
 	gdImageString(im,gdFontTiny,h_w_start+h_w_size-gdFontTiny->w*strlen(c_buf1),v_w_start+v_w_size+3,(unsigned char *)c_buf1,clr_symb);
+	int begMarkBrd = -1;
 	int endMarkBrd = vmin(h_w_start+h_w_size-gdFontTiny->w*strlen(c_buf),h_w_start+h_w_size-gdFontTiny->w*strlen(c_buf1));
     
 	//---- Draw grid and/or markers ----
@@ -1260,7 +1287,7 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
 	    {
 		tm_t = i_h/1000000;
         	ttm = localtime(&tm_t);
-        	int chLev = 0;
+        	int chLev = -1;
         	if( !first_m )
         	{
             	    if( ttm->tm_mon > ttm1.tm_mon || ttm->tm_year > ttm1.tm_year )  chLev = 5;
@@ -1268,32 +1295,43 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
             	    else if( ttm->tm_hour > ttm1.tm_hour )  chLev = 3;
             	    else if( ttm->tm_min > ttm1.tm_min )    chLev = 2;
             	    else if( ttm->tm_sec > ttm1.tm_sec )    chLev = 1;
+		    else chLev = 0;
         	}
 		c_buf[0] = c_buf1[0] = 0;
 		if( hvLev == 5 || chLev >= 4 )                                      //Date
-	    	    (chLev>=5) ? snprintf(c_buf,sizeof(c_buf),"%d-%02d-%d",ttm->tm_mday,ttm->tm_mon+1,ttm->tm_year+1900) :
+	    	    (chLev>=5 || chLev==-1) ? snprintf(c_buf,sizeof(c_buf),"%d-%02d-%d",ttm->tm_mday,ttm->tm_mon+1,ttm->tm_year+1900) :
 		                 snprintf(c_buf,sizeof(c_buf),"%d",ttm->tm_mday);
 		if( (hvLev == 4 || hvLev == 3 || ttm->tm_min) && !ttm->tm_sec )     //Hours and minuts
 		    snprintf(c_buf1,sizeof(c_buf1),"%d:%02d",ttm->tm_hour,ttm->tm_min);
 		else if( (hvLev == 2 || ttm->tm_sec) && !(i_h%1000000) )            //Seconds
-		    (chLev>=2) ? snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%02d",ttm->tm_hour,ttm->tm_min,ttm->tm_sec) :
+		    (chLev>=2 || chLev==-1) ? snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%02d",ttm->tm_hour,ttm->tm_min,ttm->tm_sec) :
 				 snprintf(c_buf1,sizeof(c_buf1),"%ds",ttm->tm_sec);
 		else if( hvLev <= 1 || i_h%1000000 )                                //Milliseconds
-	    	    (chLev>=2) ? snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%02d.%d",ttm->tm_hour,ttm->tm_min,ttm->tm_sec,i_h%1000000) :
-		    (chLev>=1) ? snprintf(c_buf1,sizeof(c_buf1),"%d.%ds",ttm->tm_sec,i_h%1000000) :
+	    	    (chLev>=2 || chLev==-1) ? snprintf(c_buf1,sizeof(c_buf1),"%d:%02d:%g",ttm->tm_hour,ttm->tm_min,(float)ttm->tm_sec+(float)(i_h%1000000)/1e6) :
+		    (chLev>=1) ? snprintf(c_buf1,sizeof(c_buf1),"%gs",(float)ttm->tm_sec+(float)(i_h%1000000)/1e6) :
 				 snprintf(c_buf1,sizeof(c_buf1),"%gms",(double)(i_h%1000000)/1000.);
-		int wdth;
-		if( c_buf[0] && (h_pos+gdFontTiny->w*strlen(c_buf)/2) < endMarkBrd )
+		int wdth, tpos, endPosTm = 0, endPosDt = 0;
+		if( c_buf[0] )
 		{
-		    wdth = gdFontTiny->w*strlen(c_buf)/2;
-		    gdImageString(im,gdFontTiny,vmax(h_pos-wdth,hv_border),v_w_start+v_w_size+3+gdFontTiny->h,(unsigned char *)c_buf,clr_symb);
+		    wdth = gdFontTiny->w*strlen(c_buf);
+		    tpos = vmax(h_pos-wdth/2,hv_border);
+		    if( (tpos+wdth) < endMarkBrd && tpos > begMarkBrd )
+		    {
+			gdImageString(im,gdFontTiny,tpos,v_w_start+v_w_size+3+gdFontTiny->h,(unsigned char *)c_buf,clr_symb);
+			endPosTm = tpos+wdth;
+		    }
 		}
-		if( c_buf1[0] && (h_pos+gdFontTiny->w*strlen(c_buf1)/2) < endMarkBrd )
-		{
-		    wdth = gdFontTiny->w*strlen(c_buf1)/2;
-		    gdImageString(im,gdFontTiny,vmax(h_pos-wdth,hv_border),v_w_start+v_w_size+3,(unsigned char *)c_buf1,clr_symb);
+		if( c_buf1[0] )
+		{		
+		    wdth = gdFontTiny->w*strlen(c_buf1);
+		    tpos = vmax(h_pos-wdth/2,hv_border);
+		    if( (tpos+wdth) < endMarkBrd && tpos > begMarkBrd )
+		    {
+			gdImageString(im,gdFontTiny,tpos,v_w_start+v_w_size+3,(unsigned char *)c_buf1,clr_symb);
+			endPosDt = tpos+wdth;
+		    }
 		}
-		
+		begMarkBrd = vmax(begMarkBrd,vmax(endPosTm,endPosDt));
 		memcpy((char*)&ttm1,(char*)ttm,sizeof(tm));
 		first_m = false;
 	    }
@@ -1316,12 +1354,17 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
 	v_min = vmin(v_min,c_val);
 	v_max = vmax(v_max,c_val);
     }
-    if(v_max==-3e300)	return rez;
-    if(v_max==v_min)	{ v_max+=1.; v_min-=1.; }
+    if(valmax!=valmin)
+    {
+	v_max = vmax(v_max,valmax);
+	v_min = vmin(v_min,valmin);
+    }
+    if( v_max==-3e300 )	{ gdImageDestroy(im); return rez; }
+    if( TSYS::realRound(v_max,3) == TSYS::realRound(v_min,3) )	{ v_max+=1.0; v_min-=1.0; }
     double v_div = 1.;
     double v_len = v_max - v_min;
-    while(v_len>=10.){ v_div*=10.; v_len/=10.; }
-    while(v_len<1.) { v_div/=10.; v_len*=10.; }
+    while(v_len>=10.)	{ v_div*=10.; v_len/=10.; }
+    while(v_len<1.) 	{ v_div/=10.; v_len*=10.; }
     v_min = floor(v_min/v_div)*v_div;    
     v_max = ceil(v_max/v_div)*v_div;
     while(((v_max-v_min)/v_div)<5) v_div/=2;
@@ -1331,8 +1374,8 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
 	int v_pos = v_w_start+v_w_size-(int)((double)v_w_size*(i_v-v_min)/(v_max-v_min));
 	gdImageLine(im,h_w_start,v_pos,h_w_start+h_w_size,v_pos,clr_grid);
 	
-	snprintf(c_buf,sizeof(c_buf),"%.*f",fmod(i_v,1)?2:0,i_v);
-	gdImageString(im,gdFontTiny,hv_border+2,v_pos-((i_v==v_max)?0:gdFontTiny->h),(unsigned char *)c_buf,clr_symb);
+	snprintf(c_buf,sizeof(c_buf),"%g",i_v);
+	gdImageString(im,gdFontTiny,hv_border+2,v_pos-((i_v>=v_max)?0:gdFontTiny->h),(unsigned char *)c_buf,clr_symb);
     }    
     
     //-- Draw trend --
@@ -1342,13 +1385,13 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
     long long aver_lsttm = 0;
     double prev_vl = EVAL_REAL;
     int    prev_pos = 0;
-    for(c_tm = buf.begin();true;c_tm++)
+    for( c_tm = buf.begin(); true; c_tm++ )
     {
 	int c_pos;
 	if(c_tm <= buf.end())
 	{
 	    c_val = buf.getR(&c_tm,true);
-	    c_pos = h_w_start+h_w_size*(c_tm-h_min)/(h_max-h_min);
+	    c_pos = h_w_start+h_w_size*(vmax(vmin(c_tm,h_max),h_min)-h_min)/(h_max-h_min);
 	}else c_pos = 0;
 	//Square Average
 	if( aver_pos == c_pos )
@@ -1385,7 +1428,7 @@ string TVArchive::makeTrendImg( long long ibeg, long long iend, const string &ia
     rez.assign(img_ptr,img_sz);
     gdFree(img_ptr);
     gdImageDestroy(im);
-    
+
     return rez;
 }
 
@@ -1526,7 +1569,7 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
 		{
 		    float round_perc = atof(opt->attr("round_perc").c_str());
 		    int   real_prec  = atoi(opt->attr("real_prec").c_str());
-		    if( !real_prec ) real_prec = 6;
+		    if( !real_prec ) real_prec = 10;
 		    double tval_pr = EVAL_REAL, tval_pr1;
 		    while( ibeg <= iend )
 		    {
@@ -1604,7 +1647,7 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
     string grp = owner().subId();
     if( opt->name() == "info" )
     {
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Value archive: ")+name());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Value archive: ")+name(),0664,"root",grp.c_str());
 	if(ctrMkNode("area",opt,-1,"/prm",_("Archive")))
 	{
 	    if(ctrMkNode("area",opt,-1,"/prm/st",_("State")))
@@ -1626,8 +1669,6 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
 		ctrMkNode("fld",opt,-1,"/prm/cfg/b_size",cfg("BSIZE").fld().descr(),0664,"root",grp.c_str(),1,"tp","dec");
 		ctrMkNode("fld",opt,-1,"/prm/cfg/b_hgrd",cfg("BHGRD").fld().descr(),0664,"root",grp.c_str(),1,"tp","bool");
 		ctrMkNode("fld",opt,-1,"/prm/cfg/b_hres",cfg("BHRES").fld().descr(),0664,"root",grp.c_str(),1,"tp","bool");
-		ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660,"root",grp.c_str());
-		ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660,"root",grp.c_str());
 	    }
 	}
 	if(ctrMkNode("area",opt,-1,"/arch",_("Archivators"),0444,"root",grp.c_str()))
@@ -1660,7 +1701,9 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
 	    else 
 	    {
 		ctrMkNode("fld",opt,-1,"/val/pct_w",_("Picture size"),0660,"root",grp.c_str(),3,"tp","dec","min","100","max","1024");
-		ctrMkNode("fld",opt,-1,"/val/pct_h","",0660,"root",grp.c_str(),3,"tp","dec","min","50","max","800");	    
+		ctrMkNode("fld",opt,-1,"/val/pct_h","",0660,"root",grp.c_str(),3,"tp","dec","min","50","max","800");
+		ctrMkNode("fld",opt,-1,"/val/max",_("Value scale"),0660,"root",grp.c_str(),1,"tp","dec");
+		ctrMkNode("fld",opt,-1,"/val/min","",0660,"root",grp.c_str(),1,"tp","dec");		
 		ctrMkNode("img",opt,-1,"/val/trend",_("Values trend"),0440,"root",grp.c_str());
 	    }
 	}
@@ -1669,29 +1712,29 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
     //-- Process command to page --
     if( a_path == "/prm/st/st" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(run_st?"1":"0");
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	atoi(opt->text().c_str())?start():stop();
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText( startStat() ? "1" : "0" );
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	atoi(opt->text().c_str()) ? start() : stop();
     }	
     else if( a_path == "/prm/st/db" )
     {
-	if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )	opt->setText(m_db);
-	if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	m_db = opt->text();
+	if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )	opt->setText( DB() );
+	if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	setDB( opt->text() );
     }	
     else if( a_path == "/prm/cfg/id" && ctrChkNode(opt) )	opt->setText(id());
     else if( a_path == "/prm/cfg/nm" )	
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(name());
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_name = opt->text();
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText( name() );
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setName( opt->text() );
     }
     else if( a_path == "/prm/cfg/dscr" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(dscr());
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_dscr = opt->text();
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText( dscr() );
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setDscr( opt->text() );
     }
     else if( a_path == "/prm/cfg/start" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(m_start?"1":"0");
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	m_start = atoi(opt->text().c_str());
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText( toStart() ? "1" : "0" );
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	setToStart( atoi(opt->text().c_str()) );
     }
     else if( a_path == "/prm/cfg/vtp" )
     {
@@ -1728,8 +1771,6 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) ) opt->setText(m_bhres?"1":"0");
 	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) ) setHighResTm(atoi(opt->text().c_str()));
     }
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) ) load();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) ) save();
     else if( a_path == "/cfg/vtp_ls" && ctrChkNode(opt) )
     {
     	opt->childAdd("el")->setAttr("id",TSYS::int2str(TFld::Boolean))->setText(_("Boolean"));
@@ -1818,7 +1859,11 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )
         {
 	    if( opt->attr("col") == "proc" )
-		atoi(opt->text().c_str())?archivatorAttach(opt->attr("key_arch")):archivatorDetach(opt->attr("key_arch"),true);
+	    {
+		atoi(opt->text().c_str()) ? archivatorAttach( opt->attr("key_arch") ) : 
+					    archivatorDetach( opt->attr("key_arch"), true );
+		modif();
+	    }
 	}    	
     }
     else if( a_path == "/val/tm" )
@@ -1828,7 +1873,8 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
 	    opt->setText(TBDS::genDBGet(owner().nodePath()+"vaTm","0",opt->attr("user")));
 	    if( !atoi(opt->text().c_str()) )	opt->setText(TSYS::int2str(time(NULL)));
 	}
-        if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	TBDS::genDBSet(owner().nodePath()+"vaTm",opt->text(),opt->attr("user"));
+        if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )
+	    TBDS::genDBSet(owner().nodePath()+"vaTm",(atoi(opt->text().c_str())>=time(NULL))?"0":opt->text(),opt->attr("user"));
     }
     else if( a_path == "/val/utm" )
     {
@@ -1859,11 +1905,21 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
     {
         if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )	opt->setText(TBDS::genDBGet(owner().nodePath()+"vPctH","230",opt->attr("user")));
         if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	TBDS::genDBSet(owner().nodePath()+"vPctH",opt->text(),opt->attr("user"));
+    }
+    else if( a_path == "/val/max" )
+    {
+        if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )	opt->setText(TBDS::genDBGet(owner().nodePath()+"vMax","0",opt->attr("user")));
+        if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	TBDS::genDBSet(owner().nodePath()+"vMax",opt->text(),opt->attr("user"));
+    }
+    else if( a_path == "/val/min" )
+    {
+        if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )	opt->setText(TBDS::genDBGet(owner().nodePath()+"vMin","0",opt->attr("user")));
+        if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	TBDS::genDBSet(owner().nodePath()+"vMin",opt->text(),opt->attr("user"));
     }    
     else if( a_path == "/val/val" && ctrChkNode(opt,"get",0440,"root",grp.c_str(),SEQ_RD) )
     {
 	long long end = (long long)atoi(TBDS::genDBGet(owner().nodePath()+"vaTm","0",opt->attr("user")).c_str())*1000000;
-	if( !end ) end = (long long)time(NULL) * 1000000;
+	if( !(end/1000000) ) end = (long long)time(NULL) * 1000000;
 	end += atoi(TBDS::genDBGet(owner().nodePath()+"vaTm_u","0",opt->attr("user")).c_str());
 	long long beg = end - (long long)(atof(TBDS::genDBGet(owner().nodePath()+"vaSize","1",opt->attr("user")).c_str())*1e6);
 	
@@ -1894,13 +1950,17 @@ void TVArchive::cntrCmdProc( XMLNode *opt )
     {
 	int vPctW = vmin(1024,vmax(100,atoi(TBDS::genDBGet(owner().nodePath()+"vPctW","650",opt->attr("user")).c_str())));
 	int vPctH = vmin(800,vmax(50,atoi(TBDS::genDBGet(owner().nodePath()+"vPctH","230",opt->attr("user")).c_str())));
+	double vMax = atof(TBDS::genDBGet(owner().nodePath()+"vMax","0",opt->attr("user")).c_str());
+	double vMin = atof(TBDS::genDBGet(owner().nodePath()+"vMin","0",opt->attr("user")).c_str());
 	long long end = (long long)atoi(TBDS::genDBGet(owner().nodePath()+"vaTm",TSYS::int2str(time(NULL)),opt->attr("user")).c_str())*1000000+
 	                     atoi(TBDS::genDBGet(owner().nodePath()+"vaTm_u","0",opt->attr("user")).c_str());
+	if( !(end/1000000) )	end = (long long)time(NULL) * 1000000;
 	long long beg = end - (long long)(atof(TBDS::genDBGet(owner().nodePath()+"vaSize","1",opt->attr("user")).c_str())*1e6);
 	
-        opt->setText(TSYS::strEncode(makeTrendImg(beg,end,TBDS::genDBGet(owner().nodePath()+"vArch","",opt->attr("user")),vPctW,vPctH),TSYS::base64));
+        opt->setText(TSYS::strEncode(makeTrendImg(beg,end,TBDS::genDBGet(owner().nodePath()+"vArch","",opt->attr("user")),vPctW,vPctH,vMax,vMin),TSYS::base64));
         opt->setAttr("tp","png");
     }
+    else TCntrNode::cntrCmdProc(opt);
 }
 
 //*************************************************
@@ -1922,6 +1982,23 @@ TVArchivator::TVArchivator( const string &iid, const string &idb, TElem *cf_el )
     timer_create(CLOCK_REALTIME,&sigev,&tmId);                        
 }
 
+TCntrNode &TVArchivator::operator=( TCntrNode &node )
+{
+    TVArchivator *src_n = dynamic_cast<TVArchivator*>(&node);
+    if( !src_n ) return *this;
+
+    //- Configuration copy -
+    string tid = id();
+    *(TConfig*)this = *(TConfig*)src_n;
+    m_id = tid;
+    m_db = src_n->m_db;
+
+    if( src_n->startStat() && toStart() && !startStat() )
+        start( );
+
+    return *this;
+}					    
+
 TVArchivator::~TVArchivator()
 {
     timer_delete(tmId);
@@ -1939,12 +2016,14 @@ string TVArchivator::tbl( )
 
 void TVArchivator::setValPeriod( double iper )
 {     
-    m_v_per = iper?iper:1.;
+    m_v_per = iper ? iper : 1.;
     
     //- Call sort for all archives -
     ResAlloc res(a_res,false);
     for( int i_l = 0; i_l < arch_el.size(); i_l++ )
         arch_el[i_l]->archive().archivatorSort();
+    
+    modif();
 }
 
 void TVArchivator::postEnable(int flag)
@@ -2057,12 +2136,12 @@ TTipArchivator &TVArchivator::owner()
     return *(TTipArchivator *)nodePrev(); 
 }
 
-void TVArchivator::load( )
+void TVArchivator::load_( )
 {
     SYS->db().at().dataGet(fullDB(),SYS->archive().at().nodePath()+tbl(),*this);
 }
 
-void TVArchivator::save( )
+void TVArchivator::save_( )
 {
     SYS->db().at().dataSet(fullDB(),SYS->archive().at().nodePath()+tbl(),*this);
 }
@@ -2182,7 +2261,7 @@ void TVArchivator::Task(union sigval obj)
 
 void TVArchivator::setArchPeriod( int iper )
 {    
-    m_a_per = iper?iper:1;
+    m_a_per = iper ? iper : 1;
     if( startStat() )
     {
 	struct itimerspec itval;
@@ -2190,6 +2269,8 @@ void TVArchivator::setArchPeriod( int iper )
 	itval.it_interval.tv_nsec = itval.it_value.tv_nsec = 0;
 	timer_settime(tmId, 0, &itval, NULL);
     }
+    
+    modif();
 }
 
 void TVArchivator::cntrCmdProc( XMLNode *opt )
@@ -2198,7 +2279,7 @@ void TVArchivator::cntrCmdProc( XMLNode *opt )
     //- Get page info -
     if( opt->name() == "info" )
     {
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Value archivator: ")+name());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Value archivator: ")+name(),0664,"root",grp.c_str());
 	if(ctrMkNode("area",opt,-1,"/prm",_("Archivator")))
 	{
 	    if(ctrMkNode("area",opt,-1,"/prm/st",_("State")))
@@ -2216,8 +2297,6 @@ void TVArchivator::cntrCmdProc( XMLNode *opt )
 		ctrMkNode("fld",opt,-1,"/prm/cfg/aper",cfg("A_PER").fld().descr(),0664,"root",grp.c_str(),1,"tp","dec");
 		ctrMkNode("fld",opt,-1,"/prm/cfg/addr",cfg("ADDR").fld().descr(),0664,"root",grp.c_str(),1,"tp","str");
 		ctrMkNode("fld",opt,-1,"/prm/cfg/start",_("To start"),0664,"root",grp.c_str(),1,"tp","bool");
-		ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660,"root",grp.c_str());
-		ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660,"root",grp.c_str());
 	    }
 	}
 	if(ctrMkNode("area",opt,-1,"/arch",_("Archives")))
@@ -2234,35 +2313,35 @@ void TVArchivator::cntrCmdProc( XMLNode *opt )
     string a_path = opt->attr("path");
     if( a_path == "/prm/st/st" )
     {
-        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText(run_st?"1":"0");
-        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      atoi(opt->text().c_str())?start():stop();
+        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText( startStat() ? "1" : "0" );
+        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      atoi(opt->text().c_str()) ? start() : stop();
     }
     else if( a_path == "/prm/st/tarch" && ctrChkNode(opt) )	opt->setText(TSYS::real2str(tm_calc,6));
     else if( a_path == "/prm/st/db" )
     {
-	if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )      opt->setText(m_db);
-        if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )      m_db = opt->text();
+	if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )      opt->setText( DB() );
+        if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )      setDB( opt->text() );
     }
     else if( a_path == "/prm/cfg/id" && ctrChkNode(opt) )       opt->setText(id());
     else if( a_path == "/prm/cfg/nm" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText(name());
-        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      m_name = opt->text();
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText( name() );
+        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      setName( opt->text() );
     }
     else if( a_path == "/prm/cfg/dscr" )
     {
-        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText(dscr());
-        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      m_dscr = opt->text();
+        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText( dscr() );
+        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      setDscr( opt->text() );
     }
     else if( a_path == "/prm/cfg/addr" )
     {
-        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText(m_addr);
-        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      m_addr = opt->text();
+        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText( addr() );
+        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      setAddr( opt->text() );
     }    
     else if( a_path == "/prm/cfg/start" )
     {
-        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText(m_start?"1":"0");
-        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      m_start = atoi(opt->text().c_str());
+        if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )      opt->setText( toStart() ? "1" : "0" );
+        if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )      setToStart( atoi(opt->text().c_str()) );
     }																					    
     else if( a_path == "/prm/cfg/vper" )	
     {
@@ -2271,8 +2350,8 @@ void TVArchivator::cntrCmdProc( XMLNode *opt )
     }	
     else if( a_path == "/prm/cfg/aper" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) ) opt->setText(TSYS::int2str(archPeriod()));
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) ) setArchPeriod(atoi(opt->text().c_str()));
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) ) 	opt->setText(TSYS::int2str(archPeriod()));
+	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) ) 	setArchPeriod(atoi(opt->text().c_str()));
     }
     else if( a_path == "/arch/arch" && ctrChkNode(opt) )
     {
@@ -2289,8 +2368,7 @@ void TVArchivator::cntrCmdProc( XMLNode *opt )
 	    if(n_size)	n_size->childAdd("el")->setText(TSYS::int2str(arch_el[i_l]->archive().size()));
 	}
     }
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_RD) )       load();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_RD) )       save();
+    else TCntrNode::cntrCmdProc(opt);
 }
 
 //*************************************************
