@@ -95,11 +95,11 @@ class TValBuf
 	    public:
 		//Public methods
 		TBuf( TpVal eval, int &isz, long long &ipr, bool &ihgrd, bool &ihres, long long& iend, long long& ibeg );
-		~TBuf();
+		~TBuf( );
 		
-		void clear();
+		void clear( );
 		
-		int realSize();
+		int realSize( );
 
 		TpVal get( long long *tm = NULL, bool up_ord = false );
 		void  set( TpVal value, long long tm = 0 );
@@ -162,6 +162,8 @@ class TVArchive : public TCntrNode, public TValBuf, public TConfig
 	//Public methods
 	TVArchive( const string &id, const string &db, TElem *cf_el );
 	~TVArchive( );
+
+	TCntrNode &operator=( TCntrNode &node );
 	
 	//- Base functions -
 	const string &id( )	{ return m_id; }
@@ -184,10 +186,12 @@ class TVArchive : public TCntrNode, public TValBuf, public TConfig
 	int size( )		{ return TValBuf::size(); }
         long long period( )	{ return TValBuf::period(); }
 	
-	void setName( const string &inm )	{ m_name = inm; }
-        void setDscr( const string &idscr )	{ m_dscr = idscr; }
+	void setName( const string &inm )	{ m_name = inm; modif(); }
+        void setDscr( const string &idscr )	{ m_dscr = idscr; modif(); }
 	void setSrcMode( SrcMode vl, const string &isrc = "" );
-	void setToStart( bool vl )		{ m_start = vl; }
+	void setToStart( bool vl )		{ m_start = vl; modif(); }
+	
+	void setDB( const string &idb )		{ m_db = idb; modifG(); }
 	
 	void setValType( TFld::Type vl );
         void setHardGrid( bool vl );
@@ -196,8 +200,6 @@ class TVArchive : public TCntrNode, public TValBuf, public TConfig
         void setPeriod( long long vl );
 	
 	//- Service -
-	void load( );
-        void save( );
 	void start( );
 	void stop( bool full_del = false );
 	
@@ -212,28 +214,33 @@ class TVArchive : public TCntrNode, public TValBuf, public TConfig
 	void setVal( TValBuf &buf, long long beg, long long end, const string &arch );
     	
 	//- Active get data from atribute -
-	void getActiveData();
+	void getActiveData( );
 	
 	//- Phisical archivator's functions -
 	void archivatorList( vector<string> &ls );
 	bool archivatorPresent( const string &arch );
 	void archivatorAttach( const string &arch );
 	void archivatorDetach( const string &arch, bool full = false );
-	void archivatorSort();
+	void archivatorSort( );
 	
-	string makeTrendImg( long long beg, long long end, const string &arch, int hsz = 650, int vsz = 230 );
+	string makeTrendImg( long long beg, long long end, const string &arch, int hsz = 650, int vsz = 230, double valmax = 0, double valmin = 0 );
 	
-	TArchiveS &owner();
+	TArchiveS &owner( );
 
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
+
+    protected:
+	//Protected methods
+	void preDisable( int flag );
+	void postDisable( int flag );	
 	
+	void load_( );
+        void save_( );
+
     private:
 	//Private methods
-	void preDisable(int flag);
-	void postDisable(int flag);
-    
-	void setUpBuf();
-	string nodeName()	{ return m_id; }
+	void setUpBuf( );
+	string nodeName( )	{ return m_id; }
     
 	//Private attributes
 	Res     a_res;
@@ -275,6 +282,8 @@ class TVArchivator : public TCntrNode, public TConfig
 	TVArchivator( const string &id, const string &db, TElem *cf_el );
 	~TVArchivator( );
 
+	TCntrNode &operator=( TCntrNode &node );
+
 	const string &id( ) 	{ return m_id; }
 	string workId( );
 	string name( );
@@ -290,14 +299,15 @@ class TVArchivator : public TCntrNode, public TConfig
 	string tbl( );
 	string fullDB( )        { return DB()+'.'+tbl(); }			
 	
-	void setName( const string &inm )	{ m_name = inm; }
-        void setDscr( const string &idscr )	{ m_dscr = idscr; }
-	void setAddr( const string &vl )	{ m_addr = vl; }
+	void setName( const string &inm )	{ m_name = inm; modif(); }
+        void setDscr( const string &idscr )	{ m_dscr = idscr; modif(); }
+	void setAddr( const string &vl )	{ m_addr = vl; modif(); }
 	virtual void setValPeriod( double per );
 	virtual void setArchPeriod( int per );
-	
-	virtual void load( );
-	virtual void save( );
+	void setToStart( bool vl )		{ m_start = vl; modif(); }
+
+	void setDB( const string &idb )		{ m_db = idb; modif(); }
+
 	virtual void start( );
 	virtual void stop( bool full_del = false );
 	
@@ -305,7 +315,7 @@ class TVArchivator : public TCntrNode, public TConfig
 	void archiveList( vector<string> &ls );
 	bool archivePresent( const string &iid );
 	
-	TTipArchivator &owner();
+	TTipArchivator &owner( );
 
     protected:
 	//Protected methods
@@ -318,7 +328,10 @@ class TVArchivator : public TCntrNode, public TConfig
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process    
 	void postEnable( int flag );
 	void preDisable( int flag );
-	void postDisable( int flag );     //Delete all DB if flag 1	
+	void postDisable( int flag );     	//Delete all DB if flag 1	
+
+	void load_( );
+	void save_( );
 	
 	//Protected attributes
 	Res	a_res;
@@ -328,8 +341,8 @@ class TVArchivator : public TCntrNode, public TConfig
 
     private:
 	//Private methods
-        string nodeName()       { return m_id; }
-	static void Task(union sigval obj);     //Process task
+        string nodeName( )	{ return m_id; }
+	static void Task( union sigval obj );	//Process task
 
 	//Private attributes
 	string	&m_id,		//Var arch id
@@ -376,7 +389,7 @@ class TVArchEl
 	TVArchivator &archivator( );
 	
 	//Public atributes
-        // - Previous averaging value -
+        //- Previous averaging value -
         long long prev_tm;
         string prev_val;
 	
