@@ -236,7 +236,8 @@ bool TBDS::dataSet( const string &bdn, const string &path, TConfig &cfg )
         try{ tbl.at().fieldSet(cfg); }
 	catch(TError err) { mess_warning(err.cat.c_str(),"%s",err.mess.c_str()); db_true = false; }
 	tbl.free();
-        close(bdn);		
+        try{ close(bdn); } 
+	catch(TError err) { mess_warning(err.cat.c_str(),"%s",err.mess.c_str()); }
 	return db_true;
     }
     //Load from Config file if tbl no present
@@ -335,18 +336,19 @@ string TBDS::genDBGet(const string &path, const string &oval, const string &user
     bool bd_ok=false;
     string rez = oval;
     
-    if(SYS->present("BD"))
+    if( SYS->present("BD") )
     {	
 	AutoHD<TBDS> dbs = SYS->db();
-	//Get from cache
+
+	//- Get from cache -
 	ResAlloc res(dbs.at().genDBCacheRes,false);
 	for( int i_cel = 0; i_cel < dbs.at().genDBCache.size(); i_cel++ )
 	    if( dbs.at().genDBCache[i_cel]->cfg("user").getS() == user && 
-		    dbs.at().genDBCache[i_cel]->cfg("id").getS() == path )
-		return dbs.at().genDBCache[i_cel]->cfg("val").getS();
+			dbs.at().genDBCache[i_cel]->cfg("id").getS() == path )
+	        return dbs.at().genDBCache[i_cel]->cfg("val").getS();
 	res.release();
-    
-	//Get from generic DB
+
+	//- Get from generic DB -
 	if(!onlyCfg)
 	{
 	    AutoHD<TTable> tbl = dbs.at().open(SYS->db().at().fullDBSYS());
@@ -368,13 +370,13 @@ string TBDS::genDBGet(const string &path, const string &oval, const string &user
 	    }      
 	}
     }
-    //Get from config file
+    //- Get from config file -
     if(!bd_ok)	
 	try{ rez = SYS->ctrId(&SYS->cfgRoot(),path)->text(); }
 	catch(...){ }
 
     //Put to cache    
-    if(SYS->present("BD"))
+    if( SYS->present("BD") )
     {    
 	AutoHD<TBDS> dbs = SYS->db();
 	ResAlloc res(dbs.at().genDBCacheRes,true);
@@ -404,7 +406,7 @@ string TBDS::optDescr(  )
     return(buf);
 }
 
-void TBDS::subLoad( )
+void TBDS::load_( )
 {
     //- Load parameters from command line -
     int next_opt;
@@ -460,40 +462,6 @@ void TBDS::subLoad( )
 	mess_err(err.cat.c_str(),"%s",err.mess.c_str());
 	mess_err(nodePath().c_str(),_("Search and open new DB error."));
     }    
-    
-    //- Load and enable DB -
-    vector<string> t_lst, o_lst;
-    modList(t_lst);
-    for( int i_t = 0; i_t < t_lst.size(); i_t++ )
-    {
-        AutoHD<TTipBD> mod = at(t_lst[i_t]);
-        mod.at().list(o_lst);
-        for( int i_o = 0; i_o < o_lst.size(); i_o++ )
-	    try
-	    {	
-		mod.at().at(o_lst[i_o]).at().load();
-		if( !mod.at().at(o_lst[i_o]).at().enableStat() && mod.at().at(o_lst[i_o]).at().toEnable() )
-        	    mod.at().at(o_lst[i_o]).at().enable(); 
-	    } catch(...){ }	
-    }
-
-    //- Load modules -
-    TSubSYS::subLoad();
-}
-
-void TBDS::subSave( )
-{
-    vector<string> t_lst, o_lst;
-    
-    //Opened DB save to DB
-    modList(t_lst);
-    for( int i_t = 0; i_t < t_lst.size(); i_t++ )
-    {
-        AutoHD<TTipBD> mod = at(t_lst[i_t]);
-        mod.at().list(o_lst);
-        for( int i_o = 0; i_o < o_lst.size(); i_o++ )
-            mod.at().at(o_lst[i_o]).at().save();
-    }
 }
 
 void TBDS::cntrCmdProc( XMLNode *opt )
@@ -502,83 +470,12 @@ void TBDS::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
 	TSubSYS::cntrCmdProc(opt);
-	if(ctrMkNode("area",opt,0,"/sub",_("Subsystem"),0444,"root",subId().c_str()))
-	{
-	    ctrMkNode("comm",opt,-1,"/sub/load_db",_("Load"),0660,"root",subId().c_str());
-    	    ctrMkNode("comm",opt,-1,"/sub/upd_db",_("Save"),0660,"root",subId().c_str());
-	}
-	if(ctrMkNode("area",opt,2,"/db_serv",_("DB service"),0440,"root",subId().c_str()))
-	    if(ctrMkNode("comm",opt,-1,"/db_serv/copy",_("Copy DB/Table"),0660,"root",subId().c_str()))
-            {
-                ctrMkNode("fld",opt,-1,"/db_serv/copy/src",_("Source"),0660,"root",subId().c_str(),3,"tp","str","dest","sel_ed","select","/db_serv/dblst");
-	        ctrMkNode("fld",opt,-1,"/db_serv/copy/dst",_("Destination"),0660,"root",subId().c_str(),3,"tp","str","dest","sel_ed","select","/db_serv/dblst");
-    	    }
 	ctrMkNode("fld",opt,-1,"/help/g_help",_("Options help"),0440,"root",subId().c_str(),3,"tp","str","cols","90","rows","10");
 	return;
     }
     //Process command to page
     string a_path = opt->attr("path");
     if( a_path == "/help/g_help" && ctrChkNode(opt,"get",0440,"root",subId().c_str(),SEQ_RD) ) 		opt->setText(optDescr());
-    else if( a_path == "/sub/load_db" && ctrChkNode(opt,"set",0660,"root",subId().c_str(),SEQ_WR) )	subLoad();
-    else if( a_path == "/sub/upd_db" && ctrChkNode(opt,"set",0660,"root",subId().c_str(),SEQ_WR) )	subSave();
-    else if( a_path == "/db_serv/copy" && ctrChkNode(opt,"set",0660,"root",subId().c_str(),SEQ_WR) )
-    {
-	//- Get parameters -
-	string dbsrc  = ctrId(opt,"src")->text();
-	string dbdest = ctrId(opt,"dst")->text();
-	string dbstbl = TSYS::strSepParse(dbsrc,2,'.');
-	string dbdtbl = TSYS::strSepParse(dbdest,2,'.');
-	vector<string>	tbl_ls;
-	
-	//- Check parameters -
-	if( !dbstbl.empty() && dbdtbl.empty() ) dbdtbl = dbstbl;
-	if( dbstbl.empty() && !dbdtbl.empty() )
-	    throw TError(nodePath().c_str(),_("Copy full DB to one table no allow."));
-	
-	//- Connect to source and destination DB -
-	AutoHD<TBD> sdb = at(TSYS::strSepParse(dbsrc,0,'.')).at().at(TSYS::strSepParse(dbsrc,1,'.'));
-	AutoHD<TBD> ddb = at(TSYS::strSepParse(dbdest,0,'.')).at().at(TSYS::strSepParse(dbdest,1,'.'));
-	
-	//- Tables process -
-	if( !dbstbl.empty() )	tbl_ls.push_back(dbstbl);
-	else sdb.at().allowList(tbl_ls);	
-	for( int i_l = 0; i_l < tbl_ls.size(); i_l++ )
-	{
-	    //-- Open source and destination tables --
-	    sdb.at().open(tbl_ls[i_l], false);
-	    ddb.at().open(dbdtbl.empty() ? tbl_ls[i_l] : dbdtbl, true);
-	    AutoHD<TTable> stbl = sdb.at().at(tbl_ls[i_l]);
-	    AutoHD<TTable> dtbl = ddb.at().at(dbdtbl.empty() ? tbl_ls[i_l] : dbdtbl);
-	    TConfig req;
-	    stbl.at().fieldStruct(req);
-	    //-- Scan source table and write to destination table
-	    for( int row = 0; stbl.at().fieldSeek(row,req); row++ )
-	    {
-		dtbl.at().fieldSet(req);
-		//--- Clear key fields ---
-		for( int i_e = 0; i_e < req.elem().fldSize(); i_e++ )
-		    if( req.elem().fldAt(i_e).flg()&TCfg::Key )
-			req.cfg(req.elem().fldAt(i_e).name()).setS("");
-	    }
-		
-	    //-- Close source and destination tables --
-	    stbl.free();
-	    dtbl.free();
-	    sdb.at().close(tbl_ls[i_l]);
-	    ddb.at().close(dbdtbl.empty() ? tbl_ls[i_l] : dbdtbl);
-	}
-    }
-    else if( a_path == "/db_serv/dblst" && ctrChkNode(opt) )
-    {
-	vector<string> mls, dbls;
-	modList(mls);
-	for( int i_m = 0; i_m < mls.size(); i_m++ )
-	{
-	    at(mls[i_m]).at().list(dbls);
-	    for( int i_db = 0; i_db < dbls.size(); i_db++ )
-		opt->childAdd("el")->setText(mls[i_m]+"."+dbls[i_db]);
-	}
-    }
     else TSubSYS::cntrCmdProc(opt);
 }
 
@@ -608,11 +505,11 @@ void TTipBD::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
 	TModule::cntrCmdProc(opt);
-	ctrMkNode("grp",opt,-1,"/br/db_",_("Opened DB"),0444,"root","root",1,"list","/db/odb");
+	ctrMkNode("grp",opt,-1,"/br/db_",_("DB"),0664,"root",grp.c_str(),1,"idm","1");
 	if(ctrMkNode("area",opt,0,"/db",_("DB"),0444))
 	{
 	    ctrMkNode("fld",opt,-1,"/db/ful_db_del",_("Full DB delete"),0660,"root",grp.c_str(),1,"tp","bool");
-	    ctrMkNode("list",opt,-1,"/db/odb",_("Opened DB"),0664,"root",grp.c_str(),4,"tp","br","idm","1","s_com","add,del","br_pref","db_");
+	    ctrMkNode("list",opt,-1,"/db/odb",_("DB"),0664,"root",grp.c_str(),4,"tp","br","idm","1","s_com","add,del","br_pref","db_");
 	}
 	return;
     }
@@ -624,7 +521,7 @@ void TTipBD::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"get",0660,"root",grp.c_str(),SEQ_RD) )	opt->setText(full_db_del?"1":"0");
 	if( ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	full_db_del = atoi(opt->text().c_str());
     }	
-    else if( a_path == "/db/odb" )
+    else if( a_path == "/br/db_" || a_path == "/db/odb" )
     {
 	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )
 	{
@@ -648,16 +545,42 @@ void TTipBD::cntrCmdProc( XMLNode *opt )
 //************************************************
 TBD::TBD( const string &iid, TElem *cf_el ) : TConfig( cf_el ),
     m_id(cfg("ID").getSd()), m_name(cfg("NAME").getSd()), m_dscr(cfg("DESCR").getSd()), 
-    m_addr(cfg("ADDR").getSd()), m_codepage(cfg("CODEPAGE").getSd()), m_toen(cfg("EN").getBd()), 
-    m_creat(false), m_en(false)
+    m_addr(cfg("ADDR").getSd()), m_codepage(cfg("CODEPAGE").getSd()), m_toen(cfg("EN").getBd()), m_en(false)
 {
     m_id = iid;
     m_tbl = grpAdd("tbl_");
 }
 
-void TBD::postEnable( int flag )
+TCntrNode &TBD::operator=( TCntrNode &node )
 {
-    cfg("TYPE").setS(owner().modId());
+    TBD *src_n = dynamic_cast<TBD*>(&node);
+    if( !src_n ) return *this;
+	
+    if( !enableStat() )
+    {
+	string tid = id();
+	*(TConfig*)this = *(TConfig*)src_n;
+	m_id = tid;
+    }
+
+    if( src_n->enableStat() && enableStat() )
+    {
+	vector<string>	tbl_ls;    
+	src_n->allowList(tbl_ls);
+	for( int i_l = 0; i_l < tbl_ls.size(); i_l++ )
+	{
+	    //-- Open source and destination tables --
+	    src_n->open(tbl_ls[i_l], false);
+	    open(tbl_ls[i_l], true);
+	    //-- Copy table --
+	    (TCntrNode&)at(tbl_ls[i_l]).at() = (TCntrNode&)src_n->at(tbl_ls[i_l]).at();
+	    //-- Close source and destination tables --
+	    src_n->close(tbl_ls[i_l]);
+	    close(tbl_ls[i_l]);
+	}    
+    }
+			
+    return *this;
 }
 
 TBD::~TBD()
@@ -665,6 +588,11 @@ TBD::~TBD()
 
 }
 
+void TBD::postEnable( int flag )
+{
+    cfg("TYPE").setS(owner().modId());
+}
+
 void TBD::preDisable(int flag)
 {
     disable();
@@ -710,12 +638,13 @@ void TBD::open( const string &table, bool create )
     chldAdd(m_tbl,openTable(table, create)); 
 }
 
-void TBD::load( )
+void TBD::load_( )
 {
     SYS->db().at().dataGet(owner().owner().fullDB(),SYS->db().at().nodePath()+"DB/",*this);
+    if( !enableStat() && toEnable() )	enable();
 }
 
-void TBD::save( )
+void TBD::save_( )
 {
     SYS->db().at().dataSet(owner().owner().fullDB(),SYS->db().at().nodePath()+"DB/",*this);
 }
@@ -726,16 +655,15 @@ void TBD::cntrCmdProc( XMLNode *opt )
     //Get page info
     if( opt->name() == "info" )
     {
-        ctrMkNode("oscada_cntr",opt,-1,"/",_("Data base: ")+name());
+        ctrMkNode("oscada_cntr",opt,-1,"/",_("Data base: ")+name(),0664,"root",grp.c_str());
 	ctrMkNode("branches",opt,-1,"/br","",0444);
-	ctrMkNode("grp",opt,-1,"/br/tbl_",_("Opened table"),0444,"root","root",1,"list","/tbls/otbl");
+	ctrMkNode("grp",opt,-1,"/br/tbl_",_("Opened table"),0664,"root",grp.c_str());
         if(ctrMkNode("area",opt,0,"/prm",_("Data base")))
 	{
     	    if(ctrMkNode("area",opt,-1,"/prm/st",_("State")))
 	    {
     		ctrMkNode("fld",opt,-1,"/prm/st/st",_("Enable"),0664,"root",grp.c_str(),1,"tp","bool");
-		ctrMkNode("fld",opt,-1,"/prm/st/mk",_("Create new DB"),0664,"root",grp.c_str(),1,"tp","bool");
-		ctrMkNode("list",opt,-1,"/prm/st/allow_tbls",_("Allow tables"),0444,"root",grp.c_str(),1,"tp","str");
+		ctrMkNode("list",opt,-1,"/prm/st/allow_tbls",_("Allow tables"),0664,"root",grp.c_str(),2,"tp","str","s_com","del");
 	    }
     	    if(ctrMkNode("area",opt,-1,"/prm/cfg",_("Config")))
 	    {
@@ -745,8 +673,6 @@ void TBD::cntrCmdProc( XMLNode *opt )
     		ctrMkNode("fld",opt,-1,"/prm/cfg/addr",cfg("ADDR").fld().descr(),0664,"root",grp.c_str(),1,"tp","str");
 		ctrMkNode("fld",opt,-1,"/prm/cfg/codep",cfg("CODEPAGE").fld().descr(),0664,"root",grp.c_str(),1,"tp","str");
 		ctrMkNode("fld",opt,-1,"/prm/cfg/toen",cfg("EN").fld().descr(),0664,"root",grp.c_str(),1,"tp","bool");
-    		ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660,"root",grp.c_str());
-    		ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660,"root",grp.c_str());
 	    }	    
 	}
 	if(ctrMkNode("area",opt,1,"/tbls",_("Tables"),0444))
@@ -761,17 +687,20 @@ void TBD::cntrCmdProc( XMLNode *opt )
     	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )	opt->setText(enableStat()?"1":"0");
 	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) )	atoi(opt->text().c_str())?enable():disable();
     }
-    else if( a_path == "/prm/st/mk" )
+    else if( a_path == "/prm/st/allow_tbls" )
     {
-	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) ) opt->setText(create()?"1":"0");
-	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) ) setCreate(atoi(opt->text().c_str()));
-    }
-    else if( a_path == "/prm/st/allow_tbls" && ctrChkNode(opt) )
-    {
-	vector<string> lst;
-	allowList(lst);
-	for( int i_l=0; i_l < lst.size(); i_l++)
-	    opt->childAdd("el")->setText(lst[i_l]);
+	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )
+	{
+	    vector<string> lst;
+	    allowList(lst);
+	    for( int i_l=0; i_l < lst.size(); i_l++)
+		opt->childAdd("el")->setText(lst[i_l]);
+	}
+	if( ctrChkNode(opt,"del",0664,"root",grp.c_str(),SEQ_WR) )
+	{
+	    open( opt->text(), false );
+	    close( opt->text(), true );
+	}
     }
     else if( a_path == "/prm/cfg/id" && ctrChkNode(opt) )	opt->setText(id());
     else if( a_path == "/prm/cfg/nm" )
@@ -799,9 +728,7 @@ void TBD::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) ) opt->setText(toEnable()?"1":"0");
 	if( ctrChkNode(opt,"set",0664,"root",grp.c_str(),SEQ_WR) ) setToEnable( atoi(opt->text().c_str()) );
     }
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )	load();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root",grp.c_str(),SEQ_WR) )    	save();
-    else if( a_path == "/tbls/otbl" )
+    else if( a_path == "/br/tbl_" || a_path == "/tbls/otbl" )
     {
 	if( ctrChkNode(opt,"get",0664,"root",grp.c_str(),SEQ_RD) )
 	{
@@ -813,6 +740,7 @@ void TBD::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"add",0664,"root",grp.c_str(),SEQ_WR) )	open(opt->text(),true);
         if( ctrChkNode(opt,"del",0664,"root",grp.c_str(),SEQ_WR) )	close(opt->text());
     }
+    else TCntrNode::cntrCmdProc(opt);
 }
 
 //************************************************
@@ -820,7 +748,7 @@ void TBD::cntrCmdProc( XMLNode *opt )
 //************************************************
 TTable::TTable( const string &name ) :  m_name(name)
 {
-
+    modifClr();
 }
 
 TTable::~TTable()
@@ -828,13 +756,34 @@ TTable::~TTable()
 
 }
 
+TCntrNode &TTable::operator=( TCntrNode &node )
+{
+    TTable *src_n = dynamic_cast<TTable*>(&node);
+    if( !src_n || !src_n->owner().enableStat() || !owner().enableStat() ) return *this;
+
+    //- Table content copy -
+    TConfig req;
+    src_n->fieldStruct(req);
+    //-- Scan source table and write to destination table
+    for( int row = 0; src_n->fieldSeek(row,req); row++ )
+    {
+        fieldSet(req);
+        //--- Clear key fields ---
+        for( int i_e = 0; i_e < req.elem().fldSize(); i_e++ )
+            if( req.elem().fldAt(i_e).flg()&TCfg::Key )
+                req.cfg(req.elem().fldAt(i_e).name()).setS("");
+    }
+
+    return *this;
+}
+
 void TTable::cntrCmdProc( XMLNode *opt )
 {
     string grp = owner().owner().owner().subId();
     //Get page info
     if( opt->name() == "info" )
     {
-        ctrMkNode("oscada_cntr",opt,-1,"/",_("Table: ")+name());
+        ctrMkNode("oscada_cntr",opt,-1,"/",_("Table: ")+name(),0664,"root",grp.c_str());
         if(ctrMkNode("area",opt,0,"/prm",_("Table")))
 	{
     	    if(ctrMkNode("area",opt,-1,"/prm/cfg",_("Config")))
@@ -843,7 +792,7 @@ void TTable::cntrCmdProc( XMLNode *opt )
 	    if( tbl=ctrMkNode("table",opt,-1,"/prm/tbl",_("Data"),0664,"root",grp.c_str(),1,"s_com","add,del") )
 	    {
 		TConfig req;
-		fieldStruct(req);
+		try{ fieldStruct(req); } catch(...) { }
 		for( int i_f = 0; i_f < req.elem().fldSize(); i_f++ )
 		{
 		    string     eid = req.elem().fldAt(i_f).name();
@@ -919,4 +868,5 @@ void TTable::cntrCmdProc( XMLNode *opt )
 	    fieldSet(req);
 	}	
     }
+    else TCntrNode::cntrCmdProc(opt);
 }    
