@@ -48,9 +48,11 @@ class TTable : public TCntrNode
     public:
 	//Public methods
 	TTable( const string &name );
-	virtual ~TTable();
+	virtual ~TTable( );
 
-	string &name()		{ return m_name; }
+	TCntrNode &operator=( TCntrNode &node );
+
+	string &name( )		{ return m_name; }
 
 	virtual void fieldStruct( TConfig &cfg )
         { throw TError(nodePath().c_str(),_("Function <%s> no support!"),"fieldStruct"); }
@@ -71,7 +73,7 @@ class TTable : public TCntrNode
     
     private:
 	//Private methods
-	string nodeName()	{ return m_name; }
+	string nodeName( )	{ return m_name; }
 
 	//Private attributes
 	string m_name;
@@ -88,29 +90,27 @@ class TBD : public TCntrNode, public TConfig
 	//Public methods
 	TBD( const string &iid, TElem *cf_el );
 	virtual ~TBD( );
+
+	TCntrNode &operator=( TCntrNode &node );
 	
 	const string &id( )		{ return m_id; }
 	string       name( );
 	const string &dscr( )   	{ return m_dscr; }
 	const string &addr( )   	{ return m_addr; }
 	const string &codePage( )	{ return m_codepage; } 
-	bool         create( )		{ return m_creat; }
 	
 	bool enableStat( )       	{ return m_en; }
 	bool toEnable( )        	{ return m_toen; }
 	
-	void setName( const string &inm )  	{ m_name = inm; }
-	void setDscr( const string &idscr )	{ m_dscr = idscr; }
-	void setAddr( const string &iaddr )	{ m_addr = iaddr; }
-	void setCodePage( const string &icp )	{ m_codepage = icp; }
-	void setCreate( bool ivl )		{ m_creat= ivl; }
-	void setToEnable( bool ivl )		{ m_toen = ivl; }
+	void setName( const string &inm )  	{ m_name = inm; modif(); }
+	void setDscr( const string &idscr )	{ m_dscr = idscr; modif(); }
+	void setAddr( const string &iaddr )	{ m_addr = iaddr; modif(); }
+	void setCodePage( const string &icp )	{ m_codepage = icp; modif(); }
+	void setToEnable( bool ivl )		{ m_toen = ivl; modif(); }
 	
 	virtual void enable( );
         virtual void disable( );
-        virtual void load( );
-        virtual void save( );
-	
+
 	//- Opened DB tables -
 	virtual void allowList( vector<string> &list )
         { throw TError(nodePath().c_str(),_("Function <%s> no support!"),"allowList"); }
@@ -134,8 +134,11 @@ class TBD : public TCntrNode, public TConfig
 	void preDisable( int flag );
         void postDisable( int flag );
 	
-	void cntrCmdProc( XMLNode *opt );       //Control interface command process
+        void load_( );
+        void save_( );	
 	
+	void cntrCmdProc( XMLNode *opt );       //Control interface command process
+
     private:
 	//Private methods
 	void postEnable( int flag );
@@ -150,7 +153,7 @@ class TBD : public TCntrNode, public TConfig
 		&m_codepage;	//DB codepage
 	bool	&m_toen;
 	
-	bool    m_en, m_creat;
+	bool    m_en;
 	//- Special options -
 	int	m_tbl;
 };
@@ -203,8 +206,6 @@ class TBDS : public TSubSYS, public TElem
        	~TBDS( );
 
 	int subVer( ) 		{ return VER_BD; }
-	void subLoad( );
-	void subSave( );
 
 	static string realDBName( const string &bdn );
 	
@@ -228,10 +229,13 @@ class TBDS : public TSubSYS, public TElem
 	
 	TElem &openDB_E( )	{ return el_db; }
 	
-	AutoHD<TTipBD> at(const string &iid)	{ return modAt(iid); }
+	AutoHD<TTipBD> at( const string &iid )	{ return modAt(iid); }
 
 	string optDescr( );
 
+    protected:
+	void load_( );
+
     private:
 	//Private methods
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
