@@ -38,10 +38,12 @@
 
 //*************************************************
 //* Controll scenaries language section           *
-TCntrNode::TCntrNode( TCntrNode *iprev ) : m_mod(Disable), m_use(0), m_oi(USHRT_MAX)
+TCntrNode::TCntrNode( TCntrNode *iprev ) : m_use(0), m_flg(0), m_oi(USHRT_MAX)
 {
+    setNodeMode(Disable);
     prev.node = iprev;
     prev.grp = -1;
+    modif();
 }
 
 TCntrNode::~TCntrNode()
@@ -49,6 +51,11 @@ TCntrNode::~TCntrNode()
     nodeDelAll();
 }
 
+TCntrNode &TCntrNode::operator=( TCntrNode &node )
+{
+    return *this;
+}
+
 void TCntrNode::nodeDelAll( )
 {
     if( nodeMode() != Disable )     nodeDis();
@@ -127,46 +134,46 @@ void TCntrNode::cntrCmd( XMLNode *opt, int lev, const string &ipath, int off )
 //* Resource section                              *
 void TCntrNode::nodeEn( int flag )
 { 
-    if( m_mod == Enable )	throw TError(nodePath().c_str(),"Node already enabled!");
-    if( m_mod != Disable )	throw TError(nodePath().c_str(),"Node already in process!");
+    if( nodeMode() == Enable )	throw TError(nodePath().c_str(),"Node already enabled!");
+    if( nodeMode() != Disable )	throw TError(nodePath().c_str(),"Node already in process!");
     
-    ResAlloc res(hd_res,true);
-    m_mod = MkEnable;
-    res.release();
+    ResAlloc res( hd_res, true );
+    setNodeMode( MkEnable );
+    res.release( );
     
     preEnable(flag);
 
     TMap::iterator p;
     for( unsigned i_g = 0; i_g < chGrp.size(); i_g++ )
-	for( p=chGrp[i_g].elem.begin(); p!=chGrp[i_g].elem.end(); p++ )	
-	    if( p->second->nodeMode() == Disable )
-		p->second->nodeEn(flag);
+	for( p=chGrp[i_g].elem.begin(); p != chGrp[i_g].elem.end(); p++ )	
+	    if( p->second->nodeMode( ) == Disable )
+		p->second->nodeEn( flag );
 		
-    res.request(true);	    
-    m_mod = Enable;
-    res.release();
+    res.request( true );
+    setNodeMode( Enable );
+    res.release( );
     
-    postEnable(flag);
+    postEnable( flag );
 };
 
 void TCntrNode::nodeDis(long tm, int flag)
 { 
-    if( m_mod == Disable )	throw TError(nodePath().c_str(),"Node already disabled!");
-    if( m_mod != Enable )	throw TError(nodePath().c_str(),"Node already in process!");
+    if( nodeMode() == Disable )	throw TError(nodePath().c_str(),"Node already disabled!");
+    if( nodeMode() != Enable )	throw TError(nodePath().c_str(),"Node already in process!");
     
-    preDisable(flag);
+    preDisable( flag );
 
-    ResAlloc res(hd_res,true);    
-    m_mod = MkDisable;
-    res.release();
+    ResAlloc res( hd_res, true );
+    setNodeMode( MkDisable );
+    res.release( );
     
     try
     {
 	TMap::iterator p;
 	for( unsigned i_g = 0; i_g < chGrp.size(); i_g++ )
-    	    for( p=chGrp[i_g].elem.begin(); p!=chGrp[i_g].elem.end(); p++ )	
+    	    for( p=chGrp[i_g].elem.begin(); p != chGrp[i_g].elem.end(); p++ )	
     		if( p->second->nodeMode() == Enable )
-		    p->second->nodeDis(tm,flag);
+		    p->second->nodeDis( tm, flag );
 	
 	//- Wait of free node -
 	time_t t_cur = time(NULL);
@@ -186,19 +193,20 @@ void TCntrNode::nodeDis(long tm, int flag)
 	    }
 	    usleep(STD_WAIT_DELAY*1000);	    
 	}
-        res.request(true);
-	m_mod = Disable;
-	res.release();			       
+        res.request( true );
+	setNodeMode( Disable );
+	res.release( );			       
     }catch(TError err)
     {	
 	mess_warning(err.cat.c_str(),_("Node disable error. Restore node enabling."));
-	res.request(true);
-	m_mod = Disable;
-	res.release();
-	nodeEn(NodeRestore|(flag<<8));
+	res.request( true );
+	setNodeMode( Disable );
+	res.release( );
+	nodeEn( NodeRestore|(flag<<8) );
 	throw;
     }   
-    postDisable(flag);     
+    try{ postDisable(flag); } 
+    catch(TError err)	{ mess_warning(err.cat.c_str(),err.mess.c_str()); }
 };
 
 void TCntrNode::nodeList(vector<string> &list, const string& gid)
@@ -232,14 +240,65 @@ AutoHD<TCntrNode> TCntrNode::nodeAt( const string &path, int lev, char sep, int
     if( chGrp.size() )	return chldAt(0,s_br).at().nodeAt(path,0,sep,off);
 }
 
-/*void TCntrNode::nodeDel( const string &path, char sep, int flag )
+void TCntrNode::nodeDel( const string &path, char sep, int flag )
 {
     AutoHD<TCntrNode> del_n = nodeAt(path,0,sep);
-    n_grp = del_n.at().prev.grp;
-    n_id  = del_n.at().nodeName();
+    int n_grp = del_n.at().prev.grp;
+    string n_id  = del_n.at().nodeName();
     del_n = AutoHD<TCntrNode>(del_n.at().prev.node);
     del_n.at().chldDel(n_grp,n_id,-1,flag);
-}*/
+}
+
+void TCntrNode::nodeCopy( const string &src, const string &dst, const string &user )
+{
+    if( src == dst )	return;
+
+    //- Attach to source node -
+    AutoHD<TCntrNode> src_n = SYS->nodeAt(src);
+
+    //- Parse destination node path -
+    string d_elp, d_el, t_el;
+    int n_del = 0;
+    for( int off = 0; !(t_el=TSYS::pathLev(dst,0,true,&off)).empty(); n_del++ )
+    { if( n_del ) d_elp += ("/"+d_el); d_el = t_el; }
+    if( !n_del ) throw TError(SYS->nodePath().c_str(),_("Copy from '%s' to '%s' impossible"),src.c_str(),dst.c_str());
+
+    //- Connect to destination containers node -
+    AutoHD<TCntrNode> dst_n = SYS->nodeAt(d_elp);
+
+    //- Get allow branches' containers and find want group -
+    XMLNode br_req("info");
+    br_req.setAttr("user",user)->setAttr("path","/%2fbr");
+    dst_n.at().cntrCmd(&br_req);
+    if( atoi(br_req.attr("rez").c_str()) || !br_req.childGet(0,true) )
+        throw TError(SYS->nodePath().c_str(),_("Destination node not have branches."));
+    XMLNode *branch = br_req.childGet(0);
+    int i_b;
+    for( i_b = 0; i_b < branch->childSize(); i_b++ )
+	if( branch->childGet(i_b)->attr("id") == d_el.substr(0,branch->childGet(i_b)->attr("id").size()) && 
+		atoi(branch->childGet(i_b)->attr("acs").c_str())&SEQ_WR )
+	    break;
+    if( i_b >= branch->childSize() )
+        throw TError(SYS->nodePath().c_str(),_("Destination node not have want branche."));
+    bool idm = atoi(branch->childGet(i_b)->attr("idm").c_str());
+    string n_grp = branch->childGet(i_b)->attr("id");
+    d_el = d_el.substr(n_grp.size());    
+    i_b = dst_n.at().grpId(n_grp);
+    if( i_b < 0 ) throw TError(SYS->nodePath().c_str(),_("Destination node not have want branche."));
+
+    //- Connect or create new destination node -
+    if( !dst_n.at().chldPresent( i_b, d_el ) )
+    {
+        br_req.clear()->setName("add")->setAttr("user",user)->setAttr("path","/%2fbr%2f"+n_grp);
+	if( idm ) br_req.setAttr("id",d_el);
+	else br_req.setText(d_el);
+	dst_n.at().cntrCmd(&br_req);
+        if( atoi(br_req.attr("rez").c_str()) )	throw TError(br_req.attr("mcat").c_str(),br_req.text().c_str());
+    }
+    
+    //- Same copy call -    
+    dst_n.at().chldAt( i_b, d_el ).at() = src_n.at();
+}
 
 unsigned TCntrNode::grpAdd( const string &iid, bool iordered )
 {
@@ -253,7 +312,21 @@ unsigned TCntrNode::grpAdd( const string &iid, bool iordered )
     return g_id;
 }
 
-void TCntrNode::chldList( unsigned igr, vector<string> &list )
+char TCntrNode::grpId( const string &sid )
+{
+    for( int g_id = 0; g_id < chGrp.size(); g_id++ )
+	if( chGrp[g_id].id == sid )	return g_id;
+    
+    return -1;
+}
+
+TCntrNode::GrpEl &TCntrNode::grpAt( char iid )
+{
+    if( iid < 0 || iid >= grpSize( ) )	throw TError(nodePath().c_str(),_("Branche group '%d' error."),iid);
+    return chGrp[iid];
+}
+
+void TCntrNode::chldList( char igr, vector<string> &list )
 {
     ResAlloc res(hd_res,false);
     if( igr >= chGrp.size() )	throw TError(nodePath().c_str(),"Group of childs %d error!",igr);
@@ -277,7 +350,7 @@ void TCntrNode::chldList( unsigned igr, vector<string> &list )
     }
 }
 
-bool TCntrNode::chldPresent( unsigned igr, const string &name )
+bool TCntrNode::chldPresent( char igr, const string &name )
 {
     ResAlloc res(hd_res,false);
     if( igr >= chGrp.size() )	throw TError(nodePath().c_str(),"Group of childs %d error!",igr);
@@ -289,7 +362,7 @@ bool TCntrNode::chldPresent( unsigned igr, const string &name )
     return false;
 }
 
-void TCntrNode::chldAdd( unsigned igr, TCntrNode *node, int pos )
+void TCntrNode::chldAdd( char igr, TCntrNode *node, int pos )
 {
     ResAlloc res(hd_res,false);
     if( igr >= chGrp.size() )	throw TError(nodePath().c_str(),"Group of childs %d error!",igr);
@@ -319,7 +392,7 @@ void TCntrNode::chldAdd( unsigned igr, TCntrNode *node, int pos )
     if( node->nodeMode() == Disable )	node->nodeEn(TCntrNode::NodeConnect);
 }
 
-void TCntrNode::chldDel( unsigned igr, const string &name, long tm, int flag )
+void TCntrNode::chldDel( char igr, const string &name, long tm, int flag )
 {
     if( tm < 0 )	tm = DEF_TIMEOUT;
     ResAlloc res(hd_res,false);
@@ -387,7 +460,7 @@ TCntrNode *TCntrNode::nodePrev( bool noex )
     throw TError(nodePath().c_str(),"Node is it root or no connect!");
 }
 
-AutoHD<TCntrNode> TCntrNode::chldAt( unsigned igr, const string &name, const string &user )
+AutoHD<TCntrNode> TCntrNode::chldAt( char igr, const string &name, const string &user )
 {
     ResAlloc res(hd_res,false);
     if( igr >= chGrp.size() ) 	throw TError(nodePath().c_str(),"Group of childs %d error!",igr);
@@ -400,6 +473,66 @@ AutoHD<TCntrNode> TCntrNode::chldAt( unsigned igr, const string &name, const str
     return AutoHD<TCntrNode>(p->second,user);
 }
 
+int TCntrNode::isModify( int f )
+{
+    int rflg = 0;
+    if( f&Self && m_flg&SelfModify )	rflg |= Self;
+    if( f&Child )
+    	for( unsigned i_g = 0; i_g < chGrp.size(); i_g++ )
+	{
+	    TMap::iterator p;
+	    for( p=chGrp[i_g].elem.begin(); p != chGrp[i_g].elem.end(); p++ )
+		if( p->second->isModify(Self|Child) )	{ rflg |= Child; break; }
+	    if( p != chGrp[i_g].elem.end() )	break;
+	}
+
+    return rflg;
+}
+
+void TCntrNode::modifG( )
+{
+    modif( );
+    for( unsigned i_g = 0; i_g < chGrp.size(); i_g++ )
+        for( TMap::iterator p=chGrp[i_g].elem.begin(); p != chGrp[i_g].elem.end(); p++ )
+	    p->second->modifG( );
+}
+
+void TCntrNode::load( )
+{
+    //- Self load -
+    if( isModify(Self)&Self ) 
+	try{ load_(); }
+        catch(TError err)
+	{
+            mess_err(err.cat.c_str(),"%s",err.mess.c_str());
+            mess_err(nodePath().c_str(),_("Load node is error."));
+        }
+    //- Childs load process -
+    if( isModify(Child)&Child )
+     	for( unsigned i_g = 0; i_g < chGrp.size(); i_g++ )
+	    for( TMap::iterator p = chGrp[i_g].elem.begin(); p != chGrp[i_g].elem.end(); p++ )
+		if( p->second->isModify(Self|Child) )	p->second->load( );
+    modifClr();
+}
+
+void TCntrNode::save( )
+{
+    //- Self load -
+    if( isModify(Self)&Self )
+	try{ save_(); }
+        catch(TError err)
+	{
+            mess_err(err.cat.c_str(),"%s",err.mess.c_str());
+            mess_err(nodePath().c_str(),_("Save node is error."));
+        }
+    //- Childs load process -
+    if( isModify(Child)&Child )
+     	for( unsigned i_g = 0; i_g < chGrp.size(); i_g++ )
+	    for( TMap::iterator p = chGrp[i_g].elem.begin(); p != chGrp[i_g].elem.end(); p++ )
+		if( p->second->isModify(Self|Child) )	p->second->save( ); 
+    modifClr();
+}
+
 void TCntrNode::AHDConnect()
 {
     conn_res.resRequestW( );
@@ -454,10 +587,7 @@ XMLNode *TCntrNode::ctrMkNode( const char *n_nd, XMLNode *nd, int pos, const cha
 	    throw TError("ContrItfc",_("Some tags on path <%s> missed!"),req.c_str());
 	obj = obj->childIns(pos);
     }
-    obj->setName(n_nd);
-    obj->setAttr("id",reqt1);
-    obj->setAttr("dscr",dscr);
-    obj->setAttr("acs",TSYS::int2str(n_acs));
+    obj->setName(n_nd)->setAttr("id",reqt1)->setAttr("dscr",dscr)->setAttr("acs",TSYS::int2str(n_acs));
     
     //- Get addon attributes -
     if( n_attr )
@@ -491,6 +621,17 @@ bool TCntrNode::ctrChkNode( XMLNode *nd, const char *cmd, int perm, const char *
 void TCntrNode::cntrCmdProc( XMLNode *opt )
 {
     if( opt->name() == "info" )
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Node: ")+nodeName());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Node: ")+nodeName(),0444,"root","root");
+    
+    //- Process command to page -
+    vector<string> c_list;
+    string a_path = opt->attr("path");
+    if( a_path == "/obj" )
+    {
+	if( ctrChkNode(opt,"modify",RWRWRW) )	opt->setText( isModify(TCntrNode::All) ? "1" : "0" );
+	if( ctrChkNode(opt,"load",RWRWRW,"root","root",SEQ_WR) )	load( );
+	if( ctrChkNode(opt,"save",RWRWRW,"root","root",SEQ_WR) )	save( );
+	if( ctrChkNode(opt,"copy",RWRWRW,"root","root",SEQ_WR) )
+	    nodeCopy(opt->attr("src"),opt->attr("dst"),opt->attr("user"));
+    }
 }
-
