@@ -41,6 +41,35 @@ TController::~TController(  )
     nodeDelAll();
 }
 
+TCntrNode &TController::operator=( TCntrNode &node )
+{
+    TController *src_n = dynamic_cast<TController*>(&node);
+    if( !src_n ) return *this;
+
+    //- Configuration copy -
+    string tid = id();
+    *(TConfig*)this = *(TConfig*)src_n;
+    m_id = tid;
+    setDB(src_n->m_db);
+
+    //- Parameters copy -
+    if( src_n->enableStat( ) )
+    {
+	if( !enableStat( ) )	enable();
+	vector<string> prm_ls;
+	src_n->list(prm_ls);
+	for( int i_p = 0; i_p < prm_ls.size(); i_p++ )
+	{
+	    if( !owner().tpPrmPresent(src_n->at(prm_ls[i_p]).at().type().name) ) continue;
+	    if( !present(prm_ls[i_p]) )	add( prm_ls[i_p], owner().tpPrmToId(src_n->at(prm_ls[i_p]).at().type().name) );
+	    (TCntrNode&)at(prm_ls[i_p]).at() = (TCntrNode&)src_n->at(prm_ls[i_p]).at();
+	    if( toEnable( ) && !enableStat( ) )	enable();
+	}
+    }
+
+    return *this;
+}
+
 void TController::preDisable(int flag)
 {
     if( startStat() ) 	stop( );
@@ -78,7 +107,7 @@ string TController::tbl( )
     return owner().owner().subId()+"_"+owner().modId();
 }
 
-void TController::load( )
+void TController::load_( )
 {
     mess_info(nodePath().c_str(),_("Load controller's configs!"));
 
@@ -88,15 +117,19 @@ void TController::load( )
     if( en_st )	LoadParmCfg( );
 }
 
-void TController::save( )
+void TController::save_( )
 {
     mess_info(nodePath().c_str(),_("Save controller's configs!"));
 
     //- Update type controller bd record -
     SYS->db().at().dataSet(fullDB(),owner().nodePath()+"DAQ",*this);
+}
 
-    //- Save parameters if enabled -
-    if( en_st ) SaveParmCfg( );
+bool TController::cfgChange( TCfg &cfg )
+{
+    modif( );
+    
+    return true;
 }
 
 void TController::start( )
@@ -177,9 +210,6 @@ void TController::disable( )
     //- Disable for children -
     disable_();
 
-    //- Free all parameters -
-    //FreeParmCfg();
-
     //- Clear enable flag -
     en_st = false;
 }
@@ -218,28 +248,14 @@ void TController::LoadParmCfg(  )
 	}
     }
     
-    //- Load present parameters -
+    //- Force load present parameters -
     vector<string> prm_ls;
     list(prm_ls);
     for( int i_p = 0; i_p < prm_ls.size(); i_p++ )
-	at(prm_ls[i_p]).at().load( );	
-}
-
-void TController::SaveParmCfg(  )
-{
-    vector<string> c_list;
-
-    list(c_list);
-    for( unsigned i_ls = 0, i_bd=0; i_ls < c_list.size(); i_ls++)
-        at(c_list[i_ls]).at().save();
-}
-
-void TController::FreeParmCfg(  )
-{
-    vector<string> c_list;
-    list(c_list);
-    for( unsigned i_ls = 0; i_ls < c_list.size(); i_ls++)
-        del( c_list[i_ls] );
+    {	
+	at(prm_ls[i_p]).at().modifG();
+	at(prm_ls[i_p]).at().load( );
+    }	
 }
 
 void TController::add( const string &name, unsigned type )
@@ -258,7 +274,7 @@ void TController::cntrCmdProc( XMLNode *opt )
     //- Get page info -
     if( opt->name() == "info" )
     {
-    	ctrMkNode("oscada_cntr",opt,-1,"/",_("Controller: ")+name());
+    	ctrMkNode("oscada_cntr",opt,-1,"/",_("Controller: ")+name(),0664,"root","root");
 	ctrMkNode("branches",opt,-1,"/br","",0444);	
 	if(ctrMkNode("area",opt,-1,"/cntr",_("Controller")))
 	{
@@ -269,39 +285,50 @@ void TController::cntrCmdProc( XMLNode *opt )
 		ctrMkNode("fld",opt,-1,"/cntr/st/db",_("Controller DB (module.db)"),0660,"root","root",1,"tp","str");
 	    }
 	    if(ctrMkNode("area",opt,-1,"/cntr/cfg",_("Config")))
-	    {
-		ctrMkNode("comm",opt,-1,"/cntr/cfg/load",_("Load"),0660);
-		ctrMkNode("comm",opt,-1,"/cntr/cfg/save",_("Save"),0660);
 		TConfig::cntrCmdMake(opt,"/cntr/cfg",0,"root","root",0664);
-	    }
 	}
     	if( owner().tpPrmSize() )
 	{
-	    ctrMkNode("grp",opt,-1,"/br/prm_",_("Parameter"),0440,"root","root",1,"list","/prm/prm");
+	    ctrMkNode("grp",opt,-1,"/br/prm_",_("Parameter"),0660,"root","root",1,"idm","1");
      	    if(ctrMkNode("area",opt,-1,"/prm",_("Parameters")))
 	    {
 		if( owner().tpPrmSize() > 1 )
 		    ctrMkNode("fld",opt,-1,"/prm/t_prm",_("To add parameters"),0660,"root","root",3,"tp","str","dest","select","select","/prm/t_lst");
 		ctrMkNode("list",opt,-1,"/prm/prm",_("Parameters"),0660,"root","root",4,"tp","br","idm","1","s_com","add,del","br_pref","prm_");
+		ctrMkNode("fld",opt,-1,"/prm/nmb",_("Number"),0444,"root","root",1,"tp","dec");
+		ctrMkNode("fld",opt,-1,"/prm/en",_("Enabled"),0444,"root","root",1,"tp","dec");	
 	    }
 	}
         return;
     }
     
     //- Process command to page -
+    vector<string> c_list;    
     string a_path = opt->attr("path");
-    if( a_path == "/prm/t_prm" && owner().tpPrmSize() )
+    if( a_path == "/prm/nmb" && ctrChkNode(opt) )
+    {
+	list(c_list);
+	opt->setText(TSYS::int2str(c_list.size()));
+    }
+    else if( a_path == "/prm/en" && ctrChkNode(opt) )
+    {
+	list(c_list);
+	int e_c = 0;
+    	for( int i_a = 0; i_a < c_list.size(); i_a++ )
+	    if( at(c_list[i_a]).at().enableStat( ) )	e_c++;
+	opt->setText(TSYS::int2str(e_c));
+    }
+    else if( a_path == "/prm/t_prm" && owner().tpPrmSize() )
     {
 	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	
 	    opt->setText(TBDS::genDBGet(owner().nodePath()+"addType",owner().tpPrmAt(0).name,opt->attr("user")));
 	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	
 	    TBDS::genDBSet(owner().nodePath()+"addType",opt->text(),opt->attr("user"));
     }
-    else if( a_path == "/prm/prm" && owner().tpPrmSize() )
+    else if( (a_path == "/br/prm_" || a_path == "/prm/prm") && owner().tpPrmSize() )
     {
 	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )
 	{
-	    vector<string> c_list;
     	    list(c_list);
     	    for( unsigned i_a=0; i_a < c_list.size(); i_a++ )
         	opt->childAdd("el")->setAttr("id",c_list[i_a])->setText(at(c_list[i_a]).at().name());
@@ -320,8 +347,8 @@ void TController::cntrCmdProc( XMLNode *opt )
     }	
     else if( a_path == "/cntr/st/db" )
     {
-	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText(m_db);
-	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	m_db = opt->text();
+	if( ctrChkNode(opt,"get",0660,"root","root",SEQ_RD) )	opt->setText(DB());
+	if( ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	setDB(opt->text());
     }
     else if( a_path == "/cntr/st/en_st" )
     {
@@ -333,7 +360,6 @@ void TController::cntrCmdProc( XMLNode *opt )
 	if( ctrChkNode(opt,"get",0664,"root","root",SEQ_RD) )	opt->setText(run_st?"1":"0");
 	if( ctrChkNode(opt,"set",0664,"root","root",SEQ_WR) )	atoi(opt->text().c_str())?start():stop();
     }
-    else if( a_path == "/cntr/cfg/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	load();
-    else if( a_path == "/cntr/cfg/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) )	save();
     else if( a_path.substr(0,9) == "/cntr/cfg" )	TConfig::cntrCmdProc(opt,TSYS::pathLev(a_path,2),"root","root",0664);
+    else TCntrNode::cntrCmdProc(opt);
 }
