@@ -41,10 +41,12 @@ class TController : public TCntrNode, public TConfig
 	//Public methods
      	TController( const string &name_c, const string &daq_db, TElem *cfgelem );
 	virtual ~TController(  );
+
+	TCntrNode &operator=( TCntrNode &node );
 	
-	const string &id() 	{ return m_id; }
-	string name();
-	string descr()		{ return m_descr; }
+	const string &id( ) 	{ return m_id; }
+	string name( );
+	string descr( )		{ return m_descr; }
 	
         string DB( )            { return m_db; }
         string tbl( );
@@ -52,14 +54,13 @@ class TController : public TCntrNode, public TConfig
 	
 	void setName( const string &nm ) 	{ m_name = nm; }
 	void setDescr( const string &dscr )	{ m_descr = dscr; }	
+	void setDB( const string &idb )		{ m_db = idb; modifG(); }
 	
-    	bool toEnable()		{ return m_aen; }
-    	bool toStart() 		{ return m_astart; }
-	bool enableStat()	{ return en_st; }
-	bool startStat()      	{ return run_st; }
+    	bool toEnable( )	{ return m_aen; }
+    	bool toStart( ) 	{ return m_astart; }
+	bool enableStat( )	{ return en_st; }
+	bool startStat( )      	{ return run_st; }
 
-	virtual void load( );
-	virtual void save( );
 	void start( );
 	void stop( );
 	void enable( );
@@ -73,7 +74,7 @@ class TController : public TCntrNode, public TConfig
         AutoHD<TParamContr> at( const string &name, const string &who = "th_contr" )
 	{ return chldAt(m_prm,name); }
 	
-	TTipDAQ &owner()	{ return *(TTipDAQ *)nodePrev(); }
+	TTipDAQ &owner( )	{ return *(TTipDAQ *)nodePrev(); }
 	
     protected:    
 	//Protected attributes
@@ -82,6 +83,8 @@ class TController : public TCntrNode, public TConfig
 	
 	//Methods
 	//- User methods -
+	void load_( );
+	void save_( );	
 	virtual void enable_(  ) 	{ }
         virtual void disable_(  )	{ }
 	virtual void start_( )	 	{ }
@@ -91,16 +94,16 @@ class TController : public TCntrNode, public TConfig
     
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 	
-	void preDisable(int flag);	//Disable if delete
-	void postDisable(int flag);     //Delete all DB if flag 1
+	bool cfgChange( TCfg &cfg );
+	
+	void preDisable( int flag );		//Disable if delete
+	void postDisable( int flag );     	//Delete all DB if flag 1
 	
     private:
 	//Private methods
-	string nodeName()       { return m_id; }
+	string nodeName( )       { return m_id; }
     
 	void LoadParmCfg(  );
-	void SaveParmCfg(  );
-	void FreeParmCfg(  );
 	
 	//Private attributes
 	string  &m_id;
