@@ -1,13 +1,12 @@
 
 //OpenSCADA system file: terror.cpp
 /***************************************************************************
- *   Copyright (C) 2003-2006 by Roman Savochenko                           *
+ *   Copyright (C) 2003-2007 by Roman Savochenko                           *
  *   rom_as@fromru.com                                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ *   the Free Software Foundation; version 2 of the License.               *
  *                                                                         *
  *   This program is distributed in the hope that it will be useful,       *
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
@@ -25,6 +24,9 @@
 
 #include "terror.h"
 
+//*************************************************
+//* TError                                        *
+//*************************************************
 TError::TError( const char *icat, const char *fmt, ... )
 {
     char str[1024];                  //!!!!
@@ -34,7 +36,21 @@ TError::TError( const char *icat, const char *fmt, ... )
     vsnprintf(str,sizeof(str),fmt,argptr);
     va_end(argptr);
 
+    cod  = 0;
     mess = str;
     cat  = icat;
 }        
 
+TError::TError( int icod, const char *icat, const char *fmt, ... )
+{
+    char str[1024];                  //!!!!
+    va_list argptr;
+
+    va_start(argptr,fmt);
+    vsnprintf(str,sizeof(str),fmt,argptr);
+    va_end(argptr);
+
+    cod  = icod;
+    mess = str;
+    cat  = icat;
+}
