@@ -120,14 +120,14 @@ class TFunction : public TCntrNode
 	void valAtt( TValFunc *vfnc );
         void valDet( TValFunc *vfnc );		
 	
-	virtual void preIOCfgChange();
-        virtual void postIOCfgChange();
+	virtual void preIOCfgChange( );
+        virtual void postIOCfgChange( );
 	
     protected:
 	//Methods
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 	
-	void preDisable(int flag);
+	void preDisable( int flag );
 	
 	//Attributes
 	string          m_id;
@@ -138,7 +138,8 @@ class TFunction : public TCntrNode
 	//Methods
 	string nodeName()       { return id(); }
     
-	//Attributes	
+	//Attributes
+	Res             f_res;
 	vector<IO*>	m_io;
 	vector<TValFunc*>	used;
 };
@@ -176,16 +177,16 @@ class TValFunc
 	}
 	
 	//- get IO value -
-	string getS( unsigned id );
-	int getI( unsigned id );
-	double getR( unsigned id );
-	bool getB( unsigned id );
+	string 	getS( unsigned id );
+	int 	getI( unsigned id );
+	double 	getR( unsigned id );
+	char 	getB( unsigned id );
 	
 	//- set IO value -
 	void setS( unsigned id, const string &val );
 	void setI( unsigned id, int val );
 	void setR( unsigned id, double val );
-	void setB( unsigned id, bool val );
+	void setB( unsigned id, char val );
 
 	//- Blocked values screen -
 	bool	blk( )			{ return m_blk; }
@@ -217,7 +218,7 @@ class TValFunc
 	        string *s;
 	        double r;
 	        int    i;
-	        bool   b;
+	        char   b;
 	    }val;										    
 	};
 	
