@@ -51,12 +51,23 @@ TMess::TMess(  ) : IOCharSet("UTF8"), m_mess_level(0), log_dir(0x2)
     textdomain(PACKAGE);
 }
 
-
 TMess::~TMess(  )
 {
     closelog();
 }
 
+void TMess::setMessLevel( int level )  
+{ 
+    m_mess_level = level;
+    SYS->modif();
+}
+
+void TMess::setLogDirect( int dir )
+{ 
+    log_dir = dir;
+    SYS->modif();
+}
+
 void TMess::put( const char *categ, Type level, const char *fmt,  ... )
 {
     char mess[STR_BUF_LEN];
@@ -120,6 +131,8 @@ string TMess::codeConv( const string &fromCH, const string &toCH, const string &
     size_t ilen, olen;
     iconv_t hd;
     
+    if( fromCH == toCH ) return mess;
+    
     hd = iconv_open(toCH.c_str(), fromCH.c_str());
     if( hd == (iconv_t)(-1) )
     {
