@@ -33,26 +33,34 @@ class TModSchedul : public TSubSYS
 {
     public:
 	//Data
-	struct SHD
+	class SHD
 	{
-    	    void                *hd;         // NULL - share lib present but no attached
-	    vector<string>      use;         // if share lib attached to show who modules used    
-	    time_t              m_tm;        // data modify of share lib for automatic update
-	    string              name;        // share lib path
+	    public:
+		//Methods
+		SHD( ) : hd(NULL), m_tm(0)	{ }
+		SHD( void *ihd, time_t itm, const string &iname ) : hd(ihd), m_tm(itm), name(iname)	{ }
+		
+		//Attributes
+    		void		*hd;         // NULL - share lib present but no attached
+		vector<string>	use;         // if share lib attached to show who modules used    
+		time_t		m_tm;        // data modify of share lib for automatic update
+		string		name;        // share lib path
 	};
 	    
 	//Methods
 	TModSchedul( );    
 	~TModSchedul( );
 	
-	void chkPer( int per );
+	int chkPer( )		{ return m_per; }
+	string modPath( )	{ return m_mod_path; }
+
+	void setChkPer( int per );
+	void setModPath( const string &vl )	{ m_mod_path = vl; modif(); }
 
-	void subLoad( );
-	void subSave( );
 	void subStart( );	
 	void subStop( );
 	
-	void loadLibS(  );      			// Load/Init/Start all share libs and registry moduls into TSubSYS	
+	void loadLibS( );      				// Load/Init/Start all share libs and registry moduls into TSubSYS	
 	
         SHD &lib( const string &name );			// Get stat share lib <name>
     	void libList( vector<string> &list );		// List present share libs
@@ -62,6 +70,8 @@ class TModSchedul : public TSubSYS
 
     protected:
 	//Methods
+	void load_( );
+        void save_( );
 	void preDisable( int flag );
 	
     private:
@@ -75,7 +85,7 @@ class TModSchedul : public TSubSYS
 	
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 
-    	static void SchedTask(union sigval obj);    
+    	static void SchedTask( union sigval obj );
 	
 	//Attributes
 	string         	m_mod_path;
@@ -83,7 +93,7 @@ class TModSchedul : public TSubSYS
    
 	Res     	hd_res;   
 	int		m_per;	//Check to new modules period
-	vector<SHD *> 	SchHD;
+	vector<SHD> 	SchHD;
 	timer_t 	tmId;   //Thread timer
 	bool         	prc_st;
 };
