@@ -32,7 +32,7 @@
 //* TParamContr                                   *
 //*************************************************
 TParamContr::TParamContr( const string &name, TTipParam *tpprm ) : 
-    TConfig(tpprm), tipparm(tpprm), m_en(false), m_export(false),
+    TConfig(tpprm), tipparm(tpprm), m_en(false),
     m_id(cfg("SHIFR").getSd()), m_name(cfg("NAME").getSd()), m_descr(cfg("DESCR").getSd()), m_aen(cfg("EN").getBd())
 {
     m_id = m_name = name;
@@ -43,6 +43,21 @@ TParamContr::~TParamContr( )
     nodeDelAll();
 }
 
+TCntrNode &TParamContr::operator=( TCntrNode &node )
+{
+    TParamContr *src_n = dynamic_cast<TParamContr*>(&node);
+    if( !src_n ) return *this;
+	
+    //- Configuration copy -
+    string tid = id();
+    *(TConfig*)this = *(TConfig*)src_n;
+    m_id = tid;
+
+    if( src_n->enableStat() && toEnable( ) && !enableStat() )	enable();
+			    
+    return *this;
+}
+
 string TParamContr::name()
 { 
     return (m_name.size())?m_name:m_id;
@@ -88,13 +103,13 @@ void TParamContr::postDisable(int flag)
     }
 }
 
-void TParamContr::load( )
+void TParamContr::load_( )
 {
     SYS->db().at().dataGet(owner().DB()+"."+owner().cfg(type().db).getS(),
 	    		   owner().owner().nodePath()+owner().cfg(type().db).getS(),*this);
 }
 
-void TParamContr::save( )
+void TParamContr::save_( )
 {
     SYS->db().at().dataSet(owner().DB()+"."+owner().cfg(type().db).getS(),
 	    		   owner().owner().nodePath()+owner().cfg(type().db).getS(),*this);
@@ -107,6 +122,13 @@ void TParamContr::save( )
             vlAt(a_ls[i_a]).at().arch().at().save();				    
 }
 
+bool TParamContr::cfgChange( TCfg &cfg )
+{
+    modif( );
+    
+    return true;
+}
+
 TParamContr & TParamContr::operator=( TParamContr & PrmCntr )
 {
     TConfig::operator=(PrmCntr);
@@ -144,7 +166,7 @@ void TParamContr::cntrCmdProc( XMLNode *opt )
     if( opt->name() == "info" )
     {
 	TValue::cntrCmdProc(opt);
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Parameter: ")+name());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Parameter: ")+name(),0664,"root","root");
 	if(ctrMkNode("area",opt,0,"/prm",_("Parameter")))
 	{
 	    if(ctrMkNode("area",opt,-1,"/prm/st",_("State")))
@@ -154,11 +176,7 @@ void TParamContr::cntrCmdProc( XMLNode *opt )
 		    ctrMkNode("fld",opt,-1,"/prm/st/en",_("Enable"),0664,"root","root",1,"tp","bool");
 	    }
 	    if(ctrMkNode("area",opt,-1,"/prm/cfg",_("Config")))
-	    {
-		ctrMkNode("comm",opt,-1,"/prm/cfg/load",_("Load"),0660);
-		ctrMkNode("comm",opt,-1,"/prm/cfg/save",_("Save"),0660);
 		TConfig::cntrCmdMake(opt,"/prm/cfg",0,"root","root",0664);
-	    }
 	}
         return;
     }
@@ -173,8 +191,6 @@ void TParamContr::cntrCmdProc( XMLNode *opt )
 	    else atoi(opt->text().c_str())?enable():disable();
 	}
     }
-    else if( a_path == "/prm/cfg/load" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) ) 	load();
-    else if( a_path == "/prm/cfg/save" && ctrChkNode(opt,"set",0660,"root","root",SEQ_WR) ) 	save();    
     else if( a_path.substr(0,8) == "/prm/cfg" ) TConfig::cntrCmdProc(opt,TSYS::pathLev(a_path,2),"root","root",0664);
     else TValue::cntrCmdProc(opt);
 }                                                                                             
