@@ -39,7 +39,7 @@ class TProtocolIn : public TCntrNode
 {
     public:
 	TProtocolIn( const string &name );
-	virtual ~TProtocolIn();
+	virtual ~TProtocolIn( );
 	
 	string &name( )		{ return m_name; }
 	
@@ -98,12 +98,14 @@ class TProtocolS : public TSubSYS
 	~TProtocolS( );
     
 	int subVer( ) 		{ return(VER_PROT); }
-	void subLoad( );
 
 	AutoHD<TProtocol> at( const string &iid )	{ return modAt(iid); }
 
 	string optDescr( );
 
+    protected:
+	void load_();
+
     private:
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 };
