@@ -38,11 +38,13 @@ class TUser : public TCntrNode, public TConfig
     public:
 	//Methods
 	TUser( const string &name, const string &db, TElem *el );
-	~TUser(  );
-	
-	const string	&name() 	{ return m_name; }
-	const string	&lName()	{ return m_lname; }
-	const string	&picture()	{ return m_pict; }	
+	~TUser( );
+
+	TCntrNode &operator=( TCntrNode &node );
+
+	const string	&name( ) 	{ return m_name; }
+	const string	&lName( )	{ return m_lname; }
+	const string	&picture( )	{ return m_pict; }	
 	bool sysItem( )			{ return m_sysIt; }	
 
 	bool auth( const string &pass );
@@ -51,20 +53,23 @@ class TUser : public TCntrNode, public TConfig
         string tbl( );
         string fullDB( )        { return DB()+'.'+tbl(); }
 	
-	void setName( const string &nm )	{ m_name = nm; }
-	void setLName( const string &nm )	{ m_lname = nm; }
-	void setPicture( const string &pct )	{ m_pict = pct; }
+	void setLName( const string &nm )	{ m_lname = nm; modif(); }
+	void setPicture( const string &pct )	{ m_pict = pct; modif(); }
 	void setPass( const string &n_pass );
 	void setSysItem( bool vl )		{ m_sysIt = vl; }
-
-	void load( );
-	void save( );
 	
-	TSecurity &owner()	{ return *(TSecurity*)nodePrev(); }
+	void setDB( const string &vl )		{ m_db = vl; modifG(); }
+
+    protected:
+	//Methods
+	void load_( );
+	void save_( );
+	
+	TSecurity &owner( )	{ return *(TSecurity*)nodePrev(); }
 	
     private:	
 	//Methods    
-	string nodeName()	{ return m_name; }
+	string nodeName( )	{ return m_name; }
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 	void postDisable( int flag );     	//Delete all DB if flag 1
 
@@ -85,34 +90,39 @@ class TGroup : public TCntrNode, public TConfig
     public:
 	//Methods
 	TGroup( const string &name, const string &db, TElem *el );
-	~TGroup(  );
+	~TGroup( );
 
-	const string &name()  	{ return m_name; }
-	const string &lName() 	{ return m_lname; }
-	bool sysItem()		{ return m_sysIt; }
+	TCntrNode &operator=( TCntrNode &node );
+
+	const string &name( )  	{ return m_name; }
+	const string &lName( ) 	{ return m_lname; }
+	bool sysItem( )		{ return m_sysIt; }
 	
 	string DB( )            { return m_db; }
         string tbl( );
         string fullDB( )        { return DB()+'.'+tbl(); }
 	
-	void setName( const string &nm )	{ m_name = nm; }
-	void setLName( const string &nm )	{ m_lname = nm; }
+	void setLName( const string &nm )	{ m_lname = nm; modif(); }
 	void setSysItem( bool vl )		{ m_sysIt = vl; }
+	
+	void setDB( const string &vl )          { m_db = vl; modifG(); }
 		
 	bool user( const string &name );
 	void userAdd( const string &name );
 	void userDel( const string &name );
 
-	void load( );
-	void save( );
+    protected:
+	//Methods
+	void load_( );
+	void save_( );
 	
-	TSecurity &owner()	{ return *(TSecurity*)nodePrev(); }
+	TSecurity &owner( )	{ return *(TSecurity*)nodePrev(); }
 	
     private:	 
 	//Methods   
-	string nodeName(){ return m_name; }
+	string nodeName( )	{ return m_name; }
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
-	void postDisable(int flag);     //Delete all DB if flag 1
+	void postDisable( int flag );     	//Delete all DB if flag 1
 	
 	//Attributes
 	string	&m_name;
@@ -132,9 +142,6 @@ class TSecurity : public TSubSYS
 	TSecurity( );    
 	~TSecurity( );
 
-	void subLoad( );
-	void subSave( );
-
 	char access( const string &user, char mode, const string &owner, const string &group, int access );
 	
 	//- Users -
@@ -151,13 +158,17 @@ class TSecurity : public TSubSYS
 	void grpAdd( const string &name, const string &db = "*.*" );
 	void grpDel( const string &name, bool complete = false );
 	AutoHD<TGroup> grpAt( const string &name )	{ return chldAt(m_grp,name); }
-	
+
+    protected:
+	//Methods
+	void load_( );
+
     private:
 	//Methods
 	string optDescr( );	
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 	
-	void postEnable(int flag);
+	void postEnable( int flag );
 	
 	//Attributes
 	int	m_usr, m_grp;
