@@ -83,24 +83,6 @@ AutoHD<TModule> TSubSYS::modAt( const string &name )
     return chldAt(m_mod,name); 
 }
 
-void TSubSYS::subLoad( ) 
-{
-    if( !subModule() )	return;
-    vector<string> list;
-    modList(list);
-    for(unsigned i_m=0; i_m < list.size(); i_m++)
-        modAt(list[i_m]).at().modLoad( ); 
-}
-
-void TSubSYS::subSave( )
-{
-    if( !subModule() )  return;
-    vector<string> list;
-    modList(list);
-    for(unsigned i_m=0; i_m < list.size(); i_m++)
-	modAt(list[i_m]).at().modSave( );
-}
-
 void TSubSYS::subStart( ) 
 {
     if( !SYS->security().at().grpPresent(subId()) )
@@ -117,7 +99,10 @@ void TSubSYS::subStart( )
     for(unsigned i_m=0; i_m < list.size(); i_m++)
 	try{ modAt(list[i_m]).at().modStart( ); }
 	catch(TError err)
-        { mess_err(err.cat.c_str(),"%s",err.mess.c_str()); }
+        { 
+	    mess_err(err.cat.c_str(),"%s",err.mess.c_str()); 
+	    mess_err(nodePath().c_str(),_("Start module '%s' is error."),list[i_m].c_str());	    
+	}
 }
 
 void TSubSYS::subStop( ) 
@@ -126,7 +111,12 @@ void TSubSYS::subStop( )
     vector<string> list;
     modList(list);
     for(unsigned i_m=0; i_m < list.size(); i_m++)
-        modAt(list[i_m]).at().modStop( );
+	try{ modAt(list[i_m]).at().modStop( ); }
+	catch(TError err)
+        { 
+	    mess_err(err.cat.c_str(),"%s",err.mess.c_str()); 
+	    mess_err(nodePath().c_str(),_("Stop module '%s' is error."),list[i_m].c_str());
+	}	
 }		
 
 void TSubSYS::cntrCmdProc( XMLNode *opt )
@@ -134,12 +124,12 @@ void TSubSYS::cntrCmdProc( XMLNode *opt )
     //Get page info
     if( opt->name() == "info" )
     {
-	ctrMkNode("oscada_cntr",opt,-1,"/",_("Subsystem: ")+subName());
+	ctrMkNode("oscada_cntr",opt,-1,"/",_("Subsystem: ")+subName(),0444);
 	ctrMkNode("branches",opt,-1,"/br","",0444);
 	if(TUIS::icoPresent(subId()))	ctrMkNode("img",opt,-1,"/ico","",0444);
 	if( subModule() )
 	{
-	    ctrMkNode("grp",opt,-1,"/br/mod_",_("Module"),0444,"root","root",1,"list","/mod/br");
+	    ctrMkNode("grp",opt,-1,"/br/mod_",_("Module"),0444,"root","root",1,"idm","1");
 	    if(ctrMkNode("area",opt,-1,"/mod",_("Modules"),0444,"root","root"))
 		ctrMkNode("list",opt,-1,"/mod/br",_("Modules"),0444,"root","root",3,"tp","br","idm","1","br_pref","mod_");
 	}
@@ -154,14 +144,12 @@ void TSubSYS::cntrCmdProc( XMLNode *opt )
         opt->setText(TSYS::strEncode(TUIS::icoGet(subId(),&itp),TSYS::base64));
         opt->setAttr("tp",itp);	
     }
-    else if( subModule() )
-    { 
-	if( a_path == "/mod/br" && ctrChkNode(opt,"get",0444,"root","root",SEQ_RD) )
-	{
-	    vector<string> list;
-	    modList(list);
-	    for( unsigned i_a=0; i_a < list.size(); i_a++ )
-		opt->childAdd("el")->setAttr("id",list[i_a])->setText(modAt(list[i_a]).at().modName());
-	}
+    else if( subModule() && (a_path == "/br/mod_" || a_path == "/mod/br") && ctrChkNode(opt,"get",0444,"root","root",SEQ_RD) )
+    {
+        vector<string> list;
+        modList(list);
+        for( unsigned i_a=0; i_a < list.size(); i_a++ )
+	    opt->childAdd("el")->setAttr("id",list[i_a])->setText(modAt(list[i_a]).at().modName());
     }
+    else TCntrNode::cntrCmdProc(opt);
 }
