@@ -33,10 +33,12 @@ typedef unsigned int ui32;
 typedef unsigned long long ui64;
 
 //- Other system's constants -
-#define TO_FREE         NULL // Object free
-#define STR_BUF_LEN     3000 // Len of string buffers (no string class)
-#define STD_WAIT_DELAY  100 // Standart wait dalay (ms)
+#define TO_FREE         NULL 	// Object free
+#define STR_BUF_LEN     3000 	// Len of string buffers (no string class)
+#define STD_WAIT_DELAY  100 	// Standart wait dalay (ms)
+#define STD_WAIT_TM	10	// Standart timeouts length (s)
 
+#include <math.h>
 #include <stdio.h>
 
 #include <string>
@@ -86,46 +88,51 @@ class TSYS : public TCntrNode
 	
 	//Public methods    
 	TSYS( int argi, char ** argb, char **env );
-	~TSYS(  );
+	~TSYS( );
 
-	void load( );
-	void save( );
 	int  start( );
 	void stop( );
 	
 	int stopSignal( )	{ return stop_signal; }
 	
         //- Programms options -
-	string id()	{ return m_id; }	
-	string name()	{ return m_name; }
-	string user()	{ return m_user; }               //Run user name 
+	string id( )		{ return m_id; }	
+	string name( )		{ return m_name; }
+	string user( )		{ return m_user; }               //Run user name 
 
 	void list( vector<string> &list )	{ chldList(m_subst,list); }
         bool present( const string &name )	{ return chldPresent(m_subst,name); }
         void add( TSubSYS *sub )		{ chldAdd(m_subst,sub); }
         void del( const string &name )      	{ chldDel(m_subst,name); }
-        AutoHD<TSubSYS> at( const string &name ){ return chldAt(m_subst,name); }
+        AutoHD<TSubSYS> at( const string &name ){ return chldAt(m_subst,name); }	
 
-	AutoHD<TUIS> 		ui()     	{ return at("UI"); }
-	AutoHD<TArchiveS>	archive()	{ return at("Archive"); } 
-	AutoHD<TBDS>		db()     	{ return at("BD"); }
-	AutoHD<TDAQS> 		daq()		{ return at("DAQ"); }
-	AutoHD<TProtocolS> 	protocol()   	{ return at("Protocol"); }
-	AutoHD<TTransportS>	transport()  	{ return at("Transport"); }
-	AutoHD<TSpecialS>    	special()    	{ return at("Special"); }
-	AutoHD<TModSchedul>  	modSchedul() 	{ return at("ModSched"); }
-	AutoHD<TSecurity>	security()  	{ return at("Security"); }
+	AutoHD<TUIS> 		ui( )     	{ return at("UI"); }
+	AutoHD<TArchiveS>	archive( )	{ return at("Archive"); } 
+	AutoHD<TBDS>		db( )     	{ return at("BD"); }
+	AutoHD<TDAQS> 		daq( )		{ return at("DAQ"); }
+	AutoHD<TProtocolS> 	protocol( )   	{ return at("Protocol"); }
+	AutoHD<TTransportS>	transport( )  	{ return at("Transport"); }
+	AutoHD<TSpecialS>    	special( )    	{ return at("Special"); }
+	AutoHD<TModSchedul>  	modSchedul( ) 	{ return at("ModSched"); }
+	AutoHD<TSecurity>	security( )  	{ return at("Security"); }
+	
+	string workDir( );
+	string setWorkDir( const string &wdir );
 	
 	//- Config file functions -
-	string cfgFile() 	{ return m_confFile; }
-	XMLNode &cfgRoot()	{ return root_n; }
+	string cfgFile( ) 	{ return m_confFile; }
+	XMLNode &cfgRoot( )	{ return root_n; }
 
 	//- Default DB -
-	string workDB()		{ return mWorkDB; }
-	bool saveAtExit()	{ return mSaveAtExit; }
+	string workDB( )	{ return mWorkDB; }
+	void setWorkDB( const string &wdb )	{ mWorkDB = wdb; modifG(); }
+	bool saveAtExit( )	{ return mSaveAtExit; }
+	void setSaveAtExit( bool vl )		{ mSaveAtExit = vl; modif(); }	
+	int  savePeriod( )	{ return mSavePeriod; }
+	void setSavePeriod( int vl )		{ mSavePeriod = vl; modif(); }
 	
 	//- Get system options from DB -
-	bool sysOptCfg()	{ return m_sysOptCfg; }
+	bool sysOptCfg( )	{ return m_sysOptCfg; }
 	
 	string optDescr( );	//print comand line options
 
@@ -145,11 +152,11 @@ class TSYS : public TCntrNode
     	    asm volatile("rdtsc; movl %%eax,%0; movl %%edx,%1;":"=r"(cntl),"=r"(cnth)::"%eax","%edx");
 	    return ((unsigned long long)cnth<<32)+cntl;	
         }
-	static long HZ();
+	static long HZ( );
 	
 	//Public system static methods
 	//- Current system time (usec) -
-	static long long curTime();
+	static long long curTime( );
 	
 	//- Wait event with timeout support -
 	static bool eventWait( bool &m_mess_r_stat, bool exempl, const string &loc, time_t time = 0 );
@@ -159,6 +166,12 @@ class TSYS : public TCntrNode
         static string uint2str( unsigned val, IntView view = Dec );	
 	static string ll2str( long long val, IntView view = Dec );
         static string real2str( double val, int prec = 15 );
+	static double realRound( double val, int dig = 0, bool toint = false )
+	{
+	    double rez = floor(val*pow(10,dig)+0.5)/pow(10,dig);
+	    if( toint ) return floor(rez+0.5);
+	    return rez;
+	}
 	
         //Adress convertors
         static string addr2str( void *addr );
@@ -180,6 +193,11 @@ class TSYS : public TCntrNode
 	const char **argv;	//Comand line seting buffer.
 	const char **envp;	//System environment.
 
+    protected:
+	//Protected methods
+	void load_( );
+	void save_( );
+
     private:
 	//Private methods
 	string nodeName()	{ return id(); }
@@ -200,6 +218,7 @@ class TSYS : public TCntrNode
 
 	string	mWorkDB;	// Work DB
 	bool	mSaveAtExit;	// Save at exit
+	int	mSavePeriod;	// Save period (s) for periodic system saving to DB
 	
 	XMLNode root_n;		// Root of the config file tree
 	
