@@ -42,6 +42,8 @@ class TTransportIn : public TCntrNode, public TConfig
 	TTransportIn( const string &id, const string &db, TElem *el );
 	virtual ~TTransportIn( );
 
+	TCntrNode &operator=( TCntrNode &node );
+
 	const string &id( )	{ return m_id; }
 	string name( );
         string dscr( )		{ return m_dscr; }
@@ -55,30 +57,35 @@ class TTransportIn : public TCntrNode, public TConfig
         string tbl( );
         string fullDB( )        { return DB()+'.'+tbl(); }
 	
-	void setName( const string &inm )  	{ m_name = inm; }
-        void setDscr( const string &idscr )	{ m_dscr = idscr; }
-        void setAddr( const string &addr ) 	{ m_addr = addr; }			
+	void setName( const string &inm )  	{ m_name = inm; modif(); }
+        void setDscr( const string &idscr )	{ m_dscr = idscr; modif(); }
+        void setAddr( const string &addr ) 	{ m_addr = addr; modif(); }
+	void setProtocol( const string &prt )	{ m_prot = prt; modif(); }
+	void setToStart( bool val )             { m_start = val; modif(); }
 	
-	void load( );
-	void save( );	
-	virtual void start()	{ };
-	virtual void stop()	{ };
+	void setDB( const string &vl )          { m_db = vl; modifG(); }
+
+	virtual void start( )	{ };
+	virtual void stop( )	{ };
 		
-	TTipTransport &owner()	{ return *(TTipTransport*)nodePrev(); }
+	TTipTransport &owner( )	{ return *(TTipTransport*)nodePrev(); }
 	
     protected:
 	//Methods
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
 	
-	void preEnable(int flag);
-	void postDisable(int flag);     //Delete all DB if flag 1
-	
+	void preEnable( int flag );
+	void postDisable( int flag );     	//Delete all DB if flag 1
+
+	void load_( );
+	void save_( );	
+
 	//Attributes
 	bool    run_st;
 	
     private:
 	//Methods
-        string nodeName()       { return m_id; }
+        string nodeName( )	{ return m_id; }
 	
 	//Attributes
 	string  &m_id;
@@ -98,7 +105,9 @@ class TTransportOut : public TCntrNode, public TConfig
     public:
 	//Methods
 	TTransportOut( const string &id, const string &db, TElem *el );
-	virtual ~TTransportOut();	
+	virtual ~TTransportOut( );
+
+	TCntrNode &operator=( TCntrNode &node );
 	
 	const string &id( )	{ return m_id; }
 	string name( );
@@ -113,15 +122,15 @@ class TTransportOut : public TCntrNode, public TConfig
         string tbl( );
         string fullDB( )        { return DB()+'.'+tbl(); }				
 	
-	void setName( const string &inm )	{ m_name = inm; }
-	void setDscr( const string &idscr )	{ m_dscr = idscr; }
-	void setAddr( const string &addr )	{ m_addr = addr; }
+	void setName( const string &inm )	{ m_name = inm; modif(); }
+	void setDscr( const string &idscr )	{ m_dscr = idscr; modif(); }
+	void setAddr( const string &addr )	{ m_addr = addr; modif(); }
 	void setPrm1( int vl )			{ m_prm1 = vl; }
 	void setPrm2( int vl )                  { m_prm2 = vl; }	
-	void setToStart( bool val )        	{ m_start = val; }
+	void setToStart( bool val )        	{ m_start = val; modif(); }
+
+	void setDB( const string &vl )          { m_db = vl; modifG(); }
 
-	void load( );
-	void save( );	
 	virtual void start( )			{ };
 	virtual void stop( )			{ };
 	
@@ -130,7 +139,7 @@ class TTransportOut : public TCntrNode, public TConfig
 	
 	string messProtIO( const string &in, const string &prot );
 	
-	TTipTransport &owner() 	{ return *(TTipTransport*)nodePrev(); }
+	TTipTransport &owner( )	{ return *(TTipTransport*)nodePrev(); }
 	
     protected:
 	//Methods
@@ -139,12 +148,15 @@ class TTransportOut : public TCntrNode, public TConfig
 	void preEnable( int flag );
 	void postDisable( int flag );     	//Delete all DB if flag 1
 
+	void load_( );
+	void save_( );	
+
 	//Attributes
 	bool    run_st;
 
     private:
 	//Methods
-        string nodeName()       { return m_id; }
+        string nodeName( )	{ return m_id; }
 	
 	//Attributes	
 	string  &m_id;
@@ -168,7 +180,7 @@ class TTipTransport: public TModule
     public:
 	//Methods
     	TTipTransport( );
-	virtual ~TTipTransport();
+	virtual ~TTipTransport( );
 
 	//- Input transports -
 	void inList( vector<string> &list )			{ chldList(m_in,list); }
@@ -184,7 +196,7 @@ class TTipTransport: public TModule
 	void outDel( const string &name, bool complete = false ){ chldDel(m_out,name,-1,complete); }
 	AutoHD<TTransportOut> outAt( const string &name )	{ return chldAt(m_out,name); }
 	
-	TTransportS &owner()	{ return (TTransportS&)TModule::owner(); }
+	TTransportS &owner( )					{ return (TTransportS&)TModule::owner(); }
 	
     protected:
 	//Methods
@@ -211,8 +223,8 @@ class TTransportS : public TSubSYS
 	{
 	    public:
         	//Methods
-		ExtHost(const string &iuser_open, const string &iid, const string &iname, 
-			    const string &itransp, const string &iaddr, const string &iuser, const string &ipass) :
+		ExtHost( const string &iuser_open, const string &iid, const string &iname, 
+			    const string &itransp, const string &iaddr, const string &iuser, const string &ipass ) :
 	            user_open(iuser_open), id(iid), name(iname), transp(itransp), addr(iaddr),
 	            user(iuser), pass(ipass), link_ok(false) { }
 								    
@@ -244,16 +256,18 @@ class TTransportS : public TSubSYS
 	void extHostSet( const ExtHost &host );
 	void extHostDel( const string &user, const string &id );
 	
-	void subLoad( );
-	void subSave( );
 	void subStart( );
 	void subStop( );
 	
-	TElem &inEl()	{ return el_in; }
-	TElem &outEl() 	{ return el_out; }
+	TElem &inEl( )			{ return el_in; }
+	TElem &outEl( ) 		{ return el_out; }
 	
         AutoHD<TTipTransport> at( const string &iid )	{ return modAt(iid); }
-	
+
+    protected:
+	void load_( );
+	void save_( );		
+
     private:
 	//Methods
 	string optDescr( );	
