@@ -39,6 +39,8 @@ class TUI : public TModule
     public:
      	TUI( );
 
+	bool startStat( )	{ return run_st; }
+
     protected:
 	//Methods
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
@@ -56,7 +58,6 @@ class TUIS : public TSubSYS
 	TUIS( );
 
 	int subVer( ) 		{ return VER_UI; }
-	void subLoad( );
         void subStart( );
         void subStop( );
 	
@@ -67,6 +68,9 @@ class TUIS : public TSubSYS
 	static string icoGet( const string &inm, string *tp = NULL );
 	static string icoPath( const string &ico );
 
+    protected:
+	void load_( );
+
     private:
 	string optDescr( );    
 	void cntrCmdProc( XMLNode *opt );       //Control interface command process
